/* avatar-details.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from avatar-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>


#define TYPE_AVATAR_DETAILS_TESTS (avatar_details_tests_get_type ())
#define AVATAR_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTests))
#define AVATAR_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTestsClass))
#define IS_AVATAR_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AVATAR_DETAILS_TESTS))
#define IS_AVATAR_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AVATAR_DETAILS_TESTS))
#define AVATAR_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTestsClass))

typedef struct _AvatarDetailsTests AvatarDetailsTests;
typedef struct _AvatarDetailsTestsClass AvatarDetailsTestsClass;
typedef struct _AvatarDetailsTestsPrivate AvatarDetailsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _AvatarDetailsTestsTestAvatarAsyncData AvatarDetailsTestsTestAvatarAsyncData;
typedef struct _AvatarDetailsTestsCheckAvatarData AvatarDetailsTestsCheckAvatarData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AvatarDetailsTests {
	EdsTestTestCase parent_instance;
	AvatarDetailsTestsPrivate * priv;
};

struct _AvatarDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _AvatarDetailsTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	GeeHashMap* _c1;
	gboolean _avatars_are_equal;
	gchar* _avatar_path;
};

struct _AvatarDetailsTestsTestAvatarAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AvatarDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};

struct _AvatarDetailsTestsCheckAvatarData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	AvatarDetailsTests* self;
	GLoadableIcon* avatar;
	GLoadableIcon* _tmp0_;
	GFileIcon* b;
	const gchar* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GFileIcon* _tmp4_;
	GFileIcon* _tmp5_;
	GLoadableIcon* _tmp6_;
	GFileIcon* _tmp7_;
	gboolean _tmp8_;
	GMainLoop* _tmp9_;
};


static gpointer avatar_details_tests_parent_class = NULL;

GType avatar_details_tests_get_type (void) G_GNUC_CONST;
#define AVATAR_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTestsPrivate))
enum  {
	AVATAR_DETAILS_TESTS_DUMMY_PROPERTY
};
AvatarDetailsTests* avatar_details_tests_new (void);
AvatarDetailsTests* avatar_details_tests_construct (GType object_type);
void avatar_details_tests_test_avatar (AvatarDetailsTests* self);
static void _avatar_details_tests_test_avatar_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _avatar_details_tests_test_avatar_async (AvatarDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _avatar_details_tests_test_avatar_finish (AvatarDetailsTests* self, GAsyncResult* _res_);
static void _avatar_details_tests_test_avatar_async_data_free (gpointer _data);
static gboolean _avatar_details_tests_test_avatar_async_co (AvatarDetailsTestsTestAvatarAsyncData* _data_);
static void _avatar_details_tests_test_avatar_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _avatar_details_tests_individuals_changed_cb (AvatarDetailsTests* self, GeeMultiMap* changes);
static void __avatar_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _avatar_details_tests_notify_cb (AvatarDetailsTests* self, GObject* individual_obj, GParamSpec* ps);
static void __avatar_details_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _avatar_details_tests_check_avatar (AvatarDetailsTests* self, GLoadableIcon* avatar, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _avatar_details_tests_check_avatar_finish (AvatarDetailsTests* self, GAsyncResult* _res_);
static void _avatar_details_tests_check_avatar_data_free (gpointer _data);
static gboolean _avatar_details_tests_check_avatar_co (AvatarDetailsTestsCheckAvatarData* _data_);
static void _avatar_details_tests_check_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void avatar_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _avatar_details_tests_test_avatar_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	avatar_details_tests_test_avatar ((AvatarDetailsTests*) self);
#line 145 "avatar-details.c"
}


AvatarDetailsTests* avatar_details_tests_construct (GType object_type) {
	AvatarDetailsTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self = (AvatarDetailsTests*) eds_test_test_case_construct (object_type, "AvatarDetails");
#line 37 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "avatar details interface", _avatar_details_tests_test_avatar_folks_test_case_test_method, self);
#line 33 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return self;
#line 157 "avatar-details.c"
}


AvatarDetailsTests* avatar_details_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return avatar_details_tests_construct (TYPE_AVATAR_DETAILS_TESTS);
#line 164 "avatar-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 42 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 171 "avatar-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 42 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_unset (self);
#line 42 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_free (self);
#line 180 "avatar-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 187 "avatar-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 57 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 194 "avatar-details.c"
}


void avatar_details_tests_test_avatar (AvatarDetailsTests* self) {
	GeeHashMap* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp3_ = NULL;
	GValue _tmp4_ = {0};
	GValue _tmp5_ = {0};
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GeeHashMap* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue* _tmp10_ = NULL;
	GValue _tmp11_ = {0};
	GValue _tmp12_ = {0};
	GValue* _tmp13_ = NULL;
	GValue* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	GeeHashMap* _tmp16_ = NULL;
	GValue* _tmp17_ = NULL;
	GValue* _tmp18_ = NULL;
	EdsTestBackend* _tmp19_ = NULL;
	GeeHashMap* _tmp20_ = NULL;
	GeeHashMap* _tmp21_ = NULL;
	GMainLoop* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
#line 40 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (self != NULL);
#line 42 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 42 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 42 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self->priv->_c1 = _tmp0_;
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp1_ = g_main_loop_new (NULL, FALSE);
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 43 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self->priv->_main_loop = _tmp1_;
#line 44 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp2_ = folks_test_utils_get_source_test_data ("data/avatar-01.jpg");
#line 44 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_free0 (self->priv->_avatar_path);
#line 44 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self->priv->_avatar_path = _tmp2_;
#line 46 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self->priv->_avatars_are_equal = FALSE;
#line 49 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp3_ = ((EdsTestTestCase*) self)->eds_backend;
#line 49 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	eds_test_backend_reset (_tmp3_);
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_init (&_tmp4_, G_TYPE_STRING);
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp5_ = _tmp4_;
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp6_ = __g_value_dup0 (&_tmp5_);
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (v);
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = _tmp6_;
#line 51 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	G_IS_VALUE (&_tmp5_) ? (g_value_unset (&_tmp5_), NULL) : NULL;
#line 52 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp7_ = v;
#line 52 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_set_string (_tmp7_, "bernie h. innocenti");
#line 53 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp8_ = self->priv->_c1;
#line 53 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp9_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp10_ = _tmp9_;
#line 53 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, "full_name", _tmp10_);
#line 53 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (_tmp10_);
#line 54 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_init (&_tmp11_, G_TYPE_STRING);
#line 54 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp12_ = _tmp11_;
#line 54 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp13_ = __g_value_dup0 (&_tmp12_);
#line 54 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (v);
#line 54 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = _tmp13_;
#line 54 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	G_IS_VALUE (&_tmp12_) ? (g_value_unset (&_tmp12_), NULL) : NULL;
#line 55 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp14_ = v;
#line 55 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp15_ = self->priv->_avatar_path;
#line 55 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_value_set_string (_tmp14_, _tmp15_);
#line 56 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp16_ = self->priv->_c1;
#line 56 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp17_ = v;
#line 56 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	v = NULL;
#line 56 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp18_ = _tmp17_;
#line 56 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp16_, "avatar", _tmp18_);
#line 56 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (_tmp18_);
#line 57 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp19_ = ((EdsTestTestCase*) self)->eds_backend;
#line 57 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp20_ = self->priv->_c1;
#line 57 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp21_ = _g_object_ref0 (_tmp20_);
#line 57 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	eds_test_backend_add_contact (_tmp19_, _tmp21_);
#line 59 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_test_avatar_async (self, NULL, NULL);
#line 61 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp22_ = self->priv->_main_loop;
#line 61 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp22_, 3);
#line 63 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp23_ = self->priv->_avatars_are_equal;
#line 63 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_vala_assert (_tmp23_, "this._avatars_are_equal");
#line 40 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	__vala_GValue_free0 (v);
#line 328 "avatar-details.c"
}


static void _avatar_details_tests_test_avatar_async_data_free (gpointer _data) {
	AvatarDetailsTestsTestAvatarAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_slice_free (AvatarDetailsTestsTestAvatarAsyncData, _data_);
#line 339 "avatar-details.c"
}


static void _avatar_details_tests_test_avatar_async (AvatarDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AvatarDetailsTestsTestAvatarAsyncData* _data_;
	AvatarDetailsTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_ = g_slice_new0 (AvatarDetailsTestsTestAvatarAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _avatar_details_tests_test_avatar_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _avatar_details_tests_test_avatar_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_test_avatar_async_co (_data_);
#line 358 "avatar-details.c"
}


static void _avatar_details_tests_test_avatar_finish (AvatarDetailsTests* self, GAsyncResult* _res_) {
	AvatarDetailsTestsTestAvatarAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 366 "avatar-details.c"
}


static void _avatar_details_tests_test_avatar_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AvatarDetailsTestsTestAvatarAsyncData* _data_;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_ = _user_data_;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_source_object_ = source_object;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_res_ = _res_;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_test_avatar_async_co (_data_);
#line 380 "avatar-details.c"
}


static void __avatar_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 74 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_individuals_changed_cb ((AvatarDetailsTests*) self, changes);
#line 387 "avatar-details.c"
}


static gboolean _avatar_details_tests_test_avatar_async_co (AvatarDetailsTestsTestAvatarAsyncData* _data_) {
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	switch (_data_->_state_) {
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		case 0:
#line 396 "avatar-details.c"
		goto _state_0;
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		case 1:
#line 400 "avatar-details.c"
		goto _state_1;
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		case 2:
#line 404 "avatar-details.c"
		goto _state_2;
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		case 3:
#line 408 "avatar-details.c"
		goto _state_3;
		default:
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_assert_not_reached ();
#line 413 "avatar-details.c"
	}
	_state_0:
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp0_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_state_ = 1;
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _avatar_details_tests_test_avatar_async_ready, _data_);
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return FALSE;
#line 426 "avatar-details.c"
	_state_1:
#line 69 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 71 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp1_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 71 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->store = _data_->_tmp1_;
#line 72 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_state_ = 2;
#line 72 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_backend_store_prepare (_data_->store, _avatar_details_tests_test_avatar_async_ready, _data_);
#line 72 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return FALSE;
#line 442 "avatar-details.c"
	_state_2:
#line 72 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 73 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp2_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 73 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 73 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 74 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp3_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 74 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __avatar_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 460 "avatar-details.c"
	{
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp4_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_state_ = 3;
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _avatar_details_tests_test_avatar_async_ready, _data_);
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		return FALSE;
#line 472 "avatar-details.c"
		_state_3:
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 78 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 478 "avatar-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->e = _data_->_inner_error_;
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_inner_error_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp5_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 82 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp6_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 82 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_warning ("avatar-details.vala:82: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_error_free0 (_data_->e);
#line 501 "avatar-details.c"
	}
	__finally0:
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (_data_->store);
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 76 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		return FALSE;
#line 514 "avatar-details.c"
	}
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (_data_->store);
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	if (_data_->_state_ == 0) {
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 522 "avatar-details.c"
	} else {
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 526 "avatar-details.c"
	}
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_object_unref (_data_->_async_result);
#line 66 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return FALSE;
#line 532 "avatar-details.c"
}


static void __avatar_details_tests_notify_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 107 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_notify_cb ((AvatarDetailsTests*) self, _sender, pspec);
#line 539 "avatar-details.c"
}


static void _avatar_details_tests_individuals_changed_cb (AvatarDetailsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
#line 86 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (self != NULL);
#line 86 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (changes != NULL);
#line 89 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = changes;
#line 89 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 89 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	added = _tmp1_;
#line 90 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp2_ = changes;
#line 90 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 90 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	removed = _tmp3_;
#line 92 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp4_ = removed;
#line 92 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 92 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp6_ = _tmp5_;
#line 92 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_vala_assert (_tmp6_ == 1, "removed.size == 1");
#line 577 "avatar-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp7_ = NULL;
		GeeIterator* _tmp8_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp7_ = removed;
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp8_ = gee_iterable_iterator ((GeeIterable*) _tmp7_);
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_i_it = _tmp8_;
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		while (TRUE) {
#line 590 "avatar-details.c"
			GeeIterator* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp11_ = NULL;
			gpointer _tmp12_ = NULL;
			FolksIndividual* _tmp13_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp9_ = _i_it;
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp10_ = gee_iterator_next (_tmp9_);
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			if (!_tmp10_) {
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				break;
#line 605 "avatar-details.c"
			}
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp11_ = _i_it;
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp12_ = gee_iterator_get (_tmp11_);
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			i = (FolksIndividual*) _tmp12_;
#line 96 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp13_ = i;
#line 96 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_vala_assert (_tmp13_ == NULL, "i == null");
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_g_object_unref0 (i);
#line 619 "avatar-details.c"
		}
#line 94 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (_i_it);
#line 623 "avatar-details.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp14_ = NULL;
		GeeIterator* _tmp15_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp14_ = added;
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_i_it = _tmp15_;
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		while (TRUE) {
#line 637 "avatar-details.c"
			GeeIterator* _tmp16_ = NULL;
			gboolean _tmp17_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp18_ = NULL;
			gpointer _tmp19_ = NULL;
			FolksIndividual* _tmp20_ = NULL;
			FolksIndividual* _tmp21_ = NULL;
			GeeSet* _tmp22_ = NULL;
			GeeSet* _tmp23_ = NULL;
			gint _tmp24_ = 0;
			gint _tmp25_ = 0;
			FolksIndividual* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp16_ = _i_it;
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp17_ = gee_iterator_next (_tmp16_);
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			if (!_tmp17_) {
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				break;
#line 660 "avatar-details.c"
			}
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp18_ = _i_it;
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp19_ = gee_iterator_get (_tmp18_);
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			i = (FolksIndividual*) _tmp19_;
#line 101 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp20_ = i;
#line 101 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_vala_assert (_tmp20_ != NULL, "i != null");
#line 103 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp21_ = i;
#line 103 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 103 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp23_ = _tmp22_;
#line 103 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 103 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp25_ = _tmp24_;
#line 103 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_vala_assert (_tmp25_ == 1, "i.personas.size == 1");
#line 105 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp26_ = i;
#line 105 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp27_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp26_);
#line 105 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_tmp28_ = _tmp27_;
#line 105 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			if (g_strcmp0 (_tmp28_, "bernie h. innocenti") == 0) {
#line 692 "avatar-details.c"
				FolksIndividual* _tmp29_ = NULL;
				FolksIndividual* _tmp30_ = NULL;
				GLoadableIcon* _tmp31_ = NULL;
				GLoadableIcon* _tmp32_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				_tmp29_ = i;
#line 107 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				g_signal_connect_object ((GObject*) _tmp29_, "notify::avatar", (GCallback) __avatar_details_tests_notify_cb_g_object_notify, self, 0);
#line 108 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				_tmp30_ = i;
#line 108 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				_tmp31_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) _tmp30_);
#line 108 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				_tmp32_ = _tmp31_;
#line 108 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
				_avatar_details_tests_check_avatar (self, _tmp32_, NULL, NULL);
#line 709 "avatar-details.c"
			}
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
			_g_object_unref0 (i);
#line 713 "avatar-details.c"
		}
#line 99 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (_i_it);
#line 717 "avatar-details.c"
	}
#line 86 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (removed);
#line 86 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (added);
#line 723 "avatar-details.c"
}


static void _avatar_details_tests_notify_cb (AvatarDetailsTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* i = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	GLoadableIcon* _tmp2_ = NULL;
	GLoadableIcon* _tmp3_ = NULL;
#line 113 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (self != NULL);
#line 113 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (individual_obj != NULL);
#line 113 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_return_if_fail (ps != NULL);
#line 115 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = individual_obj;
#line 115 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 115 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	i = _tmp1_;
#line 116 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp2_ = folks_avatar_details_get_avatar ((FolksAvatarDetails*) i);
#line 116 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp3_ = _tmp2_;
#line 116 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_check_avatar (self, _tmp3_, NULL, NULL);
#line 113 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (i);
#line 753 "avatar-details.c"
}


static void _avatar_details_tests_check_avatar_data_free (gpointer _data) {
	AvatarDetailsTestsCheckAvatarData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (_data_->avatar);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_slice_free (AvatarDetailsTestsCheckAvatarData, _data_);
#line 766 "avatar-details.c"
}


static void _avatar_details_tests_check_avatar (AvatarDetailsTests* self, GLoadableIcon* avatar, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	AvatarDetailsTestsCheckAvatarData* _data_;
	AvatarDetailsTests* _tmp0_ = NULL;
	GLoadableIcon* _tmp1_ = NULL;
	GLoadableIcon* _tmp2_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_ = g_slice_new0 (AvatarDetailsTestsCheckAvatarData);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _avatar_details_tests_check_avatar);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _avatar_details_tests_check_avatar_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp1_ = avatar;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (_data_->avatar);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->avatar = _tmp2_;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_check_avatar_co (_data_);
#line 795 "avatar-details.c"
}


static void _avatar_details_tests_check_avatar_finish (AvatarDetailsTests* self, GAsyncResult* _res_) {
	AvatarDetailsTestsCheckAvatarData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 803 "avatar-details.c"
}


static void _avatar_details_tests_check_avatar_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	AvatarDetailsTestsCheckAvatarData* _data_;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_ = _user_data_;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_source_object_ = source_object;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_res_ = _res_;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_avatar_details_tests_check_avatar_co (_data_);
#line 817 "avatar-details.c"
}


static gboolean _avatar_details_tests_check_avatar_co (AvatarDetailsTestsCheckAvatarData* _data_) {
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	switch (_data_->_state_) {
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		case 0:
#line 826 "avatar-details.c"
		goto _state_0;
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		case 1:
#line 830 "avatar-details.c"
		goto _state_1;
		default:
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_assert_not_reached ();
#line 835 "avatar-details.c"
	}
	_state_0:
#line 121 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp0_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_data_->_tmp0_ = _data_->avatar;
#line 121 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	if (_data_->_tmp0_ != NULL) {
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp1_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp1_ = _data_->self->priv->_avatar_path;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp2_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp2_ = g_file_new_for_path (_data_->_tmp1_);
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp3_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp4_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp4_ = (GFileIcon*) g_file_icon_new (_data_->_tmp3_);
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp5_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (_data_->_tmp3_);
#line 123 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->b = _data_->_tmp5_;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp6_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp6_ = _data_->avatar;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp7_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp7_ = _data_->b;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_state_ = 1;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		folks_test_utils_loadable_icons_content_equal (_data_->_tmp6_, (GLoadableIcon*) _data_->_tmp7_, -1, _avatar_details_tests_check_avatar_ready, _data_);
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		return FALSE;
#line 882 "avatar-details.c"
		_state_1:
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp8_ = FALSE;
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp8_ = folks_test_utils_loadable_icons_content_equal_finish (_data_->_res_);
#line 125 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->self->priv->_avatars_are_equal = _data_->_tmp8_;
#line 128 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp9_ = NULL;
#line 128 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_data_->_tmp9_ = _data_->self->priv->_main_loop;
#line 128 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_main_loop_quit (_data_->_tmp9_);
#line 121 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		_g_object_unref0 (_data_->b);
#line 898 "avatar-details.c"
	}
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	if (_data_->_state_ == 0) {
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 904 "avatar-details.c"
	} else {
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 908 "avatar-details.c"
	}
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_object_unref (_data_->_async_result);
#line 119 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return FALSE;
#line 914 "avatar-details.c"
}


static void avatar_details_tests_class_init (AvatarDetailsTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	avatar_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_type_class_add_private (klass, sizeof (AvatarDetailsTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	G_OBJECT_CLASS (klass)->finalize = avatar_details_tests_finalize;
#line 925 "avatar-details.c"
}


static void avatar_details_tests_instance_init (AvatarDetailsTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self->priv = AVATAR_DETAILS_TESTS_GET_PRIVATE (self);
#line 932 "avatar-details.c"
}


static void avatar_details_tests_finalize (GObject* obj) {
	AvatarDetailsTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_AVATAR_DETAILS_TESTS, AvatarDetailsTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 28 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 31 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_free0 (self->priv->_avatar_path);
#line 25 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	G_OBJECT_CLASS (avatar_details_tests_parent_class)->finalize (obj);
#line 950 "avatar-details.c"
}


GType avatar_details_tests_get_type (void) {
	static volatile gsize avatar_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&avatar_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AvatarDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) avatar_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AvatarDetailsTests), 0, (GInstanceInitFunc) avatar_details_tests_instance_init, NULL };
		GType avatar_details_tests_type_id;
		avatar_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "AvatarDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&avatar_details_tests_type_id__volatile, avatar_details_tests_type_id);
	}
	return avatar_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AvatarDetailsTests* tests = NULL;
	AvatarDetailsTests* _tmp0_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 137 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_tmp0_ = avatar_details_tests_new ();
#line 137 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	tests = _tmp0_;
#line 138 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 139 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	g_test_run ();
#line 140 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 142 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	result = 0;
#line 142 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	_g_object_unref0 (tests);
#line 142 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return result;
#line 988 "avatar-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 133 "/opt/gnome3/source/folks/tests/eds/avatar-details.vala"
	return _vala_main (argv, argc);
#line 998 "avatar-details.c"
}



