/* prefix-name-updates.c generated by valac 0.24.0, the Vala compiler
 * generated from prefix-name-updates.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_PREFIX_NAME_UPDATES_TESTS (prefix_name_updates_tests_get_type ())
#define PREFIX_NAME_UPDATES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PREFIX_NAME_UPDATES_TESTS, PrefixNameUpdatesTests))
#define PREFIX_NAME_UPDATES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PREFIX_NAME_UPDATES_TESTS, PrefixNameUpdatesTestsClass))
#define IS_PREFIX_NAME_UPDATES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PREFIX_NAME_UPDATES_TESTS))
#define IS_PREFIX_NAME_UPDATES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PREFIX_NAME_UPDATES_TESTS))
#define PREFIX_NAME_UPDATES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PREFIX_NAME_UPDATES_TESTS, PrefixNameUpdatesTestsClass))

typedef struct _PrefixNameUpdatesTests PrefixNameUpdatesTests;
typedef struct _PrefixNameUpdatesTestsClass PrefixNameUpdatesTestsClass;
typedef struct _PrefixNameUpdatesTestsPrivate PrefixNameUpdatesTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PrefixNameUpdatesTests {
	TrackerTestTestCase parent_instance;
	PrefixNameUpdatesTestsPrivate * priv;
};

struct _PrefixNameUpdatesTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _PrefixNameUpdatesTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gboolean _updated_prefix_name_found;
	gboolean _initial_prefix_name_found;
	gchar* _updated_prefix_name;
	gchar* _individual_id;
	gchar* _initial_fullname;
	gchar* _initial_prefix_name;
	gchar* _contact_urn;
};

struct _PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	PrefixNameUpdatesTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer prefix_name_updates_tests_parent_class = NULL;

GType prefix_name_updates_tests_get_type (void) G_GNUC_CONST;
#define PREFIX_NAME_UPDATES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PREFIX_NAME_UPDATES_TESTS, PrefixNameUpdatesTestsPrivate))
enum  {
	PREFIX_NAME_UPDATES_TESTS_DUMMY_PROPERTY
};
PrefixNameUpdatesTests* prefix_name_updates_tests_new (void);
PrefixNameUpdatesTests* prefix_name_updates_tests_construct (GType object_type);
void prefix_name_updates_tests_test_prefix_name_updates (PrefixNameUpdatesTests* self);
static void _prefix_name_updates_tests_test_prefix_name_updates_folks_test_case_test_method (gpointer self);
static void _prefix_name_updates_tests_test_prefix_name_updates_async (PrefixNameUpdatesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _prefix_name_updates_tests_test_prefix_name_updates_finish (PrefixNameUpdatesTests* self, GAsyncResult* _res_);
static void _prefix_name_updates_tests_test_prefix_name_updates_async_data_free (gpointer _data);
static gboolean _prefix_name_updates_tests_test_prefix_name_updates_async_co (PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData* _data_);
static void _prefix_name_updates_tests_test_prefix_name_updates_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _prefix_name_updates_tests_individuals_changed_cb (PrefixNameUpdatesTests* self, GeeMultiMap* changes);
static void __prefix_name_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _prefix_name_updates_tests_notify_prefix_name_cb (PrefixNameUpdatesTests* self, GObject* individual_obj, GParamSpec* ps);
static void __prefix_name_updates_tests_notify_prefix_name_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void prefix_name_updates_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _prefix_name_updates_tests_test_prefix_name_updates_folks_test_case_test_method (gpointer self) {
#line 42 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	prefix_name_updates_tests_test_prefix_name_updates ((PrefixNameUpdatesTests*) self);
#line 120 "prefix-name-updates.c"
}


PrefixNameUpdatesTests* prefix_name_updates_tests_construct (GType object_type) {
	PrefixNameUpdatesTests * self = NULL;
#line 40 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self = (PrefixNameUpdatesTests*) tracker_test_test_case_construct (object_type, "PrefixNameUpdates");
#line 42 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "prefix name updates", _prefix_name_updates_tests_test_prefix_name_updates_folks_test_case_test_method, self);
#line 38 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	return self;
#line 132 "prefix-name-updates.c"
}


PrefixNameUpdatesTests* prefix_name_updates_tests_new (void) {
#line 38 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	return prefix_name_updates_tests_construct (TYPE_PREFIX_NAME_UPDATES_TESTS);
#line 139 "prefix-name-updates.c"
}


void prefix_name_updates_tests_test_prefix_name_updates (PrefixNameUpdatesTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	TrackerTestBackend* _tmp9_ = NULL;
	TrackerTestBackend* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	GMainLoop* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
#line 45 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_return_if_fail (self != NULL);
#line 47 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 47 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 47 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_main_loop = _tmp0_;
#line 48 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 48 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	c1 = _tmp1_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 49 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_initial_fullname);
#line 49 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_initial_fullname = _tmp2_;
#line 50 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp3_ = g_strdup ("prefix name #1");
#line 50 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_initial_prefix_name);
#line 50 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_initial_prefix_name = _tmp3_;
#line 51 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp4_ = g_strdup ("updated prefix #1");
#line 51 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_updated_prefix_name);
#line 51 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_updated_prefix_name = _tmp4_;
#line 52 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp5_ = g_strdup ("<urn:contact001>");
#line 52 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_contact_urn);
#line 52 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_contact_urn = _tmp5_;
#line 54 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp6_ = self->priv->_contact_urn;
#line 54 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRACKER_TEST_BACKEND_URN, _tmp6_);
#line 55 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp7_ = self->priv->_initial_fullname;
#line 55 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp7_);
#line 56 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp8_ = self->priv->_initial_prefix_name;
#line 56 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_PREFIX, _tmp8_);
#line 57 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp9_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 57 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 59 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp10_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 59 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 61 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_initial_prefix_name_found = FALSE;
#line 62 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_updated_prefix_name_found = FALSE;
#line 63 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp11_ = g_strdup ("");
#line 63 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_individual_id);
#line 63 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv->_individual_id = _tmp11_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_prefix_name_updates_tests_test_prefix_name_updates_async (self, NULL, NULL);
#line 67 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp12_ = self->priv->_main_loop;
#line 67 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	folks_test_utils_loop_run_with_timeout (_tmp12_, 5);
#line 69 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp13_ = self->priv->_initial_prefix_name_found;
#line 69 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_vala_assert (_tmp13_ == TRUE, "this._initial_prefix_name_found == true");
#line 70 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp14_ = self->priv->_updated_prefix_name_found;
#line 70 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_vala_assert (_tmp14_ == TRUE, "this._updated_prefix_name_found == true");
#line 45 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (c1);
#line 242 "prefix-name-updates.c"
}


static void _prefix_name_updates_tests_test_prefix_name_updates_async_data_free (gpointer _data) {
	PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_slice_free (PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData, _data_);
#line 253 "prefix-name-updates.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	return self ? g_object_ref (self) : NULL;
#line 260 "prefix-name-updates.c"
}


static void _prefix_name_updates_tests_test_prefix_name_updates_async (PrefixNameUpdatesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData* _data_;
	PrefixNameUpdatesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_ = g_slice_new0 (PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _prefix_name_updates_tests_test_prefix_name_updates_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _prefix_name_updates_tests_test_prefix_name_updates_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_prefix_name_updates_tests_test_prefix_name_updates_async_co (_data_);
#line 279 "prefix-name-updates.c"
}


static void _prefix_name_updates_tests_test_prefix_name_updates_finish (PrefixNameUpdatesTests* self, GAsyncResult* _res_) {
	PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 287 "prefix-name-updates.c"
}


static void _prefix_name_updates_tests_test_prefix_name_updates_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData* _data_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_ = _user_data_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_source_object_ = source_object;
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_res_ = _res_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_prefix_name_updates_tests_test_prefix_name_updates_async_co (_data_);
#line 301 "prefix-name-updates.c"
}


static void __prefix_name_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 78 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_prefix_name_updates_tests_individuals_changed_cb ((PrefixNameUpdatesTests*) self, changes);
#line 308 "prefix-name-updates.c"
}


static gboolean _prefix_name_updates_tests_test_prefix_name_updates_async_co (PrefixNameUpdatesTestsTestPrefixNameUpdatesAsyncData* _data_) {
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	switch (_data_->_state_) {
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		case 0:
#line 317 "prefix-name-updates.c"
		goto _state_0;
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		case 1:
#line 321 "prefix-name-updates.c"
		goto _state_1;
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		case 2:
#line 325 "prefix-name-updates.c"
		goto _state_2;
		default:
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		g_assert_not_reached ();
#line 330 "prefix-name-updates.c"
	}
	_state_0:
#line 75 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_tmp0_ = NULL;
#line 75 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 75 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->store = _data_->_tmp0_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_state_ = 1;
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	folks_backend_store_prepare (_data_->store, _prefix_name_updates_tests_test_prefix_name_updates_async_ready, _data_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	return FALSE;
#line 345 "prefix-name-updates.c"
	_state_1:
#line 76 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 77 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_tmp1_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 77 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 77 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 78 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_tmp2_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 78 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __prefix_name_updates_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 363 "prefix-name-updates.c"
	{
#line 82 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_tmp3_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 82 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_state_ = 2;
#line 82 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _prefix_name_updates_tests_test_prefix_name_updates_async_ready, _data_);
#line 82 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		return FALSE;
#line 375 "prefix-name-updates.c"
		_state_2:
#line 82 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 82 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		if (_data_->_inner_error_ != NULL) {
#line 381 "prefix-name-updates.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->e = _data_->_inner_error_;
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_inner_error_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_tmp4_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_tmp4_ = _data_->e;
#line 86 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_tmp5_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 86 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		g_warning ("prefix-name-updates.vala:86: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_g_error_free0 (_data_->e);
#line 404 "prefix-name-updates.c"
	}
	__finally0:
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	if (_data_->_inner_error_ != NULL) {
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_g_object_unref0 (_data_->store);
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		g_clear_error (&_data_->_inner_error_);
#line 80 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		return FALSE;
#line 417 "prefix-name-updates.c"
	}
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (_data_->store);
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	if (_data_->_state_ == 0) {
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 425 "prefix-name-updates.c"
	} else {
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 429 "prefix-name-updates.c"
	}
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_object_unref (_data_->_async_result);
#line 73 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	return FALSE;
#line 435 "prefix-name-updates.c"
}


static void __prefix_name_updates_tests_notify_prefix_name_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 105 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_prefix_name_updates_tests_notify_prefix_name_cb ((PrefixNameUpdatesTests*) self, _sender, pspec);
#line 442 "prefix-name-updates.c"
}


static void _prefix_name_updates_tests_individuals_changed_cb (PrefixNameUpdatesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp33_ = NULL;
	gint _tmp34_ = 0;
	gint _tmp35_ = 0;
#line 90 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_return_if_fail (self != NULL);
#line 90 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_return_if_fail (changes != NULL);
#line 93 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp0_ = changes;
#line 93 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 93 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	added = _tmp1_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp2_ = changes;
#line 94 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	removed = _tmp3_;
#line 472 "prefix-name-updates.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_tmp4_ = added;
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_i_it = _tmp5_;
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		while (TRUE) {
#line 485 "prefix-name-updates.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp6_ = _i_it;
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			if (!_tmp7_) {
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				break;
#line 504 "prefix-name-updates.c"
			}
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp8_ = _i_it;
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			i = (FolksIndividual*) _tmp9_;
#line 98 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp10_ = i;
#line 98 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 100 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp11_ = self->priv->_initial_fullname;
#line 100 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp12_ = i;
#line 100 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp13_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp12_);
#line 100 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp14_ = _tmp13_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			if (g_strcmp0 (_tmp11_, _tmp14_) == 0) {
#line 526 "prefix-name-updates.c"
				gchar* prefix_name = NULL;
				FolksIndividual* _tmp15_ = NULL;
				FolksStructuredName* _tmp16_ = NULL;
				FolksStructuredName* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp15_ = i;
#line 102 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp16_ = folks_name_details_get_structured_name ((FolksNameDetails*) _tmp15_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp17_ = _tmp16_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp18_ = folks_structured_name_get_prefixes (_tmp17_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp19_ = _tmp18_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp20_ = g_strdup (_tmp19_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				prefix_name = _tmp20_;
#line 103 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp21_ = prefix_name;
#line 103 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_tmp22_ = self->priv->_initial_prefix_name;
#line 103 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
#line 556 "prefix-name-updates.c"
					FolksIndividual* _tmp23_ = NULL;
					FolksStructuredName* _tmp24_ = NULL;
					FolksStructuredName* _tmp25_ = NULL;
					FolksIndividual* _tmp26_ = NULL;
					const gchar* _tmp27_ = NULL;
					const gchar* _tmp28_ = NULL;
					gchar* _tmp29_ = NULL;
					TrackerTestBackend* _tmp30_ = NULL;
					const gchar* _tmp31_ = NULL;
					const gchar* _tmp32_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp23_ = i;
#line 105 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp24_ = folks_name_details_get_structured_name ((FolksNameDetails*) _tmp23_);
#line 105 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp25_ = _tmp24_;
#line 105 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					g_signal_connect_object ((GObject*) _tmp25_, "notify::prefixes", (GCallback) __prefix_name_updates_tests_notify_prefix_name_cb_g_object_notify, self, 0);
#line 107 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp26_ = i;
#line 107 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp27_ = folks_individual_get_id (_tmp26_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp28_ = _tmp27_;
#line 107 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp29_ = g_strdup (_tmp28_);
#line 107 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_g_free0 (self->priv->_individual_id);
#line 107 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					self->priv->_individual_id = _tmp29_;
#line 108 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					self->priv->_initial_prefix_name_found = TRUE;
#line 109 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp30_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 109 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp31_ = self->priv->_contact_urn;
#line 109 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					_tmp32_ = self->priv->_updated_prefix_name;
#line 109 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
					tracker_test_backend_update_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), _tmp31_, TRF_ONTOLOGY_DEFS_NCO_PREFIX, _tmp32_);
#line 597 "prefix-name-updates.c"
				}
#line 100 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				_g_free0 (prefix_name);
#line 601 "prefix-name-updates.c"
			}
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_g_object_unref0 (i);
#line 605 "prefix-name-updates.c"
		}
#line 96 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_g_object_unref0 (_i_it);
#line 609 "prefix-name-updates.c"
	}
#line 115 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp33_ = removed;
#line 115 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp34_ = gee_collection_get_size ((GeeCollection*) _tmp33_);
#line 115 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp35_ = _tmp34_;
#line 115 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_vala_assert (_tmp35_ == 1, "removed.size == 1");
#line 619 "prefix-name-updates.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp36_ = NULL;
		GeeIterator* _tmp37_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_tmp36_ = removed;
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_tmp37_ = gee_iterable_iterator ((GeeIterable*) _tmp36_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_i_it = _tmp37_;
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		while (TRUE) {
#line 632 "prefix-name-updates.c"
			GeeIterator* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp40_ = NULL;
			gpointer _tmp41_ = NULL;
			FolksIndividual* _tmp42_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp38_ = _i_it;
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp39_ = gee_iterator_next (_tmp38_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			if (!_tmp39_) {
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
				break;
#line 647 "prefix-name-updates.c"
			}
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp40_ = _i_it;
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp41_ = gee_iterator_get (_tmp40_);
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			i = (FolksIndividual*) _tmp41_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_tmp42_ = i;
#line 119 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_vala_assert (_tmp42_ == NULL, "i == null");
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
			_g_object_unref0 (i);
#line 661 "prefix-name-updates.c"
		}
#line 117 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_g_object_unref0 (_i_it);
#line 665 "prefix-name-updates.c"
	}
#line 90 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (removed);
#line 90 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (added);
#line 671 "prefix-name-updates.c"
}


static void _prefix_name_updates_tests_notify_prefix_name_cb (PrefixNameUpdatesTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksStructuredName* sname = NULL;
	GObject* _tmp0_ = NULL;
	FolksStructuredName* _tmp1_ = NULL;
	gchar* prefix_name = NULL;
	FolksStructuredName* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_return_if_fail (self != NULL);
#line 123 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_return_if_fail (individual_obj != NULL);
#line 123 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_return_if_fail (ps != NULL);
#line 125 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp0_ = individual_obj;
#line 125 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_STRUCTURED_NAME, FolksStructuredName));
#line 125 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	sname = _tmp1_;
#line 126 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp2_ = sname;
#line 126 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp3_ = folks_structured_name_get_prefixes (_tmp2_);
#line 126 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp4_ = _tmp3_;
#line 126 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 126 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	prefix_name = _tmp5_;
#line 127 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp6_ = prefix_name;
#line 127 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp7_ = self->priv->_updated_prefix_name;
#line 127 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	if (g_strcmp0 (_tmp6_, _tmp7_) == 0) {
#line 714 "prefix-name-updates.c"
		GMainLoop* _tmp8_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		self->priv->_updated_prefix_name_found = TRUE;
#line 130 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		_tmp8_ = self->priv->_main_loop;
#line 130 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
		g_main_loop_quit (_tmp8_);
#line 722 "prefix-name-updates.c"
	}
#line 123 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (prefix_name);
#line 123 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (sname);
#line 728 "prefix-name-updates.c"
}


static void prefix_name_updates_tests_class_init (PrefixNameUpdatesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	prefix_name_updates_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_type_class_add_private (klass, sizeof (PrefixNameUpdatesTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	G_OBJECT_CLASS (klass)->finalize = prefix_name_updates_tests_finalize;
#line 739 "prefix-name-updates.c"
}


static void prefix_name_updates_tests_instance_init (PrefixNameUpdatesTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self->priv = PREFIX_NAME_UPDATES_TESTS_GET_PRIVATE (self);
#line 746 "prefix-name-updates.c"
}


static void prefix_name_updates_tests_finalize (GObject* obj) {
	PrefixNameUpdatesTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PREFIX_NAME_UPDATES_TESTS, PrefixNameUpdatesTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 32 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_updated_prefix_name);
#line 33 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_individual_id);
#line 34 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_initial_fullname);
#line 35 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_initial_prefix_name);
#line 36 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_free0 (self->priv->_contact_urn);
#line 26 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	G_OBJECT_CLASS (prefix_name_updates_tests_parent_class)->finalize (obj);
#line 770 "prefix-name-updates.c"
}


GType prefix_name_updates_tests_get_type (void) {
	static volatile gsize prefix_name_updates_tests_type_id__volatile = 0;
	if (g_once_init_enter (&prefix_name_updates_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PrefixNameUpdatesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) prefix_name_updates_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PrefixNameUpdatesTests), 0, (GInstanceInitFunc) prefix_name_updates_tests_instance_init, NULL };
		GType prefix_name_updates_tests_type_id;
		prefix_name_updates_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "PrefixNameUpdatesTests", &g_define_type_info, 0);
		g_once_init_leave (&prefix_name_updates_tests_type_id__volatile, prefix_name_updates_tests_type_id);
	}
	return prefix_name_updates_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PrefixNameUpdatesTests* tests = NULL;
	PrefixNameUpdatesTests* _tmp0_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_test_init (&args_length1, &args, NULL);
#line 139 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_tmp0_ = prefix_name_updates_tests_new ();
#line 139 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	tests = _tmp0_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 141 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	g_test_run ();
#line 142 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 144 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	result = 0;
#line 144 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	_g_object_unref0 (tests);
#line 144 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	return result;
#line 808 "prefix-name-updates.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 135 "/opt/gnome3/source/folks/tests/tracker/prefix-name-updates.vala"
	return _vala_main (argv, argc);
#line 818 "prefix-name-updates.c"
}



