/* test-case.c generated by valac 0.24.0, the Vala compiler
 * generated from test-case.vala, do not modify */

/* testcase.vala
 *
 * Copyright (C) 2009 Julien Peeters
 * Copyright (C) 2013 Intel Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Julien Peeters <contact@julienpeeters.fr>
 * 	Simon McVittie <simon.mcvittie@collabora.co.uk>
 *
 * Adapted from libgee/tests/testcase.vala.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include "gtestdbus.h"
#include <locale.h>
#include <config.h>
#include <glib/gstdio.h>
#include <errno.h>
#include <gio/gio.h>
#include <stdio.h>
#include <gobject/gvaluecollector.h>


#define FOLKS_TYPE_TEST_CASE (folks_test_case_get_type ())
#define FOLKS_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_TYPE_TEST_CASE, FolksTestCase))
#define FOLKS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLKS_TYPE_TEST_CASE, FolksTestCaseClass))
#define FOLKS_IS_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_TYPE_TEST_CASE))
#define FOLKS_IS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLKS_TYPE_TEST_CASE))
#define FOLKS_TEST_CASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLKS_TYPE_TEST_CASE, FolksTestCaseClass))

typedef struct _FolksTestCase FolksTestCase;
typedef struct _FolksTestCaseClass FolksTestCaseClass;
typedef struct _FolksTestCasePrivate FolksTestCasePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR (folks_test_case_log_adaptor_get_type ())
#define FOLKS_TEST_CASE_LOG_ADAPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR, FolksTestCaseLogAdaptor))
#define FOLKS_TEST_CASE_LOG_ADAPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR, FolksTestCaseLogAdaptorClass))
#define FOLKS_TEST_CASE_IS_LOG_ADAPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR))
#define FOLKS_TEST_CASE_IS_LOG_ADAPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR))
#define FOLKS_TEST_CASE_LOG_ADAPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR, FolksTestCaseLogAdaptorClass))

typedef struct _FolksTestCaseLogAdaptor FolksTestCaseLogAdaptor;
typedef struct _FolksTestCaseLogAdaptorClass FolksTestCaseLogAdaptorClass;
typedef struct _FolksTestCaseLogAdaptorPrivate FolksTestCaseLogAdaptorPrivate;
typedef struct _FolksTestCaseParamSpecLogAdaptor FolksTestCaseParamSpecLogAdaptor;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _FolksTestCase {
	GObject parent_instance;
	FolksTestCasePrivate * priv;
	FolksTestDBus* test_dbus;
	FolksTestDBus* test_system_dbus;
};

struct _FolksTestCaseClass {
	GObjectClass parent_class;
	gchar* (*create_transient_dir) (FolksTestCase* self);
	void (*private_bus_up) (FolksTestCase* self);
	void (*set_up) (FolksTestCase* self);
	void (*tear_down) (FolksTestCase* self);
	void (*final_tear_down) (FolksTestCase* self);
	gboolean (*get_uses_dbus_1) (FolksTestCase* self);
};

struct _FolksTestCasePrivate {
	GTestSuite* _suite;
	gchar* _transient_dir;
};

typedef void (*FolksTestCaseTestMethod) (void* user_data);
struct _FolksTestCaseLogAdaptor {
	GTypeInstance parent_instance;
	volatile int ref_count;
	FolksTestCaseLogAdaptorPrivate * priv;
};

struct _FolksTestCaseLogAdaptorClass {
	GTypeClass parent_class;
	void (*finalize) (FolksTestCaseLogAdaptor *self);
};

struct _FolksTestCaseParamSpecLogAdaptor {
	GParamSpec parent_instance;
};


static gpointer folks_test_case_parent_class = NULL;
extern gboolean folks_test_case_in_final_tear_down;
gboolean folks_test_case_in_final_tear_down = FALSE;
static gpointer folks_test_case_log_adaptor_parent_class = NULL;

GType folks_test_case_get_type (void) G_GNUC_CONST;
#define FOLKS_TEST_CASE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), FOLKS_TYPE_TEST_CASE, FolksTestCasePrivate))
enum  {
	FOLKS_TEST_CASE_DUMMY_PROPERTY,
	FOLKS_TEST_CASE_TRANSIENT_DIR,
	FOLKS_TEST_CASE_USES_DBUS_1
};
void folks_test_case_final_tear_down (FolksTestCase* self);
FolksTestCase* folks_test_case_construct (GType object_type, const gchar* name);
static void folks_test_case_log_adaptor_set_up (void);
gchar* folks_test_case_create_transient_dir (FolksTestCase* self);
void folks_test_case_private_bus_up (FolksTestCase* self);
static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value);
static void _vala_array_add2 (gchar*** array, int* length, int* size, gchar* value);
static void _vala_array_add3 (gchar*** array, int* length, int* size, gchar* value);
static void _vala_array_add4 (gchar*** array, int* length, int* size, gchar* value);
static void _vala_array_add5 (gchar*** array, int* length, int* size, gchar* value);
static void _vala_array_add6 (gchar*** array, int* length, int* size, gchar* value);
static gchar* folks_test_case_real_create_transient_dir (FolksTestCase* self);
void folks_test_case_create_dbusmock_service (FolksTestCase* self, GBusType bus_type, const gchar* bus_name, const gchar* dbusmock_template_name);
const gchar* folks_test_case_get_transient_dir (FolksTestCase* self);
static void folks_test_case_real_private_bus_up (FolksTestCase* self);
void folks_test_case_register (FolksTestCase* self);
void folks_test_case_add_test (FolksTestCase* self, const gchar* name, FolksTestCaseTestMethod test, void* test_target);
GTestCase* folks_test_case_add_test_helper (FolksTestCase* self, const gchar* name, FolksTestCaseTestMethod test, void* test_target);
void folks_test_case_set_up (FolksTestCase* self);
static void folks_test_case_real_set_up (FolksTestCase* self);
void folks_test_case_tear_down (FolksTestCase* self);
static void folks_test_case_real_tear_down (FolksTestCase* self);
void _folks_test_case_dbus_1_set_no_exit_on_disconnect (void);
static void folks_test_case_real_final_tear_down (FolksTestCase* self);
gboolean folks_test_case_get_uses_dbus_1 (FolksTestCase* self);
gboolean haze_remove_directory (const gchar* path);
static gpointer folks_test_case_log_adaptor_ref (gpointer instance);
static void folks_test_case_log_adaptor_unref (gpointer instance);
static GParamSpec* folks_test_case_param_spec_log_adaptor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void folks_test_case_value_set_log_adaptor (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void folks_test_case_value_take_log_adaptor (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer folks_test_case_value_get_log_adaptor (const GValue* value) G_GNUC_UNUSED;
static GType folks_test_case_log_adaptor_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
enum  {
	FOLKS_TEST_CASE_LOG_ADAPTOR_DUMMY_PROPERTY
};
static FolksTestCaseLogAdaptor* folks_test_case_log_adaptor_new (void);
static FolksTestCaseLogAdaptor* folks_test_case_log_adaptor_construct (GType object_type);
static void _folks_test_case_log_adaptor_printerr_func_stack_trace (const gchar* text);
static void __folks_test_case_log_adaptor_printerr_func_stack_trace_gprint_func (const gchar* text);
static void _folks_test_case_log_adaptor_log_func_stack_trace (const gchar* log_domain, GLogLevelFlags log_levels, const gchar* message);
static void __folks_test_case_log_adaptor_log_func_stack_trace_glog_func (const gchar* log_domain, GLogLevelFlags log_levels, const gchar* message, gpointer self);
static void folks_test_case_log_adaptor_finalize (FolksTestCaseLogAdaptor* obj);
static void folks_test_case_finalize (GObject* obj);
static void _vala_folks_test_case_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value) {
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if ((*length) == (*size)) {
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 179 "test-case.c"
	}
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[(*length)++] = value;
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[*length] = NULL;
#line 185 "test-case.c"
}


static void _vala_array_add2 (gchar*** array, int* length, int* size, gchar* value) {
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if ((*length) == (*size)) {
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 196 "test-case.c"
	}
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[(*length)++] = value;
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[*length] = NULL;
#line 202 "test-case.c"
}


static void _vala_array_add3 (gchar*** array, int* length, int* size, gchar* value) {
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if ((*length) == (*size)) {
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 213 "test-case.c"
	}
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[(*length)++] = value;
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[*length] = NULL;
#line 219 "test-case.c"
}


static void _vala_array_add4 (gchar*** array, int* length, int* size, gchar* value) {
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if ((*length) == (*size)) {
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 230 "test-case.c"
	}
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[(*length)++] = value;
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[*length] = NULL;
#line 236 "test-case.c"
}


static void _vala_array_add5 (gchar*** array, int* length, int* size, gchar* value) {
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if ((*length) == (*size)) {
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 247 "test-case.c"
	}
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[(*length)++] = value;
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[*length] = NULL;
#line 253 "test-case.c"
}


static void _vala_array_add6 (gchar*** array, int* length, int* size, gchar* value) {
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if ((*length) == (*size)) {
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 264 "test-case.c"
	}
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[(*length)++] = value;
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	(*array)[*length] = NULL;
#line 270 "test-case.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 964 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 964 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 965 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		separator = "";
#line 287 "test-case.c"
	}
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 297 "test-case.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 307 "test-case.c"
	}
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 313 "test-case.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == (-1)) {
#line 324 "test-case.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 336 "test-case.c"
		} else {
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 340 "test-case.c"
		}
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 344 "test-case.c"
	}
#line 967 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 348 "test-case.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp59_ = NULL;
#line 969 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 371 "test-case.c"
		{
			gboolean _tmp9_ = FALSE;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			i = 0;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 380 "test-case.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 393 "test-case.c"
					gint _tmp10_ = 0;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 399 "test-case.c"
				}
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != (-1)) {
#line 409 "test-case.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 421 "test-case.c"
				} else {
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 425 "test-case.c"
				}
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 431 "test-case.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == (-1)) {
#line 442 "test-case.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 457 "test-case.c"
					} else {
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 461 "test-case.c"
					}
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 465 "test-case.c"
				}
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 970 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					break;
#line 471 "test-case.c"
				}
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 483 "test-case.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp28_ = strlen (_tmp27_);
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 504 "test-case.c"
				} else {
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 508 "test-case.c"
				}
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 971 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 514 "test-case.c"
			}
		}
#line 973 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 973 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 521 "test-case.c"
			gchar* _tmp32_ = NULL;
#line 974 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 974 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 974 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			return result;
#line 529 "test-case.c"
		}
#line 976 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 976 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 976 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 977 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 977 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 977 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp37_ = strlen (_tmp36_);
#line 977 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 977 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 977 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 979 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 979 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 979 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 980 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 980 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 980 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 980 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 980 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, _tmp44_);
#line 980 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 567 "test-case.c"
		{
			gboolean _tmp46_ = FALSE;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			i = 1;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 576 "test-case.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp57_ = NULL;
				void* _tmp58_ = NULL;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 592 "test-case.c"
					gint _tmp47_ = 0;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 598 "test-case.c"
				}
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 981 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					break;
#line 612 "test-case.c"
				}
#line 982 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 982 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 982 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, _tmp51_);
#line 982 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp53_ = _tmp56_;
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				if (_tmp53_ == NULL) {
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 636 "test-case.c"
				}
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp57_ = ptr;
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				_tmp58_ = g_stpcpy (_tmp57_, _tmp53_);
#line 983 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
				ptr = _tmp58_;
#line 644 "test-case.c"
			}
		}
#line 986 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp59_ = res;
#line 986 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		res = NULL;
#line 986 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp59_;
#line 986 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		return result;
#line 655 "test-case.c"
	} else {
		gchar* _tmp60_ = NULL;
#line 988 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		_tmp60_ = g_strdup ("");
#line 988 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		result = _tmp60_;
#line 988 "/opt/gnome3/build/share/vala-0.24/vapi/glib-2.0.vapi"
		return result;
#line 664 "test-case.c"
	}
}


FolksTestCase* folks_test_case_construct (GType object_type, const gchar* name) {
	FolksTestCase * self = NULL;
	const gchar* _tmp0_ = NULL;
	GTestSuite* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 42 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 42 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self = (FolksTestCase*) g_object_new (object_type, NULL);
#line 44 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	setlocale (LC_ALL, "");
#line 50 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("G_MESSAGES_DEBUG", "all", FALSE);
#line 51 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("FOLKS_DEBUG", "all", FALSE);
#line 55 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("GIO_USE_VFS", "local", TRUE);
#line 60 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("DBUS_STARTER_ADDRESS");
#line 61 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("DBUS_STARTER_BUS_TYPE");
#line 63 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_case_log_adaptor_set_up ();
#line 64 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = name;
#line 64 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = g_test_create_suite (_tmp0_);
#line 64 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->priv->_suite = _tmp1_;
#line 66 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp2_ = folks_test_case_create_transient_dir (self);
#line 66 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (self->priv->_transient_dir);
#line 66 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->priv->_transient_dir = _tmp2_;
#line 67 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_case_private_bus_up (self);
#line 69 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp3_ = g_getenv ("FOLKS_TESTS_INSTALLED");
#line 69 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp3_ == NULL) {
#line 711 "test-case.c"
		gchar** locations = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar** _tmp6_ = NULL;
		gint locations_length1 = 0;
		gint _locations_size_ = 0;
		gboolean _tmp7_ = FALSE;
		gboolean _tmp10_ = FALSE;
		gboolean _tmp13_ = FALSE;
		gboolean _tmp16_ = FALSE;
		gboolean _tmp19_ = FALSE;
		gboolean _tmp22_ = FALSE;
		gchar** _tmp25_ = NULL;
		gint _tmp25__length1 = 0;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp4_ = g_strdup (ABS_TOP_BUILDDIR "/backends/key-file/.libs/key-file.so");
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp5_ = g_strdup (ABS_TOP_BUILDDIR "/backends/dummy/.libs/dummy.so");
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp6_ = g_new0 (gchar*, 2 + 1);
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp6_[0] = _tmp4_;
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp6_[1] = _tmp5_;
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		locations = _tmp6_;
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		locations_length1 = 2;
#line 71 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_locations_size_ = locations_length1;
#line 76 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp7_ = HAVE_EDS;
#line 76 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (_tmp7_) {
#line 748 "test-case.c"
			gchar** _tmp8_ = NULL;
			gint _tmp8__length1 = 0;
			gchar* _tmp9_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp8_ = locations;
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp8__length1 = locations_length1;
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp9_ = g_strdup (ABS_TOP_BUILDDIR "/backends/eds/.libs/eds.so");
#line 77 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_vala_array_add1 (&locations, &locations_length1, &_locations_size_, _tmp9_);
#line 760 "test-case.c"
		}
#line 79 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp10_ = HAVE_LIBSOCIALWEB;
#line 79 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (_tmp10_) {
#line 766 "test-case.c"
			gchar** _tmp11_ = NULL;
			gint _tmp11__length1 = 0;
			gchar* _tmp12_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp11_ = locations;
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp11__length1 = locations_length1;
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp12_ = g_strdup (ABS_TOP_BUILDDIR "/backends/libsocialweb/.libs/libsocialweb.so");
#line 80 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_vala_array_add2 (&locations, &locations_length1, &_locations_size_, _tmp12_);
#line 778 "test-case.c"
		}
#line 82 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp13_ = HAVE_OFONO;
#line 82 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (_tmp13_) {
#line 784 "test-case.c"
			gchar** _tmp14_ = NULL;
			gint _tmp14__length1 = 0;
			gchar* _tmp15_ = NULL;
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp14_ = locations;
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp14__length1 = locations_length1;
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp15_ = g_strdup (ABS_TOP_BUILDDIR "/backends/ofono/.libs/ofono.so");
#line 83 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_vala_array_add3 (&locations, &locations_length1, &_locations_size_, _tmp15_);
#line 796 "test-case.c"
		}
#line 85 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp16_ = HAVE_TELEPATHY;
#line 85 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (_tmp16_) {
#line 802 "test-case.c"
			gchar** _tmp17_ = NULL;
			gint _tmp17__length1 = 0;
			gchar* _tmp18_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp17_ = locations;
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp17__length1 = locations_length1;
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp18_ = g_strdup (ABS_TOP_BUILDDIR "/backends/telepathy/.libs/telepathy.so");
#line 86 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_vala_array_add4 (&locations, &locations_length1, &_locations_size_, _tmp18_);
#line 814 "test-case.c"
		}
#line 88 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp19_ = HAVE_TRACKER;
#line 88 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (_tmp19_) {
#line 820 "test-case.c"
			gchar** _tmp20_ = NULL;
			gint _tmp20__length1 = 0;
			gchar* _tmp21_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp20_ = locations;
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp20__length1 = locations_length1;
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp21_ = g_strdup (ABS_TOP_BUILDDIR "/backends/tracker/.libs/tracker.so");
#line 89 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_vala_array_add5 (&locations, &locations_length1, &_locations_size_, _tmp21_);
#line 832 "test-case.c"
		}
#line 91 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp22_ = HAVE_BLUEZ;
#line 91 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (_tmp22_) {
#line 838 "test-case.c"
			gchar** _tmp23_ = NULL;
			gint _tmp23__length1 = 0;
			gchar* _tmp24_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp23_ = locations;
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp23__length1 = locations_length1;
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp24_ = g_strdup (ABS_TOP_BUILDDIR "/backends/bluez/.libs/bluez.so");
#line 92 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_vala_array_add6 (&locations, &locations_length1, &_locations_size_, _tmp24_);
#line 850 "test-case.c"
		}
#line 94 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp25_ = locations;
#line 94 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp25__length1 = locations_length1;
#line 94 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp26_ = _vala_g_strjoinv (":", _tmp25_, _tmp25__length1);
#line 94 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp27_ = _tmp26_;
#line 94 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_setenv ("FOLKS_BACKEND_PATH", _tmp27_, TRUE);
#line 94 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_free0 (_tmp27_);
#line 69 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		locations = (_vala_array_free (locations, locations_length1, (GDestroyNotify) g_free), NULL);
#line 866 "test-case.c"
	}
#line 99 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("FOLKS_BACKENDS_ALLOWED", "", TRUE);
#line 42 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return self;
#line 872 "test-case.c"
}


/**
   * Create and return a transient directory suitable for use as
   * //transient_dir//. Set environment variables to point into it.
   *
   * This is only called once per process, so that it can be used in
   * environment variables that are cached or otherwise considered to
   * be process-global. As such, all tests in a TestCase share it.
   *
   * Subclasses may override this method to do additional setup
   * (create more subdirectories or set more environment variables).
   */
static gchar* folks_test_case_real_create_transient_dir (FolksTestCase* self) {
	gchar* result = NULL;
	const gchar* tmp = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* transient = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* cache = NULL;
	gchar* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gchar* config = NULL;
	gchar* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gchar* local = NULL;
	gchar* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gchar* runtime = NULL;
	gchar* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gchar* dbus_system = NULL;
	gchar* _tmp21_ = NULL;
	gint _tmp22_ = 0;
	gchar* dbus_session = NULL;
	gchar* _tmp25_ = NULL;
	gint _tmp26_ = 0;
#line 131 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = g_get_tmp_dir ();
#line 131 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	tmp = _tmp0_;
#line 132 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = g_strdup_printf ("%s/folks-test.XXXXXX", tmp);
#line 132 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	transient = _tmp1_;
#line 134 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp2_ = mkdtemp (transient);
#line 134 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp2_ == NULL) {
#line 924 "test-case.c"
		gint _tmp3_ = 0;
		const gchar* _tmp4_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp3_ = errno;
#line 135 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp4_ = g_strerror (_tmp3_);
#line 135 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:135: unable to create temporary directory in '%s': %s", tmp, _tmp4_);
#line 933 "test-case.c"
	}
#line 138 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_debug ("test-case.vala:138: setting up in transient directory %s", transient);
#line 141 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("GSETTINGS_BACKEND", "memory", TRUE);
#line 144 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("HOME", transient, TRUE);
#line 148 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("G_HOME", transient, TRUE);
#line 150 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp5_ = g_strdup_printf ("%s/.cache", transient);
#line 150 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	cache = _tmp5_;
#line 151 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("XDG_CACHE_HOME", cache, TRUE);
#line 153 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp6_ = g_mkdir_with_parents (cache, 0700);
#line 153 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp6_ != 0) {
#line 953 "test-case.c"
		gint _tmp7_ = 0;
		const gchar* _tmp8_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp7_ = errno;
#line 154 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp8_ = g_strerror (_tmp7_);
#line 154 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:154: unable to create '%s': %s", cache, _tmp8_);
#line 962 "test-case.c"
	}
#line 157 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp9_ = g_strdup_printf ("%s/.config", transient);
#line 157 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	config = _tmp9_;
#line 158 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("XDG_CONFIG_HOME", config, TRUE);
#line 160 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp10_ = g_mkdir_with_parents (config, 0700);
#line 160 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp10_ != 0) {
#line 974 "test-case.c"
		gint _tmp11_ = 0;
		const gchar* _tmp12_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp11_ = errno;
#line 161 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp12_ = g_strerror (_tmp11_);
#line 161 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:161: unable to create '%s': %s", config, _tmp12_);
#line 983 "test-case.c"
	}
#line 164 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp13_ = g_strdup_printf ("%s/.local/share", transient);
#line 164 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	local = _tmp13_;
#line 165 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("XDG_DATA_HOME", local, TRUE);
#line 167 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp14_ = g_mkdir_with_parents (local, 0700);
#line 167 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp14_ != 0) {
#line 995 "test-case.c"
		gint _tmp15_ = 0;
		const gchar* _tmp16_ = NULL;
#line 168 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp15_ = errno;
#line 168 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp16_ = g_strerror (_tmp15_);
#line 168 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:168: unable to create '%s': %s", local, _tmp16_);
#line 1004 "test-case.c"
	}
#line 174 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp17_ = g_strdup_printf ("%s/XDG_RUNTIME_DIR", transient);
#line 174 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	runtime = _tmp17_;
#line 175 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("XDG_RUNTIME_DIR", runtime, TRUE);
#line 177 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp18_ = g_mkdir_with_parents (runtime, 0700);
#line 177 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp18_ != 0) {
#line 1016 "test-case.c"
		gint _tmp19_ = 0;
		const gchar* _tmp20_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp19_ = errno;
#line 178 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp20_ = g_strerror (_tmp19_);
#line 178 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:178: unable to create '%s': %s", runtime, _tmp20_);
#line 1025 "test-case.c"
	}
#line 182 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp21_ = g_strdup_printf ("%s/dbus-1/system-services", transient);
#line 182 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	dbus_system = _tmp21_;
#line 184 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp22_ = g_mkdir_with_parents (dbus_system, 0700);
#line 184 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp22_ != 0) {
#line 1035 "test-case.c"
		gint _tmp23_ = 0;
		const gchar* _tmp24_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp23_ = errno;
#line 185 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp24_ = g_strerror (_tmp23_);
#line 185 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:185: unable to create '%s': %s", local, _tmp24_);
#line 1044 "test-case.c"
	}
#line 188 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp25_ = g_strdup_printf ("%s/dbus-1/services", transient);
#line 188 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	dbus_session = _tmp25_;
#line 190 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp26_ = g_mkdir_with_parents (dbus_session, 0700);
#line 190 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp26_ != 0) {
#line 1054 "test-case.c"
		gint _tmp27_ = 0;
		const gchar* _tmp28_ = NULL;
#line 191 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp27_ = errno;
#line 191 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp28_ = g_strerror (_tmp27_);
#line 191 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:191: unable to create '%s': %s", local, _tmp28_);
#line 1063 "test-case.c"
	}
#line 196 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_DESKTOP_DIR");
#line 197 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_DOCUMENTS_DIR");
#line 198 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_DOWNLOAD_DIR");
#line 199 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_MUSIC_DIR");
#line 200 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_PICTURES_DIR");
#line 201 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_PUBLICSHARE_DIR");
#line 202 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_TEMPLATES_DIR");
#line 203 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_unsetenv ("XDG_VIDEOS_DIR");
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	result = transient;
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (dbus_session);
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (dbus_system);
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (runtime);
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (local);
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (config);
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (cache);
#line 205 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return result;
#line 1097 "test-case.c"
}


gchar* folks_test_case_create_transient_dir (FolksTestCase* self) {
#line 129 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 129 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return FOLKS_TEST_CASE_GET_CLASS (self)->create_transient_dir (self);
#line 1106 "test-case.c"
}


/**
   * Create a D-Bus service file for a python-dbusmock service.
   *
   * Create a service file to allow auto-launching a python-dbusmock service
   * which uses the given ``dbusmock_template_name`` to mock up the service
   * running at ``bus_name`` on the ``bus_type`` bus (which must either be
   * {@link BusType.SYSTEM} or {@link BusType.SESSION}.
   *
   * This requires Python 3 to be installed and available to run as ``python3``
   * somewhere in the system ``PATH``.
   *
   * It will create a temporary log file which python-dbusmock will log to if
   * launched. The name of the log file will be printed to the test logs.
   *
   * The D-Bus service file itself will be created in a subdirectory of
   * {@link TestCase.transient_dir}, which the {@link TestDBus} instance has
   * already been configured to use as a service directory. This requires
   * {@link TestCase.create_transient_dir} to have been called already.
   *
   * @param bus_type the bus the service should be auto-launchable from
   * @param bus_name the well-known bus name used by the service
   * @param dbusmock_template_name name of the python-dbusmock template to use
   *
   * @since 0.9.7
   */
void folks_test_case_create_dbusmock_service (FolksTestCase* self, GBusType bus_type, const gchar* bus_name, const gchar* dbusmock_template_name) {
	gchar* service_dir = NULL;
	GBusType _tmp0_ = 0;
	gchar* python = NULL;
	gchar* _tmp3_ = NULL;
	gchar* log_file_name = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* service_file_name = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* service_file = NULL;
	const gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	GError * _inner_error_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (self != NULL);
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (bus_name != NULL);
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (dbusmock_template_name != NULL);
#line 237 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = bus_type;
#line 237 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	switch (_tmp0_) {
#line 237 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		case G_BUS_TYPE_SYSTEM:
#line 1178 "test-case.c"
		{
			gchar* _tmp1_ = NULL;
#line 240 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp1_ = g_strdup ("system-services");
#line 240 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_g_free0 (service_dir);
#line 240 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			service_dir = _tmp1_;
#line 241 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			break;
#line 1189 "test-case.c"
		}
#line 237 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		case G_BUS_TYPE_SESSION:
#line 1193 "test-case.c"
		{
			gchar* _tmp2_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_tmp2_ = g_strdup ("services");
#line 243 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_g_free0 (service_dir);
#line 243 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			service_dir = _tmp2_;
#line 244 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			break;
#line 1204 "test-case.c"
		}
		default:
#line 237 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		case G_BUS_TYPE_STARTER:
#line 237 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		case G_BUS_TYPE_NONE:
#line 1211 "test-case.c"
		{
#line 248 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			g_assert_not_reached ();
#line 1215 "test-case.c"
		}
	}
#line 253 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp3_ = g_find_program_in_path ("python3");
#line 253 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	python = _tmp3_;
#line 254 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (python == NULL) {
#line 256 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:256: %s", "Couldn’t find `python3` in $PATH; can’t run " "python-dbusmock.");
#line 1226 "test-case.c"
	}
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp4_ = folks_test_case_get_transient_dir (self);
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp5_ = _tmp4_;
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp6_ = service_dir;
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp7_ = bus_name;
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp8_ = dbusmock_template_name;
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp9_ = g_strdup_printf ("dbusmock-%s-%s-%s.log", _tmp6_, _tmp7_, _tmp8_);
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp10_ = _tmp9_;
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp11_ = g_build_filename (_tmp5_, _tmp10_, NULL);
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp12_ = _tmp11_;
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (_tmp10_);
#line 262 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	log_file_name = _tmp12_;
#line 266 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp13_ = bus_name;
#line 266 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp14_ = dbusmock_template_name;
#line 266 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_test_message ("python-dbusmock service ‘%s’ (template ‘%s’) will log " "to ‘%s’.", _tmp13_, _tmp14_, log_file_name);
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp15_ = folks_test_case_get_transient_dir (self);
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp16_ = _tmp15_;
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp17_ = service_dir;
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp18_ = dbusmock_template_name;
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp19_ = g_strconcat (_tmp18_, ".service", NULL);
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp20_ = _tmp19_;
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp21_ = g_build_filename (_tmp16_, "dbus-1", _tmp17_, _tmp20_, NULL);
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp22_ = _tmp21_;
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (_tmp20_);
#line 270 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	service_file_name = _tmp22_;
#line 273 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp23_ = bus_name;
#line 273 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp24_ = dbusmock_template_name;
#line 273 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp25_ = g_strdup_printf ("[D-BUS Service]\n" "Name=%s\n" "Exec=%s -m dbusmock --template %s -l %s\n", _tmp23_, python, _tmp24_, log_file_name);
#line 273 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	service_file = _tmp25_;
#line 1284 "test-case.c"
	{
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_file_set_contents (service_file_name, service_file, (gssize) (-1), &_inner_error_);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (_inner_error_ != NULL) {
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			if (_inner_error_->domain == G_FILE_ERROR) {
#line 1292 "test-case.c"
				goto __catch0_g_file_error;
			}
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_g_free0 (service_file);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_g_free0 (service_file_name);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_g_free0 (log_file_name);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_g_free0 (python);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			_g_free0 (service_dir);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			g_clear_error (&_inner_error_);
#line 280 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			return;
#line 1311 "test-case.c"
		}
	}
	goto __finally0;
	__catch0_g_file_error:
	{
		GError* e2 = NULL;
		const gchar* _tmp26_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		e2 = _inner_error_;
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_inner_error_ = NULL;
#line 284 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp26_ = e2->message;
#line 284 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_error ("test-case.vala:284: Error creating D-Bus service file ‘%s’: %s", service_file_name, _tmp26_);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_error_free0 (e2);
#line 1329 "test-case.c"
	}
	__finally0:
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_inner_error_ != NULL) {
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_free0 (service_file);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_free0 (service_file_name);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_free0 (log_file_name);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_free0 (python);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_free0 (service_dir);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_clear_error (&_inner_error_);
#line 278 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		return;
#line 1350 "test-case.c"
	}
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (service_file);
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (service_file_name);
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (log_file_name);
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (python);
#line 233 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (service_dir);
#line 1362 "test-case.c"
}


/**
   * Start the temporary D-Bus session.
   *
   * This is per-process, not per-test, for the reasons mentioned for
   * //test_dbus//.
   *
   * By calling {@link TestCase.create_dbusmock_service} in an overridden
   * version of this method, python-dbusmock services may be set up.
   */
static gpointer _g_object_ref0 (gpointer self) {
#line 340 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return self ? g_object_ref (self) : NULL;
#line 1378 "test-case.c"
}


static void folks_test_case_real_private_bus_up (FolksTestCase* self) {
	FolksTestDBus* _tmp0_ = NULL;
	FolksTestDBus* test_system_dbus = NULL;
	FolksTestDBus* _tmp1_ = NULL;
	FolksTestDBus* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* system_bus_address = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	FolksTestDBus* _tmp9_ = NULL;
	FolksTestDBus* test_dbus = NULL;
	FolksTestDBus* _tmp10_ = NULL;
	FolksTestDBus* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* session_bus_address = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
#line 336 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_dbus_unset ();
#line 339 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = folks_test_dbus_new (FOLKS_TEST_DBUS_SYSTEM_BUS);
#line 339 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_object_unref0 (self->test_system_dbus);
#line 339 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->test_system_dbus = _tmp0_;
#line 340 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = self->test_system_dbus;
#line 340 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, FOLKS_TYPE_TEST_DBUS, FolksTestDBus));
#line 340 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	test_system_dbus = _tmp2_;
#line 341 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp3_ = folks_test_case_get_transient_dir (self);
#line 341 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp4_ = _tmp3_;
#line 341 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp5_ = g_strconcat (_tmp4_, "/dbus-1/system-services", NULL);
#line 341 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp6_ = _tmp5_;
#line 341 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_dbus_add_service_dir (test_system_dbus, _tmp6_);
#line 341 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (_tmp6_);
#line 344 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_dbus_up (test_system_dbus);
#line 346 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp7_ = folks_test_dbus_get_bus_address (test_system_dbus);
#line 346 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 346 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	system_bus_address = _tmp8_;
#line 349 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp9_ = folks_test_dbus_new (FOLKS_TEST_DBUS_NONE);
#line 349 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_object_unref0 (self->test_dbus);
#line 349 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->test_dbus = _tmp9_;
#line 350 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp10_ = self->test_dbus;
#line 350 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, FOLKS_TYPE_TEST_DBUS, FolksTestDBus));
#line 350 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	test_dbus = _tmp11_;
#line 351 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp12_ = folks_test_case_get_transient_dir (self);
#line 351 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp13_ = _tmp12_;
#line 351 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp14_ = g_strconcat (_tmp13_, "/dbus-1/services", NULL);
#line 351 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp15_ = _tmp14_;
#line 351 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_dbus_add_service_dir (test_dbus, _tmp15_);
#line 351 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (_tmp15_);
#line 353 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_dbus_up (test_dbus);
#line 355 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp16_ = folks_test_dbus_get_bus_address (test_dbus);
#line 355 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 355 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	session_bus_address = _tmp17_;
#line 359 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("DBUS_SYSTEM_BUS_ADDRESS", system_bus_address, TRUE);
#line 361 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("DBUS_SESSION_BUS_ADDRESS", session_bus_address, TRUE);
#line 367 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_setenv ("FOLKS_TESTS_SANDBOXED_DBUS", "no-services", TRUE);
#line 333 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (session_bus_address);
#line 333 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_object_unref0 (test_dbus);
#line 333 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (system_bus_address);
#line 333 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_object_unref0 (test_system_dbus);
#line 1485 "test-case.c"
}


void folks_test_case_private_bus_up (FolksTestCase* self) {
#line 333 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (self != NULL);
#line 333 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_GET_CLASS (self)->private_bus_up (self);
#line 1494 "test-case.c"
}


void folks_test_case_register (FolksTestCase* self) {
	GTestSuite* _tmp0_ = NULL;
	GTestSuite* _tmp1_ = NULL;
#line 371 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (self != NULL);
#line 373 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = g_test_get_root ();
#line 373 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = self->priv->_suite;
#line 373 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_test_suite_add_suite (_tmp0_, _tmp1_);
#line 1509 "test-case.c"
}


void folks_test_case_add_test (FolksTestCase* self, const gchar* name, FolksTestCaseTestMethod test, void* test_target) {
	GTestSuite* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	FolksTestCaseTestMethod _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	GTestCase* _tmp3_ = NULL;
#line 376 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (self != NULL);
#line 376 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (name != NULL);
#line 378 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = self->priv->_suite;
#line 378 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = name;
#line 378 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp2_ = test;
#line 378 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp2__target = test_target;
#line 378 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp3_ = folks_test_case_add_test_helper (self, _tmp1_, _tmp2_, _tmp2__target);
#line 378 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_test_suite_add (_tmp0_, _tmp3_);
#line 1535 "test-case.c"
}


/**
   * Set up for one test. If you have more than one test, this will
   * be called once per test.
   *
   * Subclasses may override this method. They are expected to chain up
   * as the first thing in their implementation.
   */
static void folks_test_case_real_set_up (FolksTestCase* self) {
}


void folks_test_case_set_up (FolksTestCase* self) {
#line 391 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (self != NULL);
#line 391 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_GET_CLASS (self)->set_up (self);
#line 1555 "test-case.c"
}


/**
   * Clean up after one test, undoing set_up(). If you have more than
   * one test, this will be called once per test.
   *
   * Subclasses may override this method. They are expected to chain up
   * as the last thing in their implementation.
   */
static void folks_test_case_real_tear_down (FolksTestCase* self) {
}


void folks_test_case_tear_down (FolksTestCase* self) {
#line 402 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (self != NULL);
#line 402 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_GET_CLASS (self)->tear_down (self);
#line 1575 "test-case.c"
}


/**
   * Clean up after all tests. If you have more than one test case, this
   * will be called once, the last time only. It should undo the
   * constructor, and must be idempotent (i.e. OK to call more than once).
   *
   * Subclasses may override this method. They are expected to chain up
   * as the last thing in their implementation.
   *
   * If there are no reference leaks, this method will be called
   * automatically when the TestCase is destroyed.
   */
static void folks_test_case_real_final_tear_down (FolksTestCase* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	FolksTestDBus* _tmp5_ = NULL;
	FolksTestDBus* _tmp7_ = NULL;
#line 425 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_case_in_final_tear_down = TRUE;
#line 427 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = folks_test_case_get_uses_dbus_1 (self);
#line 427 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = _tmp0_;
#line 427 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp1_) {
#line 428 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_folks_test_case_dbus_1_set_no_exit_on_disconnect ();
#line 1606 "test-case.c"
	}
#line 441 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp2_ = self->priv->_transient_dir;
#line 441 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp2_ != NULL) {
#line 1612 "test-case.c"
		const gchar* dir = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 443 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp3_ = self->priv->_transient_dir;
#line 443 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		dir = (const gchar*) _tmp3_;
#line 444 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp4_ = dir;
#line 444 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		haze_remove_directory (_tmp4_);
#line 1624 "test-case.c"
	}
#line 447 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	exit (0);
#line 449 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp5_ = self->test_dbus;
#line 449 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp5_ != NULL) {
#line 1632 "test-case.c"
		FolksTestDBus* _tmp6_ = NULL;
#line 451 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp6_ = self->test_dbus;
#line 451 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		folks_test_dbus_down (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, FOLKS_TYPE_TEST_DBUS, FolksTestDBus));
#line 452 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_object_unref0 (self->test_dbus);
#line 452 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		self->test_dbus = NULL;
#line 1642 "test-case.c"
	}
#line 455 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp7_ = self->test_system_dbus;
#line 455 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp7_ != NULL) {
#line 1648 "test-case.c"
		FolksTestDBus* _tmp8_ = NULL;
#line 457 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp8_ = self->test_system_dbus;
#line 457 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		folks_test_dbus_down (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, FOLKS_TYPE_TEST_DBUS, FolksTestDBus));
#line 458 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_g_object_unref0 (self->test_system_dbus);
#line 458 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		self->test_system_dbus = NULL;
#line 1658 "test-case.c"
	}
}


void folks_test_case_final_tear_down (FolksTestCase* self) {
#line 423 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (self != NULL);
#line 423 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_GET_CLASS (self)->final_tear_down (self);
#line 1668 "test-case.c"
}


const gchar* folks_test_case_get_transient_dir (FolksTestCase* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 113 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = self->priv->_transient_dir;
#line 113 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_vala_assert (_tmp0_ != NULL, "this._transient_dir != null");
#line 114 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = self->priv->_transient_dir;
#line 114 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	result = (const gchar*) _tmp1_;
#line 114 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return result;
#line 1688 "test-case.c"
}


gboolean folks_test_case_get_uses_dbus_1 (FolksTestCase* self) {
#line 318 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 318 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return FOLKS_TEST_CASE_GET_CLASS (self)->get_uses_dbus_1 (self);
#line 1697 "test-case.c"
}


static gboolean folks_test_case_real_get_uses_dbus_1 (FolksTestCase* base) {
	gboolean result;
	FolksTestCase* self;
#line 318 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self = base;
#line 320 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	result = FALSE;
#line 320 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return result;
#line 1710 "test-case.c"
}


static FolksTestCaseLogAdaptor* folks_test_case_log_adaptor_construct (GType object_type) {
	FolksTestCaseLogAdaptor* self = NULL;
#line 469 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self = (FolksTestCaseLogAdaptor*) g_type_create_instance (object_type);
#line 469 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return self;
#line 1720 "test-case.c"
}


static FolksTestCaseLogAdaptor* folks_test_case_log_adaptor_new (void) {
#line 469 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return folks_test_case_log_adaptor_construct (FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR);
#line 1727 "test-case.c"
}


static void __folks_test_case_log_adaptor_printerr_func_stack_trace_gprint_func (const gchar* text) {
#line 475 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_folks_test_case_log_adaptor_printerr_func_stack_trace (text);
#line 1734 "test-case.c"
}


static void __folks_test_case_log_adaptor_log_func_stack_trace_glog_func (const gchar* log_domain, GLogLevelFlags log_levels, const gchar* message, gpointer self) {
#line 476 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_folks_test_case_log_adaptor_log_func_stack_trace (log_domain, log_levels, message);
#line 1741 "test-case.c"
}


static void folks_test_case_log_adaptor_set_up (void) {
#line 475 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_set_printerr_handler (__folks_test_case_log_adaptor_printerr_func_stack_trace_gprint_func);
#line 476 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_log_set_default_handler (__folks_test_case_log_adaptor_log_func_stack_trace_glog_func, NULL);
#line 1750 "test-case.c"
}


static void _folks_test_case_log_adaptor_printerr_func_stack_trace (const gchar* text) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	FILE* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = text;
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp1_ == NULL) {
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp0_ = TRUE;
#line 1765 "test-case.c"
	} else {
		GEqualFunc _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp2_ = g_str_equal;
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp3_ = text;
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp4_ = _tmp2_ (_tmp3_, "");
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		_tmp0_ = _tmp4_;
#line 1778 "test-case.c"
	}
#line 481 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp0_) {
#line 482 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		return;
#line 1784 "test-case.c"
	}
#line 484 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp5_ = stderr;
#line 484 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp6_ = text;
#line 484 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	fprintf (_tmp5_, "%s", _tmp6_);
#line 487 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_on_error_stack_trace ("libtool --mode=execute gdb");
#line 1794 "test-case.c"
}


static void _folks_test_case_log_adaptor_log_func_stack_trace (const gchar* log_domain, GLogLevelFlags log_levels, const gchar* message) {
	GLogFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	const gchar* _tmp1_ = NULL;
	GLogLevelFlags _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GLogLevelFlags _tmp5_ = 0;
#line 490 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (message != NULL);
#line 494 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ = g_log_default_handler;
#line 494 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0__target = NULL;
#line 494 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp1_ = log_domain;
#line 494 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp2_ = log_levels;
#line 494 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp3_ = message;
#line 494 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp0_ (_tmp1_, _tmp2_, _tmp3_, _tmp0__target);
#line 499 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp4_ = folks_test_case_in_final_tear_down;
#line 499 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (_tmp4_) {
#line 500 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		return;
#line 1826 "test-case.c"
	}
#line 504 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_tmp5_ = log_levels;
#line 504 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if ((_tmp5_ & ((G_LOG_LEVEL_WARNING | G_LOG_LEVEL_ERROR) | G_LOG_LEVEL_CRITICAL)) != 0) {
#line 509 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_on_error_stack_trace ("libtool --mode=execute gdb");
#line 1834 "test-case.c"
	}
}


static void folks_test_case_value_log_adaptor_init (GValue* value) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	value->data[0].v_pointer = NULL;
#line 1842 "test-case.c"
}


static void folks_test_case_value_log_adaptor_free_value (GValue* value) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (value->data[0].v_pointer) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		folks_test_case_log_adaptor_unref (value->data[0].v_pointer);
#line 1851 "test-case.c"
	}
}


static void folks_test_case_value_log_adaptor_copy_value (const GValue* src_value, GValue* dest_value) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (src_value->data[0].v_pointer) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		dest_value->data[0].v_pointer = folks_test_case_log_adaptor_ref (src_value->data[0].v_pointer);
#line 1861 "test-case.c"
	} else {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1865 "test-case.c"
	}
}


static gpointer folks_test_case_value_log_adaptor_peek_pointer (const GValue* value) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return value->data[0].v_pointer;
#line 1873 "test-case.c"
}


static gchar* folks_test_case_value_log_adaptor_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (collect_values[0].v_pointer) {
#line 1880 "test-case.c"
		FolksTestCaseLogAdaptor* object;
		object = collect_values[0].v_pointer;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		if (object->parent_instance.g_class == NULL) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1887 "test-case.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1891 "test-case.c"
		}
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		value->data[0].v_pointer = folks_test_case_log_adaptor_ref (object);
#line 1895 "test-case.c"
	} else {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		value->data[0].v_pointer = NULL;
#line 1899 "test-case.c"
	}
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return NULL;
#line 1903 "test-case.c"
}


static gchar* folks_test_case_value_log_adaptor_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	FolksTestCaseLogAdaptor** object_p;
	object_p = collect_values[0].v_pointer;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (!object_p) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1914 "test-case.c"
	}
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (!value->data[0].v_pointer) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*object_p = NULL;
#line 1920 "test-case.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*object_p = value->data[0].v_pointer;
#line 1924 "test-case.c"
	} else {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		*object_p = folks_test_case_log_adaptor_ref (value->data[0].v_pointer);
#line 1928 "test-case.c"
	}
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return NULL;
#line 1932 "test-case.c"
}


static GParamSpec* folks_test_case_param_spec_log_adaptor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	FolksTestCaseParamSpecLogAdaptor* spec;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_val_if_fail (g_type_is_a (object_type, FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR), NULL);
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return G_PARAM_SPEC (spec);
#line 1946 "test-case.c"
}


static gpointer folks_test_case_value_get_log_adaptor (const GValue* value) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR), NULL);
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return value->data[0].v_pointer;
#line 1955 "test-case.c"
}


static void folks_test_case_value_set_log_adaptor (GValue* value, gpointer v_object) {
	FolksTestCaseLogAdaptor* old;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR));
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	old = value->data[0].v_pointer;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (v_object) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR));
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		value->data[0].v_pointer = v_object;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		folks_test_case_log_adaptor_ref (value->data[0].v_pointer);
#line 1975 "test-case.c"
	} else {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		value->data[0].v_pointer = NULL;
#line 1979 "test-case.c"
	}
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (old) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		folks_test_case_log_adaptor_unref (old);
#line 1985 "test-case.c"
	}
}


static void folks_test_case_value_take_log_adaptor (GValue* value, gpointer v_object) {
	FolksTestCaseLogAdaptor* old;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR));
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	old = value->data[0].v_pointer;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (v_object) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR));
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		value->data[0].v_pointer = v_object;
#line 2004 "test-case.c"
	} else {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		value->data[0].v_pointer = NULL;
#line 2008 "test-case.c"
	}
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (old) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		folks_test_case_log_adaptor_unref (old);
#line 2014 "test-case.c"
	}
}


static void folks_test_case_log_adaptor_class_init (FolksTestCaseLogAdaptorClass * klass) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_case_log_adaptor_parent_class = g_type_class_peek_parent (klass);
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_LOG_ADAPTOR_CLASS (klass)->finalize = folks_test_case_log_adaptor_finalize;
#line 2024 "test-case.c"
}


static void folks_test_case_log_adaptor_instance_init (FolksTestCaseLogAdaptor * self) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->ref_count = 1;
#line 2031 "test-case.c"
}


static void folks_test_case_log_adaptor_finalize (FolksTestCaseLogAdaptor* obj) {
	FolksTestCaseLogAdaptor * self;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FOLKS_TEST_CASE_TYPE_LOG_ADAPTOR, FolksTestCaseLogAdaptor);
#line 2039 "test-case.c"
}


static GType folks_test_case_log_adaptor_get_type (void) {
	static volatile gsize folks_test_case_log_adaptor_type_id__volatile = 0;
	if (g_once_init_enter (&folks_test_case_log_adaptor_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { folks_test_case_value_log_adaptor_init, folks_test_case_value_log_adaptor_free_value, folks_test_case_value_log_adaptor_copy_value, folks_test_case_value_log_adaptor_peek_pointer, "p", folks_test_case_value_log_adaptor_collect_value, "p", folks_test_case_value_log_adaptor_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (FolksTestCaseLogAdaptorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) folks_test_case_log_adaptor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FolksTestCaseLogAdaptor), 0, (GInstanceInitFunc) folks_test_case_log_adaptor_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType folks_test_case_log_adaptor_type_id;
		folks_test_case_log_adaptor_type_id = g_type_register_fundamental (g_type_fundamental_next (), "FolksTestCaseLogAdaptor", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&folks_test_case_log_adaptor_type_id__volatile, folks_test_case_log_adaptor_type_id);
	}
	return folks_test_case_log_adaptor_type_id__volatile;
}


static gpointer folks_test_case_log_adaptor_ref (gpointer instance) {
	FolksTestCaseLogAdaptor* self;
	self = instance;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_atomic_int_inc (&self->ref_count);
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	return instance;
#line 2064 "test-case.c"
}


static void folks_test_case_log_adaptor_unref (gpointer instance) {
	FolksTestCaseLogAdaptor* self;
	self = instance;
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		FOLKS_TEST_CASE_LOG_ADAPTOR_GET_CLASS (self)->finalize (self);
#line 467 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2077 "test-case.c"
	}
}


static void folks_test_case_class_init (FolksTestCaseClass * klass) {
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_case_parent_class = g_type_class_peek_parent (klass);
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_type_class_add_private (klass, sizeof (FolksTestCasePrivate));
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->create_transient_dir = folks_test_case_real_create_transient_dir;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->private_bus_up = folks_test_case_real_private_bus_up;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = folks_test_case_real_set_up;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = folks_test_case_real_tear_down;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->final_tear_down = folks_test_case_real_final_tear_down;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->get_uses_dbus_1 = folks_test_case_real_get_uses_dbus_1;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_folks_test_case_get_property;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	G_OBJECT_CLASS (klass)->finalize = folks_test_case_finalize;
#line 2103 "test-case.c"
	/**
	   * A transient directory normally created in the constructor and deleted
	   * in final_tear_down(). This can be used for temporary storage.
	   * The environment variables ``XDG_CONFIG_HOME``, ``XDG_DATA_HOME``,
	   * ``XDG_CACHE_HOME``, etc. point into it.
	   */
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_TEST_CASE_TRANSIENT_DIR, g_param_spec_string ("transient-dir", "transient-dir", "transient-dir", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 2112 "test-case.c"
	/**
	   * If true, libraries involved in this test use dbus-1 (or dbus-glib-1)
	   * so we need to turn off its exit-on-disconnect feature.
	   *
	   * FIXME: when our dependencies stop needing this, this whole feature
	   * can be removed (GNOME#696177).
	   */
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), FOLKS_TEST_CASE_USES_DBUS_1, g_param_spec_boolean ("uses-dbus-1", "uses-dbus-1", "uses-dbus-1", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 2122 "test-case.c"
}


static void folks_test_case_instance_init (FolksTestCase * self) {
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->priv = FOLKS_TEST_CASE_GET_PRIVATE (self);
#line 102 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->priv->_transient_dir = NULL;
#line 297 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->test_dbus = NULL;
#line 307 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self->test_system_dbus = NULL;
#line 2135 "test-case.c"
}


static void folks_test_case_finalize (GObject* obj) {
	FolksTestCase * self;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FOLKS_TYPE_TEST_CASE, FolksTestCase);
#line 464 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	folks_test_case_final_tear_down (self);
#line 102 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_free0 (self->priv->_transient_dir);
#line 297 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_object_unref0 (self->test_dbus);
#line 307 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	_g_object_unref0 (self->test_system_dbus);
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	G_OBJECT_CLASS (folks_test_case_parent_class)->finalize (obj);
#line 2153 "test-case.c"
}


/**
 * A test case for Folks, containing one or more individual tests.
 *
 * The constructor configures Folks to disallow all backends, via
 * ``FOLKS_BACKENDS_ALLOWED``. Subclasses are expected to reset
 * this variable to a suitable value in their constructors or
 * set_up() methods.
 */
GType folks_test_case_get_type (void) {
	static volatile gsize folks_test_case_type_id__volatile = 0;
	if (g_once_init_enter (&folks_test_case_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FolksTestCaseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) folks_test_case_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FolksTestCase), 0, (GInstanceInitFunc) folks_test_case_instance_init, NULL };
		GType folks_test_case_type_id;
		folks_test_case_type_id = g_type_register_static (G_TYPE_OBJECT, "FolksTestCase", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&folks_test_case_type_id__volatile, folks_test_case_type_id);
	}
	return folks_test_case_type_id__volatile;
}


static void _vala_folks_test_case_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	FolksTestCase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, FOLKS_TYPE_TEST_CASE, FolksTestCase);
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
	switch (property_id) {
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		case FOLKS_TEST_CASE_TRANSIENT_DIR:
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_value_set_string (value, folks_test_case_get_transient_dir (self));
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		break;
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		case FOLKS_TEST_CASE_USES_DBUS_1:
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		g_value_set_boolean (value, folks_test_case_get_uses_dbus_1 (self));
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		break;
#line 2194 "test-case.c"
		default:
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 35 "/opt/gnome3/source/folks/tests/lib/test-case.vala"
		break;
#line 2200 "test-case.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



