/* remove-persona.c generated by valac 0.24.0.111-cb21a, the Vala compiler
 * generated from remove-persona.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <gee.h>


#define TYPE_REMOVE_PERSONA_TESTS (remove_persona_tests_get_type ())
#define REMOVE_PERSONA_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_REMOVE_PERSONA_TESTS, RemovePersonaTests))
#define REMOVE_PERSONA_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_REMOVE_PERSONA_TESTS, RemovePersonaTestsClass))
#define IS_REMOVE_PERSONA_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_REMOVE_PERSONA_TESTS))
#define IS_REMOVE_PERSONA_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_REMOVE_PERSONA_TESTS))
#define REMOVE_PERSONA_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_REMOVE_PERSONA_TESTS, RemovePersonaTestsClass))

typedef struct _RemovePersonaTests RemovePersonaTests;
typedef struct _RemovePersonaTestsClass RemovePersonaTestsClass;
typedef struct _RemovePersonaTestsPrivate RemovePersonaTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _RemovePersonaTestsTestRemovePersonaAsyncData RemovePersonaTestsTestRemovePersonaAsyncData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _RemovePersonaTestsAddPersonaData RemovePersonaTestsAddPersonaData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _RemovePersonaTests {
	TrackerTestTestCase parent_instance;
	RemovePersonaTestsPrivate * priv;
};

struct _RemovePersonaTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _RemovePersonaTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname;
	gboolean _persona_removed;
	gboolean _individual_removed;
	gchar* _individual_id;
	FolksPersonaStore* _pstore;
	gchar* _persona_id;
	FolksIndividual* _individual;
	gboolean _added_persona;
};

struct _RemovePersonaTestsTestRemovePersonaAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	RemovePersonaTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GeeIterator* _backend_it;
	GeeMap* _tmp4_;
	GeeMap* _tmp5_;
	GeeCollection* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeIterator* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _tmp11_;
	gboolean _tmp12_;
	FolksBackend* backend;
	GeeIterator* _tmp13_;
	gpointer _tmp14_;
	FolksBackend* _tmp15_;
	GeeMap* _tmp16_;
	GeeMap* _tmp17_;
	gpointer _tmp18_;
	FolksPersonaStore* _tmp19_;
	FolksPersonaStore* _tmp20_;
	FolksPersonaStore* _tmp21_;
	GError* e;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _RemovePersonaTestsAddPersonaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	RemovePersonaTests* self;
	GHashTable* details;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* v1;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	GValue* _tmp11_;
	GValue* v2;
	GValue _tmp12_;
	GValue _tmp13_;
	GValue* _tmp14_;
	GValue* _tmp15_;
	GeeHashSet* emails;
	GeeHashSet* _tmp16_;
	FolksEmailFieldDetails* email_1;
	FolksEmailFieldDetails* _tmp17_;
	FolksEmailFieldDetails* email_2;
	FolksEmailFieldDetails* _tmp18_;
	GValue* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GValue* _tmp22_;
	FolksIndividualAggregator* _tmp23_;
	FolksPersonaStore* _tmp24_;
	FolksPersona* _tmp25_;
	FolksPersona* _tmp26_;
	GError* e;
	GError* _tmp27_;
	const gchar* _tmp28_;
	GError * _inner_error_;
};


static gpointer remove_persona_tests_parent_class = NULL;

GType remove_persona_tests_get_type (void) G_GNUC_CONST;
#define REMOVE_PERSONA_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_REMOVE_PERSONA_TESTS, RemovePersonaTestsPrivate))
enum  {
	REMOVE_PERSONA_TESTS_DUMMY_PROPERTY
};
RemovePersonaTests* remove_persona_tests_new (void);
RemovePersonaTests* remove_persona_tests_construct (GType object_type);
void remove_persona_tests_test_remove_persona (RemovePersonaTests* self);
static void _remove_persona_tests_test_remove_persona_folks_test_case_test_method (gpointer self);
static void _remove_persona_tests_test_remove_persona_async (RemovePersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _remove_persona_tests_test_remove_persona_finish (RemovePersonaTests* self, GAsyncResult* _res_);
static void _remove_persona_tests_test_remove_persona_async_data_free (gpointer _data);
static gboolean _remove_persona_tests_test_remove_persona_async_co (RemovePersonaTestsTestRemovePersonaAsyncData* _data_);
static void _remove_persona_tests_test_remove_persona_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _remove_persona_tests_individuals_changed_cb (RemovePersonaTests* self, GeeMultiMap* changes);
static void __remove_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _remove_persona_tests_notify_pstore_cb (RemovePersonaTests* self, GObject* _pstore, GParamSpec* ps);
static void __remove_persona_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _remove_persona_tests_try_to_add (RemovePersonaTests* self);
static void _remove_persona_tests_add_persona (RemovePersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _remove_persona_tests_add_persona_finish (RemovePersonaTests* self, GAsyncResult* _res_);
static void _remove_persona_tests_add_persona_data_free (gpointer _data);
static gboolean _remove_persona_tests_add_persona_co (RemovePersonaTestsAddPersonaData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _remove_persona_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _remove_persona_tests_personas_cb (RemovePersonaTests* self);
static void __remove_persona_tests_personas_cb_folks_persona_store_personas_changed (FolksPersonaStore* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static void remove_persona_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _remove_persona_tests_test_remove_persona_folks_test_case_test_method (gpointer self) {
#line 43 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	remove_persona_tests_test_remove_persona ((RemovePersonaTests*) self);
#line 202 "remove-persona.c"
}


RemovePersonaTests* remove_persona_tests_construct (GType object_type) {
	RemovePersonaTests * self = NULL;
#line 41 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self = (RemovePersonaTests*) tracker_test_test_case_construct (object_type, "RemovePersonaTests");
#line 43 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test adding personas to Tracker ", _remove_persona_tests_test_remove_persona_folks_test_case_test_method, self);
#line 39 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return self;
#line 214 "remove-persona.c"
}


RemovePersonaTests* remove_persona_tests_new (void) {
#line 39 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return remove_persona_tests_construct (TYPE_REMOVE_PERSONA_TESTS);
#line 221 "remove-persona.c"
}


void remove_persona_tests_test_remove_persona (RemovePersonaTests* self) {
	GMainLoop* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GMainLoop* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
#line 46 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (self != NULL);
#line 48 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 48 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 48 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self->priv->_main_loop = _tmp0_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp1_ = g_strdup ("persona #1");
#line 49 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 49 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self->priv->_persona_fullname = _tmp1_;
#line 51 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self->priv->_persona_removed = FALSE;
#line 52 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self->priv->_individual_removed = FALSE;
#line 54 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_test_remove_persona_async (self, NULL, NULL);
#line 56 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp2_ = self->priv->_main_loop;
#line 56 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	folks_test_utils_loop_run_with_timeout (_tmp2_, 5);
#line 58 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp3_ = self->priv->_persona_removed;
#line 58 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_vala_assert (_tmp3_ == TRUE, "this._persona_removed == true");
#line 59 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp4_ = self->priv->_individual_removed;
#line 59 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_vala_assert (_tmp4_ == TRUE, "this._individual_removed == true");
#line 263 "remove-persona.c"
}


static void _remove_persona_tests_test_remove_persona_async_data_free (gpointer _data) {
	RemovePersonaTestsTestRemovePersonaAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_slice_free (RemovePersonaTestsTestRemovePersonaAsyncData, _data_);
#line 274 "remove-persona.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return self ? g_object_ref (self) : NULL;
#line 281 "remove-persona.c"
}


static void _remove_persona_tests_test_remove_persona_async (RemovePersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	RemovePersonaTestsTestRemovePersonaAsyncData* _data_;
	RemovePersonaTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_ = g_slice_new0 (RemovePersonaTestsTestRemovePersonaAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _remove_persona_tests_test_remove_persona_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _remove_persona_tests_test_remove_persona_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_test_remove_persona_async_co (_data_);
#line 300 "remove-persona.c"
}


static void _remove_persona_tests_test_remove_persona_finish (RemovePersonaTests* self, GAsyncResult* _res_) {
	RemovePersonaTestsTestRemovePersonaAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 308 "remove-persona.c"
}


static void _remove_persona_tests_test_remove_persona_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	RemovePersonaTestsTestRemovePersonaAsyncData* _data_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_ = _user_data_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_source_object_ = source_object;
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_res_ = _res_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_test_remove_persona_async_co (_data_);
#line 322 "remove-persona.c"
}


static void __remove_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 67 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_individuals_changed_cb ((RemovePersonaTests*) self, changes);
#line 329 "remove-persona.c"
}


static void __remove_persona_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 82 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_notify_pstore_cb ((RemovePersonaTests*) self, _sender, pspec);
#line 336 "remove-persona.c"
}


static gboolean _remove_persona_tests_test_remove_persona_async_co (RemovePersonaTestsTestRemovePersonaAsyncData* _data_) {
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	switch (_data_->_state_) {
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		case 0:
#line 345 "remove-persona.c"
		goto _state_0;
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		case 1:
#line 349 "remove-persona.c"
		goto _state_1;
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		case 2:
#line 353 "remove-persona.c"
		goto _state_2;
		default:
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_assert_not_reached ();
#line 358 "remove-persona.c"
	}
	_state_0:
#line 64 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp0_ = NULL;
#line 64 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 64 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->store = _data_->_tmp0_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_state_ = 1;
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	folks_backend_store_prepare (_data_->store, _remove_persona_tests_test_remove_persona_async_ready, _data_);
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return FALSE;
#line 373 "remove-persona.c"
	_state_1:
#line 65 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 66 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp1_ = NULL;
#line 66 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 66 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 66 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 67 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp2_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 67 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __remove_persona_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 391 "remove-persona.c"
	{
#line 71 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp3_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 71 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_state_ = 2;
#line 71 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _remove_persona_tests_test_remove_persona_async_ready, _data_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		return FALSE;
#line 403 "remove-persona.c"
		_state_2:
#line 71 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 409 "remove-persona.c"
			goto __catch0_g_error;
		}
#line 73 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_data_->self->priv->_pstore);
#line 73 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->self->priv->_pstore = NULL;
#line 416 "remove-persona.c"
		{
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp4_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp4_ = folks_backend_store_get_enabled_backends (_data_->store);
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp5_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp6_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp6_ = gee_map_get_values (_data_->_tmp5_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp7_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp8_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp9_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp9_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp8_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp10_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_object_unref0 (_data_->_tmp8_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_data_->_backend_it = _data_->_tmp10_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			while (TRUE) {
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp11_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp11_ = _data_->_backend_it;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp12_ = FALSE;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp12_ = gee_iterator_next (_data_->_tmp11_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				if (!_data_->_tmp12_) {
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					break;
#line 464 "remove-persona.c"
				}
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp13_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp13_ = _data_->_backend_it;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp14_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp14_ = gee_iterator_get (_data_->_tmp13_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp14_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp15_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp15_ = _data_->backend;
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp16_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp16_ = folks_backend_get_persona_stores (_data_->_tmp15_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp17_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp18_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp18_ = gee_map_get (_data_->_tmp17_, "tracker");
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_g_object_unref0 (_data_->self->priv->_pstore);
#line 76 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->self->priv->_pstore = (FolksPersonaStore*) _data_->_tmp18_;
#line 77 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp19_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_data_->_tmp19_ = _data_->self->priv->_pstore;
#line 77 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				if (_data_->_tmp19_ != NULL) {
#line 78 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_g_object_unref0 (_data_->backend);
#line 78 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					break;
#line 506 "remove-persona.c"
				}
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_g_object_unref0 (_data_->backend);
#line 510 "remove-persona.c"
			}
#line 74 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 514 "remove-persona.c"
		}
#line 80 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp20_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp20_ = _data_->self->priv->_pstore;
#line 80 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_vala_assert (_data_->_tmp20_ != NULL, "this._pstore != null");
#line 82 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp21_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp21_ = _data_->self->priv->_pstore;
#line 82 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp21_, "notify::is-prepared", (GCallback) __remove_persona_tests_notify_pstore_cb_g_object_notify, _data_->self, 0);
#line 83 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_remove_persona_tests_try_to_add (_data_->self);
#line 530 "remove-persona.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->e = _data_->_inner_error_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_inner_error_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp22_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp22_ = _data_->e;
#line 87 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp23_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 87 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_warning ("remove-persona.vala:87: Error when calling prepare: %s\n", _data_->_tmp23_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_error_free0 (_data_->e);
#line 551 "remove-persona.c"
	}
	__finally0:
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_data_->store);
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_clear_error (&_data_->_inner_error_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		return FALSE;
#line 564 "remove-persona.c"
	}
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (_data_->store);
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	if (_data_->_state_ == 0) {
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 572 "remove-persona.c"
	} else {
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 576 "remove-persona.c"
	}
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_object_unref (_data_->_async_result);
#line 62 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return FALSE;
#line 582 "remove-persona.c"
}


static void _remove_persona_tests_notify_pstore_cb (RemovePersonaTests* self, GObject* _pstore, GParamSpec* ps) {
#line 91 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (self != NULL);
#line 91 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (_pstore != NULL);
#line 91 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (ps != NULL);
#line 93 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_try_to_add (self);
#line 595 "remove-persona.c"
}


static void _remove_persona_tests_try_to_add (RemovePersonaTests* self) {
	gboolean _tmp0_ = FALSE;
	FolksPersonaStore* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 96 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (self != NULL);
#line 98 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp1_ = self->priv->_pstore;
#line 98 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp2_ = folks_persona_store_get_is_prepared (_tmp1_);
#line 98 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp3_ = _tmp2_;
#line 98 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	if (_tmp3_) {
#line 614 "remove-persona.c"
		gboolean _tmp4_ = FALSE;
#line 99 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp4_ = self->priv->_added_persona;
#line 99 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp0_ = _tmp4_ == FALSE;
#line 620 "remove-persona.c"
	} else {
#line 98 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp0_ = FALSE;
#line 624 "remove-persona.c"
	}
#line 98 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	if (_tmp0_) {
#line 101 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		self->priv->_added_persona = TRUE;
#line 102 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_remove_persona_tests_add_persona (self, NULL, NULL);
#line 632 "remove-persona.c"
	}
}


static void _remove_persona_tests_add_persona_data_free (gpointer _data) {
	RemovePersonaTestsAddPersonaData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_slice_free (RemovePersonaTestsAddPersonaData, _data_);
#line 644 "remove-persona.c"
}


static void _remove_persona_tests_add_persona (RemovePersonaTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	RemovePersonaTestsAddPersonaData* _data_;
	RemovePersonaTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_ = g_slice_new0 (RemovePersonaTestsAddPersonaData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _remove_persona_tests_add_persona);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _remove_persona_tests_add_persona_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_add_persona_co (_data_);
#line 663 "remove-persona.c"
}


static void _remove_persona_tests_add_persona_finish (RemovePersonaTests* self, GAsyncResult* _res_) {
	RemovePersonaTestsAddPersonaData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 671 "remove-persona.c"
}


static void _g_free0_ (gpointer var) {
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	var = (g_free (var), NULL);
#line 678 "remove-persona.c"
}


static void _vala_GValue_free (GValue* self) {
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_value_unset (self);
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_free (self);
#line 687 "remove-persona.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 694 "remove-persona.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 701 "remove-persona.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return self ? _g_value_dup (self) : NULL;
#line 708 "remove-persona.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 116 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return result;
#line 717 "remove-persona.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 116 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return result;
#line 726 "remove-persona.c"
}


static void _remove_persona_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	RemovePersonaTestsAddPersonaData* _data_;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_ = _user_data_;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_source_object_ = source_object;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_res_ = _res_;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_add_persona_co (_data_);
#line 740 "remove-persona.c"
}


static gboolean _remove_persona_tests_add_persona_co (RemovePersonaTestsAddPersonaData* _data_) {
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	switch (_data_->_state_) {
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		case 0:
#line 749 "remove-persona.c"
		goto _state_0;
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		case 1:
#line 753 "remove-persona.c"
		goto _state_1;
		default:
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_assert_not_reached ();
#line 758 "remove-persona.c"
	}
	_state_0:
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp0_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp0_ = g_str_hash;
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp1_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp1_ = g_str_equal;
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp2_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 108 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->details = _data_->_tmp2_;
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_value_init (&_data_->_tmp3_, G_TYPE_STRING);
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GValue));
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp5_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp6_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->v1 = _data_->_tmp6_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp7_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp7_ = _data_->v1;
#line 111 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp8_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp8_ = _data_->self->priv->_persona_fullname;
#line 111 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_value_set_string (_data_->_tmp7_, _data_->_tmp8_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp9_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp9_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp10_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp10_ = g_strdup (_data_->_tmp9_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp11_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp11_ = _data_->v1;
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->v1 = NULL;
#line 112 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp10_, _data_->_tmp11_);
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	memset (&_data_->_tmp12_, 0, sizeof (GValue));
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_value_init (&_data_->_tmp12_, GEE_TYPE_SET);
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	memset (&_data_->_tmp13_, 0, sizeof (GValue));
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp14_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp14_ = __g_value_dup0 (&_data_->_tmp13_);
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp15_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	G_IS_VALUE (&_data_->_tmp13_) ? (g_value_unset (&_data_->_tmp13_), NULL) : NULL;
#line 115 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->v2 = _data_->_tmp15_;
#line 116 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp16_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp16_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 116 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->emails = _data_->_tmp16_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp17_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp17_ = folks_email_field_details_new ("test-1@example.org", NULL);
#line 119 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->email_1 = _data_->_tmp17_;
#line 120 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->emails, _data_->email_1);
#line 121 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp18_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp18_ = folks_email_field_details_new ("test-2@example.org", NULL);
#line 121 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->email_2 = _data_->_tmp18_;
#line 122 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->emails, _data_->email_2);
#line 123 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp19_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp19_ = _data_->v2;
#line 123 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_value_set_object (_data_->_tmp19_, (GObject*) _data_->emails);
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp20_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp20_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp21_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp22_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->_tmp22_ = _data_->v2;
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_data_->v2 = NULL;
#line 124 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp21_, _data_->_tmp22_);
#line 885 "remove-persona.c"
	{
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp23_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp23_ = _data_->self->priv->_aggregator;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp24_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp24_ = _data_->self->priv->_pstore;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_state_ = 1;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp23_, NULL, _data_->_tmp24_, _data_->details, _remove_persona_tests_add_persona_ready, _data_);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		return FALSE;
#line 901 "remove-persona.c"
		_state_1:
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp25_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp25_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp23_, _data_->_res_, &_data_->_inner_error_);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp26_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp26_ = _data_->_tmp25_;
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_data_->_tmp26_);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 917 "remove-persona.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_object_unref0 (_data_->email_2);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_object_unref0 (_data_->email_1);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_object_unref0 (_data_->emails);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			__vala_GValue_free0 (_data_->v2);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			__vala_GValue_free0 (_data_->v1);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_hash_table_unref0 (_data_->details);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			g_clear_error (&_data_->_inner_error_);
#line 130 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			return FALSE;
#line 938 "remove-persona.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->e = _data_->_inner_error_;
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_inner_error_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp27_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp27_ = _data_->e;
#line 135 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp28_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_data_->_tmp28_ = _data_->_tmp27_->message;
#line 135 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_warning ("remove-persona.vala:135: [RemovePersonaError] add_persona_from_details" \
": %s\n", _data_->_tmp28_);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_error_free0 (_data_->e);
#line 960 "remove-persona.c"
	}
	__finally1:
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_data_->email_2);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_data_->email_1);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_data_->emails);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		__vala_GValue_free0 (_data_->v2);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		__vala_GValue_free0 (_data_->v1);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_hash_table_unref0 (_data_->details);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_clear_error (&_data_->_inner_error_);
#line 128 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		return FALSE;
#line 983 "remove-persona.c"
	}
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (_data_->email_2);
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (_data_->email_1);
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (_data_->emails);
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	__vala_GValue_free0 (_data_->v2);
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	__vala_GValue_free0 (_data_->v1);
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_hash_table_unref0 (_data_->details);
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	if (_data_->_state_ == 0) {
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1001 "remove-persona.c"
	} else {
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1005 "remove-persona.c"
	}
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_object_unref (_data_->_async_result);
#line 106 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return FALSE;
#line 1011 "remove-persona.c"
}


static void __remove_persona_tests_personas_cb_folks_persona_store_personas_changed (FolksPersonaStore* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 167 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_remove_persona_tests_personas_cb ((RemovePersonaTests*) self);
#line 1018 "remove-persona.c"
}


static void _remove_persona_tests_individuals_changed_cb (RemovePersonaTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (self != NULL);
#line 140 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (changes != NULL);
#line 143 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp0_ = changes;
#line 143 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 143 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	added = _tmp1_;
#line 144 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp2_ = changes;
#line 144 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 144 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	removed = _tmp3_;
#line 1045 "remove-persona.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp4_ = added;
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_i_it = _tmp5_;
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		while (TRUE) {
#line 1058 "remove-persona.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp6_ = _i_it;
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			if (!_tmp7_) {
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				break;
#line 1077 "remove-persona.c"
			}
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp8_ = _i_it;
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			i = (FolksIndividual*) _tmp9_;
#line 148 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp10_ = i;
#line 148 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			if (_tmp10_ == NULL) {
#line 150 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_g_object_unref0 (i);
#line 150 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				continue;
#line 1093 "remove-persona.c"
			}
#line 153 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp11_ = i;
#line 153 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 153 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp13_ = _tmp12_;
#line 153 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp14_ = self->priv->_persona_fullname;
#line 153 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 1105 "remove-persona.c"
				FolksIndividual* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				FolksIndividual* _tmp31_ = NULL;
				FolksIndividual* _tmp32_ = NULL;
				FolksPersonaStore* _tmp33_ = NULL;
				GeeMap* _tmp34_ = NULL;
				GeeMap* _tmp35_ = NULL;
				const gchar* _tmp36_ = NULL;
				gboolean _tmp37_ = FALSE;
#line 155 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp15_ = i;
#line 155 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp16_ = folks_individual_get_id (_tmp15_);
#line 155 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp17_ = _tmp16_;
#line 155 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp18_ = g_strdup (_tmp17_);
#line 155 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_g_free0 (self->priv->_individual_id);
#line 155 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				self->priv->_individual_id = _tmp18_;
#line 1129 "remove-persona.c"
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp19_ = NULL;
					GeeSet* _tmp20_ = NULL;
					GeeSet* _tmp21_ = NULL;
					GeeIterator* _tmp22_ = NULL;
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_tmp19_ = i;
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_tmp20_ = folks_individual_get_personas (_tmp19_);
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_tmp21_ = _tmp20_;
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_p_it = _tmp22_;
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					while (TRUE) {
#line 1148 "remove-persona.c"
						GeeIterator* _tmp23_ = NULL;
						gboolean _tmp24_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp25_ = NULL;
						gpointer _tmp26_ = NULL;
						FolksPersona* _tmp27_ = NULL;
						const gchar* _tmp28_ = NULL;
						const gchar* _tmp29_ = NULL;
						gchar* _tmp30_ = NULL;
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp23_ = _p_it;
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp24_ = gee_iterator_next (_tmp23_);
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						if (!_tmp24_) {
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
							break;
#line 1166 "remove-persona.c"
						}
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp25_ = _p_it;
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp26_ = gee_iterator_get (_tmp25_);
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						p = (FolksPersona*) _tmp26_;
#line 160 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp27_ = p;
#line 160 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp28_ = folks_persona_get_iid (_tmp27_);
#line 160 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp29_ = _tmp28_;
#line 160 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_tmp30_ = g_strdup (_tmp29_);
#line 160 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_g_free0 (self->priv->_persona_id);
#line 160 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						self->priv->_persona_id = _tmp30_;
#line 161 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						_g_object_unref0 (p);
#line 161 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
						break;
#line 1190 "remove-persona.c"
					}
#line 158 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_g_object_unref0 (_p_it);
#line 1194 "remove-persona.c"
				}
#line 164 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp31_ = i;
#line 164 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp32_ = _g_object_ref0 (_tmp31_);
#line 164 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_g_object_unref0 (self->priv->_individual);
#line 164 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				self->priv->_individual = _tmp32_;
#line 165 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp33_ = self->priv->_pstore;
#line 165 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp34_ = folks_persona_store_get_personas (_tmp33_);
#line 165 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp35_ = _tmp34_;
#line 165 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp36_ = self->priv->_persona_id;
#line 165 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_tmp37_ = gee_map_has_key (_tmp35_, _tmp36_);
#line 165 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				if (_tmp37_ == TRUE) {
#line 1216 "remove-persona.c"
					FolksPersonaStore* _tmp38_ = NULL;
					FolksIndividualAggregator* _tmp39_ = NULL;
					FolksIndividual* _tmp40_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_tmp38_ = self->priv->_pstore;
#line 167 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					g_signal_connect_object (_tmp38_, "personas-changed", (GCallback) __remove_persona_tests_personas_cb_folks_persona_store_personas_changed, self, 0);
#line 168 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_tmp39_ = self->priv->_aggregator;
#line 168 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					_tmp40_ = self->priv->_individual;
#line 168 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
					folks_individual_aggregator_remove_individual (_tmp39_, _tmp40_, NULL, NULL);
#line 1230 "remove-persona.c"
				}
			}
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_object_unref0 (i);
#line 1235 "remove-persona.c"
		}
#line 146 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_i_it);
#line 1239 "remove-persona.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp41_ = NULL;
		GeeIterator* _tmp42_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp41_ = removed;
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp42_ = gee_iterable_iterator ((GeeIterable*) _tmp41_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_i_it = _tmp42_;
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		while (TRUE) {
#line 1253 "remove-persona.c"
			GeeIterator* _tmp43_ = NULL;
			gboolean _tmp44_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp45_ = NULL;
			gpointer _tmp46_ = NULL;
			FolksIndividual* _tmp47_ = NULL;
			FolksIndividual* _tmp48_ = NULL;
			const gchar* _tmp49_ = NULL;
			const gchar* _tmp50_ = NULL;
			const gchar* _tmp51_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp43_ = _i_it;
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp44_ = gee_iterator_next (_tmp43_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			if (!_tmp44_) {
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				break;
#line 1272 "remove-persona.c"
			}
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp45_ = _i_it;
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp46_ = gee_iterator_get (_tmp45_);
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			i = (FolksIndividual*) _tmp46_;
#line 175 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp47_ = i;
#line 175 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			if (_tmp47_ == NULL) {
#line 177 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				_g_object_unref0 (i);
#line 177 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				continue;
#line 1288 "remove-persona.c"
			}
#line 180 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp48_ = i;
#line 180 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp49_ = folks_individual_get_id (_tmp48_);
#line 180 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp50_ = _tmp49_;
#line 180 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_tmp51_ = self->priv->_individual_id;
#line 180 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			if (g_strcmp0 (_tmp50_, _tmp51_) == 0) {
#line 182 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
				self->priv->_individual_removed = TRUE;
#line 1302 "remove-persona.c"
			}
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
			_g_object_unref0 (i);
#line 1306 "remove-persona.c"
		}
#line 173 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_g_object_unref0 (_i_it);
#line 1310 "remove-persona.c"
	}
#line 140 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (removed);
#line 140 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (added);
#line 1316 "remove-persona.c"
}


static void _remove_persona_tests_personas_cb (RemovePersonaTests* self) {
	FolksPersonaStore* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 187 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_return_if_fail (self != NULL);
#line 189 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp0_ = self->priv->_pstore;
#line 189 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp1_ = folks_persona_store_get_personas (_tmp0_);
#line 189 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp2_ = _tmp1_;
#line 189 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp3_ = self->priv->_persona_id;
#line 189 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp4_ = gee_map_has_key (_tmp2_, _tmp3_);
#line 189 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	if (_tmp4_ == FALSE) {
#line 1340 "remove-persona.c"
		GMainLoop* _tmp5_ = NULL;
#line 191 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		self->priv->_persona_removed = TRUE;
#line 192 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		_tmp5_ = self->priv->_main_loop;
#line 192 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
		g_main_loop_quit (_tmp5_);
#line 1348 "remove-persona.c"
	}
}


static void remove_persona_tests_class_init (RemovePersonaTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	remove_persona_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_type_class_add_private (klass, sizeof (RemovePersonaTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	G_OBJECT_CLASS (klass)->finalize = remove_persona_tests_finalize;
#line 1360 "remove-persona.c"
}


static void remove_persona_tests_instance_init (RemovePersonaTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self->priv = REMOVE_PERSONA_TESTS_GET_PRIVATE (self);
#line 37 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self->priv->_added_persona = FALSE;
#line 1369 "remove-persona.c"
}


static void remove_persona_tests_finalize (GObject* obj) {
	RemovePersonaTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_REMOVE_PERSONA_TESTS, RemovePersonaTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_free0 (self->priv->_persona_fullname);
#line 33 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_free0 (self->priv->_individual_id);
#line 34 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (self->priv->_pstore);
#line 35 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_free0 (self->priv->_persona_id);
#line 36 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (self->priv->_individual);
#line 26 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	G_OBJECT_CLASS (remove_persona_tests_parent_class)->finalize (obj);
#line 1393 "remove-persona.c"
}


GType remove_persona_tests_get_type (void) {
	static volatile gsize remove_persona_tests_type_id__volatile = 0;
	if (g_once_init_enter (&remove_persona_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (RemovePersonaTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) remove_persona_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (RemovePersonaTests), 0, (GInstanceInitFunc) remove_persona_tests_instance_init, NULL };
		GType remove_persona_tests_type_id;
		remove_persona_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "RemovePersonaTests", &g_define_type_info, 0);
		g_once_init_leave (&remove_persona_tests_type_id__volatile, remove_persona_tests_type_id);
	}
	return remove_persona_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	RemovePersonaTests* tests = NULL;
	RemovePersonaTests* _tmp0_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_test_init (&args_length1, &args, NULL);
#line 201 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_tmp0_ = remove_persona_tests_new ();
#line 201 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	tests = _tmp0_;
#line 202 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 203 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	g_test_run ();
#line 204 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 206 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	result = 0;
#line 206 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	_g_object_unref0 (tests);
#line 206 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return result;
#line 1431 "remove-persona.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 197 "/opt/gnome3/source/folks/tests/tracker/remove-persona.vala"
	return _vala_main (argv, argc);
#line 1441 "remove-persona.c"
}



