/* dummy-lsw.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from dummy-lsw.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Alban Crequy <alban.crequy@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <libsocialweb-test.h>
#include <folks-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <libsocialweb-client/libsocialweb-client-hack-for-vala.h>
#include <gio/gio.h>
#include <gee.h>
#include <folks/folks-libsocialweb.h>


#define TYPE_DUMMY_LSW_TESTS (dummy_lsw_tests_get_type ())
#define DUMMY_LSW_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DUMMY_LSW_TESTS, DummyLswTests))
#define DUMMY_LSW_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DUMMY_LSW_TESTS, DummyLswTestsClass))
#define IS_DUMMY_LSW_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DUMMY_LSW_TESTS))
#define IS_DUMMY_LSW_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DUMMY_LSW_TESTS))
#define DUMMY_LSW_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DUMMY_LSW_TESTS, DummyLswTestsClass))

typedef struct _DummyLswTests DummyLswTests;
typedef struct _DummyLswTestsClass DummyLswTestsClass;
typedef struct _DummyLswTestsPrivate DummyLswTestsPrivate;
typedef struct _Block1Data Block1Data;
#define _sw_contact_unref0(var) ((var == NULL) ? NULL : (var = (sw_contact_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _libsocialweb_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (libsocialweb_test_backend_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block3Data Block3Data;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _DummyLswTests {
	LibsocialwebTestTestCase parent_instance;
	DummyLswTestsPrivate * priv;
};

struct _DummyLswTestsClass {
	LibsocialwebTestTestCaseClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	DummyLswTests* self;
	GMainLoop* main_loop;
	LibsocialwebTestLibsocialwebServiceTest* mysocialnetwork;
	FolksDisconnectionQueue* signals;
	gchar* view_path;
	FolksIndividual* i1;
	FolksIndividual* i2;
	SwContact* contact1;
};

struct _Block2Data {
	int _ref_count_;
	Block1Data * _data1_;
	char* view_path;
};

struct _Block3Data {
	int _ref_count_;
	DummyLswTests* self;
	gchar* path;
};


static gpointer dummy_lsw_tests_parent_class = NULL;

GType dummy_lsw_tests_get_type (void) G_GNUC_CONST;
enum  {
	DUMMY_LSW_TESTS_DUMMY_PROPERTY
};
DummyLswTests* dummy_lsw_tests_new (void);
DummyLswTests* dummy_lsw_tests_construct (GType object_type);
void dummy_lsw_tests_test_dummy_libsocialweb (DummyLswTests* self);
static void _dummy_lsw_tests_test_dummy_libsocialweb_folks_test_case_test_method (gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void _g_free0_ (gpointer var);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void ___lambda3_ (Block2Data* _data2_, GObject* v);
static void _vala_LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement_array_free (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* array, gint array_length);
static void ____lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda4_ (Block1Data* _data1_, const gchar* query, GHashTable* p, const gchar* path);
static void __lambda5_ (DummyLswTests* self, const gchar* path);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static gboolean __lambda6_ (Block3Data* _data3_);
static gboolean ___lambda6__gsource_func (gpointer self);
static void ___lambda5__libsocialweb_test_libsocialweb_contact_view_test_start_called (LibsocialwebTestLibsocialwebContactViewTest* _sender, const gchar* path, gpointer self);
static void ___lambda4__libsocialweb_test_libsocialweb_service_test_open_view_called (LibsocialwebTestLibsocialwebServiceTest* _sender, const gchar* query, GHashTable* p, const gchar* path, gpointer self);
static void __lambda7_ (Block1Data* _data1_, GeeMultiMap* changes);
static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda8_ (Block1Data* _data1_);
static gboolean ___lambda8__gsource_func (gpointer self);
static void __lambda9_ (Block1Data* _data1_);
static void ___lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda10_ (Block1Data* _data1_);
static gboolean ___lambda10__gsource_func (gpointer self);
static void __lambda11_ (Block1Data* _data1_, GeeMultiMap* changes);
static void ___lambda11__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
gint _vala_main (gchar** args, int args_length1);


static void _dummy_lsw_tests_test_dummy_libsocialweb_folks_test_case_test_method (gpointer self) {
#line 33 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	dummy_lsw_tests_test_dummy_libsocialweb ((DummyLswTests*) self);
#line 137 "dummy-lsw.c"
}


DummyLswTests* dummy_lsw_tests_construct (GType object_type) {
	DummyLswTests * self = NULL;
#line 31 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = (DummyLswTests*) libsocialweb_test_test_case_construct (object_type, "DummyLsw");
#line 33 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "dummy libsocialweb", _dummy_lsw_tests_test_dummy_libsocialweb_folks_test_case_test_method, self);
#line 29 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return self;
#line 149 "dummy-lsw.c"
}


DummyLswTests* dummy_lsw_tests_new (void) {
#line 29 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return dummy_lsw_tests_construct (TYPE_DUMMY_LSW_TESTS);
#line 156 "dummy-lsw.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return _data1_;
#line 165 "dummy-lsw.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 174 "dummy-lsw.c"
		DummyLswTests* self;
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		self = _data1_->self;
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_sw_contact_unref0 (_data1_->contact1);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_data1_->i2);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_data1_->i1);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_free0 (_data1_->view_path);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_data1_->signals);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_data1_->mysocialnetwork);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (self);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_slice_free (Block1Data, _data1_);
#line 196 "dummy-lsw.c"
	}
}


static gpointer _libsocialweb_test_backend_ref0 (gpointer self) {
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return self ? libsocialweb_test_backend_ref (self) : NULL;
#line 204 "dummy-lsw.c"
}


static void _g_free0_ (gpointer var) {
#line 42 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	var = (g_free (var), NULL);
#line 211 "dummy-lsw.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return _data2_;
#line 220 "dummy-lsw.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 229 "dummy-lsw.c"
		DummyLswTests* self;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		self = _data2_->_data1_->self;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_free0 (_data2_->view_path);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		block1_data_unref (_data2_->_data1_);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_data2_->_data1_ = NULL;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_slice_free (Block2Data, _data2_);
#line 241 "dummy-lsw.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 53 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return self ? g_object_ref (self) : NULL;
#line 249 "dummy-lsw.c"
}


static void _vala_LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement_array_free (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* array, gint array_length) {
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (array != NULL) {
#line 256 "dummy-lsw.c"
		int i;
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			libsocialweb_test_libsocialweb_contact_view_test_contacts_added_element_destroy (&array[i]);
#line 262 "dummy-lsw.c"
		}
	}
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_free (array);
#line 267 "dummy-lsw.c"
}


static void ___lambda3_ (Block2Data* _data2_, GObject* v) {
	Block1Data* _data1_;
	DummyLswTests* self;
	LibsocialwebTestContactView* view = NULL;
	GObject* _tmp0_ = NULL;
	LibsocialwebTestContactView* _tmp1_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp2_ = NULL;
	GeeHashMap* _tmp3_ = NULL;
	const char* _tmp4_ = NULL;
	gpointer _tmp5_ = NULL;
	LibsocialwebTestLibsocialwebContactViewTest* _tmp6_ = NULL;
	LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* _tmp7_ = NULL;
	LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	LibsocialwebTestLibsocialwebServiceTest* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	const char* _tmp11_ = NULL;
	gpointer _tmp12_ = NULL;
	LibsocialwebTestLibsocialwebContactViewTest* _tmp13_ = NULL;
	LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* _tmp14_ = NULL;
	LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement* _tmp15_ = NULL;
	gint _tmp15__length1 = 0;
	GMainLoop* _tmp16_ = NULL;
#line 51 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_ = _data2_->_data1_;
#line 51 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data1_->self;
#line 53 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = v;
#line 53 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW, LibsocialwebTestContactView));
#line 53 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	view = _tmp1_;
#line 55 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	libsocialweb_test_contact_view_Start (view, NULL, NULL);
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = _data1_->mysocialnetwork;
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp3_ = _tmp2_->contact_views;
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp4_ = _data2_->view_path;
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp5_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp3_, (const gchar*) _tmp4_);
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp6_ = (LibsocialwebTestLibsocialwebContactViewTest*) _tmp5_;
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp7_ = g_new0 (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement, 0);
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp8_ = _tmp7_;
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp8__length1 = 0;
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_signal_emit_by_name (_tmp6_, "contacts-added", _tmp8_, 0);
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp8_ = (_vala_LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement_array_free (_tmp8_, _tmp8__length1), NULL);
#line 56 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (_tmp6_);
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp9_ = _data1_->mysocialnetwork;
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp10_ = _tmp9_->contact_views;
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp11_ = _data2_->view_path;
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp12_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp10_, (const gchar*) _tmp11_);
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp13_ = (LibsocialwebTestLibsocialwebContactViewTest*) _tmp12_;
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp14_ = g_new0 (LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement, 0);
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp15_ = _tmp14_;
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp15__length1 = 0;
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_signal_emit_by_name (_tmp13_, "contacts-added", _tmp15_, 0);
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp15_ = (_vala_LibsocialwebTestLibsocialwebContactViewTestContactsAddedElement_array_free (_tmp15_, _tmp15__length1), NULL);
#line 59 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (_tmp13_);
#line 62 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp16_ = _data1_->main_loop;
#line 62 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_main_loop_quit (_tmp16_);
#line 51 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (view);
#line 356 "dummy-lsw.c"
}


static void ____lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 49 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	___lambda3_ (self, source_object);
#line 49 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	block2_data_unref (self);
#line 365 "dummy-lsw.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return _data3_;
#line 374 "dummy-lsw.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 383 "dummy-lsw.c"
		DummyLswTests* self;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		self = _data3_->self;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_free0 (_data3_->path);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (self);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_slice_free (Block3Data, _data3_);
#line 393 "dummy-lsw.c"
	}
}


static gboolean __lambda6_ (Block3Data* _data3_) {
	DummyLswTests* self;
	gboolean result = FALSE;
	gchar* text = NULL;
	gchar* _tmp0_ = NULL;
	GVariant* v = NULL;
	const gchar* _tmp1_ = NULL;
	GVariant* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data3_->self;
#line 87 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = g_strdup ("([('mysocialnetwork', 'id01', %x, " "{'id': ['id01'], 'name': ['Gargantua'], " "'X-foo': ['secret']}), " "('mysocialnetwork', 'id02', %x, " "{'id': ['id02'], 'name': ['Pantagruel']})],)");
#line 87 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	text = _tmp0_;
#line 92 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = text;
#line 92 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = g_variant_new_parsed (_tmp1_, 1300792578, 1300792579, NULL);
#line 92 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_variant_ref_sink (_tmp2_);
#line 92 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	v = _tmp2_;
#line 421 "dummy-lsw.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp3_ = NULL;
		GDBusConnection* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GVariant* _tmp6_ = NULL;
#line 95 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp3_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 95 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		conn = _tmp3_;
#line 95 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 95 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 436 "dummy-lsw.c"
				goto __catch1_g_io_error;
			}
			goto __catch1_g_error;
		}
#line 96 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp4_ = conn;
#line 96 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp5_ = _data3_->path;
#line 96 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp6_ = v;
#line 96 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_dbus_connection_emit_signal (_tmp4_, NULL, _tmp5_, "org.gnome.libsocialweb.ContactView", "ContactsAdded", _tmp6_, &_inner_error_);
#line 96 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 96 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (conn);
#line 96 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 455 "dummy-lsw.c"
				goto __catch1_g_io_error;
			}
			goto __catch1_g_error;
		}
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (conn);
#line 462 "dummy-lsw.c"
	}
	goto __finally1;
	__catch1_g_io_error:
	{
		GError* e = NULL;
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		e = _inner_error_;
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_inner_error_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_assert_not_reached ();
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_error_free0 (e);
#line 476 "dummy-lsw.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		e = _inner_error_;
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_inner_error_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_assert_not_reached ();
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_error_free0 (e);
#line 490 "dummy-lsw.c"
	}
	__finally1:
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (_inner_error_ != NULL) {
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_variant_unref0 (v);
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_free0 (text);
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_clear_error (&_inner_error_);
#line 93 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		return FALSE;
#line 505 "dummy-lsw.c"
	}
#line 108 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	result = FALSE;
#line 108 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_variant_unref0 (v);
#line 108 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_free0 (text);
#line 108 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return result;
#line 515 "dummy-lsw.c"
}


static gboolean ___lambda6__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda6_ (self);
#line 85 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return result;
#line 524 "dummy-lsw.c"
}


static void __lambda5_ (DummyLswTests* self, const gchar* path) {
	Block3Data* _data3_;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_return_if_fail (path != NULL);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data3_->_ref_count_ = 1;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data3_->self = g_object_ref (self);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = path;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_free0 (_data3_->path);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data3_->path = _tmp1_;
#line 84 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_debug ("dummy-lsw.vala:84: OpenViewCalled.connect");
#line 85 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda6__gsource_func, block3_data_ref (_data3_), block3_data_unref);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	block3_data_unref (_data3_);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data3_ = NULL;
#line 556 "dummy-lsw.c"
}


static void ___lambda5__libsocialweb_test_libsocialweb_contact_view_test_start_called (LibsocialwebTestLibsocialwebContactViewTest* _sender, const gchar* path, gpointer self) {
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	__lambda5_ ((DummyLswTests*) self, path);
#line 563 "dummy-lsw.c"
}


static void __lambda4_ (Block1Data* _data1_, const gchar* query, GHashTable* p, const gchar* path) {
	DummyLswTests* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	LibsocialwebTestLibsocialwebContactViewTest* view = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp2_ = NULL;
	GeeHashMap* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gpointer _tmp5_ = NULL;
	FolksDisconnectionQueue* _tmp6_ = NULL;
	gulong _tmp7_ = 0UL;
#line 76 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data1_->self;
#line 76 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_return_if_fail (query != NULL);
#line 76 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_return_if_fail (p != NULL);
#line 76 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_return_if_fail (path != NULL);
#line 78 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_debug ("dummy-lsw.vala:78: mysocialnetwork.OpenViewCalled.connect");
#line 79 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = path;
#line 79 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 79 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_free0 (_data1_->view_path);
#line 79 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->view_path = _tmp1_;
#line 80 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = _data1_->mysocialnetwork;
#line 80 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp3_ = _tmp2_->contact_views;
#line 80 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp4_ = path;
#line 80 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp5_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp3_, _tmp4_);
#line 80 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	view = (LibsocialwebTestLibsocialwebContactViewTest*) _tmp5_;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp6_ = _data1_->signals;
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp7_ = g_signal_connect_object (view, "start-called", (GCallback) ___lambda5__libsocialweb_test_libsocialweb_contact_view_test_start_called, self, 0);
#line 82 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_disconnection_queue_push (_tmp6_, (GObject*) view, _tmp7_);
#line 76 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (view);
#line 614 "dummy-lsw.c"
}


static void ___lambda4__libsocialweb_test_libsocialweb_service_test_open_view_called (LibsocialwebTestLibsocialwebServiceTest* _sender, const gchar* query, GHashTable* p, const gchar* path, gpointer self) {
#line 75 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	__lambda4_ (self, query, p, path);
#line 621 "dummy-lsw.c"
}


static void __lambda7_ (Block1Data* _data1_, GeeMultiMap* changes) {
	DummyLswTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GeeSet* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	GMainLoop* _tmp33_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data1_->self;
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_return_if_fail (changes != NULL);
#line 119 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = changes;
#line 119 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 119 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	added = _tmp1_;
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = changes;
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 120 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	removed = _tmp3_;
#line 122 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_debug ("dummy-lsw.vala:122: Aggregator got some data!");
#line 123 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp4_ = added;
#line 123 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp5_ = gee_collection_get_size (_tmp4_);
#line 123 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp6_ = _tmp5_;
#line 123 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_tmp6_ == 2, "added.size == 2");
#line 124 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp7_ = removed;
#line 124 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp8_ = gee_collection_get_size ((GeeCollection*) _tmp7_);
#line 124 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp9_ = _tmp8_;
#line 124 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_tmp9_ == 1, "removed.size == 1");
#line 674 "dummy-lsw.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp10_ = added;
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp11_ = gee_iterable_iterator ((GeeIterable*) _tmp10_);
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_i_it = _tmp11_;
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		while (TRUE) {
#line 687 "dummy-lsw.c"
			GeeIterator* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp14_ = NULL;
			gpointer _tmp15_ = NULL;
			gchar* nickname = NULL;
			FolksIndividual* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			const gchar* _tmp23_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp12_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp13_ = gee_iterator_next (_tmp12_);
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (!_tmp13_) {
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				break;
#line 708 "dummy-lsw.c"
			}
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp14_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp15_ = gee_iterator_get (_tmp14_);
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			i = (FolksIndividual*) _tmp15_;
#line 127 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp16_ = i;
#line 127 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp17_ = folks_name_details_get_nickname (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 127 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp18_ = _tmp17_;
#line 127 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp19_ = g_strdup (_tmp18_);
#line 127 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			nickname = _tmp19_;
#line 128 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp20_ = nickname;
#line 128 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (g_strcmp0 (_tmp20_, "Gargantua") == 0) {
#line 730 "dummy-lsw.c"
				FolksIndividual* _tmp21_ = NULL;
				FolksIndividual* _tmp22_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_tmp21_ = i;
#line 129 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_tmp22_ = _g_object_ref0 (_tmp21_);
#line 129 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_g_object_unref0 (_data1_->i1);
#line 129 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_data1_->i1 = _tmp22_;
#line 741 "dummy-lsw.c"
			}
#line 130 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp23_ = nickname;
#line 130 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (g_strcmp0 (_tmp23_, "Pantagruel") == 0) {
#line 747 "dummy-lsw.c"
				FolksIndividual* _tmp24_ = NULL;
				FolksIndividual* _tmp25_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_tmp24_ = i;
#line 131 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_tmp25_ = _g_object_ref0 (_tmp24_);
#line 131 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_g_object_unref0 (_data1_->i2);
#line 131 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				_data1_->i2 = _tmp25_;
#line 758 "dummy-lsw.c"
			}
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_free0 (nickname);
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (i);
#line 764 "dummy-lsw.c"
		}
#line 125 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_i_it);
#line 768 "dummy-lsw.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp26_ = NULL;
		GeeIterator* _tmp27_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp26_ = removed;
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_i_it = _tmp27_;
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		while (TRUE) {
#line 782 "dummy-lsw.c"
			GeeIterator* _tmp28_ = NULL;
			gboolean _tmp29_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp30_ = NULL;
			gpointer _tmp31_ = NULL;
			FolksIndividual* _tmp32_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp28_ = _i_it;
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp29_ = gee_iterator_next (_tmp28_);
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (!_tmp29_) {
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				break;
#line 797 "dummy-lsw.c"
			}
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp30_ = _i_it;
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp31_ = gee_iterator_get (_tmp30_);
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			i = (FolksIndividual*) _tmp31_;
#line 136 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp32_ = i;
#line 136 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_vala_assert (_tmp32_ == NULL, "i == null");
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (i);
#line 811 "dummy-lsw.c"
		}
#line 134 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_i_it);
#line 815 "dummy-lsw.c"
	}
#line 139 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp33_ = _data1_->main_loop;
#line 139 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_main_loop_quit (_tmp33_);
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (removed);
#line 117 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (added);
#line 825 "dummy-lsw.c"
}


static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 116 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	__lambda7_ (self, changes);
#line 832 "dummy-lsw.c"
}


static gpointer _sw_contact_ref0 (gpointer self) {
#line 161 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return self ? sw_contact_ref (self) : NULL;
#line 839 "dummy-lsw.c"
}


static gboolean __lambda8_ (Block1Data* _data1_) {
	DummyLswTests* self;
	gboolean result = FALSE;
	gchar* text = NULL;
	gchar* _tmp0_ = NULL;
	GVariant* v = NULL;
	const gchar* _tmp1_ = NULL;
	GVariant* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data1_->self;
#line 175 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = g_strdup ("([('mysocialnetwork', 'id01', %x, " "{'id': ['id01'], 'name': ['Rabelais'], " "'X-foo': ['secret'], 'X-bar': ['bar']})],)");
#line 175 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	text = _tmp0_;
#line 178 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = text;
#line 178 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = g_variant_new_parsed (_tmp1_, 1300792581, NULL);
#line 178 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_variant_ref_sink (_tmp2_);
#line 178 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	v = _tmp2_;
#line 866 "dummy-lsw.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp3_ = NULL;
		GDBusConnection* _tmp4_ = NULL;
		GVariant* _tmp5_ = NULL;
#line 181 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp3_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 181 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		conn = _tmp3_;
#line 181 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 181 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 880 "dummy-lsw.c"
				goto __catch2_g_io_error;
			}
			goto __catch2_g_error;
		}
#line 182 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp4_ = conn;
#line 182 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp5_ = v;
#line 182 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_dbus_connection_emit_signal (_tmp4_, NULL, _data1_->view_path, "org.gnome.libsocialweb.ContactView", "ContactsChanged", _tmp5_, &_inner_error_);
#line 182 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 182 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (conn);
#line 182 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 897 "dummy-lsw.c"
				goto __catch2_g_io_error;
			}
			goto __catch2_g_error;
		}
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (conn);
#line 904 "dummy-lsw.c"
	}
	goto __finally2;
	__catch2_g_io_error:
	{
		GError* e = NULL;
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		e = _inner_error_;
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_inner_error_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_assert_not_reached ();
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_error_free0 (e);
#line 918 "dummy-lsw.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		e = _inner_error_;
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_inner_error_ = NULL;
#line 192 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_assert_not_reached ();
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_error_free0 (e);
#line 932 "dummy-lsw.c"
	}
	__finally2:
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (_inner_error_ != NULL) {
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_variant_unref0 (v);
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_free0 (text);
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_clear_error (&_inner_error_);
#line 179 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		return FALSE;
#line 947 "dummy-lsw.c"
	}
#line 194 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	result = FALSE;
#line 194 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_variant_unref0 (v);
#line 194 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_free0 (text);
#line 194 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return result;
#line 957 "dummy-lsw.c"
}


static gboolean ___lambda8__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda8_ (self);
#line 173 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return result;
#line 966 "dummy-lsw.c"
}


static void __lambda9_ (Block1Data* _data1_) {
	DummyLswTests* self;
	gchar* nickname = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GMainLoop* _tmp6_ = NULL;
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data1_->self;
#line 199 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_debug ("dummy-lsw.vala:199: Aggregator changed some data!");
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = folks_name_details_get_nickname (G_TYPE_CHECK_INSTANCE_CAST (_data1_->i1, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = _tmp0_;
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 200 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	nickname = _tmp2_;
#line 201 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (g_strcmp0 (nickname, "Rabelais") == 0, "nickname == \"Rabelais\"");
#line 202 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp3_ = sw_contact_get_value (_data1_->contact1, "id");
#line 202 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (g_strcmp0 (_tmp3_, "id01") == 0, "contact1.get_value (\"id\") == \"id01\"");
#line 203 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp4_ = sw_contact_get_value (_data1_->contact1, "X-foo");
#line 203 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (g_strcmp0 (_tmp4_, "secret") == 0, "contact1.get_value (\"X-foo\") == \"secret\"");
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp5_ = sw_contact_get_value (_data1_->contact1, "X-bar");
#line 204 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (g_strcmp0 (_tmp5_, "bar") == 0, "contact1.get_value (\"X-bar\") == \"bar\"");
#line 205 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp6_ = _data1_->main_loop;
#line 205 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_main_loop_quit (_tmp6_);
#line 197 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_free0 (nickname);
#line 1012 "dummy-lsw.c"
}


static void ___lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 196 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	__lambda9_ (self);
#line 1019 "dummy-lsw.c"
}


static gboolean __lambda10_ (Block1Data* _data1_) {
	DummyLswTests* self;
	gboolean result = FALSE;
	gchar* text = NULL;
	gchar* _tmp0_ = NULL;
	GVariant* v = NULL;
	const gchar* _tmp1_ = NULL;
	GVariant* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data1_->self;
#line 214 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = g_strdup ("([('mysocialnetwork', 'id01'), " "('mysocialnetwork', 'id02')],)");
#line 214 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	text = _tmp0_;
#line 216 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = text;
#line 216 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = g_variant_new_parsed (_tmp1_, NULL);
#line 216 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_variant_ref_sink (_tmp2_);
#line 216 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	v = _tmp2_;
#line 1046 "dummy-lsw.c"
	{
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp3_ = NULL;
		GDBusConnection* _tmp4_ = NULL;
		GVariant* _tmp5_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp3_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 219 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		conn = _tmp3_;
#line 219 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 219 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1060 "dummy-lsw.c"
				goto __catch3_g_io_error;
			}
			goto __catch3_g_error;
		}
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp4_ = conn;
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp5_ = v;
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_dbus_connection_emit_signal (_tmp4_, NULL, _data1_->view_path, "org.gnome.libsocialweb.ContactView", "ContactsRemoved", _tmp5_, &_inner_error_);
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (conn);
#line 220 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1077 "dummy-lsw.c"
				goto __catch3_g_io_error;
			}
			goto __catch3_g_error;
		}
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (conn);
#line 1084 "dummy-lsw.c"
	}
	goto __finally3;
	__catch3_g_io_error:
	{
		GError* e = NULL;
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		e = _inner_error_;
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_inner_error_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_assert_not_reached ();
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_error_free0 (e);
#line 1098 "dummy-lsw.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e = NULL;
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		e = _inner_error_;
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_inner_error_ = NULL;
#line 230 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_assert_not_reached ();
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_error_free0 (e);
#line 1112 "dummy-lsw.c"
	}
	__finally3:
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (_inner_error_ != NULL) {
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_variant_unref0 (v);
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_free0 (text);
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_clear_error (&_inner_error_);
#line 217 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		return FALSE;
#line 1127 "dummy-lsw.c"
	}
#line 232 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	result = FALSE;
#line 232 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_variant_unref0 (v);
#line 232 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_free0 (text);
#line 232 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return result;
#line 1137 "dummy-lsw.c"
}


static gboolean ___lambda10__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda10_ (self);
#line 212 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return result;
#line 1146 "dummy-lsw.c"
}


static void __lambda11_ (Block1Data* _data1_, GeeMultiMap* changes) {
	DummyLswTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GeeSet* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	GMainLoop* _tmp29_ = NULL;
#line 235 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	self = _data1_->self;
#line 235 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_return_if_fail (changes != NULL);
#line 237 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = changes;
#line 237 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 237 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	added = _tmp1_;
#line 238 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = changes;
#line 238 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 238 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	removed = _tmp3_;
#line 240 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_debug ("dummy-lsw.vala:240: Aggregator deleted some data!");
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp4_ = added;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp5_ = gee_collection_get_size (_tmp4_);
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp6_ = _tmp5_;
#line 241 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_tmp6_ == 2, "added.size == 2");
#line 242 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp7_ = removed;
#line 242 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp8_ = gee_collection_get_size ((GeeCollection*) _tmp7_);
#line 242 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp9_ = _tmp8_;
#line 242 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_tmp9_ == 2, "removed.size == 2");
#line 1199 "dummy-lsw.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp10_ = removed;
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp11_ = gee_iterable_iterator ((GeeIterable*) _tmp10_);
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_i_it = _tmp11_;
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		while (TRUE) {
#line 1212 "dummy-lsw.c"
			GeeIterator* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp14_ = NULL;
			gpointer _tmp15_ = NULL;
			FolksIndividual* _tmp16_ = NULL;
			gchar* nickname = NULL;
			FolksIndividual* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp12_ = _i_it;
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp13_ = gee_iterator_next (_tmp12_);
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (!_tmp13_) {
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				break;
#line 1233 "dummy-lsw.c"
			}
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp14_ = _i_it;
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp15_ = gee_iterator_get (_tmp14_);
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			i = (FolksIndividual*) _tmp15_;
#line 246 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp16_ = i;
#line 246 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_vala_assert (_tmp16_ != NULL, "i != null");
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp17_ = i;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp18_ = folks_name_details_get_nickname (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp19_ = _tmp18_;
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp20_ = g_strdup (_tmp19_);
#line 248 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			nickname = _tmp20_;
#line 249 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp21_ = nickname;
#line 249 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			g_debug ("dummy-lsw.vala:249: deleted nickname: %s", _tmp21_);
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_free0 (nickname);
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (i);
#line 1263 "dummy-lsw.c"
		}
#line 244 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_i_it);
#line 1267 "dummy-lsw.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp22_ = NULL;
		GeeIterator* _tmp23_ = NULL;
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp22_ = added;
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_i_it = _tmp23_;
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		while (TRUE) {
#line 1281 "dummy-lsw.c"
			GeeIterator* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp26_ = NULL;
			gpointer _tmp27_ = NULL;
			FolksIndividual* _tmp28_ = NULL;
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp24_ = _i_it;
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp25_ = gee_iterator_next (_tmp24_);
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (!_tmp25_) {
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				break;
#line 1296 "dummy-lsw.c"
			}
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp26_ = _i_it;
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp27_ = gee_iterator_get (_tmp26_);
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			i = (FolksIndividual*) _tmp27_;
#line 254 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp28_ = i;
#line 254 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_vala_assert (_tmp28_ == NULL, "i == null");
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (i);
#line 1310 "dummy-lsw.c"
		}
#line 252 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_i_it);
#line 1314 "dummy-lsw.c"
	}
#line 257 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp29_ = _data1_->main_loop;
#line 257 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_main_loop_quit (_tmp29_);
#line 235 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (removed);
#line 235 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (added);
#line 1324 "dummy-lsw.c"
}


static void ___lambda11__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 235 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	__lambda11_ (self, changes);
#line 1331 "dummy-lsw.c"
}


void dummy_lsw_tests_test_dummy_libsocialweb (DummyLswTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_ = NULL;
	LibsocialwebTestBackend* lsw_backend = NULL;
	LibsocialwebTestBackend* _tmp1_ = NULL;
	LibsocialwebTestBackend* _tmp2_ = NULL;
	LibsocialwebTestBackend* _tmp3_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp4_ = NULL;
	GHashTable* p = NULL;
	GHashTable* _tmp5_ = NULL;
	FolksDisconnectionQueue* _tmp6_ = NULL;
	GMainLoop* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	FolksDisconnectionQueue* _tmp15_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp16_ = NULL;
	LibsocialwebTestLibsocialwebServiceTest* _tmp17_ = NULL;
	gulong _tmp18_ = 0UL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp19_ = NULL;
	gulong handler_id = 0UL;
	gulong _tmp20_ = 0UL;
	GMainLoop* _tmp21_ = NULL;
	gulong _tmp22_ = 0UL;
	FolksPersona* persona1 = NULL;
	FolksPersona* persona2 = NULL;
	FolksPersona* _tmp37_ = NULL;
	FolksPersona* _tmp38_ = NULL;
	FolksPersona* _tmp39_ = NULL;
	SwContact* _tmp40_ = NULL;
	SwContact* _tmp41_ = NULL;
	SwContact* _tmp42_ = NULL;
	SwContact* contact2 = NULL;
	FolksPersona* _tmp43_ = NULL;
	SwContact* _tmp44_ = NULL;
	SwContact* _tmp45_ = NULL;
	SwContact* _tmp46_ = NULL;
	const gchar* _tmp47_ = NULL;
	const gchar* _tmp48_ = NULL;
	const gchar* _tmp49_ = NULL;
	const gchar* _tmp50_ = NULL;
	const gchar* _tmp51_ = NULL;
	gulong _tmp52_ = 0UL;
	GMainLoop* _tmp53_ = NULL;
	gulong _tmp54_ = 0UL;
	gulong _tmp55_ = 0UL;
	GMainLoop* _tmp56_ = NULL;
	gulong _tmp57_ = 0UL;
	GError * _inner_error_ = NULL;
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_return_if_fail (self != NULL);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->_ref_count_ = 1;
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->self = g_object_ref (self);
#line 38 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 38 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->main_loop = _tmp0_;
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp1_ = ((LibsocialwebTestTestCase*) self)->lsw_backend;
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp2_ = _libsocialweb_test_backend_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackend));
#line 40 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	lsw_backend = _tmp2_;
#line 41 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp3_ = lsw_backend;
#line 41 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp4_ = libsocialweb_test_backend_add_service (_tmp3_, "mysocialnetwork");
#line 41 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->mysocialnetwork = _tmp4_;
#line 42 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp5_ = g_hash_table_new_full (NULL, NULL, _g_free0_, _g_free0_);
#line 42 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	p = _tmp5_;
#line 43 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp6_ = folks_disconnection_queue_new ();
#line 43 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->signals = _tmp6_;
#line 1415 "dummy-lsw.c"
	{
		Block2Data* _data2_;
		LibsocialwebTestLibsocialwebServiceTest* _tmp7_ = NULL;
		GHashTable* _tmp8_ = NULL;
		char* _tmp9_ = NULL;
		GDBusConnection* conn = NULL;
		GDBusConnection* _tmp10_ = NULL;
		GDBusConnection* _tmp11_ = NULL;
		const char* _tmp12_ = NULL;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_data2_ = g_slice_new0 (Block2Data);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_data2_->_ref_count_ = 1;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_data2_->_data1_ = block1_data_ref (_data1_);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp7_ = _data1_->mysocialnetwork;
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp8_ = p;
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp9_ = libsocialweb_test_libsocialweb_service_query_test_OpenView ((LibsocialwebTestLibsocialwebServiceQueryTest*) _tmp7_, "feed", _tmp8_, &_inner_error_);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_data2_->view_path = _tmp9_;
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			block2_data_unref (_data2_);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_data2_ = NULL;
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1447 "dummy-lsw.c"
				goto __catch0_g_io_error;
			}
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			block2_data_unref (_data2_);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_data2_ = NULL;
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_hash_table_unref0 (p);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_libsocialweb_test_backend_unref0 (lsw_backend);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			block1_data_unref (_data1_);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_data1_ = NULL;
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			g_clear_error (&_inner_error_);
#line 47 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			return;
#line 1468 "dummy-lsw.c"
		}
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp10_ = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &_inner_error_);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		conn = _tmp10_;
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		if (_inner_error_ != NULL) {
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			block2_data_unref (_data2_);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_data2_ = NULL;
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1482 "dummy-lsw.c"
				goto __catch0_g_io_error;
			}
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			block2_data_unref (_data2_);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_data2_ = NULL;
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_hash_table_unref0 (p);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_libsocialweb_test_backend_unref0 (lsw_backend);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			block1_data_unref (_data1_);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_data1_ = NULL;
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			g_clear_error (&_inner_error_);
#line 48 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			return;
#line 1503 "dummy-lsw.c"
		}
#line 49 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp11_ = conn;
#line 49 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp12_ = _data2_->view_path;
#line 49 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_async_initable_new_async (LIBSOCIALWEB_TEST_TYPE_CONTACT_VIEW_PROXY, 0, NULL, ____lambda3__gasync_ready_callback, block2_data_ref (_data2_), "g-flags", 0, "g-name", "org.gnome.libsocialweb", "g-connection", _tmp11_, "g-object-path", (const gchar*) _tmp12_, "g-interface-name", "org.gnome.libsocialweb.ContactView", NULL);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (conn);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		block2_data_unref (_data2_);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_data2_ = NULL;
#line 1517 "dummy-lsw.c"
	}
	goto __finally0;
	__catch0_g_io_error:
	{
		GError* e = NULL;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		e = _inner_error_;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_inner_error_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_assert_not_reached ();
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_error_free0 (e);
#line 1531 "dummy-lsw.c"
	}
	__finally0:
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	if (_inner_error_ != NULL) {
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_hash_table_unref0 (p);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_libsocialweb_test_backend_unref0 (lsw_backend);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		block1_data_unref (_data1_);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_data1_ = NULL;
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		g_clear_error (&_inner_error_);
#line 45 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		return;
#line 1550 "dummy-lsw.c"
	}
#line 70 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp13_ = _data1_->main_loop;
#line 70 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_test_utils_loop_run_with_timeout (_tmp13_, 5);
#line 74 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp14_ = g_strdup ("");
#line 74 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->view_path = _tmp14_;
#line 75 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp15_ = _data1_->signals;
#line 75 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp16_ = _data1_->mysocialnetwork;
#line 75 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp17_ = _data1_->mysocialnetwork;
#line 75 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp18_ = g_signal_connect_data (_tmp17_, "open-view-called", (GCallback) ___lambda4__libsocialweb_test_libsocialweb_service_test_open_view_called, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 75 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_disconnection_queue_push (_tmp15_, (GObject*) _tmp16_, _tmp18_);
#line 113 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp19_ = folks_individual_aggregator_dup ();
#line 113 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	aggregator = _tmp19_;
#line 114 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->i1 = NULL;
#line 115 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->i2 = NULL;
#line 116 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp20_ = g_signal_connect_data (aggregator, "individuals-changed-detailed", (GCallback) ___lambda7__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 116 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	handler_id = _tmp20_;
#line 141 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_individual_aggregator_prepare (aggregator, NULL, NULL);
#line 143 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp21_ = _data1_->main_loop;
#line 143 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_test_utils_loop_run_with_timeout (_tmp21_, 5);
#line 144 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp22_ = handler_id;
#line 144 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_signal_handler_disconnect ((GObject*) aggregator, _tmp22_);
#line 145 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_data1_->i1 != NULL, "i1 != null");
#line 146 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_data1_->i2 != NULL, "i2 != null");
#line 147 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	persona1 = NULL;
#line 148 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	persona2 = NULL;
#line 1600 "dummy-lsw.c"
	{
		GeeIterator* _p1_it = NULL;
		GeeSet* _tmp23_ = NULL;
		GeeSet* _tmp24_ = NULL;
		GeeIterator* _tmp25_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp23_ = folks_individual_get_personas (_data1_->i1);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp24_ = _tmp23_;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp25_ = gee_iterable_iterator ((GeeIterable*) _tmp24_);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_p1_it = _tmp25_;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		while (TRUE) {
#line 1616 "dummy-lsw.c"
			gboolean _tmp26_ = FALSE;
			FolksPersona* p1 = NULL;
			gpointer _tmp27_ = NULL;
			FolksPersona* _tmp28_ = NULL;
			FolksPersona* _tmp29_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp26_ = gee_iterator_next (_p1_it);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (!_tmp26_) {
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				break;
#line 1628 "dummy-lsw.c"
			}
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp27_ = gee_iterator_get (_p1_it);
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			p1 = (FolksPersona*) _tmp27_;
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp28_ = p1;
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp29_ = _g_object_ref0 (_tmp28_);
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (persona1);
#line 151 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			persona1 = _tmp29_;
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (p1);
#line 152 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			break;
#line 1646 "dummy-lsw.c"
		}
#line 149 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_p1_it);
#line 1650 "dummy-lsw.c"
	}
	{
		GeeIterator* _p2_it = NULL;
		GeeSet* _tmp30_ = NULL;
		GeeSet* _tmp31_ = NULL;
		GeeIterator* _tmp32_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp30_ = folks_individual_get_personas (_data1_->i2);
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp31_ = _tmp30_;
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_tmp32_ = gee_iterable_iterator ((GeeIterable*) _tmp31_);
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_p2_it = _tmp32_;
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		while (TRUE) {
#line 1667 "dummy-lsw.c"
			gboolean _tmp33_ = FALSE;
			FolksPersona* p2 = NULL;
			gpointer _tmp34_ = NULL;
			FolksPersona* _tmp35_ = NULL;
			FolksPersona* _tmp36_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp33_ = gee_iterator_next (_p2_it);
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			if (!_tmp33_) {
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
				break;
#line 1679 "dummy-lsw.c"
			}
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp34_ = gee_iterator_get (_p2_it);
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			p2 = (FolksPersona*) _tmp34_;
#line 156 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp35_ = p2;
#line 156 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_tmp36_ = _g_object_ref0 (_tmp35_);
#line 156 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (persona2);
#line 156 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			persona2 = _tmp36_;
#line 157 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			_g_object_unref0 (p2);
#line 157 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
			break;
#line 1697 "dummy-lsw.c"
		}
#line 154 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
		_g_object_unref0 (_p2_it);
#line 1701 "dummy-lsw.c"
	}
#line 159 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp37_ = persona1;
#line 159 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, SWF_TYPE_PERSONA), "persona1 is Swf.Persona");
#line 160 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp38_ = persona2;
#line 160 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, SWF_TYPE_PERSONA), "persona2 is Swf.Persona");
#line 161 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp39_ = persona1;
#line 161 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp40_ = swf_persona_get_lsw_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, SWF_TYPE_PERSONA, SwfPersona));
#line 161 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp41_ = _tmp40_;
#line 161 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp42_ = _sw_contact_ref0 (_tmp41_);
#line 161 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_->contact1 = _tmp42_;
#line 162 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp43_ = persona2;
#line 162 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp44_ = swf_persona_get_lsw_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, SWF_TYPE_PERSONA, SwfPersona));
#line 162 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp45_ = _tmp44_;
#line 162 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp46_ = _sw_contact_ref0 (_tmp45_);
#line 162 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	contact2 = _tmp46_;
#line 163 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_data1_->contact1 != NULL, "contact1 != null");
#line 164 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (contact2 != NULL, "contact2 != null");
#line 165 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp47_ = sw_contact_get_value (_data1_->contact1, "id");
#line 165 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (g_strcmp0 (_tmp47_, "id01") == 0, "contact1.get_value (\"id\") == \"id01\"");
#line 166 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp48_ = sw_contact_get_value (_data1_->contact1, "X-foo");
#line 166 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (g_strcmp0 (_tmp48_, "secret") == 0, "contact1.get_value (\"X-foo\") == \"secret\"");
#line 167 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp49_ = sw_contact_get_value (_data1_->contact1, "X-bar");
#line 167 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_tmp49_ == NULL, "contact1.get_value (\"X-bar\") == null");
#line 168 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp50_ = sw_contact_get_value (contact2, "id");
#line 168 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (g_strcmp0 (_tmp50_, "id02") == 0, "contact2.get_value (\"id\") == \"id02\"");
#line 169 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp51_ = sw_contact_get_value (contact2, "X-foo");
#line 169 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_vala_assert (_tmp51_ == NULL, "contact2.get_value (\"X-foo\") == null");
#line 173 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda8__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 196 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp52_ = g_signal_connect_data ((GObject*) _data1_->i1, "notify::nickname", (GCallback) ___lambda9__g_object_notify, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 196 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	handler_id = _tmp52_;
#line 208 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp53_ = _data1_->main_loop;
#line 208 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_test_utils_loop_run_with_timeout (_tmp53_, 5);
#line 209 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp54_ = handler_id;
#line 209 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_signal_handler_disconnect ((GObject*) _data1_->i1, _tmp54_);
#line 212 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda10__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 235 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp55_ = g_signal_connect_data (aggregator, "individuals-changed-detailed", (GCallback) ___lambda11__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 235 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	handler_id = _tmp55_;
#line 260 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp56_ = _data1_->main_loop;
#line 260 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_test_utils_loop_run_with_timeout (_tmp56_, 5);
#line 261 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp57_ = handler_id;
#line 261 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_signal_handler_disconnect ((GObject*) aggregator, _tmp57_);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_sw_contact_unref0 (contact2);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (persona2);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (persona1);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (aggregator);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_hash_table_unref0 (p);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_libsocialweb_test_backend_unref0 (lsw_backend);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	block1_data_unref (_data1_);
#line 36 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_data1_ = NULL;
#line 1799 "dummy-lsw.c"
}


static void dummy_lsw_tests_class_init (DummyLswTestsClass * klass) {
#line 27 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	dummy_lsw_tests_parent_class = g_type_class_peek_parent (klass);
#line 1806 "dummy-lsw.c"
}


static void dummy_lsw_tests_instance_init (DummyLswTests * self) {
}


GType dummy_lsw_tests_get_type (void) {
	static volatile gsize dummy_lsw_tests_type_id__volatile = 0;
	if (g_once_init_enter (&dummy_lsw_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DummyLswTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dummy_lsw_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DummyLswTests), 0, (GInstanceInitFunc) dummy_lsw_tests_instance_init, NULL };
		GType dummy_lsw_tests_type_id;
		dummy_lsw_tests_type_id = g_type_register_static (LIBSOCIALWEB_TEST_TYPE_TEST_CASE, "DummyLswTests", &g_define_type_info, 0);
		g_once_init_leave (&dummy_lsw_tests_type_id__volatile, dummy_lsw_tests_type_id);
	}
	return dummy_lsw_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	DummyLswTests* tests = NULL;
	DummyLswTests* _tmp0_ = NULL;
#line 267 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_test_init (&args_length1, &args, NULL);
#line 269 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_tmp0_ = dummy_lsw_tests_new ();
#line 269 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	tests = _tmp0_;
#line 270 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 271 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	g_test_run ();
#line 272 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 274 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	result = 0;
#line 274 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	_g_object_unref0 (tests);
#line 274 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return result;
#line 1848 "dummy-lsw.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 265 "/opt/gnome3/source/folks/tests/libsocialweb/dummy-lsw.vala"
	return _vala_main (argv, argc);
#line 1858 "dummy-lsw.c"
}



