/* individual-retrieval.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from individual-retrieval.vala, do not modify */

/*
 * Copyright (C) 2011, 2013 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Renato Araujo Oliveira Filho <renato@canonical.com>
 *          Philip Withnall <philip.withnall@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <dummy-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <folks/folks-dummy.h>
#include <folks/folks.h>
#include <gee.h>


#define TYPE_INDIVIDUAL_RETRIEVAL_TESTS (individual_retrieval_tests_get_type ())
#define INDIVIDUAL_RETRIEVAL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTests))
#define INDIVIDUAL_RETRIEVAL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsClass))
#define IS_INDIVIDUAL_RETRIEVAL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS))
#define IS_INDIVIDUAL_RETRIEVAL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INDIVIDUAL_RETRIEVAL_TESTS))
#define INDIVIDUAL_RETRIEVAL_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsClass))

typedef struct _IndividualRetrievalTests IndividualRetrievalTests;
typedef struct _IndividualRetrievalTestsClass IndividualRetrievalTestsClass;
typedef struct _IndividualRetrievalTestsPrivate IndividualRetrievalTestsPrivate;

#define INDIVIDUAL_RETRIEVAL_TESTS_TYPE_PERSONA_INFO (individual_retrieval_tests_persona_info_get_type ())
typedef struct _IndividualRetrievalTestsPersonaInfo IndividualRetrievalTestsPersonaInfo;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _IndividualRetrievalTestsCreatePersonaFromInfoData IndividualRetrievalTestsCreatePersonaFromInfoData;
typedef struct _IndividualRetrievalTestsRegisterPersonasData IndividualRetrievalTestsRegisterPersonasData;
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _IndividualRetrievalTests {
	DummyTestTestCase parent_instance;
	IndividualRetrievalTestsPrivate * priv;
};

struct _IndividualRetrievalTestsClass {
	DummyTestTestCaseClass parent_class;
};

struct _IndividualRetrievalTestsPersonaInfo {
	const gchar* contact_id;
	const gchar* full_name;
	const gchar* nickname;
	const gchar* home_email_address;
	const gchar* jabber_im_address;
	const gchar* yahoo_im_address;
};

struct _IndividualRetrievalTestsCreatePersonaFromInfoData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksDummyPersonaStore* store;
	IndividualRetrievalTestsPersonaInfo info;
	FolksPersona* result;
	FolksDummyFullPersona* p;
	FolksDummyPersonaStore* _tmp0_;
	IndividualRetrievalTestsPersonaInfo _tmp1_;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	FolksDummyFullPersona* _tmp5_;
	FolksDummyFullPersona* _tmp6_;
	FolksDummyFullPersona* _tmp7_;
	IndividualRetrievalTestsPersonaInfo _tmp8_;
	const gchar* _tmp9_;
	FolksDummyFullPersona* _tmp10_;
	IndividualRetrievalTestsPersonaInfo _tmp11_;
	const gchar* _tmp12_;
	GeeHashSet* emails;
	GeeHashSet* _tmp13_;
	FolksEmailFieldDetails* email_1;
	IndividualRetrievalTestsPersonaInfo _tmp14_;
	const gchar* _tmp15_;
	FolksEmailFieldDetails* _tmp16_;
	FolksEmailFieldDetails* _tmp17_;
	GeeHashSet* _tmp18_;
	FolksEmailFieldDetails* _tmp19_;
	FolksDummyFullPersona* _tmp20_;
	GeeHashSet* _tmp21_;
	GeeHashMultiMap* im_fds;
	GeeHashMultiMap* _tmp22_;
	GeeHashMultiMap* _tmp23_;
	IndividualRetrievalTestsPersonaInfo _tmp24_;
	const gchar* _tmp25_;
	FolksImFieldDetails* _tmp26_;
	FolksImFieldDetails* _tmp27_;
	GeeHashMultiMap* _tmp28_;
	IndividualRetrievalTestsPersonaInfo _tmp29_;
	const gchar* _tmp30_;
	FolksImFieldDetails* _tmp31_;
	FolksImFieldDetails* _tmp32_;
	FolksDummyFullPersona* _tmp33_;
	GeeHashMultiMap* _tmp34_;
	GError* e;
	const gchar* _tmp35_;
	GError * _inner_error_;
};

struct _IndividualRetrievalTestsRegisterPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	IndividualRetrievalTests* self;
	GeeHashSet* personas;
	GeeHashSet* _tmp0_;
	IndividualRetrievalTestsPersonaInfo* info_collection;
	gint info_collection_length1;
	gint _info_collection_size_;
	gint info_it;
	IndividualRetrievalTestsPersonaInfo info;
	FolksPersona* p;
	FolksDummyPersonaStore* _tmp1_;
	IndividualRetrievalTestsPersonaInfo _tmp2_;
	FolksPersona* _tmp3_;
	GeeHashSet* _tmp4_;
	FolksPersona* _tmp5_;
	FolksDummyPersonaStore* _tmp6_;
	GeeHashSet* _tmp7_;
};

struct _Block1Data {
	int _ref_count_;
	IndividualRetrievalTests* self;
	GMainLoop* main_loop;
	GeeHashSet* expected_individuals;
	FolksIndividualAggregator* aggregator;
};


static gpointer individual_retrieval_tests_parent_class = NULL;

GType individual_retrieval_tests_get_type (void) G_GNUC_CONST;
enum  {
	INDIVIDUAL_RETRIEVAL_TESTS_DUMMY_PROPERTY
};
static GType individual_retrieval_tests_persona_info_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static IndividualRetrievalTestsPersonaInfo* individual_retrieval_tests_persona_info_dup (const IndividualRetrievalTestsPersonaInfo* self);
static void individual_retrieval_tests_persona_info_free (IndividualRetrievalTestsPersonaInfo* self);
IndividualRetrievalTests* individual_retrieval_tests_new (void);
IndividualRetrievalTests* individual_retrieval_tests_construct (GType object_type);
void individual_retrieval_tests_test_aggregator (IndividualRetrievalTests* self);
static void _individual_retrieval_tests_test_aggregator_folks_test_case_test_method (gpointer self);
static void _individual_retrieval_tests_create_persona_from_info_data_free (gpointer _data);
static void _individual_retrieval_tests_create_persona_from_info (FolksDummyPersonaStore* store, IndividualRetrievalTestsPersonaInfo* info, GAsyncReadyCallback _callback_, gpointer _user_data_);
static FolksPersona* _individual_retrieval_tests_create_persona_from_info_finish (GAsyncResult* _res_);
static gboolean _individual_retrieval_tests_create_persona_from_info_co (IndividualRetrievalTestsCreatePersonaFromInfoData* _data_);
static void _individual_retrieval_tests_create_persona_from_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _individual_retrieval_tests_register_personas_data_free (gpointer _data);
static void _individual_retrieval_tests_register_personas (IndividualRetrievalTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _individual_retrieval_tests_register_personas_finish (IndividualRetrievalTests* self, GAsyncResult* _res_);
static gboolean _individual_retrieval_tests_register_personas_co (IndividualRetrievalTestsRegisterPersonasData* _data_);
static void _individual_retrieval_tests_register_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes);
static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda4_ (Block1Data* _data1_, GObject* s, GAsyncResult* r);
static void ___lambda5_ (IndividualRetrievalTests* self, GObject* s, GAsyncResult* r);
static void ____lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const IndividualRetrievalTestsPersonaInfo INDIVIDUAL_RETRIEVAL_TESTS__persona_info[2] = {{"dummy@2", "Rodrigo A", "kiko", "rodrigo@gmail.com", "rodrigo@jabber.com", "rodrigo@yahoo.com"}, {"dummy@1", "Renato F", "renatof", "renato@gmail.com", "renato@jabber.com", "renato@yahoo.com"}};

static void _individual_retrieval_tests_test_aggregator_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	individual_retrieval_tests_test_aggregator ((IndividualRetrievalTests*) self);
#line 203 "individual-retrieval.c"
}


IndividualRetrievalTests* individual_retrieval_tests_construct (GType object_type) {
	IndividualRetrievalTests * self = NULL;
#line 30 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	self = (IndividualRetrievalTests*) dummy_test_test_case_construct (object_type, "IndividualRetrieval");
#line 32 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "dummy individuals", _individual_retrieval_tests_test_aggregator_folks_test_case_test_method, self);
#line 28 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return self;
#line 215 "individual-retrieval.c"
}


IndividualRetrievalTests* individual_retrieval_tests_new (void) {
#line 28 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return individual_retrieval_tests_construct (TYPE_INDIVIDUAL_RETRIEVAL_TESTS);
#line 222 "individual-retrieval.c"
}


static void _individual_retrieval_tests_create_persona_from_info_data_free (gpointer _data) {
	IndividualRetrievalTestsCreatePersonaFromInfoData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (_data_->store);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (_data_->result);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_slice_free (IndividualRetrievalTestsCreatePersonaFromInfoData, _data_);
#line 235 "individual-retrieval.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return self ? g_object_ref (self) : NULL;
#line 242 "individual-retrieval.c"
}


static void _individual_retrieval_tests_create_persona_from_info (FolksDummyPersonaStore* store, IndividualRetrievalTestsPersonaInfo* info, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	IndividualRetrievalTestsCreatePersonaFromInfoData* _data_;
	FolksDummyPersonaStore* _tmp0_ = NULL;
	FolksDummyPersonaStore* _tmp1_ = NULL;
	IndividualRetrievalTestsPersonaInfo _tmp2_ = {0};
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_ = g_slice_new0 (IndividualRetrievalTestsCreatePersonaFromInfoData);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, _individual_retrieval_tests_create_persona_from_info);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _individual_retrieval_tests_create_persona_from_info_data_free);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp0_ = store;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (_data_->store);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->store = _tmp1_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp2_ = *info;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->info = _tmp2_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_individual_retrieval_tests_create_persona_from_info_co (_data_);
#line 271 "individual-retrieval.c"
}


static FolksPersona* _individual_retrieval_tests_create_persona_from_info_finish (GAsyncResult* _res_) {
	FolksPersona* result;
	IndividualRetrievalTestsCreatePersonaFromInfoData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	result = _data_->result;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->result = NULL;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return result;
#line 286 "individual-retrieval.c"
}


static void _individual_retrieval_tests_create_persona_from_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	IndividualRetrievalTestsCreatePersonaFromInfoData* _data_;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_ = _user_data_;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_source_object_ = source_object;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_res_ = _res_;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_individual_retrieval_tests_create_persona_from_info_co (_data_);
#line 300 "individual-retrieval.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 65 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return result;
#line 309 "individual-retrieval.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 65 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return result;
#line 318 "individual-retrieval.c"
}


static gboolean _individual_retrieval_tests_create_persona_from_info_co (IndividualRetrievalTestsCreatePersonaFromInfoData* _data_) {
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	switch (_data_->_state_) {
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		case 0:
#line 327 "individual-retrieval.c"
		goto _state_0;
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		case 1:
#line 331 "individual-retrieval.c"
		goto _state_1;
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		case 2:
#line 335 "individual-retrieval.c"
		goto _state_2;
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		case 3:
#line 339 "individual-retrieval.c"
		goto _state_3;
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		case 4:
#line 343 "individual-retrieval.c"
		goto _state_4;
		default:
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_assert_not_reached ();
#line 348 "individual-retrieval.c"
	}
	_state_0:
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp0_ = NULL;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp0_ = _data_->store;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	memset (&_data_->_tmp1_, 0, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp1_ = _data_->info;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp2_ = NULL;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp2_ = _data_->_tmp1_.contact_id;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp3_ = NULL;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp3_ = g_new0 (gchar*, 0 + 1);
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp4_ = NULL;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp4__length1 = 0;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp4__length1 = 0;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp5_ = NULL;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp5_ = folks_dummy_full_persona_new (_data_->_tmp0_, _data_->_tmp2_, FALSE, _data_->_tmp4_, 0);
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp6_ = NULL;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp4_ = (_vala_array_free (_data_->_tmp4_, _data_->_tmp4__length1, (GDestroyNotify) g_free), NULL);
#line 56 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->p = _data_->_tmp6_;
#line 387 "individual-retrieval.c"
	{
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp7_ = NULL;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp7_ = _data_->p;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		memset (&_data_->_tmp8_, 0, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp8_ = _data_->info;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp9_ = NULL;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp9_ = _data_->_tmp8_.full_name;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_state_ = 1;
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_name_details_change_full_name ((FolksNameDetails*) _data_->_tmp7_, _data_->_tmp9_, _individual_retrieval_tests_create_persona_from_info_ready, _data_);
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		return FALSE;
#line 407 "individual-retrieval.c"
		_state_1:
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_name_details_change_full_name_finish ((FolksNameDetails*) _data_->_tmp7_, _data_->_res_, &_data_->_inner_error_);
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		if (_data_->_inner_error_ != NULL) {
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 415 "individual-retrieval.c"
				goto __catch0_folks_property_error;
			}
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->p);
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_clear_error (&_data_->_inner_error_);
#line 61 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			return FALSE;
#line 426 "individual-retrieval.c"
		}
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp10_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp10_ = _data_->p;
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		memset (&_data_->_tmp11_, 0, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp11_ = _data_->info;
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp12_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp12_ = _data_->_tmp11_.nickname;
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_state_ = 2;
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_name_details_change_nickname ((FolksNameDetails*) _data_->_tmp10_, _data_->_tmp12_, _individual_retrieval_tests_create_persona_from_info_ready, _data_);
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		return FALSE;
#line 446 "individual-retrieval.c"
		_state_2:
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_name_details_change_nickname_finish ((FolksNameDetails*) _data_->_tmp10_, _data_->_res_, &_data_->_inner_error_);
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		if (_data_->_inner_error_ != NULL) {
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 454 "individual-retrieval.c"
				goto __catch0_folks_property_error;
			}
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->p);
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_clear_error (&_data_->_inner_error_);
#line 62 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			return FALSE;
#line 465 "individual-retrieval.c"
		}
#line 65 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp13_ = NULL;
#line 65 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp13_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 65 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->emails = _data_->_tmp13_;
#line 69 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		memset (&_data_->_tmp14_, 0, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 69 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp14_ = _data_->info;
#line 69 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp15_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp15_ = _data_->_tmp14_.home_email_address;
#line 69 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp16_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp16_ = folks_email_field_details_new (_data_->_tmp15_, NULL);
#line 69 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->email_1 = _data_->_tmp16_;
#line 70 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp17_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp17_ = _data_->email_1;
#line 70 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp17_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 72 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp18_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp18_ = _data_->emails;
#line 72 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp19_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp19_ = _data_->email_1;
#line 72 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp18_, _data_->_tmp19_);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp20_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp20_ = _data_->p;
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp21_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp21_ = _data_->emails;
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_state_ = 3;
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_email_details_change_email_addresses ((FolksEmailDetails*) _data_->_tmp20_, (GeeSet*) _data_->_tmp21_, _individual_retrieval_tests_create_persona_from_info_ready, _data_);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		return FALSE;
#line 517 "individual-retrieval.c"
		_state_3:
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_email_details_change_email_addresses_finish ((FolksEmailDetails*) _data_->_tmp20_, _data_->_res_, &_data_->_inner_error_);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		if (_data_->_inner_error_ != NULL) {
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->email_1);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->emails);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 529 "individual-retrieval.c"
				goto __catch0_folks_property_error;
			}
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->email_1);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->emails);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->p);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_clear_error (&_data_->_inner_error_);
#line 74 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			return FALSE;
#line 544 "individual-retrieval.c"
		}
#line 77 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp22_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp22_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->im_fds = _data_->_tmp22_;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp23_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp23_ = _data_->im_fds;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		memset (&_data_->_tmp24_, 0, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp24_ = _data_->info;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp25_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp25_ = _data_->_tmp24_.jabber_im_address;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp26_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp26_ = folks_im_field_details_new (_data_->_tmp25_, NULL);
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp27_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		gee_multi_map_set ((GeeMultiMap*) _data_->_tmp23_, "jabber", _data_->_tmp27_);
#line 78 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data_->_tmp27_);
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp28_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp28_ = _data_->im_fds;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		memset (&_data_->_tmp29_, 0, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp29_ = _data_->info;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp30_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp30_ = _data_->_tmp29_.yahoo_im_address;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp31_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp31_ = folks_im_field_details_new (_data_->_tmp30_, NULL);
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp32_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp32_ = _data_->_tmp31_;
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		gee_multi_map_set ((GeeMultiMap*) _data_->_tmp28_, "yahoo", _data_->_tmp32_);
#line 79 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data_->_tmp32_);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp33_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp33_ = _data_->p;
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp34_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp34_ = _data_->im_fds;
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_state_ = 4;
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_im_details_change_im_addresses ((FolksImDetails*) _data_->_tmp33_, (GeeMultiMap*) _data_->_tmp34_, _individual_retrieval_tests_create_persona_from_info_ready, _data_);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		return FALSE;
#line 614 "individual-retrieval.c"
		_state_4:
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_im_details_change_im_addresses_finish ((FolksImDetails*) _data_->_tmp33_, _data_->_res_, &_data_->_inner_error_);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		if (_data_->_inner_error_ != NULL) {
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->im_fds);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->email_1);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->emails);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 628 "individual-retrieval.c"
				goto __catch0_folks_property_error;
			}
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->im_fds);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->email_1);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->emails);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (_data_->p);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			g_clear_error (&_data_->_inner_error_);
#line 81 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			return FALSE;
#line 645 "individual-retrieval.c"
		}
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data_->im_fds);
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data_->email_1);
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data_->emails);
#line 653 "individual-retrieval.c"
	}
	goto __finally0;
	__catch0_folks_property_error:
	{
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->e = _data_->_inner_error_;
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_inner_error_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp35_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_tmp35_ = _data_->e->message;
#line 85 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_error ("individual-retrieval.vala:85: Error setting property: %s", _data_->_tmp35_);
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_error_free0 (_data_->e);
#line 670 "individual-retrieval.c"
	}
	__finally0:
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	if (_data_->_inner_error_ != NULL) {
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data_->p);
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_clear_error (&_data_->_inner_error_);
#line 58 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		return FALSE;
#line 683 "individual-retrieval.c"
	}
#line 88 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->result = (FolksPersona*) _data_->p;
#line 88 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	if (_data_->_state_ == 0) {
#line 88 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 691 "individual-retrieval.c"
	} else {
#line 88 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 695 "individual-retrieval.c"
	}
#line 88 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_object_unref (_data_->_async_result);
#line 88 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return FALSE;
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (_data_->p);
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	if (_data_->_state_ == 0) {
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 707 "individual-retrieval.c"
	} else {
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 711 "individual-retrieval.c"
	}
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_object_unref (_data_->_async_result);
#line 53 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return FALSE;
#line 717 "individual-retrieval.c"
}


static void _individual_retrieval_tests_register_personas_data_free (gpointer _data) {
	IndividualRetrievalTestsRegisterPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_slice_free (IndividualRetrievalTestsRegisterPersonasData, _data_);
#line 728 "individual-retrieval.c"
}


static void _individual_retrieval_tests_register_personas (IndividualRetrievalTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	IndividualRetrievalTestsRegisterPersonasData* _data_;
	IndividualRetrievalTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_ = g_slice_new0 (IndividualRetrievalTestsRegisterPersonasData);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _individual_retrieval_tests_register_personas);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _individual_retrieval_tests_register_personas_data_free);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_individual_retrieval_tests_register_personas_co (_data_);
#line 747 "individual-retrieval.c"
}


static void _individual_retrieval_tests_register_personas_finish (IndividualRetrievalTests* self, GAsyncResult* _res_) {
	IndividualRetrievalTestsRegisterPersonasData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 755 "individual-retrieval.c"
}


static void _individual_retrieval_tests_register_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	IndividualRetrievalTestsRegisterPersonasData* _data_;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_ = _user_data_;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_source_object_ = source_object;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_res_ = _res_;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_individual_retrieval_tests_register_personas_co (_data_);
#line 769 "individual-retrieval.c"
}


static gboolean _individual_retrieval_tests_register_personas_co (IndividualRetrievalTestsRegisterPersonasData* _data_) {
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	switch (_data_->_state_) {
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		case 0:
#line 778 "individual-retrieval.c"
		goto _state_0;
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		case 1:
#line 782 "individual-retrieval.c"
		goto _state_1;
		default:
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_assert_not_reached ();
#line 787 "individual-retrieval.c"
	}
	_state_0:
#line 93 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp0_ = NULL;
#line 93 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp0_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 93 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->personas = _data_->_tmp0_;
#line 796 "individual-retrieval.c"
	{
#line 96 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->info_collection_length1 = 0;
#line 96 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->_info_collection_size_ = 0;
#line 96 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->info_collection = INDIVIDUAL_RETRIEVAL_TESTS__persona_info;
#line 96 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_data_->info_collection_length1 = G_N_ELEMENTS (INDIVIDUAL_RETRIEVAL_TESTS__persona_info);
#line 96 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		for (_data_->info_it = 0; _data_->info_it < G_N_ELEMENTS (INDIVIDUAL_RETRIEVAL_TESTS__persona_info); _data_->info_it = _data_->info_it + 1) {
#line 96 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_data_->info = _data_->info_collection[_data_->info_it];
#line 810 "individual-retrieval.c"
			{
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp1_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp1_ = ((DummyTestTestCase*) _data_->self)->dummy_persona_store;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				memset (&_data_->_tmp2_, 0, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp2_ = _data_->info;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_state_ = 1;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_individual_retrieval_tests_create_persona_from_info (_data_->_tmp1_, &_data_->_tmp2_, _individual_retrieval_tests_register_personas_ready, _data_);
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				return FALSE;
#line 826 "individual-retrieval.c"
				_state_1:
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp3_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp3_ = _individual_retrieval_tests_create_persona_from_info_finish (_data_->_res_);
#line 98 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->p = _data_->_tmp3_;
#line 101 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp4_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp4_ = _data_->personas;
#line 101 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp5_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_data_->_tmp5_ = _data_->p;
#line 101 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp4_, _data_->_tmp5_);
#line 96 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				_g_object_unref0 (_data_->p);
#line 846 "individual-retrieval.c"
			}
		}
	}
#line 105 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp6_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp6_ = ((DummyTestTestCase*) _data_->self)->dummy_persona_store;
#line 105 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp7_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data_->_tmp7_ = _data_->personas;
#line 105 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	folks_dummy_persona_store_register_personas (_data_->_tmp6_, (GeeSet*) _data_->_tmp7_);
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (_data_->personas);
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	if (_data_->_state_ == 0) {
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 866 "individual-retrieval.c"
	} else {
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 870 "individual-retrieval.c"
	}
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_object_unref (_data_->_async_result);
#line 91 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return FALSE;
#line 876 "individual-retrieval.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return _data1_;
#line 885 "individual-retrieval.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 894 "individual-retrieval.c"
		IndividualRetrievalTests* self;
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		self = _data1_->self;
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data1_->aggregator);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_data1_->expected_individuals);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (self);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_slice_free (Block1Data, _data1_);
#line 908 "individual-retrieval.c"
	}
}


static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes) {
	IndividualRetrievalTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GeeSet* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	self = _data1_->self;
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_return_if_fail (changes != NULL);
#line 120 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp0_ = changes;
#line 120 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 120 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	added = _tmp1_;
#line 121 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp2_ = changes;
#line 121 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 121 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	removed = _tmp3_;
#line 123 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp4_ = added;
#line 123 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp5_ = gee_collection_get_size (_tmp4_);
#line 123 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp6_ = _tmp5_;
#line 123 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_vala_assert (_tmp6_ == 2, "added.size == 2");
#line 951 "individual-retrieval.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp7_ = NULL;
		GeeIterator* _tmp8_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_tmp7_ = added;
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_tmp8_ = gee_iterable_iterator ((GeeIterable*) _tmp7_);
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_i_it = _tmp8_;
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		while (TRUE) {
#line 964 "individual-retrieval.c"
			GeeIterator* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp11_ = NULL;
			gpointer _tmp12_ = NULL;
			FolksIndividual* _tmp13_ = NULL;
			FolksIndividual* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp9_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp10_ = gee_iterator_next (_tmp9_);
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			if (!_tmp10_) {
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
				break;
#line 982 "individual-retrieval.c"
			}
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp11_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp12_ = gee_iterator_get (_tmp11_);
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			i = (FolksIndividual*) _tmp12_;
#line 127 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp13_ = i;
#line 127 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_vala_assert (_tmp13_ != NULL, "i != null");
#line 128 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp14_ = i;
#line 128 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp15_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp14_);
#line 128 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_tmp16_ = _tmp15_;
#line 128 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			gee_abstract_collection_remove ((GeeAbstractCollection*) _data1_->expected_individuals, _tmp16_);
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
			_g_object_unref0 (i);
#line 1004 "individual-retrieval.c"
		}
#line 125 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_object_unref0 (_i_it);
#line 1008 "individual-retrieval.c"
	}
#line 131 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp17_ = removed;
#line 131 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 131 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp19_ = _tmp18_;
#line 131 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_vala_assert (_tmp19_ == 1, "removed.size == 1");
#line 133 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_main_loop_quit (_data1_->main_loop);
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (removed);
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (added);
#line 1024 "individual-retrieval.c"
}


static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	__lambda3_ (self, changes);
#line 1031 "individual-retrieval.c"
}


static void ___lambda5_ (IndividualRetrievalTests* self, GObject* s, GAsyncResult* r) {
	GAsyncResult* _tmp0_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_return_if_fail (r != NULL);
#line 149 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp0_ = r;
#line 149 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_individual_retrieval_tests_register_personas_finish (self, _tmp0_);
#line 1043 "individual-retrieval.c"
}


static void ____lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 147 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	___lambda5_ ((IndividualRetrievalTests*) self, source_object, res);
#line 147 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_object_unref (self);
#line 1052 "individual-retrieval.c"
}


static void __lambda4_ (Block1Data* _data1_, GObject* s, GAsyncResult* r) {
	IndividualRetrievalTests* self;
	GError * _inner_error_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	self = _data1_->self;
#line 139 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_return_if_fail (r != NULL);
#line 1063 "individual-retrieval.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		FolksDummyPersonaStore* _tmp2_ = NULL;
#line 143 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_tmp0_ = _data1_->aggregator;
#line 143 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_tmp1_ = r;
#line 143 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 143 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		if (_inner_error_ != NULL) {
#line 1076 "individual-retrieval.c"
			goto __catch1_g_error;
		}
#line 145 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_tmp2_ = ((DummyTestTestCase*) self)->dummy_persona_store;
#line 145 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		folks_dummy_persona_store_reach_quiescence (_tmp2_);
#line 147 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_individual_retrieval_tests_register_personas (self, ____lambda5__gasync_ready_callback, g_object_ref (self));
#line 1085 "individual-retrieval.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp3_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		e1 = _inner_error_;
#line 141 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_inner_error_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_tmp3_ = e1->message;
#line 154 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_error ("individual-retrieval.vala:154: Failed to prepare aggregator: %s", _tmp3_);
#line 141 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		_g_error_free0 (e1);
#line 1102 "individual-retrieval.c"
	}
	__finally1:
#line 141 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	if (_inner_error_ != NULL) {
#line 141 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 141 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		g_clear_error (&_inner_error_);
#line 141 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
		return;
#line 1113 "individual-retrieval.c"
	}
}


static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 139 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	__lambda4_ (self, source_object, res);
#line 139 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	block1_data_unref (self);
#line 1123 "individual-retrieval.c"
}


void individual_retrieval_tests_test_aggregator (IndividualRetrievalTests* self) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	gulong handler_id = 0UL;
	FolksIndividualAggregator* _tmp3_ = NULL;
	gulong _tmp4_ = 0UL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	FolksIndividualAggregator* _tmp8_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_return_if_fail (self != NULL);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_->_ref_count_ = 1;
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_->self = g_object_ref (self);
#line 110 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 110 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_->main_loop = _tmp0_;
#line 112 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp1_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 112 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_->expected_individuals = _tmp1_;
#line 113 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data1_->expected_individuals, "Renato F");
#line 114 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data1_->expected_individuals, "Rodrigo A");
#line 117 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp2_ = folks_individual_aggregator_dup ();
#line 117 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_->aggregator = _tmp2_;
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp3_ = _data1_->aggregator;
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp4_ = g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda3__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 118 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	handler_id = _tmp4_;
#line 139 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp5_ = _data1_->aggregator;
#line 139 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	folks_individual_aggregator_prepare (_tmp5_, ___lambda4__gasync_ready_callback, block1_data_ref (_data1_));
#line 159 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	folks_test_utils_loop_run_with_timeout (_data1_->main_loop, 5);
#line 162 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp6_ = gee_abstract_collection_get_size ((GeeCollection*) _data1_->expected_individuals);
#line 162 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp7_ = _tmp6_;
#line 162 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_vala_assert (_tmp7_ == 0, "expected_individuals.size == 0");
#line 163 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp8_ = _data1_->aggregator;
#line 163 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_signal_handler_disconnect ((GObject*) _tmp8_, handler_id);
#line 164 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (_data1_->aggregator);
#line 164 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_->aggregator = NULL;
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	block1_data_unref (_data1_);
#line 108 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_data1_ = NULL;
#line 1193 "individual-retrieval.c"
}


static IndividualRetrievalTestsPersonaInfo* individual_retrieval_tests_persona_info_dup (const IndividualRetrievalTestsPersonaInfo* self) {
	IndividualRetrievalTestsPersonaInfo* dup;
#line 35 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	dup = g_new0 (IndividualRetrievalTestsPersonaInfo, 1);
#line 35 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	memcpy (dup, self, sizeof (IndividualRetrievalTestsPersonaInfo));
#line 35 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return dup;
#line 1205 "individual-retrieval.c"
}


static void individual_retrieval_tests_persona_info_free (IndividualRetrievalTestsPersonaInfo* self) {
#line 35 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_free (self);
#line 1212 "individual-retrieval.c"
}


static GType individual_retrieval_tests_persona_info_get_type (void) {
	static volatile gsize individual_retrieval_tests_persona_info_type_id__volatile = 0;
	if (g_once_init_enter (&individual_retrieval_tests_persona_info_type_id__volatile)) {
		GType individual_retrieval_tests_persona_info_type_id;
		individual_retrieval_tests_persona_info_type_id = g_boxed_type_register_static ("IndividualRetrievalTestsPersonaInfo", (GBoxedCopyFunc) individual_retrieval_tests_persona_info_dup, (GBoxedFreeFunc) individual_retrieval_tests_persona_info_free);
		g_once_init_leave (&individual_retrieval_tests_persona_info_type_id__volatile, individual_retrieval_tests_persona_info_type_id);
	}
	return individual_retrieval_tests_persona_info_type_id__volatile;
}


static void individual_retrieval_tests_class_init (IndividualRetrievalTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	individual_retrieval_tests_parent_class = g_type_class_peek_parent (klass);
#line 1230 "individual-retrieval.c"
}


static void individual_retrieval_tests_instance_init (IndividualRetrievalTests * self) {
}


GType individual_retrieval_tests_get_type (void) {
	static volatile gsize individual_retrieval_tests_type_id__volatile = 0;
	if (g_once_init_enter (&individual_retrieval_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (IndividualRetrievalTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) individual_retrieval_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (IndividualRetrievalTests), 0, (GInstanceInitFunc) individual_retrieval_tests_instance_init, NULL };
		GType individual_retrieval_tests_type_id;
		individual_retrieval_tests_type_id = g_type_register_static (DUMMY_TEST_TYPE_TEST_CASE, "IndividualRetrievalTests", &g_define_type_info, 0);
		g_once_init_leave (&individual_retrieval_tests_type_id__volatile, individual_retrieval_tests_type_id);
	}
	return individual_retrieval_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	IndividualRetrievalTests* tests = NULL;
	IndividualRetrievalTests* _tmp0_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_test_init (&args_length1, &args, NULL);
#line 172 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_tmp0_ = individual_retrieval_tests_new ();
#line 172 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	tests = _tmp0_;
#line 173 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 174 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	g_test_run ();
#line 175 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 177 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	result = 0;
#line 177 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	_g_object_unref0 (tests);
#line 177 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return result;
#line 1272 "individual-retrieval.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 168 "/opt/gnome3/source/folks/tests/dummy/individual-retrieval.vala"
	return _vala_main (argv, argc);
#line 1282 "individual-retrieval.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



