/* helper-prepare-aggregator.c generated by valac 0.24.0.111-cb21a, the Vala compiler
 * generated from helper-prepare-aggregator.vala, do not modify */

/*
 * Copyright © 2013 Intel Corporation
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *    Simon McVittie <simon.mcvittie@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <locale.h>
#include <stdio.h>
#include <folks-test.h>
#include <unistd.h>
#include <errno.h>
#include <folks/folks.h>
#include <gee.h>
#include <gobject/gvaluecollector.h>


#define TYPE_MAIN (main_get_type ())
#define MAIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MAIN, Main))
#define MAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MAIN, MainClass))
#define IS_MAIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MAIN))
#define IS_MAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MAIN))
#define MAIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MAIN, MainClass))

typedef struct _Main Main;
typedef struct _MainClass MainClass;
typedef struct _MainPrivate MainPrivate;
typedef struct _Block1Data Block1Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _fclose0(var) ((var == NULL) ? NULL : (var = (fclose (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _MainMainAsyncData MainMainAsyncData;
typedef struct _ParamSpecMain ParamSpecMain;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _Main {
	GTypeInstance parent_instance;
	volatile int ref_count;
	MainPrivate * priv;
};

struct _MainClass {
	GTypeClass parent_class;
	void (*finalize) (Main *self);
};

struct _Block1Data {
	int _ref_count_;
	GMainLoop* loop;
	GAsyncResult* _result_;
};

struct _MainMainAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FILE* original_stdout;
	gint _tmp0_;
	FILE* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	const gchar* _tmp4_;
	gdouble _tmp5_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp6_;
	FolksBackendStore* _tmp7_;
	FolksBackendStore* _tmp8_;
	FolksBackend* eds;
	FolksBackendStore* _tmp9_;
	FolksBackend* _tmp10_;
	FolksBackend* _tmp11_;
	gdouble _tmp12_;
	FolksBackend* _tmp13_;
	gdouble _tmp14_;
	FolksIndividualAggregator* aggregator;
	FolksIndividualAggregator* _tmp15_;
	FolksIndividualAggregator* _tmp16_;
	GeeMap* map;
	FolksIndividualAggregator* _tmp17_;
	GeeMap* _tmp18_;
	GeeMap* _tmp19_;
	GeeMap* _tmp20_;
	gdouble _tmp21_;
	GeeMap* _tmp22_;
	gint _tmp23_;
	gint _tmp24_;
	GeeMapIterator* iter;
	GeeMap* _tmp25_;
	GeeMapIterator* _tmp26_;
	gint i;
	GeeMapIterator* _tmp27_;
	gboolean _tmp28_;
	FolksIndividual* individual;
	GeeMapIterator* _tmp29_;
	gpointer _tmp30_;
	GeeMapIterator* _tmp31_;
	gpointer _tmp32_;
	gchar* _tmp33_;
	FolksIndividual* _tmp34_;
	const gchar* _tmp35_;
	const gchar* _tmp36_;
	gboolean _tmp37_;
	gboolean _tmp38_;
	gint _tmp39_;
	GeeMap* _tmp40_;
	gint _tmp41_;
	gint _tmp42_;
	FolksIndividual* _tmp43_;
	const gchar* _tmp44_;
	const gchar* _tmp45_;
	GeeMapIterator* _tmp46_;
	gpointer _tmp47_;
	gchar* _tmp48_;
	GeeMapIterator* _tmp49_;
	gpointer _tmp50_;
	gchar* _tmp51_;
	gboolean _tmp52_;
	gboolean _tmp53_;
	gint _tmp54_;
	GeeMap* _tmp55_;
	gint _tmp56_;
	gint _tmp57_;
	GeeSet* personas;
	FolksIndividual* _tmp58_;
	GeeSet* _tmp59_;
	GeeSet* _tmp60_;
	GeeSet* _tmp61_;
	gint j;
	GeeIterator* _persona_it;
	GeeSet* _tmp62_;
	GeeIterator* _tmp63_;
	GeeIterator* _tmp64_;
	gboolean _tmp65_;
	FolksPersona* persona;
	GeeIterator* _tmp66_;
	gpointer _tmp67_;
	gint _tmp68_;
	GeeSet* _tmp69_;
	gint _tmp70_;
	gint _tmp71_;
	FolksPersona* _tmp72_;
	const gchar* _tmp73_;
	const gchar* _tmp74_;
	FolksPersona* _tmp75_;
	const gchar* _tmp76_;
	const gchar* _tmp77_;
	gint _tmp78_;
	gint _tmp79_;
	GError * _inner_error_;
};

struct _ParamSpecMain {
	GParamSpec parent_instance;
};


static gpointer main_parent_class = NULL;
static gboolean main__print_an_individual_id;
static gboolean main__print_an_individual_id = FALSE;
static gboolean main__print_a_persona_uid;
static gboolean main__print_a_persona_uid = FALSE;

gpointer main_ref (gpointer instance);
void main_unref (gpointer instance);
GParamSpec* param_spec_main (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_main (GValue* value, gpointer v_object);
void value_take_main (GValue* value, gpointer v_object);
gpointer value_get_main (const GValue* value);
GType main_get_type (void) G_GNUC_CONST;
enum  {
	MAIN_DUMMY_PROPERTY
};
#define MAIN__TIMEOUT ((guint) 20)
gint main_main (gchar** args, int args_length1);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
void _main_main_async (GAsyncReadyCallback _callback_, gpointer _user_data_);
void _main_main_finish (GAsyncResult* _res_, GError** error);
static void __lambda4_ (Block1Data* _data1_, GObject* nil, GAsyncResult* res);
static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _main_main_async_data_free (gpointer _data);
static gboolean _main_main_async_co (MainMainAsyncData* _data_);
static void _main_main_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
Main* main_new (void);
Main* main_construct (GType object_type);
static void main_finalize (Main* obj);

static const GOptionEntry MAIN__options[3] = {{"print-a-persona-uid", (gchar) 0, 0, G_OPTION_ARG_NONE, &main__print_a_persona_uid, "Print a more or less arbitrary Persona UID", NULL}, {"print-an-individual-id", (gchar) 0, 0, G_OPTION_ARG_NONE, &main__print_an_individual_id, "Print a more or less arbitrary Individual ID", NULL}, {NULL}};

static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return _data1_;
#line 219 "helper-prepare-aggregator.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data1_->_result_);
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_main_loop_unref0 (_data1_->loop);
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_slice_free (Block1Data, _data1_);
#line 234 "helper-prepare-aggregator.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 88 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return self ? g_object_ref (self) : NULL;
#line 242 "helper-prepare-aggregator.c"
}


static void __lambda4_ (Block1Data* _data1_, GObject* nil, GAsyncResult* res) {
	GAsyncResult* _tmp0_ = NULL;
	GAsyncResult* _tmp1_ = NULL;
	GMainLoop* _tmp2_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_return_if_fail (res != NULL);
#line 88 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_tmp0_ = res;
#line 88 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 88 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_g_object_unref0 (_data1_->_result_);
#line 88 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data1_->_result_ = _tmp1_;
#line 89 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_tmp2_ = _data1_->loop;
#line 89 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_main_loop_quit (_tmp2_);
#line 264 "helper-prepare-aggregator.c"
}


static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 86 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	__lambda4_ (self, source_object, res);
#line 86 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	block1_data_unref (self);
#line 273 "helper-prepare-aggregator.c"
}


gint main_main (gchar** args, int args_length1) {
	gint result = 0;
	Block1Data* _data1_;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	GMainLoop* _tmp12_ = NULL;
	GMainLoop* _tmp13_ = NULL;
	GError * _inner_error_ = NULL;
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data1_->_ref_count_ = 1;
#line 63 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	setlocale (LC_ALL, "");
#line 65 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_tmp2_ = g_getenv ("FOLKS_TESTS_SANDBOXED_DBUS");
#line 65 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (g_strcmp0 (_tmp2_, "no-services") != 0) {
#line 65 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp1_ = TRUE;
#line 298 "helper-prepare-aggregator.c"
	} else {
		const gchar* _tmp3_ = NULL;
#line 66 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp3_ = g_getenv ("FOLKS_BACKENDS_ALLOWED");
#line 66 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp1_ = g_strcmp0 (_tmp3_, "eds") != 0;
#line 305 "helper-prepare-aggregator.c"
	}
#line 65 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (_tmp1_) {
#line 65 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp0_ = TRUE;
#line 311 "helper-prepare-aggregator.c"
	} else {
		const gchar* _tmp4_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp4_ = g_getenv ("FOLKS_PRIMARY_STORE");
#line 67 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp0_ = _tmp4_ == NULL;
#line 318 "helper-prepare-aggregator.c"
	}
#line 65 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (_tmp0_) {
#line 68 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_error ("helper-prepare-aggregator.vala:68: %s", "e-d-s helpers must be run in a private D-Bus session with " "e-d-s services");
#line 324 "helper-prepare-aggregator.c"
	}
	{
		GOptionContext* context = NULL;
		GOptionContext* _tmp5_ = NULL;
		GOptionContext* _tmp6_ = NULL;
		GOptionContext* _tmp7_ = NULL;
		GOptionContext* _tmp8_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp5_ = g_option_context_new ("- Create many e-d-s contacts");
#line 73 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		context = _tmp5_;
#line 74 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp6_ = context;
#line 74 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_option_context_set_help_enabled (_tmp6_, TRUE);
#line 75 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp7_ = context;
#line 75 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_option_context_add_main_entries (_tmp7_, MAIN__options, NULL);
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp8_ = context;
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_option_context_parse (_tmp8_, &args_length1, &args, &_inner_error_);
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_g_option_context_free0 (context);
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			if (_inner_error_->domain == G_OPTION_ERROR) {
#line 354 "helper-prepare-aggregator.c"
				goto __catch0_g_option_error;
			}
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_g_option_context_free0 (context);
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			block1_data_unref (_data1_);
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data1_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_clear_error (&_inner_error_);
#line 76 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			return 0;
#line 369 "helper-prepare-aggregator.c"
		}
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_option_context_free0 (context);
#line 373 "helper-prepare-aggregator.c"
	}
	goto __finally0;
	__catch0_g_option_error:
	{
		GError* e = NULL;
		FILE* _tmp9_ = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		e = _inner_error_;
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_inner_error_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp9_ = stderr;
#line 80 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp10_ = e;
#line 80 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp11_ = _tmp10_->message;
#line 80 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		fprintf (_tmp9_, "Error parsing arguments: %s\n", _tmp11_);
#line 81 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		result = 2;
#line 81 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_error_free0 (e);
#line 81 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		block1_data_unref (_data1_);
#line 81 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data1_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return result;
#line 404 "helper-prepare-aggregator.c"
	}
	__finally0:
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		block1_data_unref (_data1_);
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data1_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_clear_error (&_inner_error_);
#line 71 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return 0;
#line 419 "helper-prepare-aggregator.c"
	}
#line 84 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_tmp12_ = g_main_loop_new (NULL, FALSE);
#line 84 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data1_->loop = _tmp12_;
#line 85 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data1_->_result_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_main_main_async (___lambda4__gasync_ready_callback, block1_data_ref (_data1_));
#line 92 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_tmp13_ = _data1_->loop;
#line 92 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_test_utils_loop_run_with_timeout (_tmp13_, 60);
#line 433 "helper-prepare-aggregator.c"
	{
		GAsyncResult* _tmp14_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp14_ = _data1_->_result_;
#line 96 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_main_main_finish (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, g_async_result_get_type (), GAsyncResult), &_inner_error_);
#line 96 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 442 "helper-prepare-aggregator.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
		GQuark _tmp15_ = 0U;
		const gchar* _tmp16_ = NULL;
		gint _tmp17_ = 0;
		const gchar* _tmp18_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		e = _inner_error_;
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_inner_error_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp15_ = e->domain;
#line 100 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp16_ = g_quark_to_string (_tmp15_);
#line 100 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp17_ = e->code;
#line 100 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_tmp18_ = e->message;
#line 100 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_error ("helper-prepare-aggregator.vala:100: %s #%d: %s", _tmp16_, _tmp17_, _tmp18_);
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_error_free0 (e);
#line 470 "helper-prepare-aggregator.c"
	}
	__finally1:
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		block1_data_unref (_data1_);
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data1_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_clear_error (&_inner_error_);
#line 94 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return 0;
#line 485 "helper-prepare-aggregator.c"
	}
#line 103 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	result = 0;
#line 103 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	block1_data_unref (_data1_);
#line 103 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data1_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return result;
#line 495 "helper-prepare-aggregator.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 61 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return main_main (argv, argc);
#line 505 "helper-prepare-aggregator.c"
}


static void _main_main_async_data_free (gpointer _data) {
	MainMainAsyncData* _data_;
	_data_ = _data;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_slice_free (MainMainAsyncData, _data_);
#line 514 "helper-prepare-aggregator.c"
}


void _main_main_async (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MainMainAsyncData* _data_;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_ = g_slice_new0 (MainMainAsyncData);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, _main_main_async);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _main_main_async_data_free);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_main_main_async_co (_data_);
#line 528 "helper-prepare-aggregator.c"
}


void _main_main_finish (GAsyncResult* _res_, GError** error) {
	MainMainAsyncData* _data_;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return;
#line 538 "helper-prepare-aggregator.c"
	}
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 542 "helper-prepare-aggregator.c"
}


static void _main_main_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MainMainAsyncData* _data_;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_ = _user_data_;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_source_object_ = source_object;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_res_ = _res_;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_main_main_async_co (_data_);
#line 556 "helper-prepare-aggregator.c"
}


static gboolean _main_main_async_co (MainMainAsyncData* _data_) {
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	switch (_data_->_state_) {
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		case 0:
#line 565 "helper-prepare-aggregator.c"
		goto _state_0;
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		case 1:
#line 569 "helper-prepare-aggregator.c"
		goto _state_1;
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		case 2:
#line 573 "helper-prepare-aggregator.c"
		goto _state_2;
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		case 3:
#line 577 "helper-prepare-aggregator.c"
		goto _state_3;
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		case 4:
#line 581 "helper-prepare-aggregator.c"
		goto _state_4;
		default:
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_assert_not_reached ();
#line 586 "helper-prepare-aggregator.c"
	}
	_state_0:
#line 113 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp0_ = 0;
#line 113 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp0_ = dup (1);
#line 113 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp1_ = NULL;
#line 113 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp1_ = fdopen (_data_->_tmp0_, "w");
#line 113 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->original_stdout = _data_->_tmp1_;
#line 114 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_vala_assert (_data_->original_stdout != NULL, "original_stdout != null");
#line 115 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp2_ = 0;
#line 115 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp2_ = dup2 (2, 1);
#line 115 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (_data_->_tmp2_ != 1) {
#line 116 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp3_ = 0;
#line 116 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp3_ = errno;
#line 116 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp4_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp4_ = g_strerror (_data_->_tmp3_);
#line 116 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_error ("helper-prepare-aggregator.vala:116: dup2(stderr, stdout) failed: %s", _data_->_tmp4_);
#line 617 "helper-prepare-aggregator.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_message ("helper-prepare-aggregator.vala:118: running helper-prepare-aggregator");
#line 120 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_test_timer_start ();
#line 122 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp5_ = 0.0;
#line 122 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp5_ = g_test_timer_elapsed ();
#line 122 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_message ("helper-prepare-aggregator.vala:122: %.6f Setting up test backend", _data_->_tmp5_);
#line 124 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp6_ = NULL;
#line 124 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp6_ = folks_backend_store_dup ();
#line 124 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->store = _data_->_tmp6_;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp7_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp7_ = _data_->store;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_state_ = 1;
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_backend_store_prepare (_data_->_tmp7_, _main_main_async_ready, _data_);
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return FALSE;
#line 645 "helper-prepare-aggregator.c"
	_state_1:
#line 126 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_backend_store_prepare_finish (_data_->_tmp7_, _data_->_res_);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp8_ = NULL;
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp8_ = _data_->store;
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_state_ = 2;
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_backend_store_load_backends (_data_->_tmp8_, _main_main_async_ready, _data_);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return FALSE;
#line 659 "helper-prepare-aggregator.c"
	_state_2:
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_backend_store_load_backends_finish (_data_->_tmp8_, _data_->_res_, &_data_->_inner_error_);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_error_free (_data_->_inner_error_);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data_->store);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_fclose0 (_data_->original_stdout);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (_data_->_state_ == 0) {
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 677 "helper-prepare-aggregator.c"
		} else {
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 681 "helper-prepare-aggregator.c"
		}
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_object_unref (_data_->_async_result);
#line 128 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return FALSE;
#line 687 "helper-prepare-aggregator.c"
	}
#line 130 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp9_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp9_ = _data_->store;
#line 130 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp10_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp10_ = folks_backend_store_dup_backend_by_name (_data_->_tmp9_, "eds");
#line 130 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->eds = _data_->_tmp10_;
#line 131 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp11_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp11_ = _data_->eds;
#line 131 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_vala_assert (_data_->_tmp11_ != NULL, "eds != null");
#line 133 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp12_ = 0.0;
#line 133 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp12_ = g_test_timer_elapsed ();
#line 133 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_message ("helper-prepare-aggregator.vala:133: %.6f Waiting for EDS backend", _data_->_tmp12_);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp13_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp13_ = _data_->eds;
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_state_ = 3;
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_test_utils_backend_prepare_and_wait_for_quiescence (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp13_, FOLKS_TYPE_BACKEND, FolksBackend), _main_main_async_ready, _data_);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return FALSE;
#line 721 "helper-prepare-aggregator.c"
	_state_3:
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_test_utils_backend_prepare_and_wait_for_quiescence_finish (_data_->_res_, &_data_->_inner_error_);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_error_free (_data_->_inner_error_);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data_->eds);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data_->store);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_fclose0 (_data_->original_stdout);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (_data_->_state_ == 0) {
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 741 "helper-prepare-aggregator.c"
		} else {
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 745 "helper-prepare-aggregator.c"
		}
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_object_unref (_data_->_async_result);
#line 135 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return FALSE;
#line 751 "helper-prepare-aggregator.c"
	}
#line 137 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp14_ = 0.0;
#line 137 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp14_ = g_test_timer_elapsed ();
#line 137 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_message ("helper-prepare-aggregator.vala:137: %.6f Waiting for aggregator", _data_->_tmp14_);
#line 138 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp15_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp15_ = folks_individual_aggregator_dup ();
#line 138 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->aggregator = _data_->_tmp15_;
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp16_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp16_ = _data_->aggregator;
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_state_ = 4;
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_quiescence (_data_->_tmp16_, _main_main_async_ready, _data_);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return FALSE;
#line 775 "helper-prepare-aggregator.c"
	_state_4:
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_quiescence_finish (_data_->_res_, &_data_->_inner_error_);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_error_free (_data_->_inner_error_);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data_->aggregator);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data_->eds);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data_->store);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_fclose0 (_data_->original_stdout);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (_data_->_state_ == 0) {
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 797 "helper-prepare-aggregator.c"
		} else {
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 801 "helper-prepare-aggregator.c"
		}
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_object_unref (_data_->_async_result);
#line 139 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return FALSE;
#line 807 "helper-prepare-aggregator.c"
	}
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp17_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp17_ = _data_->aggregator;
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp18_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp18_ = folks_individual_aggregator_get_individuals (_data_->_tmp17_);
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp19_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp20_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp20_ = _g_object_ref0 (_data_->_tmp19_);
#line 141 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->map = _data_->_tmp20_;
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp21_ = 0.0;
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp21_ = g_test_timer_elapsed ();
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp22_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp22_ = _data_->map;
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp23_ = 0;
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp23_ = gee_map_get_size (_data_->_tmp22_);
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp24_ = 0;
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp24_ = _data_->_tmp23_;
#line 142 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_message ("helper-prepare-aggregator.vala:142: %.6f Aggregated into %d individual" \
"s", _data_->_tmp21_, _data_->_tmp24_);
#line 145 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp25_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp25_ = _data_->map;
#line 145 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp26_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->_tmp26_ = gee_map_map_iterator (_data_->_tmp25_);
#line 145 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->iter = _data_->_tmp26_;
#line 146 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_data_->i = 0;
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	while (TRUE) {
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp27_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp27_ = _data_->iter;
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp28_ = FALSE;
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp28_ = gee_map_iterator_next (_data_->_tmp27_);
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (!_data_->_tmp28_) {
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			break;
#line 871 "helper-prepare-aggregator.c"
		}
#line 150 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp29_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp29_ = _data_->iter;
#line 150 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp30_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp30_ = gee_map_iterator_get_value (_data_->_tmp29_);
#line 150 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->individual = (FolksIndividual*) _data_->_tmp30_;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp31_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp31_ = _data_->iter;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp32_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp32_ = gee_map_iterator_get_key (_data_->_tmp31_);
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp33_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp33_ = (gchar*) _data_->_tmp32_;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp34_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp34_ = _data_->individual;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp35_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp35_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp34_);
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp36_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_debug ("helper-prepare-aggregator.vala:152: %s → %s", _data_->_tmp33_, _data_->_tmp36_);
#line 152 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_free0 (_data_->_tmp33_);
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp38_ = FALSE;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp38_ = main__print_an_individual_id;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (_data_->_tmp38_) {
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp39_ = 0;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp39_ = _data_->i;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp40_ = NULL;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp40_ = _data_->map;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp41_ = 0;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp41_ = gee_map_get_size (_data_->_tmp40_);
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp42_ = 0;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp42_ = _data_->_tmp41_;
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp37_ = _data_->_tmp39_ == (_data_->_tmp42_ / 2);
#line 935 "helper-prepare-aggregator.c"
		} else {
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp37_ = FALSE;
#line 939 "helper-prepare-aggregator.c"
		}
#line 157 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (_data_->_tmp37_) {
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp43_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp43_ = _data_->individual;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp44_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp44_ = folks_individual_get_id (_data_->_tmp43_);
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp45_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp45_ = _data_->_tmp44_;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp46_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp46_ = _data_->iter;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp47_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp47_ = gee_map_iterator_get_key (_data_->_tmp46_);
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp48_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp48_ = (gchar*) _data_->_tmp47_;
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			g_message ("helper-prepare-aggregator.vala:159: choosing individual %s - %s\n", _data_->_tmp45_, _data_->_tmp48_);
#line 159 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_g_free0 (_data_->_tmp48_);
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp49_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp49_ = _data_->iter;
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp50_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp50_ = gee_map_iterator_get_key (_data_->_tmp49_);
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp51_ = NULL;
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp51_ = (gchar*) _data_->_tmp50_;
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			fprintf (_data_->original_stdout, "%s\n", _data_->_tmp51_);
#line 161 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_g_free0 (_data_->_tmp51_);
#line 987 "helper-prepare-aggregator.c"
		}
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp53_ = FALSE;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp53_ = main__print_a_persona_uid;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (_data_->_tmp53_) {
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp54_ = 0;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp54_ = _data_->i;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp55_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp55_ = _data_->map;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp56_ = 0;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp56_ = gee_map_get_size (_data_->_tmp55_);
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp57_ = 0;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp57_ = _data_->_tmp56_;
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp52_ = _data_->_tmp54_ == (_data_->_tmp57_ / 2);
#line 1013 "helper-prepare-aggregator.c"
		} else {
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp52_ = FALSE;
#line 1017 "helper-prepare-aggregator.c"
		}
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (_data_->_tmp52_) {
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp58_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp58_ = _data_->individual;
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp59_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp59_ = folks_individual_get_personas (_data_->_tmp58_);
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp60_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp60_ = _data_->_tmp59_;
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp61_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->_tmp61_ = _g_object_ref0 (_data_->_tmp60_);
#line 166 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->personas = _data_->_tmp61_;
#line 167 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_data_->j = 0;
#line 1041 "helper-prepare-aggregator.c"
			{
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
				_data_->_tmp62_ = NULL;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
				_data_->_tmp62_ = _data_->personas;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
				_data_->_tmp63_ = NULL;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
				_data_->_tmp63_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp62_);
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
				_data_->_persona_it = _data_->_tmp63_;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
				while (TRUE) {
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp64_ = NULL;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp64_ = _data_->_persona_it;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp65_ = FALSE;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp65_ = gee_iterator_next (_data_->_tmp64_);
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					if (!_data_->_tmp65_) {
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						break;
#line 1067 "helper-prepare-aggregator.c"
					}
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp66_ = NULL;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp66_ = _data_->_persona_it;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp67_ = NULL;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp67_ = gee_iterator_get (_data_->_tmp66_);
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->persona = (FolksPersona*) _data_->_tmp67_;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp68_ = 0;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp68_ = _data_->j;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp69_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp69_ = _data_->personas;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp70_ = 0;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp70_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp69_);
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp71_ = 0;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp71_ = _data_->_tmp70_;
#line 173 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					if (_data_->_tmp68_ == (_data_->_tmp71_ / 2)) {
#line 175 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp72_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp72_ = _data_->persona;
#line 175 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp73_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp73_ = folks_persona_get_uid (_data_->_tmp72_);
#line 175 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp74_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp74_ = _data_->_tmp73_;
#line 175 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						g_message ("helper-prepare-aggregator.vala:175: choosing persona %s\n", _data_->_tmp74_);
#line 176 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp75_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp75_ = _data_->persona;
#line 176 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp76_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp76_ = folks_persona_get_uid (_data_->_tmp75_);
#line 176 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp77_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						_data_->_tmp77_ = _data_->_tmp76_;
#line 176 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
						fprintf (_data_->original_stdout, "%s\n", _data_->_tmp77_);
#line 1125 "helper-prepare-aggregator.c"
					}
#line 179 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp78_ = 0;
#line 179 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->_tmp78_ = _data_->j;
#line 179 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_data_->j = _data_->_tmp78_ + 1;
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
					_g_object_unref0 (_data_->persona);
#line 1135 "helper-prepare-aggregator.c"
				}
#line 169 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
				_g_object_unref0 (_data_->_persona_it);
#line 1139 "helper-prepare-aggregator.c"
			}
#line 164 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			_g_object_unref0 (_data_->personas);
#line 1143 "helper-prepare-aggregator.c"
		}
#line 183 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp79_ = 0;
#line 183 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->_tmp79_ = _data_->i;
#line 183 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_data_->i = _data_->_tmp79_ + 1;
#line 148 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		_g_object_unref0 (_data_->individual);
#line 1153 "helper-prepare-aggregator.c"
	}
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_g_object_unref0 (_data_->iter);
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_g_object_unref0 (_data_->map);
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_g_object_unref0 (_data_->aggregator);
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_g_object_unref0 (_data_->eds);
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_g_object_unref0 (_data_->store);
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	_fclose0 (_data_->original_stdout);
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (_data_->_state_ == 0) {
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1171 "helper-prepare-aggregator.c"
	} else {
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1175 "helper-prepare-aggregator.c"
	}
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_object_unref (_data_->_async_result);
#line 106 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return FALSE;
#line 1181 "helper-prepare-aggregator.c"
}


Main* main_construct (GType object_type) {
	Main* self = NULL;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	self = (Main*) g_type_create_instance (object_type);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return self;
#line 1191 "helper-prepare-aggregator.c"
}


Main* main_new (void) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return main_construct (TYPE_MAIN);
#line 1198 "helper-prepare-aggregator.c"
}


static void value_main_init (GValue* value) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	value->data[0].v_pointer = NULL;
#line 1205 "helper-prepare-aggregator.c"
}


static void value_main_free_value (GValue* value) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (value->data[0].v_pointer) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		main_unref (value->data[0].v_pointer);
#line 1214 "helper-prepare-aggregator.c"
	}
}


static void value_main_copy_value (const GValue* src_value, GValue* dest_value) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (src_value->data[0].v_pointer) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		dest_value->data[0].v_pointer = main_ref (src_value->data[0].v_pointer);
#line 1224 "helper-prepare-aggregator.c"
	} else {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1228 "helper-prepare-aggregator.c"
	}
}


static gpointer value_main_peek_pointer (const GValue* value) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return value->data[0].v_pointer;
#line 1236 "helper-prepare-aggregator.c"
}


static gchar* value_main_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (collect_values[0].v_pointer) {
#line 1243 "helper-prepare-aggregator.c"
		Main* object;
		object = collect_values[0].v_pointer;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		if (object->parent_instance.g_class == NULL) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1250 "helper-prepare-aggregator.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1254 "helper-prepare-aggregator.c"
		}
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		value->data[0].v_pointer = main_ref (object);
#line 1258 "helper-prepare-aggregator.c"
	} else {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		value->data[0].v_pointer = NULL;
#line 1262 "helper-prepare-aggregator.c"
	}
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return NULL;
#line 1266 "helper-prepare-aggregator.c"
}


static gchar* value_main_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	Main** object_p;
	object_p = collect_values[0].v_pointer;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (!object_p) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1277 "helper-prepare-aggregator.c"
	}
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (!value->data[0].v_pointer) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		*object_p = NULL;
#line 1283 "helper-prepare-aggregator.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		*object_p = value->data[0].v_pointer;
#line 1287 "helper-prepare-aggregator.c"
	} else {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		*object_p = main_ref (value->data[0].v_pointer);
#line 1291 "helper-prepare-aggregator.c"
	}
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return NULL;
#line 1295 "helper-prepare-aggregator.c"
}


GParamSpec* param_spec_main (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecMain* spec;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_MAIN), NULL);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return G_PARAM_SPEC (spec);
#line 1309 "helper-prepare-aggregator.c"
}


gpointer value_get_main (const GValue* value) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MAIN), NULL);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return value->data[0].v_pointer;
#line 1318 "helper-prepare-aggregator.c"
}


void value_set_main (GValue* value, gpointer v_object) {
	Main* old;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MAIN));
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	old = value->data[0].v_pointer;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (v_object) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MAIN));
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		value->data[0].v_pointer = v_object;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		main_ref (value->data[0].v_pointer);
#line 1338 "helper-prepare-aggregator.c"
	} else {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		value->data[0].v_pointer = NULL;
#line 1342 "helper-prepare-aggregator.c"
	}
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (old) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		main_unref (old);
#line 1348 "helper-prepare-aggregator.c"
	}
}


void value_take_main (GValue* value, gpointer v_object) {
	Main* old;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MAIN));
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	old = value->data[0].v_pointer;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (v_object) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MAIN));
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		value->data[0].v_pointer = v_object;
#line 1367 "helper-prepare-aggregator.c"
	} else {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		value->data[0].v_pointer = NULL;
#line 1371 "helper-prepare-aggregator.c"
	}
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (old) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		main_unref (old);
#line 1377 "helper-prepare-aggregator.c"
	}
}


static void main_class_init (MainClass * klass) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	main_parent_class = g_type_class_peek_parent (klass);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	MAIN_CLASS (klass)->finalize = main_finalize;
#line 1387 "helper-prepare-aggregator.c"
}


static void main_instance_init (Main * self) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	self->ref_count = 1;
#line 1394 "helper-prepare-aggregator.c"
}


static void main_finalize (Main* obj) {
	Main * self;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MAIN, Main);
#line 1402 "helper-prepare-aggregator.c"
}


/**
 * helper-prepare-aggregator [--print-an-individual-id] [--print-a-persona-uid]
 *
 * Prepare a Folks IndividualAggregator and iterate through all individuals,
 * emulating an "ordinary" Folks client application like gnome-contacts.
 *
 * If --print-an-individual-id is given, output a representative individual's
 * globally-unique identifier (Individual.id) to stdout. This can be used
 * as input for a search, to benchmark how long it takes to search for a
 * representative individual.
 *
 * If --print-a-persona-uid is given, output the globally-unique identifier
 * (Persona.uid) of a representative one of that individual's personas
 * to stdout. This can be used as input for a search, to benchmark how long
 * it takes to search for a representative persona.
 *
 * The Individual chosen is the one halfway through iteration, in an attempt
 * to avoid pathologically good or bad performance. Similarly, the Persona
 * chosen is the one halfway through when iterating that Individual's
 * personas.
 */
GType main_get_type (void) {
	static volatile gsize main_type_id__volatile = 0;
	if (g_once_init_enter (&main_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_main_init, value_main_free_value, value_main_copy_value, value_main_peek_pointer, "p", value_main_collect_value, "p", value_main_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (MainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) main_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Main), 0, (GInstanceInitFunc) main_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType main_type_id;
		main_type_id = g_type_register_fundamental (g_type_fundamental_next (), "Main", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&main_type_id__volatile, main_type_id);
	}
	return main_type_id__volatile;
}


gpointer main_ref (gpointer instance) {
	Main* self;
	self = instance;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	g_atomic_int_inc (&self->ref_count);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	return instance;
#line 1448 "helper-prepare-aggregator.c"
}


void main_unref (gpointer instance) {
	Main* self;
	self = instance;
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		MAIN_GET_CLASS (self)->finalize (self);
#line 44 "/opt/gnome3/source/folks/tests/eds/helper-prepare-aggregator.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1461 "helper-prepare-aggregator.c"
	}
}



