/* individual-retrieval.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from individual-retrieval.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <tpf-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks.h>
#include <gio/gio.h>
#include <folks/folks-telepathy.h>


#define TYPE_INDIVIDUAL_RETRIEVAL_TESTS (individual_retrieval_tests_get_type ())
#define INDIVIDUAL_RETRIEVAL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTests))
#define INDIVIDUAL_RETRIEVAL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsClass))
#define IS_INDIVIDUAL_RETRIEVAL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS))
#define IS_INDIVIDUAL_RETRIEVAL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INDIVIDUAL_RETRIEVAL_TESTS))
#define INDIVIDUAL_RETRIEVAL_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsClass))

typedef struct _IndividualRetrievalTests IndividualRetrievalTests;
typedef struct _IndividualRetrievalTestsClass IndividualRetrievalTestsClass;
typedef struct _IndividualRetrievalTestsPrivate IndividualRetrievalTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block1Data Block1Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
typedef struct _IndividualRetrievalTestsAddPersonasData IndividualRetrievalTestsAddPersonasData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _IndividualRetrievalTests {
	TpfTestTestCase parent_instance;
	IndividualRetrievalTestsPrivate * priv;
};

struct _IndividualRetrievalTestsClass {
	TpfTestTestCaseClass parent_class;
};

struct _IndividualRetrievalTestsPrivate {
	GeeHashSet* default_individuals;
};

struct _Block1Data {
	int _ref_count_;
	IndividualRetrievalTests* self;
	GeeHashSet* expected_individuals;
	FolksIndividualAggregator* aggregator;
};

struct _Block2Data {
	int _ref_count_;
	IndividualRetrievalTests* self;
	GeeHashSet* added_individuals;
	FolksIndividualAggregator* aggregator;
};

struct _Block3Data {
	int _ref_count_;
	Block2Data * _data2_;
	gboolean adding_done;
};

struct _Block4Data {
	int _ref_count_;
	IndividualRetrievalTests* self;
	TpfPersonaStore* store;
	gpointer _async_data_;
};

struct _Block5Data {
	int _ref_count_;
	Block4Data * _data4_;
	GeeHashSet* ids_remaining;
};

struct _Block6Data {
	int _ref_count_;
	Block5Data * _data5_;
	GHashTable* details;
};

struct _IndividualRetrievalTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	IndividualRetrievalTests* self;
	TpfPersonaStore* store;
	GeeHashSet* ids_add;
	Block4Data* _data4_;
	TpfPersonaStore* _tmp0_;
	Block5Data* _data5_;
	TpfPersonaStore* _tmp1_;
	GeeHashSet* _tmp2_;
	GeeIterator* _contact_id_it;
	GeeHashSet* _tmp3_;
	GeeIterator* _tmp4_;
	GeeIterator* _tmp5_;
	gboolean _tmp6_;
	gchar* contact_id;
	GeeIterator* _tmp7_;
	gpointer _tmp8_;
	GeeHashSet* _tmp9_;
	const gchar* _tmp10_;
	GError* e2;
	TpfPersonaStore* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	GError * _inner_error_;
};


static gpointer individual_retrieval_tests_parent_class = NULL;
static gchar* individual_retrieval_tests_iid_prefix;
static gchar* individual_retrieval_tests_iid_prefix = NULL;

GType individual_retrieval_tests_get_type (void) G_GNUC_CONST;
#define INDIVIDUAL_RETRIEVAL_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsPrivate))
enum  {
	INDIVIDUAL_RETRIEVAL_TESTS_DUMMY_PROPERTY
};
IndividualRetrievalTests* individual_retrieval_tests_new (void);
IndividualRetrievalTests* individual_retrieval_tests_construct (GType object_type);
void individual_retrieval_tests_test_aggregator (IndividualRetrievalTests* self);
static void _individual_retrieval_tests_test_aggregator_folks_test_case_test_method (gpointer self);
void individual_retrieval_tests_test_aggregator_add (IndividualRetrievalTests* self);
static void _individual_retrieval_tests_test_aggregator_add_folks_test_case_test_method (gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes);
static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda4_ (Block1Data* _data1_);
static void __lambda5_ (Block1Data* _data1_, GObject* s, GAsyncResult* r);
static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda4__gsource_func (gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda6_ (Block2Data* _data2_, GeeMultiMap* changes);
static void ___lambda6__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda7_ (Block2Data* _data2_);
static void __lambda8_ (Block2Data* _data2_, GObject* s, GAsyncResult* r);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void ____lambda9_ (Block3Data* _data3_, FolksPersonaStore* store);
static void individual_retrieval_tests_add_personas (IndividualRetrievalTests* self, TpfPersonaStore* store, GeeHashSet* ids_add, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void individual_retrieval_tests_add_personas_finish (IndividualRetrievalTests* self, GAsyncResult* _res_);
static void _____lambda9__folks_backend_persona_store_added (FolksBackend* _sender, FolksPersonaStore* store, gpointer self);
static void ___lambda8__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda7__gsource_func (gpointer self);
static void individual_retrieval_tests_add_personas_data_free (gpointer _data);
static gboolean individual_retrieval_tests_add_personas_co (IndividualRetrievalTestsAddPersonasData* _data_);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void individual_retrieval_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static gboolean ___lambda10_ (Block5Data* _data5_);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static void ____lambda11_ (Block6Data* _data6_, GObject* s2, GAsyncResult* res);
static GValue* _g_value_dup (GValue* self);
static void _____lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ____lambda10__gsource_func (gpointer self);
static void individual_retrieval_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _individual_retrieval_tests_test_aggregator_folks_test_case_test_method (gpointer self) {
#line 60 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	individual_retrieval_tests_test_aggregator ((IndividualRetrievalTests*) self);
#line 206 "individual-retrieval.c"
}


static void _individual_retrieval_tests_test_aggregator_add_folks_test_case_test_method (gpointer self) {
#line 61 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	individual_retrieval_tests_test_aggregator_add ((IndividualRetrievalTests*) self);
#line 213 "individual-retrieval.c"
}


IndividualRetrievalTests* individual_retrieval_tests_construct (GType object_type) {
	IndividualRetrievalTests * self = NULL;
	GeeHashSet* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GeeHashSet* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	GeeHashSet* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	GeeHashSet* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	GeeHashSet* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	GeeHashSet* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	GeeHashSet* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	GeeHashSet* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	GeeHashSet* _tmp49_ = NULL;
	const gchar* _tmp50_ = NULL;
	gchar* _tmp51_ = NULL;
	gchar* _tmp52_ = NULL;
	gchar* _tmp53_ = NULL;
	gchar* _tmp54_ = NULL;
#line 36 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = (IndividualRetrievalTests*) tpf_test_test_case_construct (object_type, "IndividualRetrieval");
#line 39 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 39 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (self->priv->default_individuals);
#line 39 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self->priv->default_individuals = _tmp0_;
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp1_ = self->priv->default_individuals;
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp2_ = individual_retrieval_tests_iid_prefix;
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp3_ = g_strconcat (_tmp2_, "me@example.com", NULL);
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp4_ = _tmp3_;
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp5_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp4_, (gsize) (-1));
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp6_ = _tmp5_;
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp1_, _tmp6_);
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp6_);
#line 41 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp4_);
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp7_ = self->priv->default_individuals;
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp8_ = individual_retrieval_tests_iid_prefix;
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp9_ = g_strconcat (_tmp8_, "travis@example.com", NULL);
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp10_ = _tmp9_;
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp11_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp10_, (gsize) (-1));
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp12_ = _tmp11_;
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, _tmp12_);
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp12_);
#line 43 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp10_);
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp13_ = self->priv->default_individuals;
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp14_ = individual_retrieval_tests_iid_prefix;
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp15_ = g_strconcat (_tmp14_, "guillaume@example.com", NULL);
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp16_ = _tmp15_;
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp17_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp16_, (gsize) (-1));
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp18_ = _tmp17_;
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, _tmp18_);
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp18_);
#line 45 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp16_);
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp19_ = self->priv->default_individuals;
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp20_ = individual_retrieval_tests_iid_prefix;
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp21_ = g_strconcat (_tmp20_, "olivier@example.com", NULL);
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp22_ = _tmp21_;
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp23_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp22_, (gsize) (-1));
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp24_ = _tmp23_;
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp19_, _tmp24_);
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp24_);
#line 47 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp22_);
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp25_ = self->priv->default_individuals;
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp26_ = individual_retrieval_tests_iid_prefix;
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp27_ = g_strconcat (_tmp26_, "sjoerd@example.com", NULL);
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp28_ = _tmp27_;
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp29_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp28_, (gsize) (-1));
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp30_ = _tmp29_;
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp25_, _tmp30_);
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp30_);
#line 49 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp28_);
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp31_ = self->priv->default_individuals;
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp32_ = individual_retrieval_tests_iid_prefix;
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp33_ = g_strconcat (_tmp32_, "geraldine@example.com", NULL);
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp34_ = _tmp33_;
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp35_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp34_, (gsize) (-1));
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp36_ = _tmp35_;
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp31_, _tmp36_);
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp36_);
#line 51 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp34_);
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp37_ = self->priv->default_individuals;
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp38_ = individual_retrieval_tests_iid_prefix;
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp39_ = g_strconcat (_tmp38_, "helen@example.com", NULL);
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp40_ = _tmp39_;
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp41_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp40_, (gsize) (-1));
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp42_ = _tmp41_;
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp37_, _tmp42_);
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp42_);
#line 53 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp40_);
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp43_ = self->priv->default_individuals;
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp44_ = individual_retrieval_tests_iid_prefix;
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp45_ = g_strconcat (_tmp44_, "wim@example.com", NULL);
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp46_ = _tmp45_;
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp47_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp46_, (gsize) (-1));
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp48_ = _tmp47_;
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp43_, _tmp48_);
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp48_);
#line 55 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp46_);
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp49_ = self->priv->default_individuals;
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp50_ = individual_retrieval_tests_iid_prefix;
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp51_ = g_strconcat (_tmp50_, "christian@example.com", NULL);
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp52_ = _tmp51_;
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp53_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp52_, (gsize) (-1));
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp54_ = _tmp53_;
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp49_, _tmp54_);
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp54_);
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_free0 (_tmp52_);
#line 60 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "aggregator", _individual_retrieval_tests_test_aggregator_folks_test_case_test_method, self);
#line 61 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "aggregator:add", _individual_retrieval_tests_test_aggregator_add_folks_test_case_test_method, self);
#line 34 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return self;
#line 450 "individual-retrieval.c"
}


IndividualRetrievalTests* individual_retrieval_tests_new (void) {
#line 34 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return individual_retrieval_tests_construct (TYPE_INDIVIDUAL_RETRIEVAL_TESTS);
#line 457 "individual-retrieval.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return _data1_;
#line 466 "individual-retrieval.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 475 "individual-retrieval.c"
		IndividualRetrievalTests* self;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		self = _data1_->self;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_data1_->aggregator);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_data1_->expected_individuals);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (self);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_slice_free (Block1Data, _data1_);
#line 487 "individual-retrieval.c"
	}
}


static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes) {
	IndividualRetrievalTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data1_->self;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (changes != NULL);
#line 77 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = changes;
#line 77 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 77 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	added = _tmp1_;
#line 78 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp2_ = changes;
#line 78 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 78 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	removed = _tmp3_;
#line 519 "individual-retrieval.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp4_ = added;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_i_it = _tmp5_;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		while (TRUE) {
#line 532 "individual-retrieval.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			GeeHashSet* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp6_ = _i_it;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (!_tmp7_) {
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 551 "individual-retrieval.c"
			}
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp8_ = _i_it;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			i = (FolksIndividual*) _tmp9_;
#line 82 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp10_ = i;
#line 82 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp11_ = _data1_->expected_individuals;
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp12_ = i;
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp13_ = folks_individual_get_id (_tmp12_);
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp14_ = _tmp13_;
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp11_, _tmp14_);
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_object_unref0 (i);
#line 575 "individual-retrieval.c"
		}
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_i_it);
#line 579 "individual-retrieval.c"
	}
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp15_ = removed;
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp17_ = _tmp16_;
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_vala_assert (_tmp17_ == 1, "removed.size == 1");
#line 589 "individual-retrieval.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp18_ = NULL;
		GeeIterator* _tmp19_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp18_ = removed;
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_i_it = _tmp19_;
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		while (TRUE) {
#line 602 "individual-retrieval.c"
			GeeIterator* _tmp20_ = NULL;
			gboolean _tmp21_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp22_ = NULL;
			gpointer _tmp23_ = NULL;
			FolksIndividual* _tmp24_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp20_ = _i_it;
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp21_ = gee_iterator_next (_tmp20_);
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (!_tmp21_) {
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 617 "individual-retrieval.c"
			}
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp22_ = _i_it;
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp23_ = gee_iterator_get (_tmp22_);
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			i = (FolksIndividual*) _tmp23_;
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp24_ = i;
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_vala_assert (_tmp24_ == NULL, "i == null");
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_object_unref0 (i);
#line 631 "individual-retrieval.c"
		}
#line 88 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_i_it);
#line 635 "individual-retrieval.c"
	}
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (removed);
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (added);
#line 641 "individual-retrieval.c"
}


static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	__lambda3_ (self, changes);
#line 648 "individual-retrieval.c"
}


static void __lambda5_ (Block1Data* _data1_, GObject* s, GAsyncResult* r) {
	IndividualRetrievalTests* self;
	GError * _inner_error_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data1_->self;
#line 100 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (r != NULL);
#line 659 "individual-retrieval.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp0_ = _data1_->aggregator;
#line 104 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp1_ = r;
#line 104 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 104 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		if (_inner_error_ != NULL) {
#line 671 "individual-retrieval.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		e1 = _inner_error_;
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_inner_error_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp2_ = e1->message;
#line 108 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_critical ("individual-retrieval.vala:108: failed to prepare aggregator: %s", _tmp2_);
#line 110 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_assert_not_reached ();
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_error_free0 (e1);
#line 692 "individual-retrieval.c"
	}
	__finally0:
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (_inner_error_ != NULL) {
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_clear_error (&_inner_error_);
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		return;
#line 703 "individual-retrieval.c"
	}
}


static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 100 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	__lambda5_ (self, source_object, res);
#line 100 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	block1_data_unref (self);
#line 713 "individual-retrieval.c"
}


static gboolean __lambda4_ (Block1Data* _data1_) {
	IndividualRetrievalTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data1_->self;
#line 100 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = _data1_->aggregator;
#line 100 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda5__gasync_ready_callback, block1_data_ref (_data1_));
#line 114 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	result = FALSE;
#line 114 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return result;
#line 731 "individual-retrieval.c"
}


static gboolean ___lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda4_ (self);
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return result;
#line 740 "individual-retrieval.c"
}


void individual_retrieval_tests_test_aggregator (IndividualRetrievalTests* self) {
	Block1Data* _data1_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp10_ = NULL;
	FolksIndividualAggregator* _tmp11_ = NULL;
	GMainLoop* _tmp12_ = NULL;
	GeeHashSet* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (self != NULL);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data1_->_ref_count_ = 1;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data1_->self = g_object_ref (self);
#line 66 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 66 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	main_loop = _tmp0_;
#line 69 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp1_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 69 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data1_->expected_individuals = _tmp1_;
#line 771 "individual-retrieval.c"
	{
		GeeIterator* _id_it = NULL;
		GeeHashSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp2_ = self->priv->default_individuals;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp3_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp2_);
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_id_it = _tmp3_;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		while (TRUE) {
#line 784 "individual-retrieval.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			gchar* id = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			GeeHashSet* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp4_ = _id_it;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (!_tmp5_) {
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 800 "individual-retrieval.c"
			}
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp6_ = _id_it;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			id = (gchar*) _tmp7_;
#line 71 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp8_ = _data1_->expected_individuals;
#line 71 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp9_ = id;
#line 71 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp8_, _tmp9_);
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_free0 (id);
#line 816 "individual-retrieval.c"
		}
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_id_it);
#line 820 "individual-retrieval.c"
	}
#line 74 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp10_ = folks_individual_aggregator_dup ();
#line 74 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data1_->aggregator = _tmp10_;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp11_ = _data1_->aggregator;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_signal_connect_data (_tmp11_, "individuals-changed-detailed", (GCallback) ___lambda3__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda4__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 117 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp12_ = main_loop;
#line 117 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp12_, 3);
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp13_ = _data1_->expected_individuals;
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp14_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp13_);
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp15_ = _tmp14_;
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_vala_assert (_tmp15_ == 0, "expected_individuals.size == 0");
#line 123 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (_data1_->aggregator);
#line 123 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data1_->aggregator = NULL;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_main_loop_unref0 (main_loop);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	block1_data_unref (_data1_);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data1_ = NULL;
#line 854 "individual-retrieval.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return _data2_;
#line 863 "individual-retrieval.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 872 "individual-retrieval.c"
		IndividualRetrievalTests* self;
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		self = _data2_->self;
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_data2_->aggregator);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_data2_->added_individuals);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (self);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_slice_free (Block2Data, _data2_);
#line 884 "individual-retrieval.c"
	}
}


static void __lambda6_ (Block2Data* _data2_, GeeMultiMap* changes) {
	IndividualRetrievalTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gint _tmp26_ = 0;
#line 138 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data2_->self;
#line 138 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (changes != NULL);
#line 140 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = changes;
#line 140 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 140 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	added = _tmp1_;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp2_ = changes;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	removed = _tmp3_;
#line 916 "individual-retrieval.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp4_ = added;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_i_it = _tmp5_;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		while (TRUE) {
#line 929 "individual-retrieval.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp6_ = _i_it;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (!_tmp7_) {
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 944 "individual-retrieval.c"
			}
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp8_ = _i_it;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			i = (FolksIndividual*) _tmp9_;
#line 147 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp10_ = i;
#line 147 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 956 "individual-retrieval.c"
			{
				GeeIterator* _p_it = NULL;
				FolksIndividual* _tmp11_ = NULL;
				GeeSet* _tmp12_ = NULL;
				GeeSet* _tmp13_ = NULL;
				GeeIterator* _tmp14_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp11_ = i;
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp13_ = _tmp12_;
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp14_ = gee_iterable_iterator ((GeeIterable*) _tmp13_);
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_p_it = _tmp14_;
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				while (TRUE) {
#line 975 "individual-retrieval.c"
					GeeIterator* _tmp15_ = NULL;
					gboolean _tmp16_ = FALSE;
					FolksPersona* p = NULL;
					GeeIterator* _tmp17_ = NULL;
					gpointer _tmp18_ = NULL;
					FolksPersona* _tmp19_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp15_ = _p_it;
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp16_ = gee_iterator_next (_tmp15_);
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					if (!_tmp16_) {
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						break;
#line 990 "individual-retrieval.c"
					}
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp17_ = _p_it;
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp18_ = gee_iterator_get (_tmp17_);
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					p = (FolksPersona*) _tmp18_;
#line 155 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp19_ = p;
#line 155 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, TPF_TYPE_PERSONA)) {
#line 1002 "individual-retrieval.c"
						FolksPersona* _tmp20_ = NULL;
						const gchar* _tmp21_ = NULL;
						const gchar* _tmp22_ = NULL;
						gboolean _tmp23_ = FALSE;
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp20_ = p;
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp21_ = folks_persona_get_display_id ((FolksPersona*) G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, TPF_TYPE_PERSONA, TpfPersona));
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp22_ = _tmp21_;
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp23_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _data2_->added_individuals, _tmp22_);
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						if (_tmp23_) {
#line 157 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
							_g_object_unref0 (p);
#line 157 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
							break;
#line 1021 "individual-retrieval.c"
						}
					}
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_g_object_unref0 (p);
#line 1026 "individual-retrieval.c"
				}
#line 153 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_g_object_unref0 (_p_it);
#line 1030 "individual-retrieval.c"
			}
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_object_unref0 (i);
#line 1034 "individual-retrieval.c"
		}
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_i_it);
#line 1038 "individual-retrieval.c"
	}
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp24_ = removed;
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp25_ = gee_collection_get_size ((GeeCollection*) _tmp24_);
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp26_ = _tmp25_;
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_vala_assert (_tmp26_ == 1, "removed.size == 1");
#line 1048 "individual-retrieval.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp27_ = NULL;
		GeeIterator* _tmp28_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp27_ = removed;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp28_ = gee_iterable_iterator ((GeeIterable*) _tmp27_);
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_i_it = _tmp28_;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		while (TRUE) {
#line 1061 "individual-retrieval.c"
			GeeIterator* _tmp29_ = NULL;
			gboolean _tmp30_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp31_ = NULL;
			gpointer _tmp32_ = NULL;
			FolksIndividual* _tmp33_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp29_ = _i_it;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp30_ = gee_iterator_next (_tmp29_);
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (!_tmp30_) {
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 1076 "individual-retrieval.c"
			}
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp31_ = _i_it;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp32_ = gee_iterator_get (_tmp31_);
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			i = (FolksIndividual*) _tmp32_;
#line 165 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp33_ = i;
#line 165 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_vala_assert (_tmp33_ == NULL, "i == null");
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_object_unref0 (i);
#line 1090 "individual-retrieval.c"
		}
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_i_it);
#line 1094 "individual-retrieval.c"
	}
#line 138 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (removed);
#line 138 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (added);
#line 1100 "individual-retrieval.c"
}


static void ___lambda6__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 138 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	__lambda6_ (self, changes);
#line 1107 "individual-retrieval.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return _data3_;
#line 1116 "individual-retrieval.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1125 "individual-retrieval.c"
		IndividualRetrievalTests* self;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		self = _data3_->_data2_->self;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		block2_data_unref (_data3_->_data2_);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data3_->_data2_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_slice_free (Block3Data, _data3_);
#line 1135 "individual-retrieval.c"
	}
}


static void ____lambda9_ (Block3Data* _data3_, FolksPersonaStore* store) {
	Block2Data* _data2_;
	IndividualRetrievalTests* self;
	gboolean _tmp0_ = FALSE;
	FolksPersonaStore* _tmp1_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_ = _data3_->_data2_;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data2_->self;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (store != NULL);
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp1_ = store;
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, TPF_TYPE_PERSONA_STORE)) {
#line 1155 "individual-retrieval.c"
		gboolean _tmp2_ = FALSE;
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp2_ = _data3_->adding_done;
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp0_ = !_tmp2_;
#line 1161 "individual-retrieval.c"
	} else {
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp0_ = FALSE;
#line 1165 "individual-retrieval.c"
	}
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (_tmp0_) {
#line 1169 "individual-retrieval.c"
		FolksPersonaStore* _tmp3_ = NULL;
#line 204 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp3_ = store;
#line 204 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		individual_retrieval_tests_add_personas (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TPF_TYPE_PERSONA_STORE, TpfPersonaStore), _data2_->added_individuals, NULL, NULL);
#line 206 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data3_->adding_done = TRUE;
#line 1177 "individual-retrieval.c"
	}
}


static void _____lambda9__folks_backend_persona_store_added (FolksBackend* _sender, FolksPersonaStore* store, gpointer self) {
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	____lambda9_ (self, store);
#line 1185 "individual-retrieval.c"
}


static void __lambda8_ (Block2Data* _data2_, GObject* s, GAsyncResult* r) {
	IndividualRetrievalTests* self;
	Block3Data* _data3_;
	FolksBackendStore* backend_store = NULL;
	FolksBackendStore* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data2_->self;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (r != NULL);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data3_->_ref_count_ = 1;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data3_->_data2_ = block2_data_ref (_data2_);
#line 1205 "individual-retrieval.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp0_ = _data2_->aggregator;
#line 179 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp1_ = r;
#line 179 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 179 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		if (_inner_error_ != NULL) {
#line 1217 "individual-retrieval.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		e1 = _inner_error_;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_inner_error_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp2_ = e1->message;
#line 183 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_critical ("individual-retrieval.vala:183: failed to prepare aggregator: %s", _tmp2_);
#line 185 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_assert_not_reached ();
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_error_free0 (e1);
#line 1238 "individual-retrieval.c"
	}
	__finally1:
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (_inner_error_ != NULL) {
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		block3_data_unref (_data3_);
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data3_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_clear_error (&_inner_error_);
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		return;
#line 1253 "individual-retrieval.c"
	}
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data3_->adding_done = FALSE;
#line 196 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp3_ = folks_backend_store_dup ();
#line 196 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	backend_store = _tmp3_;
#line 1261 "individual-retrieval.c"
	{
		GeeIterator* _backend_it = NULL;
		FolksBackendStore* _tmp4_ = NULL;
		GeeMap* _tmp5_ = NULL;
		GeeMap* _tmp6_ = NULL;
		GeeCollection* _tmp7_ = NULL;
		GeeCollection* _tmp8_ = NULL;
		GeeCollection* _tmp9_ = NULL;
		GeeIterator* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp4_ = backend_store;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp5_ = folks_backend_store_get_enabled_backends (_tmp4_);
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp6_ = _tmp5_;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp7_ = gee_map_get_values (_tmp6_);
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp8_ = _tmp7_;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp9_ = _tmp8_;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp10_ = gee_iterable_iterator ((GeeIterable*) _tmp9_);
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp11_ = _tmp10_;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_tmp9_);
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_backend_it = _tmp11_;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		while (TRUE) {
#line 1294 "individual-retrieval.c"
			GeeIterator* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			FolksBackend* backend = NULL;
			GeeIterator* _tmp14_ = NULL;
			gpointer _tmp15_ = NULL;
			FolksBackend* _tmp16_ = NULL;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp12_ = _backend_it;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp13_ = gee_iterator_next (_tmp12_);
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (!_tmp13_) {
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 1309 "individual-retrieval.c"
			}
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp14_ = _backend_it;
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp15_ = gee_iterator_get (_tmp14_);
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			backend = (FolksBackend*) _tmp15_;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp16_ = backend;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			g_signal_connect_data (_tmp16_, "persona-store-added", (GCallback) _____lambda9__folks_backend_persona_store_added, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 1321 "individual-retrieval.c"
			{
				GeeIterator* _store_it = NULL;
				FolksBackend* _tmp17_ = NULL;
				GeeMap* _tmp18_ = NULL;
				GeeMap* _tmp19_ = NULL;
				GeeCollection* _tmp20_ = NULL;
				GeeCollection* _tmp21_ = NULL;
				GeeCollection* _tmp22_ = NULL;
				GeeIterator* _tmp23_ = NULL;
				GeeIterator* _tmp24_ = NULL;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp17_ = backend;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp18_ = folks_backend_get_persona_stores (_tmp17_);
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp19_ = _tmp18_;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp20_ = gee_map_get_values (_tmp19_);
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp21_ = _tmp20_;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp22_ = _tmp21_;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_tmp24_ = _tmp23_;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_g_object_unref0 (_tmp22_);
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_store_it = _tmp24_;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				while (TRUE) {
#line 1354 "individual-retrieval.c"
					GeeIterator* _tmp25_ = NULL;
					gboolean _tmp26_ = FALSE;
					FolksPersonaStore* store = NULL;
					GeeIterator* _tmp27_ = NULL;
					gpointer _tmp28_ = NULL;
					gboolean _tmp29_ = FALSE;
					FolksPersonaStore* _tmp30_ = NULL;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp25_ = _store_it;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp26_ = gee_iterator_next (_tmp25_);
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					if (!_tmp26_) {
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						break;
#line 1370 "individual-retrieval.c"
					}
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp27_ = _store_it;
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp28_ = gee_iterator_get (_tmp27_);
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					store = (FolksPersonaStore*) _tmp28_;
#line 212 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_tmp30_ = store;
#line 212 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, TPF_TYPE_PERSONA_STORE)) {
#line 1382 "individual-retrieval.c"
						gboolean _tmp31_ = FALSE;
#line 212 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp31_ = _data3_->adding_done;
#line 212 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp29_ = !_tmp31_;
#line 1388 "individual-retrieval.c"
					} else {
#line 212 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp29_ = FALSE;
#line 1392 "individual-retrieval.c"
					}
#line 212 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					if (_tmp29_) {
#line 1396 "individual-retrieval.c"
						FolksPersonaStore* _tmp32_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_tmp32_ = store;
#line 214 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						individual_retrieval_tests_add_personas (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, TPF_TYPE_PERSONA_STORE, TpfPersonaStore), _data2_->added_individuals, NULL, NULL);
#line 216 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
						_data3_->adding_done = TRUE;
#line 1404 "individual-retrieval.c"
					}
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					_g_object_unref0 (store);
#line 1408 "individual-retrieval.c"
				}
#line 210 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_g_object_unref0 (_store_it);
#line 1412 "individual-retrieval.c"
			}
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_object_unref0 (backend);
#line 1416 "individual-retrieval.c"
		}
#line 197 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_backend_it);
#line 1420 "individual-retrieval.c"
	}
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (backend_store);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	block3_data_unref (_data3_);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data3_ = NULL;
#line 1428 "individual-retrieval.c"
}


static void ___lambda8__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	__lambda8_ (self, source_object, res);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	block2_data_unref (self);
#line 1437 "individual-retrieval.c"
}


static gboolean __lambda7_ (Block2Data* _data2_) {
	IndividualRetrievalTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data2_->self;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = _data2_->aggregator;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda8__gasync_ready_callback, block2_data_ref (_data2_));
#line 222 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	result = FALSE;
#line 222 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return result;
#line 1455 "individual-retrieval.c"
}


static gboolean ___lambda7__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda7_ (self);
#line 173 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return result;
#line 1464 "individual-retrieval.c"
}


void individual_retrieval_tests_test_aggregator_add (IndividualRetrievalTests* self) {
	Block2Data* _data2_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (self != NULL);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_->_ref_count_ = 1;
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_->self = g_object_ref (self);
#line 128 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 128 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	main_loop = _tmp0_;
#line 130 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp1_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 130 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_->added_individuals = _tmp1_;
#line 131 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data2_->added_individuals, "master.shake@example.com");
#line 132 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data2_->added_individuals, "2wycked@example.com");
#line 133 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data2_->added_individuals, "carl-brutananadilewski@example.com");
#line 136 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp2_ = folks_individual_aggregator_dup ();
#line 136 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_->aggregator = _tmp2_;
#line 138 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp3_ = _data2_->aggregator;
#line 138 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda6__folks_individual_aggregator_individuals_changed_detailed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 173 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda7__gsource_func, block2_data_ref (_data2_), block2_data_unref);
#line 225 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 228 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp4_ = gee_abstract_collection_get_size ((GeeCollection*) _data2_->added_individuals);
#line 228 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp5_ = _tmp4_;
#line 228 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_vala_assert (_tmp5_ == 0, "added_individuals.size == 0");
#line 231 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (_data2_->aggregator);
#line 231 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_->aggregator = NULL;
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_main_loop_unref0 (main_loop);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	block2_data_unref (_data2_);
#line 126 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data2_ = NULL;
#line 1527 "individual-retrieval.c"
}


static void individual_retrieval_tests_add_personas_data_free (gpointer _data) {
	IndividualRetrievalTestsAddPersonasData* _data_;
	_data_ = _data;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (_data_->ids_add);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (_data_->self);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_slice_free (IndividualRetrievalTestsAddPersonasData, _data_);
#line 1540 "individual-retrieval.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return self ? g_object_ref (self) : NULL;
#line 1547 "individual-retrieval.c"
}


static void individual_retrieval_tests_add_personas (IndividualRetrievalTests* self, TpfPersonaStore* store, GeeHashSet* ids_add, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	IndividualRetrievalTestsAddPersonasData* _data_;
	IndividualRetrievalTests* _tmp0_ = NULL;
	TpfPersonaStore* _tmp1_ = NULL;
	TpfPersonaStore* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeHashSet* _tmp4_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_ = g_slice_new0 (IndividualRetrievalTestsAddPersonasData);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, individual_retrieval_tests_add_personas);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, individual_retrieval_tests_add_personas_data_free);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->self = _tmp0_;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp1_ = store;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (_data_->store);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->store = _tmp2_;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp3_ = ids_add;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (_data_->ids_add);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->ids_add = _tmp4_;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	individual_retrieval_tests_add_personas_co (_data_);
#line 1586 "individual-retrieval.c"
}


static void individual_retrieval_tests_add_personas_finish (IndividualRetrievalTests* self, GAsyncResult* _res_) {
	IndividualRetrievalTestsAddPersonasData* _data_;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1594 "individual-retrieval.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return _data4_;
#line 1603 "individual-retrieval.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 1612 "individual-retrieval.c"
		IndividualRetrievalTests* self;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		self = _data4_->self;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_data4_->store);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (self);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_slice_free (Block4Data, _data4_);
#line 1622 "individual-retrieval.c"
	}
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return _data5_;
#line 1632 "individual-retrieval.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 1641 "individual-retrieval.c"
		IndividualRetrievalTests* self;
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		self = _data5_->_data4_->self;
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_data5_->ids_remaining);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		block4_data_unref (_data5_->_data4_);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data5_->_data4_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_slice_free (Block5Data, _data5_);
#line 1653 "individual-retrieval.c"
	}
}


static void individual_retrieval_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	IndividualRetrievalTestsAddPersonasData* _data_;
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_ = _user_data_;
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_source_object_ = source_object;
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_res_ = _res_;
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	individual_retrieval_tests_add_personas_co (_data_);
#line 1668 "individual-retrieval.c"
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return _data6_;
#line 1677 "individual-retrieval.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 1686 "individual-retrieval.c"
		IndividualRetrievalTests* self;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		self = _data6_->_data5_->_data4_->self;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_hash_table_unref0 (_data6_->details);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		block5_data_unref (_data6_->_data5_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data6_->_data5_ = NULL;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_slice_free (Block6Data, _data6_);
#line 1698 "individual-retrieval.c"
	}
}


static void _g_free0_ (gpointer var) {
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	var = (g_free (var), NULL);
#line 1706 "individual-retrieval.c"
}


static void _vala_GValue_free (GValue* self) {
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_value_unset (self);
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_free (self);
#line 1715 "individual-retrieval.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1722 "individual-retrieval.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1729 "individual-retrieval.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1736 "individual-retrieval.c"
}


static void ____lambda11_ (Block6Data* _data6_, GObject* s2, GAsyncResult* res) {
	Block5Data* _data5_;
	Block4Data* _data4_;
	IndividualRetrievalTests* self;
	GError * _inner_error_ = NULL;
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data5_ = _data6_->_data5_;
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data4_ = _data5_->_data4_;
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data4_->self;
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_return_if_fail (res != NULL);
#line 1753 "individual-retrieval.c"
	{
		TpfPersonaStore* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		FolksPersona* _tmp2_ = NULL;
		FolksPersona* _tmp3_ = NULL;
		GValue* id_added_value = NULL;
		GHashTable* _tmp4_ = NULL;
		gconstpointer _tmp5_ = NULL;
		GValue* _tmp6_ = NULL;
		gchar* id_added = NULL;
		GValue* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp0_ = _data4_->store;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp1_ = res;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp2_ = folks_persona_store_add_persona_from_details_finish ((FolksPersonaStore*) _tmp0_, _tmp1_, &_inner_error_);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp3_ = _tmp2_;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_tmp3_);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		if (_inner_error_ != NULL) {
#line 1780 "individual-retrieval.c"
			goto __catch3_g_error;
		}
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp4_ = _data6_->details;
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp5_ = g_hash_table_lookup (_tmp4_, "contact");
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp6_ = __g_value_dup0 ((GValue*) _tmp5_);
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		id_added_value = _tmp6_;
#line 269 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp7_ = id_added_value;
#line 269 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp8_ = g_value_get_string (_tmp7_);
#line 269 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 269 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		id_added = _tmp9_;
#line 270 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp10_ = id_added;
#line 270 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		if (_tmp10_ != NULL) {
#line 1803 "individual-retrieval.c"
			GeeHashSet* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
#line 271 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp11_ = _data5_->ids_remaining;
#line 271 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp12_ = id_added;
#line 271 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp11_, _tmp12_);
#line 1812 "individual-retrieval.c"
		}
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_free0 (id_added);
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		__vala_GValue_free0 (id_added_value);
#line 1818 "individual-retrieval.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e1 = NULL;
		GError* _tmp13_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		e1 = _inner_error_;
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_inner_error_ = NULL;
#line 276 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp13_ = e1;
#line 276 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		if (!g_error_matches (_tmp13_, FOLKS_PERSONA_STORE_ERROR, FOLKS_PERSONA_STORE_ERROR_STORE_OFFLINE)) {
#line 1833 "individual-retrieval.c"
			GError* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp14_ = e1;
#line 278 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp15_ = _tmp14_->message;
#line 278 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			g_critical ("individual-retrieval.vala:278: failed to add persona: %s", _tmp15_);
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			g_assert_not_reached ();
#line 1844 "individual-retrieval.c"
		}
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_error_free0 (e1);
#line 1848 "individual-retrieval.c"
	}
	__finally3:
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (_inner_error_ != NULL) {
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_clear_error (&_inner_error_);
#line 264 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		return;
#line 1859 "individual-retrieval.c"
	}
}


static void _____lambda11__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	____lambda11_ (self, source_object, res);
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	block6_data_unref (self);
#line 1869 "individual-retrieval.c"
}


static gboolean ___lambda10_ (Block5Data* _data5_) {
	Block4Data* _data4_;
	IndividualRetrievalTests* self;
	gboolean result = FALSE;
	gboolean try_again = FALSE;
#line 249 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data4_ = _data5_->_data4_;
#line 249 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = _data4_->self;
#line 251 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	try_again = FALSE;
#line 1884 "individual-retrieval.c"
	{
		GeeIterator* _id_it = NULL;
		GeeHashSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp0_ = _data5_->ids_remaining;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_tmp1_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp0_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_id_it = _tmp1_;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		while (TRUE) {
#line 1897 "individual-retrieval.c"
			Block6Data* _data6_;
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			gchar* id = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			GHashFunc _tmp6_ = NULL;
			GEqualFunc _tmp7_ = NULL;
			GHashTable* _tmp8_ = NULL;
			GHashTable* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			GValue* _tmp12_ = NULL;
			TpfPersonaStore* _tmp13_ = NULL;
			GHashTable* _tmp14_ = NULL;
			GeeHashSet* _tmp15_ = NULL;
			gint _tmp16_ = 0;
			gint _tmp17_ = 0;
			gboolean _tmp18_ = FALSE;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data6_ = g_slice_new0 (Block6Data);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data6_->_ref_count_ = 1;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data6_->_data5_ = block5_data_ref (_data5_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp2_ = _id_it;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (!_tmp3_) {
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				block6_data_unref (_data6_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data6_ = NULL;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 1935 "individual-retrieval.c"
			}
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp4_ = _id_it;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			id = (gchar*) _tmp5_;
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp6_ = g_str_hash;
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp7_ = g_str_equal;
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp8_ = g_hash_table_new_full (_tmp6_, _tmp7_, _g_free0_, __vala_GValue_free0_);
#line 255 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data6_->details = _tmp8_;
#line 256 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp9_ = _data6_->details;
#line 256 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp10_ = g_strdup ("contact");
#line 256 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp11_ = id;
#line 256 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp12_ = g_new0 (GValue, 1);
#line 256 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			g_value_init (_tmp12_, G_TYPE_STRING);
#line 256 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			g_value_set_string (_tmp12_, _tmp11_);
#line 256 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			g_hash_table_insert (_tmp9_, _tmp10_, _tmp12_);
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp13_ = _data4_->store;
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp14_ = _data6_->details;
#line 262 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			folks_persona_store_add_persona_from_details ((FolksPersonaStore*) _tmp13_, _tmp14_, _____lambda11__gasync_ready_callback, block6_data_ref (_data6_));
#line 285 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp15_ = _data5_->ids_remaining;
#line 285 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp16_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp15_);
#line 285 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp17_ = _tmp16_;
#line 285 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			try_again = _tmp17_ > 0;
#line 286 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_tmp18_ = try_again;
#line 286 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			if (_tmp18_) {
#line 287 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_g_free0 (id);
#line 287 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				block6_data_unref (_data6_);
#line 287 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data6_ = NULL;
#line 287 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				break;
#line 1991 "individual-retrieval.c"
			}
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_free0 (id);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			block6_data_unref (_data6_);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data6_ = NULL;
#line 1999 "individual-retrieval.c"
		}
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_object_unref0 (_id_it);
#line 2003 "individual-retrieval.c"
	}
#line 290 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	result = try_again;
#line 290 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return result;
#line 2009 "individual-retrieval.c"
}


static gboolean ____lambda10__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda10_ (self);
#line 249 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return result;
#line 2018 "individual-retrieval.c"
}


static gboolean individual_retrieval_tests_add_personas_co (IndividualRetrievalTestsAddPersonasData* _data_) {
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	switch (_data_->_state_) {
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		case 0:
#line 2027 "individual-retrieval.c"
		goto _state_0;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		case 1:
#line 2031 "individual-retrieval.c"
		goto _state_1;
		default:
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_assert_not_reached ();
#line 2036 "individual-retrieval.c"
	}
	_state_0:
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_data4_ = g_slice_new0 (Block4Data);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_data4_->_ref_count_ = 1;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_data4_->self = g_object_ref (_data_->self);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_tmp0_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_tmp0_ = _data_->store;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (_data_->_data4_->store);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_data4_->store = _data_->_tmp0_;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_data4_->_async_data_ = _data_;
#line 2055 "individual-retrieval.c"
	{
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_data5_ = g_slice_new0 (Block5Data);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_data5_->_ref_count_ = 1;
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_data5_->_data4_ = block4_data_ref (_data_->_data4_);
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp1_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp1_ = _data_->_data4_->store;
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_state_ = 1;
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		folks_persona_store_prepare ((FolksPersonaStore*) _data_->_tmp1_, individual_retrieval_tests_add_personas_ready, _data_);
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		return FALSE;
#line 2073 "individual-retrieval.c"
		_state_1:
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		folks_persona_store_prepare_finish ((FolksPersonaStore*) _data_->_tmp1_, _data_->_res_, &_data_->_inner_error_);
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		if (_data_->_inner_error_ != NULL) {
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			block5_data_unref (_data_->_data5_);
#line 239 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data_->_data5_ = NULL;
#line 2083 "individual-retrieval.c"
			goto __catch2_g_error;
		}
#line 245 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp2_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp2_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 245 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_data5_->ids_remaining = _data_->_tmp2_;
#line 2092 "individual-retrieval.c"
		{
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data_->_tmp3_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data_->_tmp3_ = _data_->ids_add;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data_->_tmp4_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data_->_tmp4_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _data_->_tmp3_);
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_data_->_contact_id_it = _data_->_tmp4_;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			while (TRUE) {
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp5_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp5_ = _data_->_contact_id_it;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp6_ = FALSE;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp6_ = gee_iterator_next (_data_->_tmp5_);
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				if (!_data_->_tmp6_) {
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
					break;
#line 2118 "individual-retrieval.c"
				}
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp7_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp7_ = _data_->_contact_id_it;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp8_ = NULL;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp8_ = gee_iterator_get (_data_->_tmp7_);
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->contact_id = (gchar*) _data_->_tmp8_;
#line 247 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp9_ = NULL;
#line 247 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp9_ = _data_->_data5_->ids_remaining;
#line 247 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp10_ = NULL;
#line 247 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_data_->_tmp10_ = _data_->contact_id;
#line 247 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp9_, _data_->_tmp10_);
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
				_g_free0 (_data_->contact_id);
#line 2142 "individual-retrieval.c"
			}
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
			_g_object_unref0 (_data_->_contact_id_it);
#line 2146 "individual-retrieval.c"
		}
#line 249 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ____lambda10__gsource_func, block5_data_ref (_data_->_data5_), block5_data_unref);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		block5_data_unref (_data_->_data5_);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_data5_ = NULL;
#line 2154 "individual-retrieval.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->e2 = _data_->_inner_error_;
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_inner_error_ = NULL;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp11_ = NULL;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp11_ = _data_->_data4_->store;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp12_ = NULL;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp12_ = folks_persona_store_get_id ((FolksPersonaStore*) _data_->_tmp11_);
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp13_ = NULL;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp14_ = NULL;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_tmp14_ = _data_->e2->message;
#line 295 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_warning ("individual-retrieval.vala:295: Error preparing PersonaStore '%s': %s", _data_->_tmp13_, _data_->_tmp14_);
#line 297 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_assert_not_reached ();
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_g_error_free0 (_data_->e2);
#line 2185 "individual-retrieval.c"
	}
	__finally2:
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (_data_->_inner_error_ != NULL) {
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		block4_data_unref (_data_->_data4_);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		_data_->_data4_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_clear_error (&_data_->_inner_error_);
#line 237 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		return FALSE;
#line 2200 "individual-retrieval.c"
	}
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	block4_data_unref (_data_->_data4_);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_data_->_data4_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	if (_data_->_state_ == 0) {
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2210 "individual-retrieval.c"
	} else {
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2214 "individual-retrieval.c"
	}
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_object_unref (_data_->_async_result);
#line 234 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return FALSE;
#line 2220 "individual-retrieval.c"
}


static void individual_retrieval_tests_class_init (IndividualRetrievalTestsClass * klass) {
	gchar* _tmp0_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	individual_retrieval_tests_parent_class = g_type_class_peek_parent (klass);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_type_class_add_private (klass, sizeof (IndividualRetrievalTestsPrivate));
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	G_OBJECT_CLASS (klass)->finalize = individual_retrieval_tests_finalize;
#line 31 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = g_strdup ("telepathy:/org/freedesktop/Telepathy/Account/cm/protocol/account:");
#line 31 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	individual_retrieval_tests_iid_prefix = _tmp0_;
#line 2236 "individual-retrieval.c"
}


static void individual_retrieval_tests_instance_init (IndividualRetrievalTests * self) {
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self->priv = INDIVIDUAL_RETRIEVAL_TESTS_GET_PRIVATE (self);
#line 2243 "individual-retrieval.c"
}


static void individual_retrieval_tests_finalize (GObject* obj) {
	IndividualRetrievalTests * self;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTests);
#line 29 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (self->priv->default_individuals);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	G_OBJECT_CLASS (individual_retrieval_tests_parent_class)->finalize (obj);
#line 2255 "individual-retrieval.c"
}


GType individual_retrieval_tests_get_type (void) {
	static volatile gsize individual_retrieval_tests_type_id__volatile = 0;
	if (g_once_init_enter (&individual_retrieval_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (IndividualRetrievalTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) individual_retrieval_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (IndividualRetrievalTests), 0, (GInstanceInitFunc) individual_retrieval_tests_instance_init, NULL };
		GType individual_retrieval_tests_type_id;
		individual_retrieval_tests_type_id = g_type_register_static (TPF_TEST_TYPE_TEST_CASE, "IndividualRetrievalTests", &g_define_type_info, 0);
		g_once_init_leave (&individual_retrieval_tests_type_id__volatile, individual_retrieval_tests_type_id);
	}
	return individual_retrieval_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	IndividualRetrievalTests* tests = NULL;
	IndividualRetrievalTests* _tmp0_ = NULL;
#line 304 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_test_init (&args_length1, &args, NULL);
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_tmp0_ = individual_retrieval_tests_new ();
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	tests = _tmp0_;
#line 307 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 308 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	g_test_run ();
#line 309 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 311 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	result = 0;
#line 311 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	_g_object_unref0 (tests);
#line 311 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return result;
#line 2293 "individual-retrieval.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 302 "/opt/gnome3/source/folks/tests/telepathy/individual-retrieval.vala"
	return _vala_main (argv, argc);
#line 2303 "individual-retrieval.c"
}



