/* phone-details.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from phone-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <folks/folks-eds.h>


#define TYPE_PHONE_DETAILS_TESTS (phone_details_tests_get_type ())
#define PHONE_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTests))
#define PHONE_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsClass))
#define IS_PHONE_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHONE_DETAILS_TESTS))
#define IS_PHONE_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHONE_DETAILS_TESTS))
#define PHONE_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsClass))

typedef struct _PhoneDetailsTests PhoneDetailsTests;
typedef struct _PhoneDetailsTestsClass PhoneDetailsTestsClass;
typedef struct _PhoneDetailsTestsPrivate PhoneDetailsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PhoneDetailsTestsTestPhoneNumbersAsyncData PhoneDetailsTestsTestPhoneNumbersAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PhoneDetailsTests {
	EdsTestTestCase parent_instance;
	PhoneDetailsTestsPrivate * priv;
};

struct _PhoneDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _PhoneDetailsTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _phones_count;
	GeeHashSet* _phone_types;
	GeeHashMap* _c1;
	GeeHashMap* _c2;
};

struct _PhoneDetailsTestsTestPhoneNumbersAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	PhoneDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer phone_details_tests_parent_class = NULL;

GType phone_details_tests_get_type (void) G_GNUC_CONST;
#define PHONE_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTestsPrivate))
enum  {
	PHONE_DETAILS_TESTS_DUMMY_PROPERTY
};
PhoneDetailsTests* phone_details_tests_new (void);
PhoneDetailsTests* phone_details_tests_construct (GType object_type);
void phone_details_tests_test_phone_numbers (PhoneDetailsTests* self);
static void _phone_details_tests_test_phone_numbers_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _phone_details_tests_test_phone_numbers_async (PhoneDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _phone_details_tests_test_phone_numbers_finish (PhoneDetailsTests* self, GAsyncResult* _res_);
static gboolean _vala_string_array_contains (const gchar** stack, int stack_length, const gchar* needle);
static void _phone_details_tests_test_phone_numbers_async_data_free (gpointer _data);
static gboolean _phone_details_tests_test_phone_numbers_async_co (PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_);
static void _phone_details_tests_test_phone_numbers_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _phone_details_tests_individuals_changed_cb (PhoneDetailsTests* self, GeeMultiMap* changes);
static void __phone_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void phone_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _phone_details_tests_test_phone_numbers_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	phone_details_tests_test_phone_numbers ((PhoneDetailsTests*) self);
#line 120 "phone-details.c"
}


PhoneDetailsTests* phone_details_tests_construct (GType object_type) {
	PhoneDetailsTests * self = NULL;
#line 36 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self = (PhoneDetailsTests*) eds_test_test_case_construct (object_type, "PhoneDetails");
#line 38 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "phone details interface", _phone_details_tests_test_phone_numbers_folks_test_case_test_method, self);
#line 34 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return self;
#line 132 "phone-details.c"
}


PhoneDetailsTests* phone_details_tests_new (void) {
#line 34 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return phone_details_tests_construct (TYPE_PHONE_DETAILS_TESTS);
#line 139 "phone-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 146 "phone-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_unset (self);
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_free (self);
#line 155 "phone-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 162 "phone-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 169 "phone-details.c"
}


static gboolean _vala_string_array_contains (const gchar** stack, int stack_length, const gchar* needle) {
	int i;
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	for (i = 0; i < stack_length; i++) {
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			return TRUE;
#line 181 "phone-details.c"
		}
	}
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 186 "phone-details.c"
}


void phone_details_tests_test_phone_numbers (PhoneDetailsTests* self) {
	GeeHashSet* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GeeHashMap* _tmp2_ = NULL;
	GMainLoop* _tmp3_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp4_ = NULL;
	GValue _tmp5_ = {0};
	GValue _tmp6_ = {0};
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GeeHashMap* _tmp9_ = NULL;
	GValue* _tmp10_ = NULL;
	GValue* _tmp11_ = NULL;
	GValue _tmp12_ = {0};
	GValue _tmp13_ = {0};
	GValue* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	GeeHashMap* _tmp16_ = NULL;
	GValue* _tmp17_ = NULL;
	GValue* _tmp18_ = NULL;
	GValue _tmp19_ = {0};
	GValue _tmp20_ = {0};
	GValue* _tmp21_ = NULL;
	GValue* _tmp22_ = NULL;
	GeeHashMap* _tmp23_ = NULL;
	GValue* _tmp24_ = NULL;
	GValue* _tmp25_ = NULL;
	GValue _tmp26_ = {0};
	GValue _tmp27_ = {0};
	GValue* _tmp28_ = NULL;
	GValue* _tmp29_ = NULL;
	GeeHashMap* _tmp30_ = NULL;
	GValue* _tmp31_ = NULL;
	GValue* _tmp32_ = NULL;
	EdsTestBackend* _tmp33_ = NULL;
	GeeHashMap* _tmp34_ = NULL;
	GeeHashMap* _tmp35_ = NULL;
	GValue _tmp36_ = {0};
	GValue _tmp37_ = {0};
	GValue* _tmp38_ = NULL;
	GValue* _tmp39_ = NULL;
	GeeHashMap* _tmp40_ = NULL;
	GValue* _tmp41_ = NULL;
	GValue* _tmp42_ = NULL;
	GValue _tmp43_ = {0};
	GValue _tmp44_ = {0};
	GValue* _tmp45_ = NULL;
	GValue* _tmp46_ = NULL;
	GeeHashMap* _tmp47_ = NULL;
	GValue* _tmp48_ = NULL;
	GValue* _tmp49_ = NULL;
	GValue _tmp50_ = {0};
	GValue _tmp51_ = {0};
	GValue* _tmp52_ = NULL;
	GValue* _tmp53_ = NULL;
	GeeHashMap* _tmp54_ = NULL;
	GValue* _tmp55_ = NULL;
	GValue* _tmp56_ = NULL;
	GValue _tmp57_ = {0};
	GValue _tmp58_ = {0};
	GValue* _tmp59_ = NULL;
	GValue* _tmp60_ = NULL;
	GeeHashMap* _tmp61_ = NULL;
	GValue* _tmp62_ = NULL;
	GValue* _tmp63_ = NULL;
	EdsTestBackend* _tmp64_ = NULL;
	GeeHashMap* _tmp65_ = NULL;
	GeeHashMap* _tmp66_ = NULL;
	GMainLoop* _tmp67_ = NULL;
	gint _tmp68_ = 0;
	GeeHashSet* _tmp69_ = NULL;
	gint _tmp70_ = 0;
	gint _tmp71_ = 0;
	GeeHashMap* _tmp72_ = NULL;
	gint _tmp73_ = 0;
	gint _tmp74_ = 0;
	GeeHashMap* _tmp75_ = NULL;
	gint _tmp76_ = 0;
	gint _tmp77_ = 0;
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_return_if_fail (self != NULL);
#line 43 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self->priv->_phones_count = 0;
#line 44 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 44 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_phone_types);
#line 44 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self->priv->_phone_types = _tmp0_;
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 45 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self->priv->_c1 = _tmp1_;
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 46 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self->priv->_c2 = _tmp2_;
#line 47 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp3_ = g_main_loop_new (NULL, FALSE);
#line 47 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 47 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self->priv->_main_loop = _tmp3_;
#line 50 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp4_ = ((EdsTestTestCase*) self)->eds_backend;
#line 50 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_reset (_tmp4_);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp5_, G_TYPE_STRING);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp6_ = _tmp5_;
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp7_ = __g_value_dup0 (&_tmp6_);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp7_;
#line 52 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp6_) ? (g_value_unset (&_tmp6_), NULL) : NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp8_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp8_, "bernie h. innocenti");
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp9_ = self->priv->_c1;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp10_ = v;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp11_ = _tmp10_;
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp9_, "full_name", _tmp11_);
#line 54 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp11_);
#line 55 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp12_, G_TYPE_STRING);
#line 55 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp13_ = _tmp12_;
#line 55 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp14_ = __g_value_dup0 (&_tmp13_);
#line 55 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 55 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp14_;
#line 55 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp13_) ? (g_value_unset (&_tmp13_), NULL) : NULL;
#line 56 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp15_ = v;
#line 56 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp15_, "123");
#line 57 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp16_ = self->priv->_c1;
#line 57 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp17_ = v;
#line 57 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp18_ = _tmp17_;
#line 57 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp16_, "car_phone", _tmp18_);
#line 57 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp18_);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp19_, G_TYPE_STRING);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp20_ = _tmp19_;
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp21_ = __g_value_dup0 (&_tmp20_);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp21_;
#line 58 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp20_) ? (g_value_unset (&_tmp20_), NULL) : NULL;
#line 59 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp22_ = v;
#line 59 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp22_, "1234");
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp23_ = self->priv->_c1;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp24_ = v;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp25_ = _tmp24_;
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp23_, "company_phone", _tmp25_);
#line 60 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp25_);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp26_, G_TYPE_STRING);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp27_ = _tmp26_;
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp28_ = __g_value_dup0 (&_tmp27_);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp28_;
#line 61 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp27_) ? (g_value_unset (&_tmp27_), NULL) : NULL;
#line 62 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp29_ = v;
#line 62 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp29_, "12345");
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp30_ = self->priv->_c1;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp31_ = v;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp32_ = _tmp31_;
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp30_, "home_phone", _tmp32_);
#line 63 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp32_);
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp33_ = ((EdsTestTestCase*) self)->eds_backend;
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp34_ = self->priv->_c1;
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp35_ = _g_object_ref0 (_tmp34_);
#line 64 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_add_contact (_tmp33_, _tmp35_);
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp36_, G_TYPE_STRING);
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp37_ = _tmp36_;
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp38_ = __g_value_dup0 (&_tmp37_);
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp38_;
#line 66 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp37_) ? (g_value_unset (&_tmp37_), NULL) : NULL;
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp39_ = v;
#line 67 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp39_, "richard m. stallman");
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp40_ = self->priv->_c2;
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp41_ = v;
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp42_ = _tmp41_;
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp40_, "full_name", _tmp42_);
#line 68 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp42_);
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp43_, G_TYPE_STRING);
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp44_ = _tmp43_;
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp45_ = __g_value_dup0 (&_tmp44_);
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp45_;
#line 69 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp44_) ? (g_value_unset (&_tmp44_), NULL) : NULL;
#line 70 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp46_ = v;
#line 70 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp46_, "54321");
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp47_ = self->priv->_c2;
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp48_ = v;
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp49_ = _tmp48_;
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp47_, "car_phone", _tmp49_);
#line 71 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp49_);
#line 72 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp50_, G_TYPE_STRING);
#line 72 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp51_ = _tmp50_;
#line 72 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp52_ = __g_value_dup0 (&_tmp51_);
#line 72 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 72 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp52_;
#line 72 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp51_) ? (g_value_unset (&_tmp51_), NULL) : NULL;
#line 73 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp53_ = v;
#line 73 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp53_, "4321");
#line 74 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp54_ = self->priv->_c2;
#line 74 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp55_ = v;
#line 74 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 74 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp56_ = _tmp55_;
#line 74 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp54_, "company_phone", _tmp56_);
#line 74 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp56_);
#line 75 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_init (&_tmp57_, G_TYPE_STRING);
#line 75 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp58_ = _tmp57_;
#line 75 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp59_ = __g_value_dup0 (&_tmp58_);
#line 75 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 75 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = _tmp59_;
#line 75 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_IS_VALUE (&_tmp58_) ? (g_value_unset (&_tmp58_), NULL) : NULL;
#line 76 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp60_ = v;
#line 76 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_value_set_string (_tmp60_, "321");
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp61_ = self->priv->_c2;
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp62_ = v;
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	v = NULL;
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp63_ = _tmp62_;
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp61_, "home_phone", _tmp63_);
#line 77 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (_tmp63_);
#line 78 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp64_ = ((EdsTestTestCase*) self)->eds_backend;
#line 78 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp65_ = self->priv->_c2;
#line 78 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp66_ = _g_object_ref0 (_tmp65_);
#line 78 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_add_contact (_tmp64_, _tmp66_);
#line 80 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_test_phone_numbers_async (self, NULL, NULL);
#line 82 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp67_ = self->priv->_main_loop;
#line 82 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp67_, 5);
#line 84 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp68_ = self->priv->_phones_count;
#line 84 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp68_ == 6, "this._phones_count == 6");
#line 85 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp69_ = self->priv->_phone_types;
#line 85 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp70_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp69_);
#line 85 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp71_ = _tmp70_;
#line 85 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp71_ == 3, "this._phone_types.size == 3");
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp72_ = self->priv->_c1;
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp73_ = gee_abstract_map_get_size ((GeeMap*) _tmp72_);
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp74_ = _tmp73_;
#line 86 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp74_ == 0, "this._c1.size == 0");
#line 87 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp75_ = self->priv->_c2;
#line 87 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp76_ = gee_abstract_map_get_size ((GeeMap*) _tmp75_);
#line 87 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp77_ = _tmp76_;
#line 87 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp77_ == 0, "this._c2.size == 0");
#line 576 "phone-details.c"
	{
		GeeIterator* _pt_it = NULL;
		GeeHashSet* _tmp78_ = NULL;
		GeeIterator* _tmp79_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp78_ = self->priv->_phone_types;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp79_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp78_);
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_pt_it = _tmp79_;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		while (TRUE) {
#line 589 "phone-details.c"
			GeeIterator* _tmp80_ = NULL;
			gboolean _tmp81_ = FALSE;
			gchar* pt = NULL;
			GeeIterator* _tmp82_ = NULL;
			gpointer _tmp83_ = NULL;
			const gchar* _tmp84_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp80_ = _pt_it;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp81_ = gee_iterator_next (_tmp80_);
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			if (!_tmp81_) {
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				break;
#line 604 "phone-details.c"
			}
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp82_ = _pt_it;
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp83_ = gee_iterator_get (_tmp82_);
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			pt = (gchar*) _tmp83_;
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp84_ = pt;
#line 91 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_vala_assert (_vala_string_array_contains (EDSF_PERSONA_phone_fields, G_N_ELEMENTS (EDSF_PERSONA_phone_fields), _tmp84_), "pt in Edsf.Persona.phone_fields");
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_g_free0 (pt);
#line 618 "phone-details.c"
		}
#line 89 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_pt_it);
#line 622 "phone-details.c"
	}
#line 41 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	__vala_GValue_free0 (v);
#line 626 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_async_data_free (gpointer _data) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_slice_free (PhoneDetailsTestsTestPhoneNumbersAsyncData, _data_);
#line 637 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_async (PhoneDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
	PhoneDetailsTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_ = g_slice_new0 (PhoneDetailsTestsTestPhoneNumbersAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _phone_details_tests_test_phone_numbers_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _phone_details_tests_test_phone_numbers_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_test_phone_numbers_async_co (_data_);
#line 656 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_finish (PhoneDetailsTests* self, GAsyncResult* _res_) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 664 "phone-details.c"
}


static void _phone_details_tests_test_phone_numbers_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_;
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_ = _user_data_;
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_source_object_ = source_object;
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_res_ = _res_;
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_test_phone_numbers_async_co (_data_);
#line 678 "phone-details.c"
}


static void __phone_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 103 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_phone_details_tests_individuals_changed_cb ((PhoneDetailsTests*) self, changes);
#line 685 "phone-details.c"
}


static gboolean _phone_details_tests_test_phone_numbers_async_co (PhoneDetailsTestsTestPhoneNumbersAsyncData* _data_) {
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	switch (_data_->_state_) {
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		case 0:
#line 694 "phone-details.c"
		goto _state_0;
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		case 1:
#line 698 "phone-details.c"
		goto _state_1;
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		case 2:
#line 702 "phone-details.c"
		goto _state_2;
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		case 3:
#line 706 "phone-details.c"
		goto _state_3;
		default:
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		g_assert_not_reached ();
#line 711 "phone-details.c"
	}
	_state_0:
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp0_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_state_ = 1;
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _phone_details_tests_test_phone_numbers_async_ready, _data_);
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 724 "phone-details.c"
	_state_1:
#line 98 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 100 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp1_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 100 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->store = _data_->_tmp1_;
#line 101 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_state_ = 2;
#line 101 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_backend_store_prepare (_data_->store, _phone_details_tests_test_phone_numbers_async_ready, _data_);
#line 101 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 740 "phone-details.c"
	_state_2:
#line 101 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 102 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp2_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 102 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 102 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 103 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp3_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 103 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __phone_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 758 "phone-details.c"
	{
#line 107 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp4_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 107 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_state_ = 3;
#line 107 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _phone_details_tests_test_phone_numbers_async_ready, _data_);
#line 107 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		return FALSE;
#line 770 "phone-details.c"
		_state_3:
#line 107 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 107 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 776 "phone-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->e = _data_->_inner_error_;
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_inner_error_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp5_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 111 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp6_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 111 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		g_warning ("phone-details.vala:111: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_g_error_free0 (_data_->e);
#line 799 "phone-details.c"
	}
	__finally0:
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_data_->store);
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 105 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		return FALSE;
#line 812 "phone-details.c"
	}
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (_data_->store);
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	if (_data_->_state_ == 0) {
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 820 "phone-details.c"
	} else {
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 824 "phone-details.c"
	}
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_object_unref (_data_->_async_result);
#line 95 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return FALSE;
#line 830 "phone-details.c"
}


static void _phone_details_tests_individuals_changed_cb (PhoneDetailsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gint _tmp66_ = 0;
	GeeSet* _tmp68_ = NULL;
	gint _tmp69_ = 0;
	gint _tmp70_ = 0;
#line 115 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_return_if_fail (self != NULL);
#line 115 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_return_if_fail (changes != NULL);
#line 118 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = changes;
#line 118 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 118 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	added = _tmp1_;
#line 119 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp2_ = changes;
#line 119 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 119 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	removed = _tmp3_;
#line 861 "phone-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp4_ = added;
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_i_it = _tmp5_;
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		while (TRUE) {
#line 874 "phone-details.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			GeeHashMap* contact = NULL;
			FolksIndividual* _tmp11_ = NULL;
			GeeSet* _tmp12_ = NULL;
			GeeSet* _tmp13_ = NULL;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			FolksIndividual* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			GeeHashMap* _tmp24_ = NULL;
			GeeHashMap* _tmp25_ = NULL;
			FolksPhoneDetails* phone_numbers = NULL;
			FolksIndividual* _tmp26_ = NULL;
			FolksPhoneDetails* _tmp27_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp6_ = _i_it;
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			if (!_tmp7_) {
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				break;
#line 903 "phone-details.c"
			}
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp8_ = _i_it;
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 123 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp10_ = i;
#line 123 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 125 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			contact = NULL;
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp11_ = i;
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp13_ = _tmp12_;
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp15_ = _tmp14_;
#line 126 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_vala_assert (_tmp15_ == 1, "i.personas.size == 1");
#line 128 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp16_ = i;
#line 128 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp17_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp16_);
#line 128 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp18_ = _tmp17_;
#line 128 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			if (g_strcmp0 (_tmp18_, "bernie h. innocenti") == 0) {
#line 937 "phone-details.c"
				GeeHashMap* _tmp19_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp19_ = self->priv->_c1;
#line 130 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				contact = _tmp19_;
#line 943 "phone-details.c"
			} else {
				FolksIndividual* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp20_ = i;
#line 132 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp21_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp20_);
#line 132 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp22_ = _tmp21_;
#line 132 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				if (g_strcmp0 (_tmp22_, "richard m. stallman") == 0) {
#line 956 "phone-details.c"
					GeeHashMap* _tmp23_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp23_ = self->priv->_c2;
#line 134 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					contact = _tmp23_;
#line 962 "phone-details.c"
				}
			}
#line 137 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp24_ = contact;
#line 137 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			if (_tmp24_ == NULL) {
#line 139 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_g_object_unref0 (i);
#line 139 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				continue;
#line 973 "phone-details.c"
			}
#line 142 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp25_ = contact;
#line 142 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			gee_abstract_map_unset ((GeeAbstractMap*) _tmp25_, "full_name", NULL);
#line 143 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp26_ = i;
#line 143 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, FOLKS_TYPE_PHONE_DETAILS, FolksPhoneDetails));
#line 143 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			phone_numbers = _tmp27_;
#line 985 "phone-details.c"
			{
				GeeIterator* _phone_fd_it = NULL;
				FolksPhoneDetails* _tmp28_ = NULL;
				GeeSet* _tmp29_ = NULL;
				GeeSet* _tmp30_ = NULL;
				GeeIterator* _tmp31_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp28_ = phone_numbers;
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp29_ = folks_phone_details_get_phone_numbers (_tmp28_);
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp30_ = _tmp29_;
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_tmp31_ = gee_iterable_iterator ((GeeIterable*) _tmp30_);
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_phone_fd_it = _tmp31_;
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				while (TRUE) {
#line 1004 "phone-details.c"
					GeeIterator* _tmp32_ = NULL;
					gboolean _tmp33_ = FALSE;
					FolksPhoneFieldDetails* phone_fd = NULL;
					GeeIterator* _tmp34_ = NULL;
					gpointer _tmp35_ = NULL;
					gint _tmp36_ = 0;
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp32_ = _phone_fd_it;
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp33_ = gee_iterator_next (_tmp32_);
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					if (!_tmp33_) {
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						break;
#line 1019 "phone-details.c"
					}
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp34_ = _phone_fd_it;
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp35_ = gee_iterator_get (_tmp34_);
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					phone_fd = (FolksPhoneFieldDetails*) _tmp35_;
#line 146 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_tmp36_ = self->priv->_phones_count;
#line 146 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					self->priv->_phones_count = _tmp36_ + 1;
#line 1031 "phone-details.c"
					{
						GeeIterator* _t_it = NULL;
						FolksPhoneFieldDetails* _tmp37_ = NULL;
						GeeCollection* _tmp38_ = NULL;
						GeeCollection* _tmp39_ = NULL;
						GeeIterator* _tmp40_ = NULL;
						GeeIterator* _tmp41_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp37_ = phone_fd;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp38_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp37_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp39_ = _tmp38_;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp40_ = gee_iterable_iterator ((GeeIterable*) _tmp39_);
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_tmp41_ = _tmp40_;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_g_object_unref0 (_tmp39_);
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_t_it = _tmp41_;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						while (TRUE) {
#line 1055 "phone-details.c"
							GeeIterator* _tmp42_ = NULL;
							gboolean _tmp43_ = FALSE;
							gchar* t = NULL;
							GeeIterator* _tmp44_ = NULL;
							gpointer _tmp45_ = NULL;
							gchar* v = NULL;
							const gchar* _tmp46_ = NULL;
							const gchar* _tmp52_ = NULL;
							GeeHashSet* _tmp53_ = NULL;
							const gchar* _tmp54_ = NULL;
							GeeHashMap* _tmp55_ = NULL;
							const gchar* _tmp56_ = NULL;
							gpointer _tmp57_ = NULL;
							GValue* _tmp58_ = NULL;
							GValue _tmp59_ = {0};
							const gchar* _tmp60_ = NULL;
							FolksPhoneFieldDetails* _tmp61_ = NULL;
							gconstpointer _tmp62_ = NULL;
							const gchar* _tmp63_ = NULL;
							GeeHashMap* _tmp64_ = NULL;
							const gchar* _tmp65_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp42_ = _t_it;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp43_ = gee_iterator_next (_tmp42_);
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							if (!_tmp43_) {
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								break;
#line 1085 "phone-details.c"
							}
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp44_ = _t_it;
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp45_ = gee_iterator_get (_tmp44_);
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							t = (gchar*) _tmp45_;
#line 150 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							v = NULL;
#line 152 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp46_ = t;
#line 152 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							if (g_strcmp0 (_tmp46_, "car") == 0) {
#line 1099 "phone-details.c"
								gchar* _tmp47_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp47_ = g_strdup ("car_phone");
#line 154 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_g_free0 (v);
#line 154 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								v = _tmp47_;
#line 1107 "phone-details.c"
							} else {
								const gchar* _tmp48_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_tmp48_ = t;
#line 156 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								if (g_strcmp0 (_tmp48_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME) == 0) {
#line 1114 "phone-details.c"
									gchar* _tmp49_ = NULL;
#line 158 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp49_ = g_strdup ("home_phone");
#line 158 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_g_free0 (v);
#line 158 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									v = _tmp49_;
#line 1122 "phone-details.c"
								} else {
									const gchar* _tmp50_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									_tmp50_ = t;
#line 160 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
									if (g_strcmp0 (_tmp50_, "x-evolution-company") == 0) {
#line 1129 "phone-details.c"
										gchar* _tmp51_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										_tmp51_ = g_strdup ("company_phone");
#line 162 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										_g_free0 (v);
#line 162 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
										v = _tmp51_;
#line 1137 "phone-details.c"
									}
								}
							}
#line 165 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp52_ = v;
#line 165 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							if (_tmp52_ == NULL) {
#line 167 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_g_free0 (v);
#line 167 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								_g_free0 (t);
#line 167 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
								continue;
#line 1151 "phone-details.c"
							}
#line 170 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp53_ = self->priv->_phone_types;
#line 170 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp54_ = v;
#line 170 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							gee_abstract_collection_add ((GeeAbstractCollection*) _tmp53_, _tmp54_);
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp55_ = contact;
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp56_ = v;
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp57_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp55_, _tmp56_);
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp58_ = (GValue*) _tmp57_;
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp59_ = *_tmp58_;
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp60_ = g_value_get_string (&_tmp59_);
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp61_ = phone_fd;
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp62_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp61_);
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp63_ = _tmp62_;
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_vala_assert (g_strcmp0 (_tmp60_, (const gchar*) _tmp63_) == 0, "contact.get (v).get_string () == phone_fd.value");
#line 171 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							__vala_GValue_free0 (_tmp58_);
#line 172 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp64_ = contact;
#line 172 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_tmp65_ = v;
#line 172 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							gee_abstract_map_unset ((GeeAbstractMap*) _tmp64_, _tmp65_, NULL);
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_g_free0 (v);
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
							_g_free0 (t);
#line 1191 "phone-details.c"
						}
#line 147 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
						_g_object_unref0 (_t_it);
#line 1195 "phone-details.c"
					}
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
					_g_object_unref0 (phone_fd);
#line 1199 "phone-details.c"
				}
#line 144 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				_g_object_unref0 (_phone_fd_it);
#line 1203 "phone-details.c"
			}
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_g_object_unref0 (phone_numbers);
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_g_object_unref0 (i);
#line 1209 "phone-details.c"
		}
#line 121 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_i_it);
#line 1213 "phone-details.c"
	}
#line 177 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp66_ = self->priv->_phones_count;
#line 177 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	if (_tmp66_ == 6) {
#line 1219 "phone-details.c"
		GMainLoop* _tmp67_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp67_ = self->priv->_main_loop;
#line 179 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		g_main_loop_quit (_tmp67_);
#line 1225 "phone-details.c"
	}
#line 182 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp68_ = removed;
#line 182 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp69_ = gee_collection_get_size ((GeeCollection*) _tmp68_);
#line 182 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp70_ = _tmp69_;
#line 182 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_vala_assert (_tmp70_ == 1, "removed.size == 1");
#line 1235 "phone-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp71_ = NULL;
		GeeIterator* _tmp72_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp71_ = removed;
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_tmp72_ = gee_iterable_iterator ((GeeIterable*) _tmp71_);
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_i_it = _tmp72_;
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		while (TRUE) {
#line 1248 "phone-details.c"
			GeeIterator* _tmp73_ = NULL;
			gboolean _tmp74_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp75_ = NULL;
			gpointer _tmp76_ = NULL;
			FolksIndividual* _tmp77_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp73_ = _i_it;
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp74_ = gee_iterator_next (_tmp73_);
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			if (!_tmp74_) {
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
				break;
#line 1263 "phone-details.c"
			}
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp75_ = _i_it;
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp76_ = gee_iterator_get (_tmp75_);
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			i = (FolksIndividual*) _tmp76_;
#line 186 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_tmp77_ = i;
#line 186 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_vala_assert (_tmp77_ == NULL, "i == null");
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
			_g_object_unref0 (i);
#line 1277 "phone-details.c"
		}
#line 184 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
		_g_object_unref0 (_i_it);
#line 1281 "phone-details.c"
	}
#line 115 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (removed);
#line 115 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (added);
#line 1287 "phone-details.c"
}


static void phone_details_tests_class_init (PhoneDetailsTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	phone_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_type_class_add_private (klass, sizeof (PhoneDetailsTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_OBJECT_CLASS (klass)->finalize = phone_details_tests_finalize;
#line 1298 "phone-details.c"
}


static void phone_details_tests_instance_init (PhoneDetailsTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self->priv = PHONE_DETAILS_TESTS_GET_PRIVATE (self);
#line 1305 "phone-details.c"
}


static void phone_details_tests_finalize (GObject* obj) {
	PhoneDetailsTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHONE_DETAILS_TESTS, PhoneDetailsTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 28 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_phone_types);
#line 31 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 32 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 25 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	G_OBJECT_CLASS (phone_details_tests_parent_class)->finalize (obj);
#line 1325 "phone-details.c"
}


GType phone_details_tests_get_type (void) {
	static volatile gsize phone_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&phone_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhoneDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) phone_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhoneDetailsTests), 0, (GInstanceInitFunc) phone_details_tests_instance_init, NULL };
		GType phone_details_tests_type_id;
		phone_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "PhoneDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&phone_details_tests_type_id__volatile, phone_details_tests_type_id);
	}
	return phone_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PhoneDetailsTests* tests = NULL;
	PhoneDetailsTests* _tmp0_ = NULL;
#line 193 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 195 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_tmp0_ = phone_details_tests_new ();
#line 195 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	tests = _tmp0_;
#line 196 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 197 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	g_test_run ();
#line 198 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 200 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	result = 0;
#line 200 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	_g_object_unref0 (tests);
#line 200 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return result;
#line 1363 "phone-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 191 "/opt/gnome3/source/folks/tests/eds/phone-details.vala"
	return _vala_main (argv, argc);
#line 1373 "phone-details.c"
}



