/* match-name.c generated by valac 0.24.0.111-cb21a, the Vala compiler
 * generated from match-name.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-tracker.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <gee.h>


#define TYPE_MATCH_NAME_TESTS (match_name_tests_get_type ())
#define MATCH_NAME_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MATCH_NAME_TESTS, MatchNameTests))
#define MATCH_NAME_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MATCH_NAME_TESTS, MatchNameTestsClass))
#define IS_MATCH_NAME_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MATCH_NAME_TESTS))
#define IS_MATCH_NAME_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MATCH_NAME_TESTS))
#define MATCH_NAME_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MATCH_NAME_TESTS, MatchNameTestsClass))

typedef struct _MatchNameTests MatchNameTests;
typedef struct _MatchNameTestsClass MatchNameTestsClass;
typedef struct _MatchNameTestsPrivate MatchNameTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _MatchNameTestsTestMatchNameAsyncData MatchNameTestsTestMatchNameAsyncData;
typedef struct _MatchNameTestsTryToAddData MatchNameTestsTryToAddData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _MatchNameTestsAddPersonasData MatchNameTestsAddPersonasData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _MatchNameTests {
	TrackerTestTestCase parent_instance;
	MatchNameTestsPrivate * priv;
};

struct _MatchNameTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _MatchNameTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _persona_fullname_2;
	gboolean _added_personas;
	gchar* _individual_id_1;
	gchar* _individual_id_2;
	FolksMatchResult _match;
	TrfPersonaStore* _pstore;
};

struct _MatchNameTestsTestMatchNameAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchNameTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	FolksIndividualAggregator* _tmp5_;
	GeeIterator* _backend_it;
	FolksBackendStore* _tmp6_;
	GeeMap* _tmp7_;
	GeeMap* _tmp8_;
	GeeCollection* _tmp9_;
	GeeCollection* _tmp10_;
	GeeCollection* _tmp11_;
	GeeIterator* _tmp12_;
	GeeIterator* _tmp13_;
	GeeIterator* _tmp14_;
	gboolean _tmp15_;
	FolksBackend* backend;
	GeeIterator* _tmp16_;
	gpointer _tmp17_;
	FolksBackend* _tmp18_;
	GeeMap* _tmp19_;
	GeeMap* _tmp20_;
	gpointer _tmp21_;
	TrfPersonaStore* _tmp22_;
	TrfPersonaStore* _tmp23_;
	TrfPersonaStore* _tmp24_;
	GError* e;
	GError* _tmp25_;
	const gchar* _tmp26_;
	GError * _inner_error_;
};

struct _MatchNameTestsTryToAddData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchNameTests* self;
	gboolean _tmp0_;
	TrfPersonaStore* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
};

struct _MatchNameTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchNameTests* self;
	GHashTable* details1;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GHashTable* details2;
	GHashFunc _tmp3_;
	GEqualFunc _tmp4_;
	GHashTable* _tmp5_;
	GValue* val;
	GValue _tmp6_;
	GValue _tmp7_;
	GValue* _tmp8_;
	GValue* _tmp9_;
	const gchar* _tmp10_;
	GHashTable* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	GValue* _tmp14_;
	GValue _tmp15_;
	GValue _tmp16_;
	GValue* _tmp17_;
	GValue* _tmp18_;
	const gchar* _tmp19_;
	GHashTable* _tmp20_;
	const gchar* _tmp21_;
	gchar* _tmp22_;
	GValue* _tmp23_;
	FolksIndividualAggregator* _tmp24_;
	TrfPersonaStore* _tmp25_;
	GHashTable* _tmp26_;
	FolksPersona* _tmp27_;
	FolksPersona* _tmp28_;
	FolksIndividualAggregator* _tmp29_;
	TrfPersonaStore* _tmp30_;
	GHashTable* _tmp31_;
	FolksPersona* _tmp32_;
	FolksPersona* _tmp33_;
	GError* e;
	GError* _tmp34_;
	const gchar* _tmp35_;
	GError * _inner_error_;
};


static gpointer match_name_tests_parent_class = NULL;

GType match_name_tests_get_type (void) G_GNUC_CONST;
#define MATCH_NAME_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MATCH_NAME_TESTS, MatchNameTestsPrivate))
enum  {
	MATCH_NAME_TESTS_DUMMY_PROPERTY
};
MatchNameTests* match_name_tests_new (void);
MatchNameTests* match_name_tests_construct (GType object_type);
void match_name_tests_test_match_name_1 (MatchNameTests* self);
static void _match_name_tests_test_match_name_1_folks_test_case_test_method (gpointer self);
void match_name_tests_test_match_name_2 (MatchNameTests* self);
static void _match_name_tests_test_match_name_2_folks_test_case_test_method (gpointer self);
void match_name_tests_test_match_name_3 (MatchNameTests* self);
static void _match_name_tests_test_match_name_3_folks_test_case_test_method (gpointer self);
void match_name_tests_test_match_name_4 (MatchNameTests* self);
static void _match_name_tests_test_match_name_4_folks_test_case_test_method (gpointer self);
void match_name_tests_test_match_name_5 (MatchNameTests* self);
static void _match_name_tests_test_match_name_5_folks_test_case_test_method (gpointer self);
void match_name_tests_test_match_name_6 (MatchNameTests* self);
static void _match_name_tests_test_match_name_6_folks_test_case_test_method (gpointer self);
static void _match_name_tests_test_match_name (MatchNameTests* self, const gchar* full_name1, const gchar* full_name2);
static void _match_name_tests_test_match_name_async (MatchNameTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_name_tests_test_match_name_finish (MatchNameTests* self, GAsyncResult* _res_);
static void _match_name_tests_test_match_name_async_data_free (gpointer _data);
static gboolean _match_name_tests_test_match_name_async_co (MatchNameTestsTestMatchNameAsyncData* _data_);
static void _match_name_tests_test_match_name_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _match_name_tests_individuals_changed_cb (MatchNameTests* self, GeeMultiMap* changes);
static void __match_name_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _match_name_tests_notify_pstore_cb (MatchNameTests* self, GObject* _pstore, GParamSpec* ps);
static void __match_name_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _match_name_tests_try_to_add (MatchNameTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_name_tests_try_to_add_finish (MatchNameTests* self, GAsyncResult* _res_);
static void _match_name_tests_try_potential_match (MatchNameTests* self);
static void _match_name_tests_try_to_add_data_free (gpointer _data);
static gboolean _match_name_tests_try_to_add_co (MatchNameTestsTryToAddData* _data_);
static void _match_name_tests_add_personas (MatchNameTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_name_tests_add_personas_finish (MatchNameTests* self, GAsyncResult* _res_);
static void _match_name_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _match_name_tests_add_personas_data_free (gpointer _data);
static gboolean _match_name_tests_add_personas_co (MatchNameTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static void _match_name_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void match_name_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _match_name_tests_test_match_name_1_folks_test_case_test_method (gpointer self) {
#line 42 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	match_name_tests_test_match_name_1 ((MatchNameTests*) self);
#line 235 "match-name.c"
}


static void _match_name_tests_test_match_name_2_folks_test_case_test_method (gpointer self) {
#line 44 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	match_name_tests_test_match_name_2 ((MatchNameTests*) self);
#line 242 "match-name.c"
}


static void _match_name_tests_test_match_name_3_folks_test_case_test_method (gpointer self) {
#line 46 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	match_name_tests_test_match_name_3 ((MatchNameTests*) self);
#line 249 "match-name.c"
}


static void _match_name_tests_test_match_name_4_folks_test_case_test_method (gpointer self) {
#line 48 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	match_name_tests_test_match_name_4 ((MatchNameTests*) self);
#line 256 "match-name.c"
}


static void _match_name_tests_test_match_name_5_folks_test_case_test_method (gpointer self) {
#line 50 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	match_name_tests_test_match_name_5 ((MatchNameTests*) self);
#line 263 "match-name.c"
}


static void _match_name_tests_test_match_name_6_folks_test_case_test_method (gpointer self) {
#line 52 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	match_name_tests_test_match_name_6 ((MatchNameTests*) self);
#line 270 "match-name.c"
}


MatchNameTests* match_name_tests_construct (GType object_type) {
	MatchNameTests * self = NULL;
#line 40 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self = (MatchNameTests*) tracker_test_test_case_construct (object_type, "MatchNameTests");
#line 42 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match by name #1 ", _match_name_tests_test_match_name_1_folks_test_case_test_method, self);
#line 44 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match by name #2 ", _match_name_tests_test_match_name_2_folks_test_case_test_method, self);
#line 46 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match by name #3 ", _match_name_tests_test_match_name_3_folks_test_case_test_method, self);
#line 48 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match by name #4 ", _match_name_tests_test_match_name_4_folks_test_case_test_method, self);
#line 50 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match by name #5 ", _match_name_tests_test_match_name_5_folks_test_case_test_method, self);
#line 52 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match by name #6 ", _match_name_tests_test_match_name_6_folks_test_case_test_method, self);
#line 38 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return self;
#line 292 "match-name.c"
}


MatchNameTests* match_name_tests_new (void) {
#line 38 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return match_name_tests_construct (TYPE_MATCH_NAME_TESTS);
#line 299 "match-name.c"
}


static void _match_name_tests_test_match_name (MatchNameTests* self, const gchar* full_name1, const gchar* full_name2) {
	GMainLoop* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GMainLoop* _tmp7_ = NULL;
#line 56 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 56 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (full_name1 != NULL);
#line 56 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (full_name2 != NULL);
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_main_loop = _tmp0_;
#line 60 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_match = FOLKS_MATCH_RESULT_MIN;
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_added_personas = FALSE;
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp1_ = full_name1;
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_persona_fullname_1 = _tmp2_;
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp3_ = full_name2;
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_persona_fullname_2 = _tmp4_;
#line 64 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp5_ = g_strdup ("");
#line 64 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_individual_id_1);
#line 64 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_individual_id_1 = _tmp5_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp6_ = g_strdup ("");
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_individual_id_2);
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_individual_id_2 = _tmp6_;
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name_async (self, NULL, NULL);
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp7_ = self->priv->_main_loop;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_utils_loop_run_with_timeout (_tmp7_, 5);
#line 362 "match-name.c"
}


void match_name_tests_test_match_name_1 (MatchNameTests* self) {
	FolksMatchResult _tmp0_ = 0;
#line 72 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 74 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name (self, "Bernie Innocenti", "Bernardo H. Innocenti");
#line 75 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = self->priv->_match;
#line 75 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_vala_assert (_tmp0_ >= FOLKS_MATCH_RESULT_MEDIUM, "this._match >= Folks.MatchResult.MEDIUM");
#line 376 "match-name.c"
}


void match_name_tests_test_match_name_2 (MatchNameTests* self) {
	FolksMatchResult _tmp0_ = 0;
#line 78 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 80 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name (self, "AAAA BBBBB", "CCCCC DDDDD");
#line 81 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = self->priv->_match;
#line 81 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_vala_assert (_tmp0_ <= FOLKS_MATCH_RESULT_LOW, "this._match <= Folks.MatchResult.LOW");
#line 390 "match-name.c"
}


void match_name_tests_test_match_name_3 (MatchNameTests* self) {
	FolksMatchResult _tmp0_ = 0;
#line 84 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 86 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name (self, "Travis Reitter", "Travis R.");
#line 87 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = self->priv->_match;
#line 87 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_vala_assert (_tmp0_ >= FOLKS_MATCH_RESULT_MEDIUM, "this._match >= Folks.MatchResult.MEDIUM");
#line 404 "match-name.c"
}


void match_name_tests_test_match_name_4 (MatchNameTests* self) {
	FolksMatchResult _tmp0_ = 0;
#line 90 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 95 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name (self, "PâtéPâtéPâté", "patepatepate");
#line 96 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = self->priv->_match;
#line 96 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_vala_assert (_tmp0_ >= FOLKS_MATCH_RESULT_MEDIUM, "this._match >= Folks.MatchResult.MEDIUM");
#line 418 "match-name.c"
}


void match_name_tests_test_match_name_5 (MatchNameTests* self) {
	FolksMatchResult _tmp0_ = 0;
#line 99 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 102 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name (self, "Frédéric Peters", "Frederic Peters");
#line 103 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = self->priv->_match;
#line 103 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_vala_assert (_tmp0_ >= FOLKS_MATCH_RESULT_HIGH, "this._match >= Folks.MatchResult.HIGH");
#line 432 "match-name.c"
}


void match_name_tests_test_match_name_6 (MatchNameTests* self) {
	FolksMatchResult _tmp0_ = 0;
#line 106 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 109 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name (self, "Alice Badger", "alice.badger");
#line 110 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = self->priv->_match;
#line 110 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_vala_assert (_tmp0_ >= FOLKS_MATCH_RESULT_HIGH, "this._match >= Folks.MatchResult.HIGH");
#line 446 "match-name.c"
}


static void _match_name_tests_test_match_name_async_data_free (gpointer _data) {
	MatchNameTestsTestMatchNameAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_slice_free (MatchNameTestsTestMatchNameAsyncData, _data_);
#line 457 "match-name.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return self ? g_object_ref (self) : NULL;
#line 464 "match-name.c"
}


static void _match_name_tests_test_match_name_async (MatchNameTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchNameTestsTestMatchNameAsyncData* _data_;
	MatchNameTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = g_slice_new0 (MatchNameTestsTestMatchNameAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_name_tests_test_match_name_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_name_tests_test_match_name_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name_async_co (_data_);
#line 483 "match-name.c"
}


static void _match_name_tests_test_match_name_finish (MatchNameTests* self, GAsyncResult* _res_) {
	MatchNameTestsTestMatchNameAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 491 "match-name.c"
}


static void _match_name_tests_test_match_name_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchNameTestsTestMatchNameAsyncData* _data_;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = _user_data_;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_source_object_ = source_object;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_res_ = _res_;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_test_match_name_async_co (_data_);
#line 505 "match-name.c"
}


static void __match_name_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 121 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_individuals_changed_cb ((MatchNameTests*) self, changes);
#line 512 "match-name.c"
}


static void __match_name_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 137 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_notify_pstore_cb ((MatchNameTests*) self, _sender, pspec);
#line 519 "match-name.c"
}


static gboolean _match_name_tests_test_match_name_async_co (MatchNameTestsTestMatchNameAsyncData* _data_) {
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	switch (_data_->_state_) {
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 0:
#line 528 "match-name.c"
		goto _state_0;
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 1:
#line 532 "match-name.c"
		goto _state_1;
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 2:
#line 536 "match-name.c"
		goto _state_2;
		default:
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_assert_not_reached ();
#line 541 "match-name.c"
	}
	_state_0:
#line 115 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp0_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 115 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->store = _data_->_tmp0_;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp1_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp1_ = _data_->store;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_state_ = 1;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_backend_store_prepare (_data_->_tmp1_, _match_name_tests_test_match_name_async_ready, _data_);
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return FALSE;
#line 560 "match-name.c"
	_state_1:
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_backend_store_prepare_finish (_data_->_tmp1_, _data_->_res_);
#line 118 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp2_ = NULL;
#line 118 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 118 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (_data_->_tmp2_ == NULL) {
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp3_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp3_ = folks_individual_aggregator_dup ();
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_object_unref0 (_data_->self->priv->_aggregator);
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->self->priv->_aggregator = _data_->_tmp3_;
#line 121 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp4_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 121 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_signal_connect_object (_data_->_tmp4_, "individuals-changed-detailed", (GCallback) __match_name_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 584 "match-name.c"
	}
	{
#line 127 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp5_ = NULL;
#line 127 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp5_ = _data_->self->priv->_aggregator;
#line 127 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_state_ = 2;
#line 127 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		folks_individual_aggregator_prepare (_data_->_tmp5_, _match_name_tests_test_match_name_async_ready, _data_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		return FALSE;
#line 597 "match-name.c"
		_state_2:
#line 127 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 603 "match-name.c"
			goto __catch0_g_error;
		}
#line 128 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_object_unref0 (_data_->self->priv->_pstore);
#line 128 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->self->priv->_pstore = NULL;
#line 610 "match-name.c"
		{
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp6_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp6_ = _data_->store;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp7_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp7_ = folks_backend_store_get_enabled_backends (_data_->_tmp6_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp8_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp9_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp9_ = gee_map_get_values (_data_->_tmp8_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp10_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp11_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp11_ = _data_->_tmp10_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp12_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp12_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp11_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp13_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_tmp13_ = _data_->_tmp12_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_object_unref0 (_data_->_tmp11_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_data_->_backend_it = _data_->_tmp13_;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			while (TRUE) {
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp14_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp14_ = _data_->_backend_it;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp15_ = FALSE;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp15_ = gee_iterator_next (_data_->_tmp14_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				if (!_data_->_tmp15_) {
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					break;
#line 662 "match-name.c"
				}
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp16_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp16_ = _data_->_backend_it;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp17_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp17_ = gee_iterator_get (_data_->_tmp16_);
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp17_;
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp18_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp18_ = _data_->backend;
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp19_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp19_ = folks_backend_get_persona_stores (_data_->_tmp18_);
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp20_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp20_ = _data_->_tmp19_;
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp21_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp21_ = gee_map_get (_data_->_tmp20_, "tracker");
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_g_object_unref0 (_data_->self->priv->_pstore);
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->self->priv->_pstore = G_TYPE_CHECK_INSTANCE_CAST ((FolksPersonaStore*) _data_->_tmp21_, TRF_TYPE_PERSONA_STORE, TrfPersonaStore);
#line 133 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp22_ = NULL;
#line 133 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_data_->_tmp22_ = _data_->self->priv->_pstore;
#line 133 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				if (_data_->_tmp22_ != NULL) {
#line 134 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					_g_object_unref0 (_data_->backend);
#line 134 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					break;
#line 704 "match-name.c"
				}
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_g_object_unref0 (_data_->backend);
#line 708 "match-name.c"
			}
#line 129 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 712 "match-name.c"
		}
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp23_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp23_ = _data_->self->priv->_pstore;
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_vala_assert (_data_->_tmp23_ != NULL, "this._pstore != null");
#line 137 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp24_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp24_ = _data_->self->priv->_pstore;
#line 137 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp24_, "notify::is-prepared", (GCallback) __match_name_tests_notify_pstore_cb_g_object_notify, _data_->self, 0);
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_match_name_tests_try_to_add (_data_->self, NULL, NULL);
#line 728 "match-name.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->e = _data_->_inner_error_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_inner_error_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp25_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp25_ = _data_->e;
#line 142 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp26_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp26_ = _data_->_tmp25_->message;
#line 142 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_warning ("match-name.vala:142: Error when calling prepare: %s\n", _data_->_tmp26_);
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_error_free0 (_data_->e);
#line 749 "match-name.c"
	}
	__finally0:
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_object_unref0 (_data_->store);
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_clear_error (&_data_->_inner_error_);
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		return FALSE;
#line 762 "match-name.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (_data_->store);
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (_data_->_state_ == 0) {
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 770 "match-name.c"
	} else {
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 774 "match-name.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_object_unref (_data_->_async_result);
#line 113 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return FALSE;
#line 780 "match-name.c"
}


static void _match_name_tests_individuals_changed_cb (MatchNameTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp27_ = FALSE;
	const gchar* _tmp28_ = NULL;
	GeeSet* _tmp30_ = NULL;
	gint _tmp31_ = 0;
	gint _tmp32_ = 0;
#line 146 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 146 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (changes != NULL);
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = changes;
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	added = _tmp1_;
#line 150 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp2_ = changes;
#line 150 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 150 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	removed = _tmp3_;
#line 812 "match-name.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_tmp4_ = added;
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_i_it = _tmp5_;
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		while (TRUE) {
#line 825 "match-name.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp6_ = _i_it;
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			if (!_tmp7_) {
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				break;
#line 844 "match-name.c"
			}
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp8_ = _i_it;
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			i = (FolksIndividual*) _tmp9_;
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp10_ = i;
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp11_ = i;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp13_ = _tmp12_;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp14_ = self->priv->_persona_fullname_1;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 866 "match-name.c"
				FolksIndividual* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
#line 158 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp15_ = i;
#line 158 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp16_ = folks_individual_get_id (_tmp15_);
#line 158 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp17_ = _tmp16_;
#line 158 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp18_ = g_strdup (_tmp17_);
#line 158 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_g_free0 (self->priv->_individual_id_1);
#line 158 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				self->priv->_individual_id_1 = _tmp18_;
#line 883 "match-name.c"
			} else {
				FolksIndividual* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp19_ = i;
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp20_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp19_);
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp21_ = _tmp20_;
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				_tmp22_ = self->priv->_persona_fullname_2;
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
#line 899 "match-name.c"
					FolksIndividual* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					const gchar* _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					_tmp23_ = i;
#line 162 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					_tmp24_ = folks_individual_get_id (_tmp23_);
#line 162 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					_tmp25_ = _tmp24_;
#line 162 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					_tmp26_ = g_strdup (_tmp25_);
#line 162 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					_g_free0 (self->priv->_individual_id_2);
#line 162 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
					self->priv->_individual_id_2 = _tmp26_;
#line 916 "match-name.c"
				}
			}
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_object_unref0 (i);
#line 921 "match-name.c"
		}
#line 152 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_object_unref0 (_i_it);
#line 925 "match-name.c"
	}
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp28_ = self->priv->_individual_id_1;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (g_strcmp0 (_tmp28_, "") != 0) {
#line 931 "match-name.c"
		const gchar* _tmp29_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_tmp29_ = self->priv->_individual_id_2;
#line 167 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_tmp27_ = g_strcmp0 (_tmp29_, "") != 0;
#line 937 "match-name.c"
	} else {
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_tmp27_ = FALSE;
#line 941 "match-name.c"
	}
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (_tmp27_) {
#line 169 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_match_name_tests_try_potential_match (self);
#line 947 "match-name.c"
	}
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp30_ = removed;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp32_ = _tmp31_;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_vala_assert (_tmp32_ == 1, "removed.size == 1");
#line 957 "match-name.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp33_ = NULL;
		GeeIterator* _tmp34_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_tmp33_ = removed;
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_tmp34_ = gee_iterable_iterator ((GeeIterable*) _tmp33_);
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_i_it = _tmp34_;
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		while (TRUE) {
#line 970 "match-name.c"
			GeeIterator* _tmp35_ = NULL;
			gboolean _tmp36_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp37_ = NULL;
			gpointer _tmp38_ = NULL;
			FolksIndividual* _tmp39_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp35_ = _i_it;
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp36_ = gee_iterator_next (_tmp35_);
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			if (!_tmp36_) {
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
				break;
#line 985 "match-name.c"
			}
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp37_ = _i_it;
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp38_ = gee_iterator_get (_tmp37_);
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			i = (FolksIndividual*) _tmp38_;
#line 176 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_tmp39_ = i;
#line 176 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_vala_assert (_tmp39_ == NULL, "i == null");
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_object_unref0 (i);
#line 999 "match-name.c"
		}
#line 174 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_object_unref0 (_i_it);
#line 1003 "match-name.c"
	}
#line 146 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (removed);
#line 146 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (added);
#line 1009 "match-name.c"
}


static void _match_name_tests_try_potential_match (MatchNameTests* self) {
	FolksIndividual* ind1 = NULL;
	FolksIndividualAggregator* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	FolksIndividual* ind2 = NULL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	GeeMap* _tmp6_ = NULL;
	GeeMap* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gpointer _tmp9_ = NULL;
	FolksPotentialMatch* matchObj = NULL;
	FolksPotentialMatch* _tmp10_ = NULL;
	FolksMatchResult _tmp11_ = 0;
	GMainLoop* _tmp12_ = NULL;
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 182 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = self->priv->_aggregator;
#line 182 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp1_ = folks_individual_aggregator_get_individuals (_tmp0_);
#line 182 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp2_ = _tmp1_;
#line 182 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp3_ = self->priv->_individual_id_1;
#line 182 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp4_ = gee_map_get (_tmp2_, _tmp3_);
#line 182 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	ind1 = (FolksIndividual*) _tmp4_;
#line 183 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp5_ = self->priv->_aggregator;
#line 183 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp6_ = folks_individual_aggregator_get_individuals (_tmp5_);
#line 183 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp7_ = _tmp6_;
#line 183 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp8_ = self->priv->_individual_id_2;
#line 183 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp9_ = gee_map_get (_tmp7_, _tmp8_);
#line 183 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	ind2 = (FolksIndividual*) _tmp9_;
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp10_ = folks_potential_match_new ();
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	matchObj = _tmp10_;
#line 186 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp11_ = folks_potential_match_potential_match (matchObj, ind1, ind2);
#line 186 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_match = _tmp11_;
#line 188 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp12_ = self->priv->_main_loop;
#line 188 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_main_loop_quit (_tmp12_);
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (matchObj);
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (ind2);
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (ind1);
#line 1074 "match-name.c"
}


static void _match_name_tests_notify_pstore_cb (MatchNameTests* self, GObject* _pstore, GParamSpec* ps) {
#line 191 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (self != NULL);
#line 191 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (_pstore != NULL);
#line 191 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_return_if_fail (ps != NULL);
#line 193 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_try_to_add (self, NULL, NULL);
#line 1087 "match-name.c"
}


static void _match_name_tests_try_to_add_data_free (gpointer _data) {
	MatchNameTestsTryToAddData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_slice_free (MatchNameTestsTryToAddData, _data_);
#line 1098 "match-name.c"
}


static void _match_name_tests_try_to_add (MatchNameTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchNameTestsTryToAddData* _data_;
	MatchNameTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = g_slice_new0 (MatchNameTestsTryToAddData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_name_tests_try_to_add);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_name_tests_try_to_add_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_try_to_add_co (_data_);
#line 1117 "match-name.c"
}


static void _match_name_tests_try_to_add_finish (MatchNameTests* self, GAsyncResult* _res_) {
	MatchNameTestsTryToAddData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1125 "match-name.c"
}


static void _match_name_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchNameTestsTryToAddData* _data_;
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = _user_data_;
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_source_object_ = source_object;
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_res_ = _res_;
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_try_to_add_co (_data_);
#line 1139 "match-name.c"
}


static gboolean _match_name_tests_try_to_add_co (MatchNameTestsTryToAddData* _data_) {
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	switch (_data_->_state_) {
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 0:
#line 1148 "match-name.c"
		goto _state_0;
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 1:
#line 1152 "match-name.c"
		goto _state_1;
		default:
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_assert_not_reached ();
#line 1157 "match-name.c"
	}
	_state_0:
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp1_ = NULL;
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp1_ = _data_->self->priv->_pstore;
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp2_ = FALSE;
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp2_ = folks_persona_store_get_is_prepared ((FolksPersonaStore*) _data_->_tmp1_);
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp3_ = FALSE;
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (_data_->_tmp3_) {
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp4_ = FALSE;
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp4_ = _data_->self->priv->_added_personas;
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp0_ = _data_->_tmp4_ == FALSE;
#line 1180 "match-name.c"
	} else {
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp0_ = FALSE;
#line 1184 "match-name.c"
	}
#line 198 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (_data_->_tmp0_) {
#line 200 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->self->priv->_added_personas = TRUE;
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_state_ = 1;
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_match_name_tests_add_personas (_data_->self, _match_name_tests_try_to_add_ready, _data_);
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		return FALSE;
#line 1196 "match-name.c"
		_state_1:
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_match_name_tests_add_personas_finish (_data_->self, _data_->_res_);
#line 1200 "match-name.c"
	}
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (_data_->_state_ == 0) {
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1206 "match-name.c"
	} else {
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1210 "match-name.c"
	}
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_object_unref (_data_->_async_result);
#line 196 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return FALSE;
#line 1216 "match-name.c"
}


static void _match_name_tests_add_personas_data_free (gpointer _data) {
	MatchNameTestsAddPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_slice_free (MatchNameTestsAddPersonasData, _data_);
#line 1227 "match-name.c"
}


static void _match_name_tests_add_personas (MatchNameTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchNameTestsAddPersonasData* _data_;
	MatchNameTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = g_slice_new0 (MatchNameTestsAddPersonasData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_name_tests_add_personas);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_name_tests_add_personas_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_add_personas_co (_data_);
#line 1246 "match-name.c"
}


static void _match_name_tests_add_personas_finish (MatchNameTests* self, GAsyncResult* _res_) {
	MatchNameTestsAddPersonasData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1254 "match-name.c"
}


static void _g_free0_ (gpointer var) {
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	var = (g_free (var), NULL);
#line 1261 "match-name.c"
}


static void _vala_GValue_free (GValue* self) {
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_value_unset (self);
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_free (self);
#line 1270 "match-name.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1277 "match-name.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1284 "match-name.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1291 "match-name.c"
}


static void _match_name_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchNameTestsAddPersonasData* _data_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_ = _user_data_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_source_object_ = source_object;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_res_ = _res_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_match_name_tests_add_personas_co (_data_);
#line 1305 "match-name.c"
}


static gboolean _match_name_tests_add_personas_co (MatchNameTestsAddPersonasData* _data_) {
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	switch (_data_->_state_) {
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 0:
#line 1314 "match-name.c"
		goto _state_0;
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 1:
#line 1318 "match-name.c"
		goto _state_1;
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		case 2:
#line 1322 "match-name.c"
		goto _state_2;
		default:
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_assert_not_reached ();
#line 1327 "match-name.c"
	}
	_state_0:
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp0_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp0_ = g_str_hash;
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp1_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp1_ = g_str_equal;
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp2_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->details1 = _data_->_tmp2_;
#line 209 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp3_ = NULL;
#line 209 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp3_ = g_str_hash;
#line 209 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp4_ = NULL;
#line 209 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp4_ = g_str_equal;
#line 209 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp5_ = NULL;
#line 209 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp5_ = g_hash_table_new_full (_data_->_tmp3_, _data_->_tmp4_, _g_free0_, __vala_GValue_free0_);
#line 209 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->details2 = _data_->_tmp5_;
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	memset (&_data_->_tmp6_, 0, sizeof (GValue));
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_value_init (&_data_->_tmp6_, G_TYPE_STRING);
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	memset (&_data_->_tmp7_, 0, sizeof (GValue));
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp8_ = NULL;
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp8_ = __g_value_dup0 (&_data_->_tmp7_);
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	__vala_GValue_free0 (_data_->val);
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->val = _data_->_tmp8_;
#line 213 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	G_IS_VALUE (&_data_->_tmp7_) ? (g_value_unset (&_data_->_tmp7_), NULL) : NULL;
#line 214 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp9_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp9_ = _data_->val;
#line 214 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp10_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp10_ = _data_->self->priv->_persona_fullname_1;
#line 214 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_value_set_string (_data_->_tmp9_, _data_->_tmp10_);
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp11_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp11_ = _data_->details1;
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp12_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp12_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp13_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp13_ = g_strdup (_data_->_tmp12_);
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp14_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp14_ = _data_->val;
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->val = NULL;
#line 215 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_hash_table_insert (_data_->_tmp11_, _data_->_tmp13_, _data_->_tmp14_);
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	memset (&_data_->_tmp15_, 0, sizeof (GValue));
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_value_init (&_data_->_tmp15_, G_TYPE_STRING);
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	memset (&_data_->_tmp16_, 0, sizeof (GValue));
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp17_ = NULL;
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp17_ = __g_value_dup0 (&_data_->_tmp16_);
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	__vala_GValue_free0 (_data_->val);
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->val = _data_->_tmp17_;
#line 218 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	G_IS_VALUE (&_data_->_tmp16_) ? (g_value_unset (&_data_->_tmp16_), NULL) : NULL;
#line 219 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp18_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp18_ = _data_->val;
#line 219 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp19_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp19_ = _data_->self->priv->_persona_fullname_2;
#line 219 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_value_set_string (_data_->_tmp18_, _data_->_tmp19_);
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp20_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp20_ = _data_->details2;
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp21_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp21_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp22_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp22_ = g_strdup (_data_->_tmp21_);
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp23_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->_tmp23_ = _data_->val;
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_data_->val = NULL;
#line 220 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_hash_table_insert (_data_->_tmp20_, _data_->_tmp22_, _data_->_tmp23_);
#line 1454 "match-name.c"
	{
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp24_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp24_ = _data_->self->priv->_aggregator;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp25_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp25_ = _data_->self->priv->_pstore;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp26_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp26_ = _data_->details1;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_state_ = 1;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp24_, NULL, (FolksPersonaStore*) _data_->_tmp25_, _data_->_tmp26_, _match_name_tests_add_personas_ready, _data_);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		return FALSE;
#line 1474 "match-name.c"
		_state_1:
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp27_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp27_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp24_, _data_->_res_, &_data_->_inner_error_);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp28_ = NULL;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_object_unref0 (_data_->_tmp28_);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1490 "match-name.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			__vala_GValue_free0 (_data_->val);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			g_clear_error (&_data_->_inner_error_);
#line 225 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			return FALSE;
#line 1505 "match-name.c"
		}
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp29_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp29_ = _data_->self->priv->_aggregator;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp30_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp30_ = _data_->self->priv->_pstore;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp31_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp31_ = _data_->details2;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_state_ = 2;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp29_, NULL, (FolksPersonaStore*) _data_->_tmp30_, _data_->_tmp31_, _match_name_tests_add_personas_ready, _data_);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		return FALSE;
#line 1525 "match-name.c"
		_state_2:
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp32_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp32_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error_);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp33_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_object_unref0 (_data_->_tmp33_);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1541 "match-name.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			__vala_GValue_free0 (_data_->val);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			g_clear_error (&_data_->_inner_error_);
#line 228 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
			return FALSE;
#line 1556 "match-name.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->e = _data_->_inner_error_;
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_inner_error_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp34_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp34_ = _data_->e;
#line 233 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp35_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_data_->_tmp35_ = _data_->_tmp34_->message;
#line 233 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_warning ("match-name.vala:233: [AddPersonaError] add_persona_from_details: %s\n", _data_->_tmp35_);
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_error_free0 (_data_->e);
#line 1578 "match-name.c"
	}
	__finally1:
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		__vala_GValue_free0 (_data_->val);
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_hash_table_unref0 (_data_->details2);
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_clear_error (&_data_->_inner_error_);
#line 223 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		return FALSE;
#line 1595 "match-name.c"
	}
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	__vala_GValue_free0 (_data_->val);
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_hash_table_unref0 (_data_->details2);
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	if (_data_->_state_ == 0) {
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1607 "match-name.c"
	} else {
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1611 "match-name.c"
	}
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_object_unref (_data_->_async_result);
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return FALSE;
#line 1617 "match-name.c"
}


static void match_name_tests_class_init (MatchNameTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	match_name_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_type_class_add_private (klass, sizeof (MatchNameTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	G_OBJECT_CLASS (klass)->finalize = match_name_tests_finalize;
#line 1628 "match-name.c"
}


static void match_name_tests_instance_init (MatchNameTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv = MATCH_NAME_TESTS_GET_PRIVATE (self);
#line 29 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_aggregator = NULL;
#line 30 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = g_strdup ("Bernie Innocenti");
#line 30 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_persona_fullname_1 = _tmp0_;
#line 31 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp1_ = g_strdup ("Bernardo H. Innocenti");
#line 31 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_persona_fullname_2 = _tmp1_;
#line 33 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp2_ = g_strdup ("");
#line 33 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_individual_id_1 = _tmp2_;
#line 34 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp3_ = g_strdup ("");
#line 34 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self->priv->_individual_id_2 = _tmp3_;
#line 1657 "match-name.c"
}


static void match_name_tests_finalize (GObject* obj) {
	MatchNameTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MATCH_NAME_TESTS, MatchNameTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 31 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 33 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_individual_id_1);
#line 34 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_free0 (self->priv->_individual_id_2);
#line 36 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (self->priv->_pstore);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	G_OBJECT_CLASS (match_name_tests_parent_class)->finalize (obj);
#line 1681 "match-name.c"
}


GType match_name_tests_get_type (void) {
	static volatile gsize match_name_tests_type_id__volatile = 0;
	if (g_once_init_enter (&match_name_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (MatchNameTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) match_name_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MatchNameTests), 0, (GInstanceInitFunc) match_name_tests_instance_init, NULL };
		GType match_name_tests_type_id;
		match_name_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "MatchNameTests", &g_define_type_info, 0);
		g_once_init_leave (&match_name_tests_type_id__volatile, match_name_tests_type_id);
	}
	return match_name_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	MatchNameTests* tests = NULL;
	MatchNameTests* _tmp0_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_test_init (&args_length1, &args, NULL);
#line 243 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_tmp0_ = match_name_tests_new ();
#line 243 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	tests = _tmp0_;
#line 244 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 245 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	g_test_run ();
#line 246 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 248 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	result = 0;
#line 248 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	_g_object_unref0 (tests);
#line 248 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return result;
#line 1719 "match-name.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 239 "/opt/gnome3/source/folks/tests/tracker/match-name.vala"
	return _vala_main (argv, argc);
#line 1729 "match-name.c"
}



