/* match-im-addresses.c generated by valac 0.24.0.111-cb21a, the Vala compiler
 * generated from match-im-addresses.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-tracker.h>
#include <folks-test.h>
#include <gio/gio.h>
#include <gee.h>


#define TYPE_MATCH_IM_ADDRESSES_TESTS (match_im_addresses_tests_get_type ())
#define MATCH_IM_ADDRESSES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MATCH_IM_ADDRESSES_TESTS, MatchIMAddressesTests))
#define MATCH_IM_ADDRESSES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MATCH_IM_ADDRESSES_TESTS, MatchIMAddressesTestsClass))
#define IS_MATCH_IM_ADDRESSES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MATCH_IM_ADDRESSES_TESTS))
#define IS_MATCH_IM_ADDRESSES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MATCH_IM_ADDRESSES_TESTS))
#define MATCH_IM_ADDRESSES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MATCH_IM_ADDRESSES_TESTS, MatchIMAddressesTestsClass))

typedef struct _MatchIMAddressesTests MatchIMAddressesTests;
typedef struct _MatchIMAddressesTestsClass MatchIMAddressesTestsClass;
typedef struct _MatchIMAddressesTestsPrivate MatchIMAddressesTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _MatchImAddressesTestsTestMatchImAddressesAsyncData MatchImAddressesTestsTestMatchImAddressesAsyncData;
typedef struct _MatchImAddressesTestsTryToAddData MatchImAddressesTestsTryToAddData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _MatchImAddressesTestsAddPersonasData MatchImAddressesTestsAddPersonasData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _MatchIMAddressesTests {
	TrackerTestTestCase parent_instance;
	MatchIMAddressesTestsPrivate * priv;
};

struct _MatchIMAddressesTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _MatchIMAddressesTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _persona_fullname_2;
	gchar* _im_addr_1;
	gchar* _im_addr_2;
	gboolean _added_personas;
	gchar* _individual_id_1;
	gchar* _individual_id_2;
	FolksMatchResult _match;
	TrfPersonaStore* _pstore;
};

struct _MatchImAddressesTestsTestMatchImAddressesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchIMAddressesTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GeeIterator* _backend_it;
	GeeMap* _tmp4_;
	GeeMap* _tmp5_;
	GeeCollection* _tmp6_;
	GeeCollection* _tmp7_;
	GeeCollection* _tmp8_;
	GeeIterator* _tmp9_;
	GeeIterator* _tmp10_;
	GeeIterator* _tmp11_;
	gboolean _tmp12_;
	FolksBackend* backend;
	GeeIterator* _tmp13_;
	gpointer _tmp14_;
	FolksBackend* _tmp15_;
	GeeMap* _tmp16_;
	GeeMap* _tmp17_;
	gpointer _tmp18_;
	TrfPersonaStore* _tmp19_;
	TrfPersonaStore* _tmp20_;
	TrfPersonaStore* _tmp21_;
	GError* e;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _MatchImAddressesTestsTryToAddData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchIMAddressesTests* self;
	gboolean _tmp0_;
	TrfPersonaStore* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
};

struct _MatchImAddressesTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	MatchIMAddressesTests* self;
	GHashTable* details1;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GHashTable* details2;
	GHashFunc _tmp3_;
	GEqualFunc _tmp4_;
	GHashTable* _tmp5_;
	GValue* val;
	GeeHashMultiMap* im_addrs;
	GValue _tmp6_;
	GValue _tmp7_;
	GValue* _tmp8_;
	GValue* _tmp9_;
	const gchar* _tmp10_;
	GHashTable* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	GValue* _tmp14_;
	GValue _tmp15_;
	GValue _tmp16_;
	GValue* _tmp17_;
	GeeHashMultiMap* _tmp18_;
	GeeHashMultiMap* _tmp19_;
	const gchar* _tmp20_;
	FolksImFieldDetails* _tmp21_;
	FolksImFieldDetails* _tmp22_;
	GeeHashMultiMap* _tmp23_;
	const gchar* _tmp24_;
	FolksImFieldDetails* _tmp25_;
	FolksImFieldDetails* _tmp26_;
	GValue* _tmp27_;
	GeeHashMultiMap* _tmp28_;
	GHashTable* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	GValue* _tmp32_;
	GValue _tmp33_;
	GValue _tmp34_;
	GValue* _tmp35_;
	GValue* _tmp36_;
	const gchar* _tmp37_;
	GHashTable* _tmp38_;
	const gchar* _tmp39_;
	gchar* _tmp40_;
	GValue* _tmp41_;
	GValue _tmp42_;
	GValue _tmp43_;
	GValue* _tmp44_;
	GeeHashMultiMap* _tmp45_;
	GeeHashMultiMap* _tmp46_;
	const gchar* _tmp47_;
	FolksImFieldDetails* _tmp48_;
	FolksImFieldDetails* _tmp49_;
	GValue* _tmp50_;
	GeeHashMultiMap* _tmp51_;
	GHashTable* _tmp52_;
	const gchar* _tmp53_;
	gchar* _tmp54_;
	GValue* _tmp55_;
	FolksIndividualAggregator* _tmp56_;
	TrfPersonaStore* _tmp57_;
	GHashTable* _tmp58_;
	FolksPersona* _tmp59_;
	FolksPersona* _tmp60_;
	FolksIndividualAggregator* _tmp61_;
	TrfPersonaStore* _tmp62_;
	GHashTable* _tmp63_;
	FolksPersona* _tmp64_;
	FolksPersona* _tmp65_;
	GError* e;
	GError* _tmp66_;
	const gchar* _tmp67_;
	GError * _inner_error_;
};


static gpointer match_im_addresses_tests_parent_class = NULL;

GType match_im_addresses_tests_get_type (void) G_GNUC_CONST;
#define MATCH_IM_ADDRESSES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MATCH_IM_ADDRESSES_TESTS, MatchIMAddressesTestsPrivate))
enum  {
	MATCH_IM_ADDRESSES_TESTS_DUMMY_PROPERTY
};
MatchIMAddressesTests* match_im_addresses_tests_new (void);
MatchIMAddressesTests* match_im_addresses_tests_construct (GType object_type);
void match_im_addresses_tests_test_match_im_addresses (MatchIMAddressesTests* self);
static void _match_im_addresses_tests_test_match_im_addresses_folks_test_case_test_method (gpointer self);
static void _match_im_addresses_tests_test_match_im_addresses_async (MatchIMAddressesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_im_addresses_tests_test_match_im_addresses_finish (MatchIMAddressesTests* self, GAsyncResult* _res_);
static void _match_im_addresses_tests_test_match_im_addresses_async_data_free (gpointer _data);
static gboolean _match_im_addresses_tests_test_match_im_addresses_async_co (MatchImAddressesTestsTestMatchImAddressesAsyncData* _data_);
static void _match_im_addresses_tests_test_match_im_addresses_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _match_im_addresses_tests_individuals_changed_cb (MatchIMAddressesTests* self, GeeMultiMap* changes);
static void __match_im_addresses_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _match_im_addresses_tests_notify_pstore_cb (MatchIMAddressesTests* self, GObject* _pstore, GParamSpec* ps);
static void __match_im_addresses_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _match_im_addresses_tests_try_to_add (MatchIMAddressesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_im_addresses_tests_try_to_add_finish (MatchIMAddressesTests* self, GAsyncResult* _res_);
static void _match_im_addresses_tests_try_potential_match (MatchIMAddressesTests* self);
static void _match_im_addresses_tests_try_to_add_data_free (gpointer _data);
static gboolean _match_im_addresses_tests_try_to_add_co (MatchImAddressesTestsTryToAddData* _data_);
static void _match_im_addresses_tests_add_personas (MatchIMAddressesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _match_im_addresses_tests_add_personas_finish (MatchIMAddressesTests* self, GAsyncResult* _res_);
static void _match_im_addresses_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _match_im_addresses_tests_add_personas_data_free (gpointer _data);
static gboolean _match_im_addresses_tests_add_personas_co (MatchImAddressesTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _match_im_addresses_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void match_im_addresses_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _match_im_addresses_tests_test_match_im_addresses_folks_test_case_test_method (gpointer self) {
#line 44 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	match_im_addresses_tests_test_match_im_addresses ((MatchIMAddressesTests*) self);
#line 258 "match-im-addresses.c"
}


MatchIMAddressesTests* match_im_addresses_tests_construct (GType object_type) {
	MatchIMAddressesTests * self = NULL;
#line 42 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self = (MatchIMAddressesTests*) tracker_test_test_case_construct (object_type, "MatchIMAddressesTests");
#line 44 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test potential match by IM addresses ", _match_im_addresses_tests_test_match_im_addresses_folks_test_case_test_method, self);
#line 40 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return self;
#line 270 "match-im-addresses.c"
}


MatchIMAddressesTests* match_im_addresses_tests_new (void) {
#line 40 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return match_im_addresses_tests_construct (TYPE_MATCH_IM_ADDRESSES_TESTS);
#line 277 "match-im-addresses.c"
}


void match_im_addresses_tests_test_match_im_addresses (MatchIMAddressesTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
	FolksMatchResult _tmp2_ = 0;
#line 48 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_return_if_fail (self != NULL);
#line 50 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 50 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 50 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_main_loop = _tmp0_;
#line 52 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_test_match_im_addresses_async (self, NULL, NULL);
#line 54 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp1_ = self->priv->_main_loop;
#line 54 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	folks_test_utils_loop_run_with_timeout (_tmp1_, 5);
#line 55 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp2_ = self->priv->_match;
#line 55 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_vala_assert (_tmp2_ >= FOLKS_MATCH_RESULT_HIGH, "this._match >= Folks.MatchResult.HIGH");
#line 303 "match-im-addresses.c"
}


static void _match_im_addresses_tests_test_match_im_addresses_async_data_free (gpointer _data) {
	MatchImAddressesTestsTestMatchImAddressesAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_slice_free (MatchImAddressesTestsTestMatchImAddressesAsyncData, _data_);
#line 314 "match-im-addresses.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return self ? g_object_ref (self) : NULL;
#line 321 "match-im-addresses.c"
}


static void _match_im_addresses_tests_test_match_im_addresses_async (MatchIMAddressesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchImAddressesTestsTestMatchImAddressesAsyncData* _data_;
	MatchIMAddressesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = g_slice_new0 (MatchImAddressesTestsTestMatchImAddressesAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_im_addresses_tests_test_match_im_addresses_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_im_addresses_tests_test_match_im_addresses_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_test_match_im_addresses_async_co (_data_);
#line 340 "match-im-addresses.c"
}


static void _match_im_addresses_tests_test_match_im_addresses_finish (MatchIMAddressesTests* self, GAsyncResult* _res_) {
	MatchImAddressesTestsTestMatchImAddressesAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 348 "match-im-addresses.c"
}


static void _match_im_addresses_tests_test_match_im_addresses_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchImAddressesTestsTestMatchImAddressesAsyncData* _data_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = _user_data_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_source_object_ = source_object;
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_res_ = _res_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_test_match_im_addresses_async_co (_data_);
#line 362 "match-im-addresses.c"
}


static void __match_im_addresses_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_individuals_changed_cb ((MatchIMAddressesTests*) self, changes);
#line 369 "match-im-addresses.c"
}


static void __match_im_addresses_tests_notify_pstore_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 77 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_notify_pstore_cb ((MatchIMAddressesTests*) self, _sender, pspec);
#line 376 "match-im-addresses.c"
}


static gboolean _match_im_addresses_tests_test_match_im_addresses_async_co (MatchImAddressesTestsTestMatchImAddressesAsyncData* _data_) {
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	switch (_data_->_state_) {
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 0:
#line 385 "match-im-addresses.c"
		goto _state_0;
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 1:
#line 389 "match-im-addresses.c"
		goto _state_1;
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 2:
#line 393 "match-im-addresses.c"
		goto _state_2;
		default:
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_assert_not_reached ();
#line 398 "match-im-addresses.c"
	}
	_state_0:
#line 60 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp0_ = NULL;
#line 60 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 60 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->store = _data_->_tmp0_;
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_state_ = 1;
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	folks_backend_store_prepare (_data_->store, _match_im_addresses_tests_test_match_im_addresses_async_ready, _data_);
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return FALSE;
#line 413 "match-im-addresses.c"
	_state_1:
#line 61 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp1_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 62 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp2_ = NULL;
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 63 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __match_im_addresses_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 431 "match-im-addresses.c"
	{
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp3_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_state_ = 2;
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _match_im_addresses_tests_test_match_im_addresses_async_ready, _data_);
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		return FALSE;
#line 443 "match-im-addresses.c"
		_state_2:
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 67 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 449 "match-im-addresses.c"
			goto __catch0_g_error;
		}
#line 68 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_object_unref0 (_data_->self->priv->_pstore);
#line 68 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->self->priv->_pstore = NULL;
#line 456 "match-im-addresses.c"
		{
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp4_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp4_ = folks_backend_store_get_enabled_backends (_data_->store);
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp5_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp6_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp6_ = gee_map_get_values (_data_->_tmp5_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp7_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp8_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp9_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp9_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp8_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp10_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_tmp10_ = _data_->_tmp9_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_object_unref0 (_data_->_tmp8_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_data_->_backend_it = _data_->_tmp10_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			while (TRUE) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp11_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp11_ = _data_->_backend_it;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp12_ = FALSE;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp12_ = gee_iterator_next (_data_->_tmp11_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				if (!_data_->_tmp12_) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					break;
#line 504 "match-im-addresses.c"
				}
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp13_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp13_ = _data_->_backend_it;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp14_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp14_ = gee_iterator_get (_data_->_tmp13_);
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->backend = (FolksBackend*) _data_->_tmp14_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp15_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp15_ = _data_->backend;
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp16_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp16_ = folks_backend_get_persona_stores (_data_->_tmp15_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp17_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp18_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp18_ = gee_map_get (_data_->_tmp17_, "tracker");
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_g_object_unref0 (_data_->self->priv->_pstore);
#line 71 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->self->priv->_pstore = G_TYPE_CHECK_INSTANCE_CAST ((FolksPersonaStore*) _data_->_tmp18_, TRF_TYPE_PERSONA_STORE, TrfPersonaStore);
#line 73 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp19_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_data_->_tmp19_ = _data_->self->priv->_pstore;
#line 73 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				if (_data_->_tmp19_ != NULL) {
#line 74 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					_g_object_unref0 (_data_->backend);
#line 74 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					break;
#line 546 "match-im-addresses.c"
				}
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_g_object_unref0 (_data_->backend);
#line 550 "match-im-addresses.c"
			}
#line 69 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_object_unref0 (_data_->_backend_it);
#line 554 "match-im-addresses.c"
		}
#line 76 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp20_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp20_ = _data_->self->priv->_pstore;
#line 76 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_vala_assert (_data_->_tmp20_ != NULL, "this._pstore != null");
#line 77 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp21_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp21_ = _data_->self->priv->_pstore;
#line 77 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_signal_connect_object ((GObject*) _data_->_tmp21_, "notify::is-prepared", (GCallback) __match_im_addresses_tests_notify_pstore_cb_g_object_notify, _data_->self, 0);
#line 78 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_match_im_addresses_tests_try_to_add (_data_->self, NULL, NULL);
#line 570 "match-im-addresses.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->e = _data_->_inner_error_;
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_inner_error_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp22_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp22_ = _data_->e;
#line 82 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp23_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 82 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_warning ("match-im-addresses.vala:82: Error when calling prepare: %s\n", _data_->_tmp23_);
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_error_free0 (_data_->e);
#line 591 "match-im-addresses.c"
	}
	__finally0:
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_object_unref0 (_data_->store);
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_clear_error (&_data_->_inner_error_);
#line 65 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		return FALSE;
#line 604 "match-im-addresses.c"
	}
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->store);
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (_data_->_state_ == 0) {
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 612 "match-im-addresses.c"
	} else {
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 616 "match-im-addresses.c"
	}
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_object_unref (_data_->_async_result);
#line 58 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return FALSE;
#line 622 "match-im-addresses.c"
}


static void _match_im_addresses_tests_individuals_changed_cb (MatchIMAddressesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp27_ = FALSE;
	const gchar* _tmp28_ = NULL;
	GeeSet* _tmp30_ = NULL;
	gint _tmp31_ = 0;
	gint _tmp32_ = 0;
#line 86 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_return_if_fail (self != NULL);
#line 86 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_return_if_fail (changes != NULL);
#line 89 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = changes;
#line 89 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 89 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	added = _tmp1_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp2_ = changes;
#line 90 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	removed = _tmp3_;
#line 654 "match-im-addresses.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_tmp4_ = added;
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_i_it = _tmp5_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		while (TRUE) {
#line 667 "match-im-addresses.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp6_ = _i_it;
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			if (!_tmp7_) {
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				break;
#line 686 "match-im-addresses.c"
			}
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp8_ = _i_it;
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			i = (FolksIndividual*) _tmp9_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp10_ = i;
#line 94 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 96 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp11_ = i;
#line 96 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 96 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp13_ = _tmp12_;
#line 96 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp14_ = self->priv->_persona_fullname_1;
#line 96 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 708 "match-im-addresses.c"
				FolksIndividual* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp15_ = i;
#line 98 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp16_ = folks_individual_get_id (_tmp15_);
#line 98 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp17_ = _tmp16_;
#line 98 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp18_ = g_strdup (_tmp17_);
#line 98 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_g_free0 (self->priv->_individual_id_1);
#line 98 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				self->priv->_individual_id_1 = _tmp18_;
#line 725 "match-im-addresses.c"
			} else {
				FolksIndividual* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp19_ = i;
#line 100 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp20_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp19_);
#line 100 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp21_ = _tmp20_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				_tmp22_ = self->priv->_persona_fullname_2;
#line 100 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
#line 741 "match-im-addresses.c"
					FolksIndividual* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					const gchar* _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					_tmp23_ = i;
#line 102 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					_tmp24_ = folks_individual_get_id (_tmp23_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					_tmp25_ = _tmp24_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					_tmp26_ = g_strdup (_tmp25_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					_g_free0 (self->priv->_individual_id_2);
#line 102 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
					self->priv->_individual_id_2 = _tmp26_;
#line 758 "match-im-addresses.c"
				}
			}
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_object_unref0 (i);
#line 763 "match-im-addresses.c"
		}
#line 92 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_object_unref0 (_i_it);
#line 767 "match-im-addresses.c"
	}
#line 106 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp28_ = self->priv->_individual_id_1;
#line 106 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (g_strcmp0 (_tmp28_, "") != 0) {
#line 773 "match-im-addresses.c"
		const gchar* _tmp29_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_tmp29_ = self->priv->_individual_id_2;
#line 107 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_tmp27_ = g_strcmp0 (_tmp29_, "") != 0;
#line 779 "match-im-addresses.c"
	} else {
#line 106 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_tmp27_ = FALSE;
#line 783 "match-im-addresses.c"
	}
#line 106 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (_tmp27_) {
#line 109 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_match_im_addresses_tests_try_potential_match (self);
#line 789 "match-im-addresses.c"
	}
#line 112 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp30_ = removed;
#line 112 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp32_ = _tmp31_;
#line 112 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_vala_assert (_tmp32_ == 1, "removed.size == 1");
#line 799 "match-im-addresses.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp33_ = NULL;
		GeeIterator* _tmp34_ = NULL;
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_tmp33_ = removed;
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_tmp34_ = gee_iterable_iterator ((GeeIterable*) _tmp33_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_i_it = _tmp34_;
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		while (TRUE) {
#line 812 "match-im-addresses.c"
			GeeIterator* _tmp35_ = NULL;
			gboolean _tmp36_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp37_ = NULL;
			gpointer _tmp38_ = NULL;
			FolksIndividual* _tmp39_ = NULL;
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp35_ = _i_it;
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp36_ = gee_iterator_next (_tmp35_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			if (!_tmp36_) {
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
				break;
#line 827 "match-im-addresses.c"
			}
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp37_ = _i_it;
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp38_ = gee_iterator_get (_tmp37_);
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			i = (FolksIndividual*) _tmp38_;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_tmp39_ = i;
#line 116 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_vala_assert (_tmp39_ == NULL, "i == null");
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_object_unref0 (i);
#line 841 "match-im-addresses.c"
		}
#line 114 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_object_unref0 (_i_it);
#line 845 "match-im-addresses.c"
	}
#line 86 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (removed);
#line 86 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (added);
#line 851 "match-im-addresses.c"
}


static void _match_im_addresses_tests_try_potential_match (MatchIMAddressesTests* self) {
	FolksIndividual* ind1 = NULL;
	FolksIndividualAggregator* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	FolksIndividual* ind2 = NULL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	GeeMap* _tmp6_ = NULL;
	GeeMap* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gpointer _tmp9_ = NULL;
	FolksPotentialMatch* matchObj = NULL;
	FolksPotentialMatch* _tmp10_ = NULL;
	FolksMatchResult _tmp11_ = 0;
	GMainLoop* _tmp12_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_return_if_fail (self != NULL);
#line 122 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = self->priv->_aggregator;
#line 122 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp1_ = folks_individual_aggregator_get_individuals (_tmp0_);
#line 122 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp2_ = _tmp1_;
#line 122 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp3_ = self->priv->_individual_id_1;
#line 122 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp4_ = gee_map_get (_tmp2_, _tmp3_);
#line 122 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	ind1 = (FolksIndividual*) _tmp4_;
#line 123 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp5_ = self->priv->_aggregator;
#line 123 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp6_ = folks_individual_aggregator_get_individuals (_tmp5_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp7_ = _tmp6_;
#line 123 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp8_ = self->priv->_individual_id_2;
#line 123 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp9_ = gee_map_get (_tmp7_, _tmp8_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	ind2 = (FolksIndividual*) _tmp9_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp10_ = folks_potential_match_new ();
#line 125 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	matchObj = _tmp10_;
#line 126 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp11_ = folks_potential_match_potential_match (matchObj, ind1, ind2);
#line 126 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_match = _tmp11_;
#line 128 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp12_ = self->priv->_main_loop;
#line 128 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_main_loop_quit (_tmp12_);
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (matchObj);
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (ind2);
#line 120 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (ind1);
#line 916 "match-im-addresses.c"
}


static void _match_im_addresses_tests_notify_pstore_cb (MatchIMAddressesTests* self, GObject* _pstore, GParamSpec* ps) {
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_return_if_fail (self != NULL);
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_return_if_fail (_pstore != NULL);
#line 131 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_return_if_fail (ps != NULL);
#line 133 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_try_to_add (self, NULL, NULL);
#line 929 "match-im-addresses.c"
}


static void _match_im_addresses_tests_try_to_add_data_free (gpointer _data) {
	MatchImAddressesTestsTryToAddData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_slice_free (MatchImAddressesTestsTryToAddData, _data_);
#line 940 "match-im-addresses.c"
}


static void _match_im_addresses_tests_try_to_add (MatchIMAddressesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchImAddressesTestsTryToAddData* _data_;
	MatchIMAddressesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = g_slice_new0 (MatchImAddressesTestsTryToAddData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_im_addresses_tests_try_to_add);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_im_addresses_tests_try_to_add_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_try_to_add_co (_data_);
#line 959 "match-im-addresses.c"
}


static void _match_im_addresses_tests_try_to_add_finish (MatchIMAddressesTests* self, GAsyncResult* _res_) {
	MatchImAddressesTestsTryToAddData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 967 "match-im-addresses.c"
}


static void _match_im_addresses_tests_try_to_add_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchImAddressesTestsTryToAddData* _data_;
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = _user_data_;
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_source_object_ = source_object;
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_res_ = _res_;
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_try_to_add_co (_data_);
#line 981 "match-im-addresses.c"
}


static gboolean _match_im_addresses_tests_try_to_add_co (MatchImAddressesTestsTryToAddData* _data_) {
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	switch (_data_->_state_) {
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 0:
#line 990 "match-im-addresses.c"
		goto _state_0;
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 1:
#line 994 "match-im-addresses.c"
		goto _state_1;
		default:
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_assert_not_reached ();
#line 999 "match-im-addresses.c"
	}
	_state_0:
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp1_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp1_ = _data_->self->priv->_pstore;
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp2_ = FALSE;
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp2_ = folks_persona_store_get_is_prepared ((FolksPersonaStore*) _data_->_tmp1_);
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp3_ = FALSE;
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (_data_->_tmp3_) {
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp4_ = FALSE;
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp4_ = _data_->self->priv->_added_personas;
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp0_ = _data_->_tmp4_ == FALSE;
#line 1022 "match-im-addresses.c"
	} else {
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp0_ = FALSE;
#line 1026 "match-im-addresses.c"
	}
#line 138 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (_data_->_tmp0_) {
#line 140 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->self->priv->_added_personas = TRUE;
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_state_ = 1;
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_match_im_addresses_tests_add_personas (_data_->self, _match_im_addresses_tests_try_to_add_ready, _data_);
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		return FALSE;
#line 1038 "match-im-addresses.c"
		_state_1:
#line 141 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_match_im_addresses_tests_add_personas_finish (_data_->self, _data_->_res_);
#line 1042 "match-im-addresses.c"
	}
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (_data_->_state_ == 0) {
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1048 "match-im-addresses.c"
	} else {
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1052 "match-im-addresses.c"
	}
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_object_unref (_data_->_async_result);
#line 136 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return FALSE;
#line 1058 "match-im-addresses.c"
}


static void _match_im_addresses_tests_add_personas_data_free (gpointer _data) {
	MatchImAddressesTestsAddPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_slice_free (MatchImAddressesTestsAddPersonasData, _data_);
#line 1069 "match-im-addresses.c"
}


static void _match_im_addresses_tests_add_personas (MatchIMAddressesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	MatchImAddressesTestsAddPersonasData* _data_;
	MatchIMAddressesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = g_slice_new0 (MatchImAddressesTestsAddPersonasData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _match_im_addresses_tests_add_personas);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _match_im_addresses_tests_add_personas_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_add_personas_co (_data_);
#line 1088 "match-im-addresses.c"
}


static void _match_im_addresses_tests_add_personas_finish (MatchIMAddressesTests* self, GAsyncResult* _res_) {
	MatchImAddressesTestsAddPersonasData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1096 "match-im-addresses.c"
}


static void _g_free0_ (gpointer var) {
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	var = (g_free (var), NULL);
#line 1103 "match-im-addresses.c"
}


static void _vala_GValue_free (GValue* self) {
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_unset (self);
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_free (self);
#line 1112 "match-im-addresses.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1119 "match-im-addresses.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1126 "match-im-addresses.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1133 "match-im-addresses.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return result;
#line 1142 "match-im-addresses.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return result;
#line 1151 "match-im-addresses.c"
}


static void _match_im_addresses_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	MatchImAddressesTestsAddPersonasData* _data_;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_ = _user_data_;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_source_object_ = source_object;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_res_ = _res_;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_match_im_addresses_tests_add_personas_co (_data_);
#line 1165 "match-im-addresses.c"
}


static gboolean _match_im_addresses_tests_add_personas_co (MatchImAddressesTestsAddPersonasData* _data_) {
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	switch (_data_->_state_) {
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 0:
#line 1174 "match-im-addresses.c"
		goto _state_0;
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 1:
#line 1178 "match-im-addresses.c"
		goto _state_1;
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		case 2:
#line 1182 "match-im-addresses.c"
		goto _state_2;
		default:
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_assert_not_reached ();
#line 1187 "match-im-addresses.c"
	}
	_state_0:
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp0_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp0_ = g_str_hash;
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp1_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp1_ = g_str_equal;
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp2_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 147 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->details1 = _data_->_tmp2_;
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp3_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp3_ = g_str_hash;
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp4_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp4_ = g_str_equal;
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp5_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp5_ = g_hash_table_new_full (_data_->_tmp3_, _data_->_tmp4_, _g_free0_, __vala_GValue_free0_);
#line 149 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->details2 = _data_->_tmp5_;
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp6_, 0, sizeof (GValue));
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_init (&_data_->_tmp6_, G_TYPE_STRING);
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp7_, 0, sizeof (GValue));
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp8_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp8_ = __g_value_dup0 (&_data_->_tmp7_);
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	__vala_GValue_free0 (_data_->val);
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = _data_->_tmp8_;
#line 154 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	G_IS_VALUE (&_data_->_tmp7_) ? (g_value_unset (&_data_->_tmp7_), NULL) : NULL;
#line 155 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp9_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp9_ = _data_->val;
#line 155 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp10_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp10_ = _data_->self->priv->_persona_fullname_1;
#line 155 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_set_string (_data_->_tmp9_, _data_->_tmp10_);
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp11_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp11_ = _data_->details1;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp12_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp12_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp13_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp13_ = g_strdup (_data_->_tmp12_);
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp14_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp14_ = _data_->val;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = NULL;
#line 156 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_hash_table_insert (_data_->_tmp11_, _data_->_tmp13_, _data_->_tmp14_);
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp15_, 0, sizeof (GValue));
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_init (&_data_->_tmp15_, GEE_TYPE_MULTI_MAP);
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp16_, 0, sizeof (GValue));
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp17_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp17_ = __g_value_dup0 (&_data_->_tmp16_);
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	__vala_GValue_free0 (_data_->val);
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = _data_->_tmp17_;
#line 159 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	G_IS_VALUE (&_data_->_tmp16_) ? (g_value_unset (&_data_->_tmp16_), NULL) : NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp18_ = NULL;
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp18_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->im_addrs);
#line 160 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->im_addrs = _data_->_tmp18_;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp19_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp19_ = _data_->im_addrs;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp20_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp20_ = _data_->self->priv->_im_addr_1;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp21_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp21_ = folks_im_field_details_new (_data_->_tmp20_, NULL);
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp22_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp22_ = _data_->_tmp21_;
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->_tmp19_, "jabber", _data_->_tmp22_);
#line 163 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->_tmp22_);
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp23_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp23_ = _data_->im_addrs;
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp24_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp24_ = _data_->self->priv->_im_addr_2;
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp25_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp25_ = folks_im_field_details_new (_data_->_tmp24_, NULL);
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp26_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->_tmp23_, "yahoo", _data_->_tmp26_);
#line 164 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->_tmp26_);
#line 165 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp27_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp27_ = _data_->val;
#line 165 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp28_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp28_ = _data_->im_addrs;
#line 165 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_set_object (_data_->_tmp27_, (GObject*) _data_->_tmp28_);
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp29_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp29_ = _data_->details1;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp30_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp30_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_IM_ADDRESSES);
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp31_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp31_ = g_strdup (_data_->_tmp30_);
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp32_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp32_ = _data_->val;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = NULL;
#line 166 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_hash_table_insert (_data_->_tmp29_, _data_->_tmp31_, _data_->_tmp32_);
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp33_, 0, sizeof (GValue));
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_init (&_data_->_tmp33_, G_TYPE_STRING);
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp34_, 0, sizeof (GValue));
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp34_ = _data_->_tmp33_;
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp35_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp35_ = __g_value_dup0 (&_data_->_tmp34_);
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	__vala_GValue_free0 (_data_->val);
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = _data_->_tmp35_;
#line 170 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	G_IS_VALUE (&_data_->_tmp34_) ? (g_value_unset (&_data_->_tmp34_), NULL) : NULL;
#line 171 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp36_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp36_ = _data_->val;
#line 171 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp37_ = NULL;
#line 171 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp37_ = _data_->self->priv->_persona_fullname_2;
#line 171 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_set_string (_data_->_tmp36_, _data_->_tmp37_);
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp38_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp38_ = _data_->details2;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp39_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp39_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp40_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp40_ = g_strdup (_data_->_tmp39_);
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp41_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp41_ = _data_->val;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_hash_table_insert (_data_->_tmp38_, _data_->_tmp40_, _data_->_tmp41_);
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp42_, 0, sizeof (GValue));
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_init (&_data_->_tmp42_, GEE_TYPE_MULTI_MAP);
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	memset (&_data_->_tmp43_, 0, sizeof (GValue));
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp43_ = _data_->_tmp42_;
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp44_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp44_ = __g_value_dup0 (&_data_->_tmp43_);
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	__vala_GValue_free0 (_data_->val);
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = _data_->_tmp44_;
#line 175 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	G_IS_VALUE (&_data_->_tmp43_) ? (g_value_unset (&_data_->_tmp43_), NULL) : NULL;
#line 176 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp45_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp45_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, FOLKS_TYPE_IM_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 176 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->im_addrs);
#line 176 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->im_addrs = _data_->_tmp45_;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp46_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp46_ = _data_->im_addrs;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp47_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp47_ = _data_->self->priv->_im_addr_2;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp48_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp48_ = folks_im_field_details_new (_data_->_tmp47_, NULL);
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp49_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp49_ = _data_->_tmp48_;
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	gee_multi_map_set ((GeeMultiMap*) _data_->_tmp46_, "jabber", _data_->_tmp49_);
#line 179 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->_tmp49_);
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp50_ = NULL;
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp50_ = _data_->val;
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp51_ = NULL;
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp51_ = _data_->im_addrs;
#line 180 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_value_set_object (_data_->_tmp50_, (GObject*) _data_->_tmp51_);
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp52_ = NULL;
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp52_ = _data_->details2;
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp53_ = NULL;
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp53_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_IM_ADDRESSES);
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp54_ = NULL;
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp54_ = g_strdup (_data_->_tmp53_);
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp55_ = NULL;
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->_tmp55_ = _data_->val;
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_data_->val = NULL;
#line 181 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_hash_table_insert (_data_->_tmp52_, _data_->_tmp54_, _data_->_tmp55_);
#line 1486 "match-im-addresses.c"
	{
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp56_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp56_ = _data_->self->priv->_aggregator;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp57_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp57_ = _data_->self->priv->_pstore;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp58_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp58_ = _data_->details1;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_state_ = 1;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp56_, NULL, (FolksPersonaStore*) _data_->_tmp57_, _data_->_tmp58_, _match_im_addresses_tests_add_personas_ready, _data_);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		return FALSE;
#line 1506 "match-im-addresses.c"
		_state_1:
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp59_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp59_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp56_, _data_->_res_, &_data_->_inner_error_);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp60_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp60_ = _data_->_tmp59_;
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_object_unref0 (_data_->_tmp60_);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1522 "match-im-addresses.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_object_unref0 (_data_->im_addrs);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			__vala_GValue_free0 (_data_->val);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			g_clear_error (&_data_->_inner_error_);
#line 187 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			return FALSE;
#line 1539 "match-im-addresses.c"
		}
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp61_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp61_ = _data_->self->priv->_aggregator;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp62_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp62_ = _data_->self->priv->_pstore;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp63_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp63_ = _data_->details2;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_state_ = 2;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp61_, NULL, (FolksPersonaStore*) _data_->_tmp62_, _data_->_tmp63_, _match_im_addresses_tests_add_personas_ready, _data_);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		return FALSE;
#line 1559 "match-im-addresses.c"
		_state_2:
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp64_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp64_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp61_, _data_->_res_, &_data_->_inner_error_);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp65_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp65_ = _data_->_tmp64_;
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_object_unref0 (_data_->_tmp65_);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1575 "match-im-addresses.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_object_unref0 (_data_->im_addrs);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			__vala_GValue_free0 (_data_->val);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			g_clear_error (&_data_->_inner_error_);
#line 190 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
			return FALSE;
#line 1592 "match-im-addresses.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->e = _data_->_inner_error_;
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_inner_error_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp66_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp66_ = _data_->e;
#line 195 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp67_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_data_->_tmp67_ = _data_->_tmp66_->message;
#line 195 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_warning ("match-im-addresses.vala:195: [AddPersonaError] add_persona_from_detail" \
"s: %s\n", _data_->_tmp67_);
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_error_free0 (_data_->e);
#line 1614 "match-im-addresses.c"
	}
	__finally1:
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_object_unref0 (_data_->im_addrs);
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		__vala_GValue_free0 (_data_->val);
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_hash_table_unref0 (_data_->details2);
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_clear_error (&_data_->_inner_error_);
#line 185 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		return FALSE;
#line 1633 "match-im-addresses.c"
	}
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (_data_->im_addrs);
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	__vala_GValue_free0 (_data_->val);
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_hash_table_unref0 (_data_->details2);
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	if (_data_->_state_ == 0) {
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1647 "match-im-addresses.c"
	} else {
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1651 "match-im-addresses.c"
	}
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_object_unref (_data_->_async_result);
#line 145 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return FALSE;
#line 1657 "match-im-addresses.c"
}


static void match_im_addresses_tests_class_init (MatchIMAddressesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	match_im_addresses_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_type_class_add_private (klass, sizeof (MatchIMAddressesTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	G_OBJECT_CLASS (klass)->finalize = match_im_addresses_tests_finalize;
#line 1668 "match-im-addresses.c"
}


static void match_im_addresses_tests_instance_init (MatchIMAddressesTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv = MATCH_IM_ADDRESSES_TESTS_GET_PRIVATE (self);
#line 30 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = g_strdup ("aaa");
#line 30 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_persona_fullname_1 = _tmp0_;
#line 31 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp1_ = g_strdup ("bbb");
#line 31 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_persona_fullname_2 = _tmp1_;
#line 32 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp2_ = g_strdup ("some-address@jabber.example.org");
#line 32 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_im_addr_1 = _tmp2_;
#line 33 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp3_ = g_strdup ("some-other-address@jabber.example.org");
#line 33 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_im_addr_2 = _tmp3_;
#line 34 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_added_personas = FALSE;
#line 35 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp4_ = g_strdup ("");
#line 35 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_individual_id_1 = _tmp4_;
#line 36 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp5_ = g_strdup ("");
#line 36 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self->priv->_individual_id_2 = _tmp5_;
#line 1707 "match-im-addresses.c"
}


static void match_im_addresses_tests_finalize (GObject* obj) {
	MatchIMAddressesTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MATCH_IM_ADDRESSES_TESTS, MatchIMAddressesTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 31 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 32 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_free0 (self->priv->_im_addr_1);
#line 33 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_free0 (self->priv->_im_addr_2);
#line 35 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_free0 (self->priv->_individual_id_1);
#line 36 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_free0 (self->priv->_individual_id_2);
#line 38 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (self->priv->_pstore);
#line 26 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	G_OBJECT_CLASS (match_im_addresses_tests_parent_class)->finalize (obj);
#line 1735 "match-im-addresses.c"
}


GType match_im_addresses_tests_get_type (void) {
	static volatile gsize match_im_addresses_tests_type_id__volatile = 0;
	if (g_once_init_enter (&match_im_addresses_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (MatchIMAddressesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) match_im_addresses_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MatchIMAddressesTests), 0, (GInstanceInitFunc) match_im_addresses_tests_instance_init, NULL };
		GType match_im_addresses_tests_type_id;
		match_im_addresses_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "MatchIMAddressesTests", &g_define_type_info, 0);
		g_once_init_leave (&match_im_addresses_tests_type_id__volatile, match_im_addresses_tests_type_id);
	}
	return match_im_addresses_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	MatchIMAddressesTests* tests = NULL;
	MatchIMAddressesTests* _tmp0_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_test_init (&args_length1, &args, NULL);
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_tmp0_ = match_im_addresses_tests_new ();
#line 205 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	tests = _tmp0_;
#line 206 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 207 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	g_test_run ();
#line 208 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 210 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	result = 0;
#line 210 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	_g_object_unref0 (tests);
#line 210 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return result;
#line 1773 "match-im-addresses.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 201 "/opt/gnome3/source/folks/tests/tracker/match-im-addresses.vala"
	return _vala_main (argv, argc);
#line 1783 "match-im-addresses.c"
}



