/* note-details-interface.c generated by valac 0.24.0, the Vala compiler
 * generated from note-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_NOTE_DETAILS_INTERFACE_TESTS (note_details_interface_tests_get_type ())
#define NOTE_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NOTE_DETAILS_INTERFACE_TESTS, NoteDetailsInterfaceTests))
#define NOTE_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NOTE_DETAILS_INTERFACE_TESTS, NoteDetailsInterfaceTestsClass))
#define IS_NOTE_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NOTE_DETAILS_INTERFACE_TESTS))
#define IS_NOTE_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NOTE_DETAILS_INTERFACE_TESTS))
#define NOTE_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NOTE_DETAILS_INTERFACE_TESTS, NoteDetailsInterfaceTestsClass))

typedef struct _NoteDetailsInterfaceTests NoteDetailsInterfaceTests;
typedef struct _NoteDetailsInterfaceTestsClass NoteDetailsInterfaceTestsClass;
typedef struct _NoteDetailsInterfaceTestsPrivate NoteDetailsInterfaceTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _NoteDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	NoteDetailsInterfaceTestsPrivate * priv;
};

struct _NoteDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _NoteDetailsInterfaceTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gboolean _found_note;
	gchar* _note;
	gchar* _fullname;
};

struct _NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	NoteDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer note_details_interface_tests_parent_class = NULL;

GType note_details_interface_tests_get_type (void) G_GNUC_CONST;
#define NOTE_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_NOTE_DETAILS_INTERFACE_TESTS, NoteDetailsInterfaceTestsPrivate))
enum  {
	NOTE_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
NoteDetailsInterfaceTests* note_details_interface_tests_new (void);
NoteDetailsInterfaceTests* note_details_interface_tests_construct (GType object_type);
void note_details_interface_tests_test_note_details_interface (NoteDetailsInterfaceTests* self);
static void _note_details_interface_tests_test_note_details_interface_folks_test_case_test_method (gpointer self);
static void _note_details_interface_tests_test_note_details_interface_async (NoteDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _note_details_interface_tests_test_note_details_interface_finish (NoteDetailsInterfaceTests* self, GAsyncResult* _res_);
static void _note_details_interface_tests_test_note_details_interface_async_data_free (gpointer _data);
static gboolean _note_details_interface_tests_test_note_details_interface_async_co (NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData* _data_);
static void _note_details_interface_tests_test_note_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _note_details_interface_tests_individuals_changed_cb (NoteDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __note_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _note_details_interface_tests_notify_note_cb (NoteDetailsInterfaceTests* self, GObject* individual_obj, GParamSpec* ps);
static void __note_details_interface_tests_notify_note_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void note_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _note_details_interface_tests_test_note_details_interface_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	note_details_interface_tests_test_note_details_interface ((NoteDetailsInterfaceTests*) self);
#line 116 "note-details-interface.c"
}


NoteDetailsInterfaceTests* note_details_interface_tests_construct (GType object_type) {
	NoteDetailsInterfaceTests * self = NULL;
#line 36 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self = (NoteDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "NoteDetailsInterfaceTests");
#line 38 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test note details interface", _note_details_interface_tests_test_note_details_interface_folks_test_case_test_method, self);
#line 34 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	return self;
#line 128 "note-details-interface.c"
}


NoteDetailsInterfaceTests* note_details_interface_tests_new (void) {
#line 34 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	return note_details_interface_tests_construct (TYPE_NOTE_DETAILS_INTERFACE_TESTS);
#line 135 "note-details-interface.c"
}


void note_details_interface_tests_test_note_details_interface (NoteDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	TrackerTestBackend* _tmp6_ = NULL;
	TrackerTestBackend* _tmp7_ = NULL;
	GMainLoop* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
#line 42 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 44 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 44 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 44 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 45 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	c1 = _tmp1_;
#line 46 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 46 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_free0 (self->priv->_fullname);
#line 46 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self->priv->_fullname = _tmp2_;
#line 47 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp3_ = g_strdup ("this is a note");
#line 47 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_free0 (self->priv->_note);
#line 47 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self->priv->_note = _tmp3_;
#line 49 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp4_ = self->priv->_fullname;
#line 49 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp4_);
#line 50 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp5_ = self->priv->_note;
#line 50 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_NOTE, _tmp5_);
#line 51 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp6_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 51 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 53 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp7_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 53 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 55 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self->priv->_found_note = FALSE;
#line 57 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_note_details_interface_tests_test_note_details_interface_async (self, NULL, NULL);
#line 59 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp8_ = self->priv->_main_loop;
#line 59 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp8_, 5);
#line 61 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp9_ = self->priv->_found_note;
#line 61 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_vala_assert (_tmp9_ == TRUE, "this._found_note == true");
#line 42 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (c1);
#line 205 "note-details-interface.c"
}


static void _note_details_interface_tests_test_note_details_interface_async_data_free (gpointer _data) {
	NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_slice_free (NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData, _data_);
#line 216 "note-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 223 "note-details-interface.c"
}


static void _note_details_interface_tests_test_note_details_interface_async (NoteDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData* _data_;
	NoteDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_ = g_slice_new0 (NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _note_details_interface_tests_test_note_details_interface_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _note_details_interface_tests_test_note_details_interface_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_note_details_interface_tests_test_note_details_interface_async_co (_data_);
#line 242 "note-details-interface.c"
}


static void _note_details_interface_tests_test_note_details_interface_finish (NoteDetailsInterfaceTests* self, GAsyncResult* _res_) {
	NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 250 "note-details-interface.c"
}


static void _note_details_interface_tests_test_note_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData* _data_;
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_ = _user_data_;
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_res_ = _res_;
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_note_details_interface_tests_test_note_details_interface_async_co (_data_);
#line 264 "note-details-interface.c"
}


static void __note_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 69 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_note_details_interface_tests_individuals_changed_cb ((NoteDetailsInterfaceTests*) self, changes);
#line 271 "note-details-interface.c"
}


static gboolean _note_details_interface_tests_test_note_details_interface_async_co (NoteDetailsInterfaceTestsTestNoteDetailsInterfaceAsyncData* _data_) {
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	switch (_data_->_state_) {
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		case 0:
#line 280 "note-details-interface.c"
		goto _state_0;
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		case 1:
#line 284 "note-details-interface.c"
		goto _state_1;
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		case 2:
#line 288 "note-details-interface.c"
		goto _state_2;
		default:
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		g_assert_not_reached ();
#line 293 "note-details-interface.c"
	}
	_state_0:
#line 66 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 66 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 66 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_state_ = 1;
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	folks_backend_store_prepare (_data_->store, _note_details_interface_tests_test_note_details_interface_async_ready, _data_);
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	return FALSE;
#line 308 "note-details-interface.c"
	_state_1:
#line 67 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 68 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 68 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 68 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 68 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 69 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 69 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __note_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 326 "note-details-interface.c"
	{
#line 73 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 73 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_state_ = 2;
#line 73 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _note_details_interface_tests_test_note_details_interface_async_ready, _data_);
#line 73 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		return FALSE;
#line 338 "note-details-interface.c"
		_state_2:
#line 73 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 73 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		if (_data_->_inner_error_ != NULL) {
#line 344 "note-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 77 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 77 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		g_warning ("note-details-interface.vala:77: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 367 "note-details-interface.c"
	}
	__finally0:
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	if (_data_->_inner_error_ != NULL) {
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		return FALSE;
#line 380 "note-details-interface.c"
	}
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 388 "note-details-interface.c"
	} else {
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 392 "note-details-interface.c"
	}
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 64 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	return FALSE;
#line 398 "note-details-interface.c"
}


static void __note_details_interface_tests_notify_note_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 93 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_note_details_interface_tests_notify_note_cb ((NoteDetailsInterfaceTests*) self, _sender, pspec);
#line 405 "note-details-interface.c"
}


static void _note_details_interface_tests_individuals_changed_cb (NoteDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp50_ = NULL;
	gint _tmp51_ = 0;
	gint _tmp52_ = 0;
#line 81 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 81 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 84 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp0_ = changes;
#line 84 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 84 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	added = _tmp1_;
#line 85 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp2_ = changes;
#line 85 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 85 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	removed = _tmp3_;
#line 435 "note-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp4_ = added;
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_i_it = _tmp5_;
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		while (TRUE) {
#line 448 "note-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp6_ = _i_it;
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			if (!_tmp7_) {
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				break;
#line 467 "note-details-interface.c"
			}
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp8_ = _i_it;
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 89 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp10_ = i;
#line 89 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 91 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp11_ = i;
#line 91 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 91 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 91 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp14_ = self->priv->_fullname;
#line 91 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 489 "note-details-interface.c"
				FolksIndividual* _tmp15_ = NULL;
#line 93 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				_tmp15_ = i;
#line 93 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				g_signal_connect_object ((GObject*) _tmp15_, "notify::notes", (GCallback) __note_details_interface_tests_notify_note_cb_g_object_notify, self, 0);
#line 495 "note-details-interface.c"
				{
					GeeIterator* _note_fd_it = NULL;
					FolksIndividual* _tmp16_ = NULL;
					GeeSet* _tmp17_ = NULL;
					GeeSet* _tmp18_ = NULL;
					GeeIterator* _tmp19_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
					_tmp16_ = i;
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
					_tmp17_ = folks_note_details_get_notes ((FolksNoteDetails*) _tmp16_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
					_tmp18_ = _tmp17_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
					_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
					_note_fd_it = _tmp19_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
					while (TRUE) {
#line 514 "note-details-interface.c"
						GeeIterator* _tmp20_ = NULL;
						gboolean _tmp21_ = FALSE;
						FolksNoteFieldDetails* note_fd = NULL;
						GeeIterator* _tmp22_ = NULL;
						gpointer _tmp23_ = NULL;
						FolksNoteFieldDetails* note_fd_expected = NULL;
						const gchar* _tmp24_ = NULL;
						FolksNoteFieldDetails* _tmp25_ = NULL;
						FolksNoteFieldDetails* _tmp26_ = NULL;
						FolksNoteFieldDetails* _tmp27_ = NULL;
						const gchar* _tmp28_ = NULL;
						const gchar* _tmp29_ = NULL;
						FolksNoteFieldDetails* _tmp30_ = NULL;
						FolksNoteFieldDetails* _tmp31_ = NULL;
						gboolean _tmp32_ = FALSE;
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp20_ = _note_fd_it;
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp21_ = gee_iterator_next (_tmp20_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						if (!_tmp21_) {
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							break;
#line 538 "note-details-interface.c"
						}
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp22_ = _note_fd_it;
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp23_ = gee_iterator_get (_tmp22_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						note_fd = (FolksNoteFieldDetails*) _tmp23_;
#line 96 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp24_ = self->priv->_note;
#line 96 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp25_ = folks_note_field_details_new (_tmp24_, NULL, NULL);
#line 96 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						note_fd_expected = _tmp25_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp26_ = note_fd_expected;
#line 102 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp27_ = note_fd;
#line 102 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp28_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp27_);
#line 102 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp29_ = _tmp28_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _tmp26_, _tmp29_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp30_ = note_fd;
#line 104 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp31_ = note_fd_expected;
#line 104 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_tmp32_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp30_, (FolksAbstractFieldDetails*) _tmp31_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						if (_tmp32_) {
#line 570 "note-details-interface.c"
							FolksNoteFieldDetails* note_fd_2 = NULL;
							FolksNoteFieldDetails* _tmp33_ = NULL;
							gconstpointer _tmp34_ = NULL;
							const gchar* _tmp35_ = NULL;
							FolksNoteFieldDetails* _tmp36_ = NULL;
							const gchar* _tmp37_ = NULL;
							const gchar* _tmp38_ = NULL;
							FolksNoteFieldDetails* _tmp39_ = NULL;
							FolksNoteFieldDetails* _tmp40_ = NULL;
							FolksNoteFieldDetails* _tmp41_ = NULL;
							gboolean _tmp42_ = FALSE;
							FolksNoteFieldDetails* _tmp43_ = NULL;
							const gchar* _tmp44_ = NULL;
							const gchar* _tmp45_ = NULL;
							FolksNoteFieldDetails* _tmp46_ = NULL;
							const gchar* _tmp47_ = NULL;
							const gchar* _tmp48_ = NULL;
							GMainLoop* _tmp49_ = NULL;
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp33_ = note_fd_expected;
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp34_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp33_);
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp35_ = _tmp34_;
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp36_ = note_fd;
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp37_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp36_);
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp38_ = _tmp37_;
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp39_ = folks_note_field_details_new ((const gchar*) _tmp35_, NULL, _tmp38_);
#line 109 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							note_fd_2 = _tmp39_;
#line 111 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp40_ = note_fd;
#line 111 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp41_ = note_fd_2;
#line 111 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp42_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp40_, (FolksAbstractFieldDetails*) _tmp41_);
#line 111 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_vala_assert (_tmp42_, "note_fd.equal (note_fd_2)");
#line 112 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp43_ = note_fd;
#line 112 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp44_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp43_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp45_ = _tmp44_;
#line 112 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp46_ = note_fd_2;
#line 112 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp47_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp46_);
#line 112 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp48_ = _tmp47_;
#line 112 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_vala_assert (g_strcmp0 (_tmp45_, _tmp48_) == 0, "note_fd.id == note_fd_2.id");
#line 114 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							self->priv->_found_note = TRUE;
#line 115 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_tmp49_ = self->priv->_main_loop;
#line 115 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							g_main_loop_quit (_tmp49_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
							_g_object_unref0 (note_fd_2);
#line 635 "note-details-interface.c"
						}
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_g_object_unref0 (note_fd_expected);
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
						_g_object_unref0 (note_fd);
#line 641 "note-details-interface.c"
					}
#line 94 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
					_g_object_unref0 (_note_fd_it);
#line 645 "note-details-interface.c"
				}
			}
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_g_object_unref0 (i);
#line 650 "note-details-interface.c"
		}
#line 87 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 654 "note-details-interface.c"
	}
#line 121 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp50_ = removed;
#line 121 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp51_ = gee_collection_get_size ((GeeCollection*) _tmp50_);
#line 121 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp52_ = _tmp51_;
#line 121 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_vala_assert (_tmp52_ == 1, "removed.size == 1");
#line 664 "note-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp53_ = NULL;
		GeeIterator* _tmp54_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp53_ = removed;
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp54_ = gee_iterable_iterator ((GeeIterable*) _tmp53_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_i_it = _tmp54_;
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		while (TRUE) {
#line 677 "note-details-interface.c"
			GeeIterator* _tmp55_ = NULL;
			gboolean _tmp56_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp57_ = NULL;
			gpointer _tmp58_ = NULL;
			FolksIndividual* _tmp59_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp55_ = _i_it;
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp56_ = gee_iterator_next (_tmp55_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			if (!_tmp56_) {
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				break;
#line 692 "note-details-interface.c"
			}
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp57_ = _i_it;
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp58_ = gee_iterator_get (_tmp57_);
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			i = (FolksIndividual*) _tmp58_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp59_ = i;
#line 125 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_vala_assert (_tmp59_ == NULL, "i == null");
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_g_object_unref0 (i);
#line 706 "note-details-interface.c"
		}
#line 123 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 710 "note-details-interface.c"
	}
#line 81 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (removed);
#line 81 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (added);
#line 716 "note-details-interface.c"
}


static void _note_details_interface_tests_notify_note_cb (NoteDetailsInterfaceTests* self, GObject* individual_obj, GParamSpec* ps) {
	FolksIndividual* individual = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 129 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_return_if_fail (individual_obj != NULL);
#line 129 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_return_if_fail (ps != NULL);
#line 131 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp0_ = individual_obj;
#line 131 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 131 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	individual = _tmp1_;
#line 736 "note-details-interface.c"
	{
		GeeIterator* _n_it = NULL;
		FolksIndividual* _tmp2_ = NULL;
		GeeSet* _tmp3_ = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp2_ = individual;
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp3_ = folks_note_details_get_notes ((FolksNoteDetails*) _tmp2_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp4_ = _tmp3_;
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_n_it = _tmp5_;
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		while (TRUE) {
#line 755 "note-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksNoteFieldDetails* n = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksNoteFieldDetails* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			FolksNoteFieldDetails* _tmp12_ = NULL;
			FolksNoteFieldDetails* _tmp13_ = NULL;
			gboolean _tmp14_ = FALSE;
			gboolean _tmp15_ = FALSE;
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp6_ = _n_it;
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			if (!_tmp7_) {
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				break;
#line 775 "note-details-interface.c"
			}
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp8_ = _n_it;
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			n = (FolksNoteFieldDetails*) _tmp9_;
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp10_ = n;
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp11_ = self->priv->_note;
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp12_ = folks_note_field_details_new (_tmp11_, NULL, NULL);
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp14_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp10_, (FolksAbstractFieldDetails*) _tmp13_);
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_tmp15_ = _tmp14_;
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_g_object_unref0 (_tmp13_);
#line 134 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			if (_tmp15_) {
#line 799 "note-details-interface.c"
				GMainLoop* _tmp16_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				self->priv->_found_note = TRUE;
#line 137 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				_tmp16_ = self->priv->_main_loop;
#line 137 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
				g_main_loop_quit (_tmp16_);
#line 807 "note-details-interface.c"
			}
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
			_g_object_unref0 (n);
#line 811 "note-details-interface.c"
		}
#line 132 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
		_g_object_unref0 (_n_it);
#line 815 "note-details-interface.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (individual);
#line 819 "note-details-interface.c"
}


static void note_details_interface_tests_class_init (NoteDetailsInterfaceTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	note_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_type_class_add_private (klass, sizeof (NoteDetailsInterfaceTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = note_details_interface_tests_finalize;
#line 830 "note-details-interface.c"
}


static void note_details_interface_tests_instance_init (NoteDetailsInterfaceTests * self) {
	gchar* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self->priv = NOTE_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 32 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp0_ = g_strdup ("persona #1");
#line 32 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self->priv->_fullname = _tmp0_;
#line 842 "note-details-interface.c"
}


static void note_details_interface_tests_finalize (GObject* obj) {
	NoteDetailsInterfaceTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_NOTE_DETAILS_INTERFACE_TESTS, NoteDetailsInterfaceTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_free0 (self->priv->_note);
#line 32 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_free0 (self->priv->_fullname);
#line 26 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	G_OBJECT_CLASS (note_details_interface_tests_parent_class)->finalize (obj);
#line 860 "note-details-interface.c"
}


GType note_details_interface_tests_get_type (void) {
	static volatile gsize note_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&note_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NoteDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) note_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NoteDetailsInterfaceTests), 0, (GInstanceInitFunc) note_details_interface_tests_instance_init, NULL };
		GType note_details_interface_tests_type_id;
		note_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "NoteDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&note_details_interface_tests_type_id__volatile, note_details_interface_tests_type_id);
	}
	return note_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	NoteDetailsInterfaceTests* tests = NULL;
	NoteDetailsInterfaceTests* _tmp0_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 147 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_tmp0_ = note_details_interface_tests_new ();
#line 147 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	tests = _tmp0_;
#line 148 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 149 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	g_test_run ();
#line 150 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 152 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	result = 0;
#line 152 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	_g_object_unref0 (tests);
#line 152 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	return result;
#line 898 "note-details-interface.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 143 "/opt/gnome3/source/folks/tests/tracker/note-details-interface.vala"
	return _vala_main (argv, argc);
#line 908 "note-details-interface.c"
}



