/* set-emails.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from set-emails.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>


#define TYPE_SET_EMAILS_TESTS (set_emails_tests_get_type ())
#define SET_EMAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_EMAILS_TESTS, SetEmailsTests))
#define SET_EMAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_EMAILS_TESTS, SetEmailsTestsClass))
#define IS_SET_EMAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_EMAILS_TESTS))
#define IS_SET_EMAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_EMAILS_TESTS))
#define SET_EMAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_EMAILS_TESTS, SetEmailsTestsClass))

typedef struct _SetEmailsTests SetEmailsTests;
typedef struct _SetEmailsTestsClass SetEmailsTestsClass;
typedef struct _SetEmailsTestsPrivate SetEmailsTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SetEmailsTestsTestSetEmailsAsyncData SetEmailsTestsTestSetEmailsAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SetEmailsTests {
	EdsTestTestCase parent_instance;
	SetEmailsTestsPrivate * priv;
};

struct _SetEmailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _SetEmailsTestsPrivate {
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	gboolean _found_before_update;
	gboolean _found_after_update;
};

struct _SetEmailsTestsTestSetEmailsAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	SetEmailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer set_emails_tests_parent_class = NULL;

GType set_emails_tests_get_type (void) G_GNUC_CONST;
#define SET_EMAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_EMAILS_TESTS, SetEmailsTestsPrivate))
enum  {
	SET_EMAILS_TESTS_DUMMY_PROPERTY
};
SetEmailsTests* set_emails_tests_new (void);
SetEmailsTests* set_emails_tests_construct (GType object_type);
static void set_emails_tests_test_set_emails (SetEmailsTests* self);
static void _set_emails_tests_test_set_emails_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _set_emails_tests_test_set_emails_async (SetEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _set_emails_tests_test_set_emails_finish (SetEmailsTests* self, GAsyncResult* _res_);
static void _set_emails_tests_test_set_emails_async_data_free (gpointer _data);
static gboolean _set_emails_tests_test_set_emails_async_co (SetEmailsTestsTestSetEmailsAsyncData* _data_);
static void _set_emails_tests_test_set_emails_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _set_emails_tests_individuals_changed_cb (SetEmailsTests* self, GeeMultiMap* changes);
static void __set_emails_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void set_emails_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _set_emails_tests_test_set_emails_folks_test_case_test_method (gpointer self) {
#line 36 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	set_emails_tests_test_set_emails ((SetEmailsTests*) self);
#line 117 "set-emails.c"
}


SetEmailsTests* set_emails_tests_construct (GType object_type) {
	SetEmailsTests * self = NULL;
#line 34 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	self = (SetEmailsTests*) eds_test_test_case_construct (object_type, "SetEmails");
#line 36 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "setting emails on e-d-s persona", _set_emails_tests_test_set_emails_folks_test_case_test_method, self);
#line 32 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return self;
#line 129 "set-emails.c"
}


SetEmailsTests* set_emails_tests_new (void) {
#line 32 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return set_emails_tests_construct (TYPE_SET_EMAILS_TESTS);
#line 136 "set-emails.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 41 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 143 "set-emails.c"
}


static void _vala_GValue_free (GValue* self) {
#line 41 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_value_unset (self);
#line 41 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_free (self);
#line 152 "set-emails.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 50 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return self ? _g_value_dup (self) : NULL;
#line 159 "set-emails.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 53 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return self ? g_object_ref (self) : NULL;
#line 166 "set-emails.c"
}


static void set_emails_tests_test_set_emails (SetEmailsTests* self) {
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp2_ = NULL;
	GValue _tmp3_ = {0};
	GValue _tmp4_ = {0};
	GValue* _tmp5_ = NULL;
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	EdsTestBackend* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	GMainLoop* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
#line 39 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_return_if_fail (self != NULL);
#line 41 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 41 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	c1 = _tmp0_;
#line 42 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp1_ = g_main_loop_new (NULL, FALSE);
#line 42 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 42 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	self->priv->_main_loop = _tmp1_;
#line 45 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	self->priv->_found_before_update = FALSE;
#line 46 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	self->priv->_found_after_update = FALSE;
#line 48 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp2_ = ((EdsTestTestCase*) self)->eds_backend;
#line 48 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	eds_test_backend_reset (_tmp2_);
#line 50 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_value_init (&_tmp3_, G_TYPE_STRING);
#line 50 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp4_ = _tmp3_;
#line 50 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp5_ = __g_value_dup0 (&_tmp4_);
#line 50 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	__vala_GValue_free0 (v);
#line 50 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	v = _tmp5_;
#line 50 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	G_IS_VALUE (&_tmp4_) ? (g_value_unset (&_tmp4_), NULL) : NULL;
#line 51 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp6_ = v;
#line 51 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_value_set_string (_tmp6_, "bernie h. innocenti");
#line 52 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp7_ = v;
#line 52 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	v = NULL;
#line 52 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp8_ = _tmp7_;
#line 52 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp8_);
#line 52 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	__vala_GValue_free0 (_tmp8_);
#line 53 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp9_ = ((EdsTestTestCase*) self)->eds_backend;
#line 53 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp10_ = _g_object_ref0 (c1);
#line 53 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	eds_test_backend_add_contact (_tmp9_, _tmp10_);
#line 55 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_set_emails_tests_test_set_emails_async (self, NULL, NULL);
#line 57 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp11_ = self->priv->_main_loop;
#line 57 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	folks_test_utils_loop_run_with_timeout (_tmp11_, 5);
#line 59 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp12_ = self->priv->_found_before_update;
#line 59 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_vala_assert (_tmp12_, "this._found_before_update");
#line 60 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp13_ = self->priv->_found_after_update;
#line 60 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_vala_assert (_tmp13_, "this._found_after_update");
#line 39 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	__vala_GValue_free0 (v);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_object_unref0 (c1);
#line 257 "set-emails.c"
}


static void _set_emails_tests_test_set_emails_async_data_free (gpointer _data) {
	SetEmailsTestsTestSetEmailsAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_slice_free (SetEmailsTestsTestSetEmailsAsyncData, _data_);
#line 268 "set-emails.c"
}


static void _set_emails_tests_test_set_emails_async (SetEmailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	SetEmailsTestsTestSetEmailsAsyncData* _data_;
	SetEmailsTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_ = g_slice_new0 (SetEmailsTestsTestSetEmailsAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _set_emails_tests_test_set_emails_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _set_emails_tests_test_set_emails_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_set_emails_tests_test_set_emails_async_co (_data_);
#line 287 "set-emails.c"
}


static void _set_emails_tests_test_set_emails_finish (SetEmailsTests* self, GAsyncResult* _res_) {
	SetEmailsTestsTestSetEmailsAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 295 "set-emails.c"
}


static void _set_emails_tests_test_set_emails_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	SetEmailsTestsTestSetEmailsAsyncData* _data_;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_ = _user_data_;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_source_object_ = source_object;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_res_ = _res_;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_set_emails_tests_test_set_emails_async_co (_data_);
#line 309 "set-emails.c"
}


static void __set_emails_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 70 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_set_emails_tests_individuals_changed_cb ((SetEmailsTests*) self, changes);
#line 316 "set-emails.c"
}


static gboolean _set_emails_tests_test_set_emails_async_co (SetEmailsTestsTestSetEmailsAsyncData* _data_) {
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	switch (_data_->_state_) {
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		case 0:
#line 325 "set-emails.c"
		goto _state_0;
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		case 1:
#line 329 "set-emails.c"
		goto _state_1;
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		case 2:
#line 333 "set-emails.c"
		goto _state_2;
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		case 3:
#line 337 "set-emails.c"
		goto _state_3;
		default:
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		g_assert_not_reached ();
#line 342 "set-emails.c"
	}
	_state_0:
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp0_ = NULL;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_state_ = 1;
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _set_emails_tests_test_set_emails_async_ready, _data_);
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return FALSE;
#line 355 "set-emails.c"
	_state_1:
#line 65 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 67 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp1_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 67 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->store = _data_->_tmp1_;
#line 68 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_state_ = 2;
#line 68 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	folks_backend_store_prepare (_data_->store, _set_emails_tests_test_set_emails_async_ready, _data_);
#line 68 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return FALSE;
#line 371 "set-emails.c"
	_state_2:
#line 68 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 69 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp2_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 69 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 69 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 70 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp3_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 70 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __set_emails_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 389 "set-emails.c"
	{
#line 74 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_tmp4_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 74 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_state_ = 3;
#line 74 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _set_emails_tests_test_set_emails_async_ready, _data_);
#line 74 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		return FALSE;
#line 401 "set-emails.c"
		_state_3:
#line 74 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 74 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		if (_data_->_inner_error_ != NULL) {
#line 407 "set-emails.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->e = _data_->_inner_error_;
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_inner_error_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_tmp5_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_tmp5_ = _data_->e;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_tmp6_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		g_warning ("set-emails.vala:78: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_g_error_free0 (_data_->e);
#line 430 "set-emails.c"
	}
	__finally0:
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	if (_data_->_inner_error_ != NULL) {
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_g_object_unref0 (_data_->store);
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		g_clear_error (&_data_->_inner_error_);
#line 72 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		return FALSE;
#line 443 "set-emails.c"
	}
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_object_unref0 (_data_->store);
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	if (_data_->_state_ == 0) {
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 451 "set-emails.c"
	} else {
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 455 "set-emails.c"
	}
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_object_unref (_data_->_async_result);
#line 63 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return FALSE;
#line 461 "set-emails.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 105 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return result;
#line 470 "set-emails.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 105 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return result;
#line 479 "set-emails.c"
}


static void _set_emails_tests_individuals_changed_cb (SetEmailsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_return_if_fail (self != NULL);
#line 82 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_return_if_fail (changes != NULL);
#line 85 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp0_ = changes;
#line 85 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 85 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	added = _tmp1_;
#line 497 "set-emails.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_tmp2_ = added;
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_i_it = _tmp3_;
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		while (TRUE) {
#line 510 "set-emails.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksIndividual* _tmp8_ = NULL;
			FolksNameDetails* name = NULL;
			FolksIndividual* _tmp9_ = NULL;
			FolksNameDetails* _tmp10_ = NULL;
			FolksNameDetails* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gboolean _tmp14_ = FALSE;
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp4_ = _i_it;
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			if (!_tmp5_) {
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
				break;
#line 532 "set-emails.c"
			}
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp6_ = _i_it;
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			i = (FolksIndividual*) _tmp7_;
#line 89 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp8_ = i;
#line 89 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_vala_assert (_tmp8_ != NULL, "i != null");
#line 91 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp9_ = i;
#line 91 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 91 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			name = _tmp10_;
#line 93 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp11_ = name;
#line 93 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp12_ = folks_name_details_get_full_name (_tmp11_);
#line 93 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp13_ = _tmp12_;
#line 93 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			if (g_strcmp0 (_tmp13_, "bernie h. innocenti") != 0) {
#line 94 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
				_g_object_unref0 (name);
#line 94 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
				_g_object_unref0 (i);
#line 94 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
				continue;
#line 564 "set-emails.c"
			}
#line 99 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_tmp14_ = self->priv->_found_before_update;
#line 99 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			if (!_tmp14_) {
#line 101 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
				self->priv->_found_before_update = TRUE;
#line 572 "set-emails.c"
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp15_ = NULL;
					GeeSet* _tmp16_ = NULL;
					GeeSet* _tmp17_ = NULL;
					GeeIterator* _tmp18_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp15_ = i;
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp16_ = folks_individual_get_personas (_tmp15_);
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp17_ = _tmp16_;
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp18_ = gee_iterable_iterator ((GeeIterable*) _tmp17_);
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_p_it = _tmp18_;
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					while (TRUE) {
#line 591 "set-emails.c"
						GeeIterator* _tmp19_ = NULL;
						gboolean _tmp20_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp21_ = NULL;
						gpointer _tmp22_ = NULL;
						GeeHashSet* emails = NULL;
						GeeHashSet* _tmp23_ = NULL;
						FolksEmailFieldDetails* email_1 = NULL;
						FolksEmailFieldDetails* _tmp24_ = NULL;
						FolksEmailFieldDetails* _tmp25_ = NULL;
						GeeHashSet* _tmp26_ = NULL;
						FolksEmailFieldDetails* _tmp27_ = NULL;
						FolksPersona* _tmp28_ = NULL;
						GeeHashSet* _tmp29_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp19_ = _p_it;
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp20_ = gee_iterator_next (_tmp19_);
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						if (!_tmp20_) {
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
							break;
#line 614 "set-emails.c"
						}
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp21_ = _p_it;
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp22_ = gee_iterator_get (_tmp21_);
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						p = (FolksPersona*) _tmp22_;
#line 105 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp23_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 105 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						emails = _tmp23_;
#line 108 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp24_ = folks_email_field_details_new ("bernie@example.org", NULL);
#line 108 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						email_1 = _tmp24_;
#line 109 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp25_ = email_1;
#line 109 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _tmp25_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 111 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp26_ = emails;
#line 111 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp27_ = email_1;
#line 111 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp26_, _tmp27_);
#line 112 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp28_ = p;
#line 112 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp29_ = emails;
#line 112 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						folks_email_details_set_email_addresses (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, FOLKS_TYPE_EMAIL_DETAILS, FolksEmailDetails), (GeeSet*) _tmp29_);
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_g_object_unref0 (email_1);
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_g_object_unref0 (emails);
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_g_object_unref0 (p);
#line 652 "set-emails.c"
					}
#line 103 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_g_object_unref0 (_p_it);
#line 656 "set-emails.c"
				}
			} else {
				{
					GeeIterator* _e_it = NULL;
					FolksIndividual* _tmp30_ = NULL;
					GeeSet* _tmp31_ = NULL;
					GeeSet* _tmp32_ = NULL;
					GeeIterator* _tmp33_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp30_ = i;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp31_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp30_);
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp32_ = _tmp31_;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_tmp33_ = gee_iterable_iterator ((GeeIterable*) _tmp32_);
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_e_it = _tmp33_;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					while (TRUE) {
#line 677 "set-emails.c"
						GeeIterator* _tmp34_ = NULL;
						gboolean _tmp35_ = FALSE;
						FolksEmailFieldDetails* e = NULL;
						GeeIterator* _tmp36_ = NULL;
						gpointer _tmp37_ = NULL;
						FolksEmailFieldDetails* _tmp38_ = NULL;
						gconstpointer _tmp39_ = NULL;
						const gchar* _tmp40_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp34_ = _e_it;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp35_ = gee_iterator_next (_tmp34_);
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						if (!_tmp35_) {
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
							break;
#line 694 "set-emails.c"
						}
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp36_ = _e_it;
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp37_ = gee_iterator_get (_tmp36_);
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						e = (FolksEmailFieldDetails*) _tmp37_;
#line 119 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp38_ = e;
#line 119 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp39_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp38_);
#line 119 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_tmp40_ = _tmp39_;
#line 119 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						if (g_strcmp0 ((const gchar*) _tmp40_, "bernie@example.org") == 0) {
#line 710 "set-emails.c"
							GMainLoop* _tmp41_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
							self->priv->_found_after_update = TRUE;
#line 122 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
							_tmp41_ = self->priv->_main_loop;
#line 122 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
							g_main_loop_quit (_tmp41_);
#line 718 "set-emails.c"
						}
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
						_g_object_unref0 (e);
#line 722 "set-emails.c"
					}
#line 117 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
					_g_object_unref0 (_e_it);
#line 726 "set-emails.c"
				}
			}
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_g_object_unref0 (name);
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
			_g_object_unref0 (i);
#line 733 "set-emails.c"
		}
#line 87 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
		_g_object_unref0 (_i_it);
#line 737 "set-emails.c"
	}
#line 82 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_object_unref0 (added);
#line 741 "set-emails.c"
}


static void set_emails_tests_class_init (SetEmailsTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	set_emails_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_type_class_add_private (klass, sizeof (SetEmailsTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	G_OBJECT_CLASS (klass)->finalize = set_emails_tests_finalize;
#line 752 "set-emails.c"
}


static void set_emails_tests_instance_init (SetEmailsTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	self->priv = SET_EMAILS_TESTS_GET_PRIVATE (self);
#line 759 "set-emails.c"
}


static void set_emails_tests_finalize (GObject* obj) {
	SetEmailsTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_EMAILS_TESTS, SetEmailsTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 28 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 25 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	G_OBJECT_CLASS (set_emails_tests_parent_class)->finalize (obj);
#line 773 "set-emails.c"
}


GType set_emails_tests_get_type (void) {
	static volatile gsize set_emails_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_emails_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetEmailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_emails_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetEmailsTests), 0, (GInstanceInitFunc) set_emails_tests_instance_init, NULL };
		GType set_emails_tests_type_id;
		set_emails_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "SetEmailsTests", &g_define_type_info, 0);
		g_once_init_leave (&set_emails_tests_type_id__volatile, set_emails_tests_type_id);
	}
	return set_emails_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SetEmailsTests* tests = NULL;
	SetEmailsTests* _tmp0_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_test_init (&args_length1, &args, NULL);
#line 134 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_tmp0_ = set_emails_tests_new ();
#line 134 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	tests = _tmp0_;
#line 135 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 136 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	g_test_run ();
#line 137 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 139 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	result = 0;
#line 139 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	_g_object_unref0 (tests);
#line 139 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return result;
#line 811 "set-emails.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 130 "/opt/gnome3/source/folks/tests/eds/set-emails.vala"
	return _vala_main (argv, argc);
#line 821 "set-emails.c"
}



