/* email-details-interface.c generated by valac 0.24.0.111-cb21a, the Vala compiler
 * generated from email-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_EMAIL_DETAILS_INTERFACE_TESTS (email_details_interface_tests_get_type ())
#define EMAIL_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EMAIL_DETAILS_INTERFACE_TESTS, EmailDetailsInterfaceTests))
#define EMAIL_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EMAIL_DETAILS_INTERFACE_TESTS, EmailDetailsInterfaceTestsClass))
#define IS_EMAIL_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EMAIL_DETAILS_INTERFACE_TESTS))
#define IS_EMAIL_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EMAIL_DETAILS_INTERFACE_TESTS))
#define EMAIL_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EMAIL_DETAILS_INTERFACE_TESTS, EmailDetailsInterfaceTestsClass))

typedef struct _EmailDetailsInterfaceTests EmailDetailsInterfaceTests;
typedef struct _EmailDetailsInterfaceTestsClass EmailDetailsInterfaceTestsClass;
typedef struct _EmailDetailsInterfaceTestsPrivate EmailDetailsInterfaceTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _EmailDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	EmailDetailsInterfaceTestsPrivate * priv;
};

struct _EmailDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _EmailDetailsInterfaceTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _num_emails;
	gboolean _found_email_1;
	gboolean _found_email_2;
};

struct _EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	EmailDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer email_details_interface_tests_parent_class = NULL;

GType email_details_interface_tests_get_type (void) G_GNUC_CONST;
#define EMAIL_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_EMAIL_DETAILS_INTERFACE_TESTS, EmailDetailsInterfaceTestsPrivate))
enum  {
	EMAIL_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
EmailDetailsInterfaceTests* email_details_interface_tests_new (void);
EmailDetailsInterfaceTests* email_details_interface_tests_construct (GType object_type);
void email_details_interface_tests_test_email_details_interface (EmailDetailsInterfaceTests* self);
static void _email_details_interface_tests_test_email_details_interface_folks_test_case_test_method (gpointer self);
static void _email_details_interface_tests_test_email_details_interface_async (EmailDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _email_details_interface_tests_test_email_details_interface_finish (EmailDetailsInterfaceTests* self, GAsyncResult* _res_);
static void _email_details_interface_tests_test_email_details_interface_async_data_free (gpointer _data);
static gboolean _email_details_interface_tests_test_email_details_interface_async_co (EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData* _data_);
static void _email_details_interface_tests_test_email_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _email_details_interface_tests_individuals_changed_cb (EmailDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __email_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void email_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _email_details_interface_tests_test_email_details_interface_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	email_details_interface_tests_test_email_details_interface ((EmailDetailsInterfaceTests*) self);
#line 114 "email-details-interface.c"
}


EmailDetailsInterfaceTests* email_details_interface_tests_construct (GType object_type) {
	EmailDetailsInterfaceTests * self = NULL;
#line 36 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	self = (EmailDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "EmailDetailsInterfaceTests");
#line 38 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test email details interface", _email_details_interface_tests_test_email_details_interface_folks_test_case_test_method, self);
#line 34 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	return self;
#line 126 "email-details-interface.c"
}


EmailDetailsInterfaceTests* email_details_interface_tests_new (void) {
#line 34 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	return email_details_interface_tests_construct (TYPE_EMAIL_DETAILS_INTERFACE_TESTS);
#line 133 "email-details-interface.c"
}


void email_details_interface_tests_test_email_details_interface (EmailDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	TrackerTestBackend* _tmp2_ = NULL;
	TrackerTestBackend* _tmp3_ = NULL;
	GMainLoop* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
#line 42 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 44 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 44 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 44 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 45 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	c1 = _tmp1_;
#line 47 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, "persona #1");
#line 48 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_EMAIL_PROP, "test1@example.org,test2@example.org");
#line 50 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp2_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 50 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 52 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp3_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 52 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 54 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	self->priv->_num_emails = 0;
#line 55 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	self->priv->_found_email_1 = FALSE;
#line 56 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	self->priv->_found_email_2 = FALSE;
#line 58 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_email_details_interface_tests_test_email_details_interface_async (self, NULL, NULL);
#line 60 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp4_ = self->priv->_main_loop;
#line 60 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp4_, 5);
#line 62 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp5_ = self->priv->_num_emails;
#line 62 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_vala_assert (_tmp5_ == 2, "this._num_emails == 2");
#line 63 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp6_ = self->priv->_found_email_1;
#line 63 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_vala_assert (_tmp6_ == TRUE, "this._found_email_1 == true");
#line 64 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp7_ = self->priv->_found_email_2;
#line 64 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_vala_assert (_tmp7_ == TRUE, "this._found_email_2 == true");
#line 42 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (c1);
#line 197 "email-details-interface.c"
}


static void _email_details_interface_tests_test_email_details_interface_async_data_free (gpointer _data) {
	EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_slice_free (EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData, _data_);
#line 208 "email-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 215 "email-details-interface.c"
}


static void _email_details_interface_tests_test_email_details_interface_async (EmailDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData* _data_;
	EmailDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_ = g_slice_new0 (EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _email_details_interface_tests_test_email_details_interface_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _email_details_interface_tests_test_email_details_interface_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_email_details_interface_tests_test_email_details_interface_async_co (_data_);
#line 234 "email-details-interface.c"
}


static void _email_details_interface_tests_test_email_details_interface_finish (EmailDetailsInterfaceTests* self, GAsyncResult* _res_) {
	EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 242 "email-details-interface.c"
}


static void _email_details_interface_tests_test_email_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData* _data_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_ = _user_data_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_res_ = _res_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_email_details_interface_tests_test_email_details_interface_async_co (_data_);
#line 256 "email-details-interface.c"
}


static void __email_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 72 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_email_details_interface_tests_individuals_changed_cb ((EmailDetailsInterfaceTests*) self, changes);
#line 263 "email-details-interface.c"
}


static gboolean _email_details_interface_tests_test_email_details_interface_async_co (EmailDetailsInterfaceTestsTestEmailDetailsInterfaceAsyncData* _data_) {
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	switch (_data_->_state_) {
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		case 0:
#line 272 "email-details-interface.c"
		goto _state_0;
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		case 1:
#line 276 "email-details-interface.c"
		goto _state_1;
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		case 2:
#line 280 "email-details-interface.c"
		goto _state_2;
		default:
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		g_assert_not_reached ();
#line 285 "email-details-interface.c"
	}
	_state_0:
#line 69 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 69 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 69 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_state_ = 1;
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	folks_backend_store_prepare (_data_->store, _email_details_interface_tests_test_email_details_interface_async_ready, _data_);
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	return FALSE;
#line 300 "email-details-interface.c"
	_state_1:
#line 70 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 71 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 71 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 71 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 72 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 72 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __email_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 318 "email-details-interface.c"
	{
#line 76 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 76 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_state_ = 2;
#line 76 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _email_details_interface_tests_test_email_details_interface_async_ready, _data_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		return FALSE;
#line 330 "email-details-interface.c"
		_state_2:
#line 76 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 336 "email-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 80 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 80 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		g_warning ("email-details-interface.vala:80: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 359 "email-details-interface.c"
	}
	__finally0:
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 74 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		return FALSE;
#line 372 "email-details-interface.c"
	}
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 380 "email-details-interface.c"
	} else {
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 384 "email-details-interface.c"
	}
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 67 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	return FALSE;
#line 390 "email-details-interface.c"
}


static void _email_details_interface_tests_individuals_changed_cb (EmailDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp32_ = FALSE;
	gboolean _tmp33_ = FALSE;
	gboolean _tmp34_ = FALSE;
	GeeSet* _tmp38_ = NULL;
	gint _tmp39_ = 0;
	gint _tmp40_ = 0;
#line 84 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 84 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 87 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp0_ = changes;
#line 87 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 87 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	added = _tmp1_;
#line 88 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp2_ = changes;
#line 88 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 88 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	removed = _tmp3_;
#line 423 "email-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp4_ = added;
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_i_it = _tmp5_;
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		while (TRUE) {
#line 436 "email-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp6_ = _i_it;
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			if (!_tmp7_) {
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
				break;
#line 457 "email-details-interface.c"
			}
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp8_ = _i_it;
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 92 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp10_ = i;
#line 92 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 94 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp11_ = i;
#line 94 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 94 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 94 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			full_name = _tmp14_;
#line 95 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp15_ = full_name;
#line 95 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			if (_tmp15_ != NULL) {
#line 483 "email-details-interface.c"
				{
					GeeIterator* _email_it = NULL;
					FolksIndividual* _tmp16_ = NULL;
					GeeSet* _tmp17_ = NULL;
					GeeSet* _tmp18_ = NULL;
					GeeIterator* _tmp19_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
					_tmp16_ = i;
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
					_tmp17_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp16_);
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
					_tmp18_ = _tmp17_;
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
					_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
					_email_it = _tmp19_;
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
					while (TRUE) {
#line 502 "email-details-interface.c"
						GeeIterator* _tmp20_ = NULL;
						gboolean _tmp21_ = FALSE;
						FolksEmailFieldDetails* email = NULL;
						GeeIterator* _tmp22_ = NULL;
						gpointer _tmp23_ = NULL;
						FolksEmailFieldDetails* _tmp24_ = NULL;
						gconstpointer _tmp25_ = NULL;
						const gchar* _tmp26_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_tmp20_ = _email_it;
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_tmp21_ = gee_iterator_next (_tmp20_);
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						if (!_tmp21_) {
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							break;
#line 519 "email-details-interface.c"
						}
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_tmp22_ = _email_it;
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_tmp23_ = gee_iterator_get (_tmp22_);
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						email = (FolksEmailFieldDetails*) _tmp23_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_tmp24_ = email;
#line 99 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_tmp25_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp24_);
#line 99 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_tmp26_ = _tmp25_;
#line 99 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						if (g_strcmp0 ((const gchar*) _tmp26_, "test1@example.org") == 0) {
#line 535 "email-details-interface.c"
							gint _tmp27_ = 0;
#line 101 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							self->priv->_found_email_1 = TRUE;
#line 102 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							_tmp27_ = self->priv->_num_emails;
#line 102 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							self->priv->_num_emails = _tmp27_ + 1;
#line 543 "email-details-interface.c"
						} else {
							FolksEmailFieldDetails* _tmp28_ = NULL;
							gconstpointer _tmp29_ = NULL;
							const gchar* _tmp30_ = NULL;
#line 104 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							_tmp28_ = email;
#line 104 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							_tmp29_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp28_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							_tmp30_ = _tmp29_;
#line 104 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
							if (g_strcmp0 ((const gchar*) _tmp30_, "test2@example.org") == 0) {
#line 556 "email-details-interface.c"
								gint _tmp31_ = 0;
#line 106 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
								self->priv->_found_email_2 = TRUE;
#line 107 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
								_tmp31_ = self->priv->_num_emails;
#line 107 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
								self->priv->_num_emails = _tmp31_ + 1;
#line 564 "email-details-interface.c"
							}
						}
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
						_g_object_unref0 (email);
#line 569 "email-details-interface.c"
					}
#line 97 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
					_g_object_unref0 (_email_it);
#line 573 "email-details-interface.c"
				}
			}
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_g_free0 (full_name);
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_g_object_unref0 (i);
#line 580 "email-details-interface.c"
		}
#line 90 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 584 "email-details-interface.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp34_ = self->priv->_found_email_1;
#line 113 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	if (_tmp34_) {
#line 590 "email-details-interface.c"
		gboolean _tmp35_ = FALSE;
#line 114 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp35_ = self->priv->_found_email_2;
#line 114 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp33_ = _tmp35_;
#line 596 "email-details-interface.c"
	} else {
#line 113 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp33_ = FALSE;
#line 600 "email-details-interface.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	if (_tmp33_) {
#line 604 "email-details-interface.c"
		gint _tmp36_ = 0;
#line 115 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp36_ = self->priv->_num_emails;
#line 115 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp32_ = _tmp36_ == 2;
#line 610 "email-details-interface.c"
	} else {
#line 113 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp32_ = FALSE;
#line 614 "email-details-interface.c"
	}
#line 113 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	if (_tmp32_) {
#line 618 "email-details-interface.c"
		GMainLoop* _tmp37_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp37_ = self->priv->_main_loop;
#line 116 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		g_main_loop_quit (_tmp37_);
#line 624 "email-details-interface.c"
	}
#line 118 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp38_ = removed;
#line 118 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp39_ = gee_collection_get_size ((GeeCollection*) _tmp38_);
#line 118 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp40_ = _tmp39_;
#line 118 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_vala_assert (_tmp40_ == 1, "removed.size == 1");
#line 634 "email-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp41_ = NULL;
		GeeIterator* _tmp42_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp41_ = removed;
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_tmp42_ = gee_iterable_iterator ((GeeIterable*) _tmp41_);
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_i_it = _tmp42_;
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		while (TRUE) {
#line 647 "email-details-interface.c"
			GeeIterator* _tmp43_ = NULL;
			gboolean _tmp44_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp45_ = NULL;
			gpointer _tmp46_ = NULL;
			FolksIndividual* _tmp47_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp43_ = _i_it;
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp44_ = gee_iterator_next (_tmp43_);
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			if (!_tmp44_) {
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
				break;
#line 662 "email-details-interface.c"
			}
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp45_ = _i_it;
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp46_ = gee_iterator_get (_tmp45_);
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			i = (FolksIndividual*) _tmp46_;
#line 122 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_tmp47_ = i;
#line 122 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_vala_assert (_tmp47_ == NULL, "i == null");
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
			_g_object_unref0 (i);
#line 676 "email-details-interface.c"
		}
#line 120 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 680 "email-details-interface.c"
	}
#line 84 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (removed);
#line 84 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (added);
#line 686 "email-details-interface.c"
}


static void email_details_interface_tests_class_init (EmailDetailsInterfaceTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	email_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_type_class_add_private (klass, sizeof (EmailDetailsInterfaceTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = email_details_interface_tests_finalize;
#line 697 "email-details-interface.c"
}


static void email_details_interface_tests_instance_init (EmailDetailsInterfaceTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	self->priv = EMAIL_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 704 "email-details-interface.c"
}


static void email_details_interface_tests_finalize (GObject* obj) {
	EmailDetailsInterfaceTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_EMAIL_DETAILS_INTERFACE_TESTS, EmailDetailsInterfaceTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 26 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	G_OBJECT_CLASS (email_details_interface_tests_parent_class)->finalize (obj);
#line 718 "email-details-interface.c"
}


GType email_details_interface_tests_get_type (void) {
	static volatile gsize email_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&email_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EmailDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) email_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EmailDetailsInterfaceTests), 0, (GInstanceInitFunc) email_details_interface_tests_instance_init, NULL };
		GType email_details_interface_tests_type_id;
		email_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "EmailDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&email_details_interface_tests_type_id__volatile, email_details_interface_tests_type_id);
	}
	return email_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	EmailDetailsInterfaceTests* tests = NULL;
	EmailDetailsInterfaceTests* _tmp0_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 131 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_tmp0_ = email_details_interface_tests_new ();
#line 131 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	tests = _tmp0_;
#line 132 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 133 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	g_test_run ();
#line 134 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 136 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	result = 0;
#line 136 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	_g_object_unref0 (tests);
#line 136 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	return result;
#line 756 "email-details-interface.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 127 "/opt/gnome3/source/folks/tests/tracker/email-details-interface.vala"
	return _vala_main (argv, argc);
#line 766 "email-details-interface.c"
}



