/* persona-store-tests.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from persona-store-tests.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks.h>
#include <folks/folks-eds.h>
#include <gio/gio.h>


#define TYPE_PERSONA_STORE_TESTS (persona_store_tests_get_type ())
#define PERSONA_STORE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PERSONA_STORE_TESTS, PersonaStoreTests))
#define PERSONA_STORE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PERSONA_STORE_TESTS, PersonaStoreTestsClass))
#define IS_PERSONA_STORE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PERSONA_STORE_TESTS))
#define IS_PERSONA_STORE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PERSONA_STORE_TESTS))
#define PERSONA_STORE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PERSONA_STORE_TESTS, PersonaStoreTestsClass))

typedef struct _PersonaStoreTests PersonaStoreTests;
typedef struct _PersonaStoreTestsClass PersonaStoreTestsClass;
typedef struct _PersonaStoreTestsPrivate PersonaStoreTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PersonaStoreTests {
	EdsTestTestCase parent_instance;
	PersonaStoreTestsPrivate * priv;
};

struct _PersonaStoreTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _PersonaStoreTestsPrivate {
	GeeHashSet* _capabilities_received;
};

struct _Block1Data {
	int _ref_count_;
	PersonaStoreTests* self;
	FolksBackendStore* backend_store;
};

struct _Block2Data {
	int _ref_count_;
	PersonaStoreTests* self;
	FolksPersonaStore* store;
};


static gpointer persona_store_tests_parent_class = NULL;

GType persona_store_tests_get_type (void) G_GNUC_CONST;
#define PERSONA_STORE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PERSONA_STORE_TESTS, PersonaStoreTestsPrivate))
enum  {
	PERSONA_STORE_TESTS_DUMMY_PROPERTY
};
PersonaStoreTests* persona_store_tests_new (void);
PersonaStoreTests* persona_store_tests_construct (GType object_type);
void persona_store_tests_test_persona_store (PersonaStoreTests* self);
static void _persona_store_tests_test_persona_store_folks_test_case_test_method (gpointer self);
static void persona_store_tests_real_set_up (FolksTestCase* base);
static void persona_store_tests_real_tear_down (FolksTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void __lambda3_ (Block1Data* _data1_, GObject* o, GAsyncResult* r);
static void ___lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda4_ (PersonaStoreTests* self, FolksBackend* b);
static void ___lambda5_ (PersonaStoreTests* self, FolksPersonaStore* ps);
static void _persona_store_tests_set_up_persona_store (PersonaStoreTests* self, FolksPersonaStore* store);
static void ____lambda5__folks_backend_persona_store_added (FolksBackend* _sender, FolksPersonaStore* store, gpointer self);
static void ___lambda4__folks_backend_store_backend_available (FolksBackendStore* _sender, FolksBackend* backend, gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda6_ (Block2Data* _data2_, GObject* obj, GAsyncResult* _result_);
static void _persona_store_tests_can_add_personas_cb (PersonaStoreTests* self, GObject* s, GParamSpec* p);
static void __persona_store_tests_can_add_personas_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _persona_store_tests_can_remove_personas_cb (PersonaStoreTests* self, GObject* s, GParamSpec* p);
static void __persona_store_tests_can_remove_personas_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static void _persona_store_tests_check_can_alias_personas (PersonaStoreTests* self, GObject* s, GParamSpec* p);
static void _persona_store_tests_check_can_group_personas (PersonaStoreTests* self, GObject* s, GParamSpec* p);
static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void persona_store_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _persona_store_tests_test_persona_store_folks_test_case_test_method (gpointer self) {
#line 32 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	persona_store_tests_test_persona_store ((PersonaStoreTests*) self);
#line 123 "persona-store-tests.c"
}


PersonaStoreTests* persona_store_tests_construct (GType object_type) {
	PersonaStoreTests * self = NULL;
#line 31 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self = (PersonaStoreTests*) eds_test_test_case_construct (object_type, "PersonaStoreTests");
#line 32 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "persona store tests", _persona_store_tests_test_persona_store_folks_test_case_test_method, self);
#line 29 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return self;
#line 135 "persona-store-tests.c"
}


PersonaStoreTests* persona_store_tests_new (void) {
#line 29 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return persona_store_tests_construct (TYPE_PERSONA_STORE_TESTS);
#line 142 "persona-store-tests.c"
}


static void persona_store_tests_real_set_up (FolksTestCase* base) {
	PersonaStoreTests * self;
	GeeHashSet* _tmp0_ = NULL;
#line 35 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self = (PersonaStoreTests*) base;
#line 37 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	FOLKS_TEST_CASE_CLASS (persona_store_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, EDS_TEST_TYPE_TEST_CASE, EdsTestTestCase));
#line 38 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 38 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (self->priv->_capabilities_received);
#line 38 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self->priv->_capabilities_received = _tmp0_;
#line 159 "persona-store-tests.c"
}


static void persona_store_tests_real_tear_down (FolksTestCase* base) {
	PersonaStoreTests * self;
#line 41 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self = (PersonaStoreTests*) base;
#line 43 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (self->priv->_capabilities_received);
#line 43 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self->priv->_capabilities_received = NULL;
#line 44 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	FOLKS_TEST_CASE_CLASS (persona_store_tests_parent_class)->tear_down ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, EDS_TEST_TYPE_TEST_CASE, EdsTestTestCase));
#line 173 "persona-store-tests.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return _data1_;
#line 182 "persona-store-tests.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 191 "persona-store-tests.c"
		PersonaStoreTests* self;
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		self = _data1_->self;
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_g_object_unref0 (_data1_->backend_store);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_g_object_unref0 (self);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_slice_free (Block1Data, _data1_);
#line 201 "persona-store-tests.c"
	}
}


static GValue* _g_value_dup (GValue* self) {
#line 49 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 209 "persona-store-tests.c"
}


static void _vala_GValue_free (GValue* self) {
#line 49 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_unset (self);
#line 49 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_free (self);
#line 218 "persona-store-tests.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 56 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return self ? _g_value_dup (self) : NULL;
#line 225 "persona-store-tests.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 62 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return self ? g_object_ref (self) : NULL;
#line 232 "persona-store-tests.c"
}


static void __lambda3_ (Block1Data* _data1_, GObject* o, GAsyncResult* r) {
	PersonaStoreTests* self;
	GAsyncResult* _tmp0_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self = _data1_->self;
#line 73 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (r != NULL);
#line 75 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = r;
#line 75 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_backend_store_prepare_finish (_data1_->backend_store, _tmp0_);
#line 247 "persona-store-tests.c"
}


static void ___lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 73 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__lambda3_ (self, source_object, res);
#line 73 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	block1_data_unref (self);
#line 256 "persona-store-tests.c"
}


static void ___lambda5_ (PersonaStoreTests* self, FolksPersonaStore* ps) {
	FolksPersonaStore* _tmp0_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (ps != NULL);
#line 83 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = ps;
#line 83 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_persona_store_tests_set_up_persona_store (self, _tmp0_);
#line 268 "persona-store-tests.c"
}


static void ____lambda5__folks_backend_persona_store_added (FolksBackend* _sender, FolksPersonaStore* store, gpointer self) {
#line 81 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	___lambda5_ ((PersonaStoreTests*) self, store);
#line 275 "persona-store-tests.c"
}


static void __lambda4_ (PersonaStoreTests* self, FolksBackend* b) {
	FolksBackend* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (b != NULL);
#line 79 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = b;
#line 79 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp1_ = folks_backend_get_name (_tmp0_);
#line 79 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp2_ = _tmp1_;
#line 79 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (g_strcmp0 (_tmp2_, "eds") == 0) {
#line 293 "persona-store-tests.c"
		FolksBackend* _tmp3_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp3_ = b;
#line 81 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_signal_connect_object (_tmp3_, "persona-store-added", (GCallback) ____lambda5__folks_backend_persona_store_added, self, 0);
#line 299 "persona-store-tests.c"
		{
			GeeIterator* _store_it = NULL;
			FolksBackend* _tmp4_ = NULL;
			GeeMap* _tmp5_ = NULL;
			GeeMap* _tmp6_ = NULL;
			GeeCollection* _tmp7_ = NULL;
			GeeCollection* _tmp8_ = NULL;
			GeeCollection* _tmp9_ = NULL;
			GeeIterator* _tmp10_ = NULL;
			GeeIterator* _tmp11_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp4_ = b;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp5_ = folks_backend_get_persona_stores (_tmp4_);
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp6_ = _tmp5_;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp7_ = gee_map_get_values (_tmp6_);
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp8_ = _tmp7_;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp9_ = _tmp8_;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp10_ = gee_iterable_iterator ((GeeIterable*) _tmp9_);
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp11_ = _tmp10_;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_g_object_unref0 (_tmp9_);
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_store_it = _tmp11_;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			while (TRUE) {
#line 332 "persona-store-tests.c"
				GeeIterator* _tmp12_ = NULL;
				gboolean _tmp13_ = FALSE;
				FolksPersonaStore* store = NULL;
				GeeIterator* _tmp14_ = NULL;
				gpointer _tmp15_ = NULL;
				FolksPersonaStore* _tmp16_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				_tmp12_ = _store_it;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				_tmp13_ = gee_iterator_next (_tmp12_);
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				if (!_tmp13_) {
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
					break;
#line 347 "persona-store-tests.c"
				}
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				_tmp14_ = _store_it;
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				_tmp15_ = gee_iterator_get (_tmp14_);
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				store = (FolksPersonaStore*) _tmp15_;
#line 88 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				_tmp16_ = store;
#line 88 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				_persona_store_tests_set_up_persona_store (self, _tmp16_);
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
				_g_object_unref0 (store);
#line 361 "persona-store-tests.c"
			}
#line 86 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_g_object_unref0 (_store_it);
#line 365 "persona-store-tests.c"
		}
	}
}


static void ___lambda4__folks_backend_store_backend_available (FolksBackendStore* _sender, FolksBackend* backend, gpointer self) {
#line 77 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__lambda4_ ((PersonaStoreTests*) self, backend);
#line 374 "persona-store-tests.c"
}


void persona_store_tests_test_persona_store (PersonaStoreTests* self) {
	Block1Data* _data1_;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* c2 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp2_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp3_ = NULL;
	GValue _tmp4_ = {0};
	GValue _tmp5_ = {0};
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue _tmp10_ = {0};
	GValue _tmp11_ = {0};
	GValue* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	EdsTestBackend* _tmp17_ = NULL;
	GeeHashMap* _tmp18_ = NULL;
	GValue _tmp19_ = {0};
	GValue _tmp20_ = {0};
	GValue* _tmp21_ = NULL;
	GValue* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	GValue* _tmp24_ = NULL;
	GValue _tmp25_ = {0};
	GValue _tmp26_ = {0};
	GValue* _tmp27_ = NULL;
	GValue* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	GValue* _tmp30_ = NULL;
	GValue* _tmp31_ = NULL;
	EdsTestBackend* _tmp32_ = NULL;
	GeeHashMap* _tmp33_ = NULL;
	FolksBackendStore* _tmp34_ = NULL;
	GeeHashSet* _tmp35_ = NULL;
	gboolean _tmp36_ = FALSE;
	GeeHashSet* _tmp37_ = NULL;
	gboolean _tmp38_ = FALSE;
	GeeHashSet* _tmp39_ = NULL;
	gboolean _tmp40_ = FALSE;
	GeeHashSet* _tmp41_ = NULL;
	gboolean _tmp42_ = FALSE;
	EdsTestBackend* _tmp43_ = NULL;
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (self != NULL);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data1_->_ref_count_ = 1;
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data1_->self = g_object_ref (self);
#line 49 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 49 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	c1 = _tmp0_;
#line 50 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 50 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	c2 = _tmp1_;
#line 51 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp2_ = g_main_loop_new (NULL, FALSE);
#line 51 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	main_loop = _tmp2_;
#line 54 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp3_ = ((EdsTestTestCase*) self)->eds_backend;
#line 54 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	eds_test_backend_reset (_tmp3_);
#line 56 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_init (&_tmp4_, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp5_ = _tmp4_;
#line 56 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp6_ = __g_value_dup0 (&_tmp5_);
#line 56 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (v);
#line 56 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = _tmp6_;
#line 56 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	G_IS_VALUE (&_tmp5_) ? (g_value_unset (&_tmp5_), NULL) : NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp7_ = v;
#line 57 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_set_string (_tmp7_, "bernie h. innocenti");
#line 58 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp8_ = v;
#line 58 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = NULL;
#line 58 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp9_ = _tmp8_;
#line 58 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp9_);
#line 58 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (_tmp9_);
#line 59 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_init (&_tmp10_, G_TYPE_STRING);
#line 59 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp11_ = _tmp10_;
#line 59 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp12_ = __g_value_dup0 (&_tmp11_);
#line 59 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (v);
#line 59 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = _tmp12_;
#line 59 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	G_IS_VALUE (&_tmp11_) ? (g_value_unset (&_tmp11_), NULL) : NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp13_ = v;
#line 60 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_set_string (_tmp13_, "bernie@example.org");
#line 61 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp14_ = EDSF_PERSONA_email_fields[0];
#line 61 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp15_ = v;
#line 61 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = NULL;
#line 61 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp16_ = _tmp15_;
#line 61 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, _tmp14_, _tmp16_);
#line 61 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (_tmp16_);
#line 62 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp17_ = ((EdsTestTestCase*) self)->eds_backend;
#line 62 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp18_ = _g_object_ref0 (c1);
#line 62 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	eds_test_backend_add_contact (_tmp17_, _tmp18_);
#line 64 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_init (&_tmp19_, G_TYPE_STRING);
#line 64 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp20_ = _tmp19_;
#line 64 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp21_ = __g_value_dup0 (&_tmp20_);
#line 64 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (v);
#line 64 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = _tmp21_;
#line 64 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	G_IS_VALUE (&_tmp20_) ? (g_value_unset (&_tmp20_), NULL) : NULL;
#line 65 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp22_ = v;
#line 65 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_set_string (_tmp22_, "richard m. stallman");
#line 66 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp23_ = v;
#line 66 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = NULL;
#line 66 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp24_ = _tmp23_;
#line 66 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, "full_name", _tmp24_);
#line 66 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (_tmp24_);
#line 67 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_init (&_tmp25_, G_TYPE_STRING);
#line 67 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp26_ = _tmp25_;
#line 67 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp27_ = __g_value_dup0 (&_tmp26_);
#line 67 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (v);
#line 67 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = _tmp27_;
#line 67 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	G_IS_VALUE (&_tmp26_) ? (g_value_unset (&_tmp26_), NULL) : NULL;
#line 68 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp28_ = v;
#line 68 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_value_set_string (_tmp28_, "rms@example.org");
#line 69 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp29_ = EDSF_PERSONA_email_fields[0];
#line 69 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp30_ = v;
#line 69 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	v = NULL;
#line 69 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp31_ = _tmp30_;
#line 69 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, _tmp29_, _tmp31_);
#line 69 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (_tmp31_);
#line 70 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp32_ = ((EdsTestTestCase*) self)->eds_backend;
#line 70 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp33_ = _g_object_ref0 (c2);
#line 70 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	eds_test_backend_add_contact (_tmp32_, _tmp33_);
#line 72 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp34_ = folks_backend_store_dup ();
#line 72 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data1_->backend_store = _tmp34_;
#line 73 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_backend_store_prepare (_data1_->backend_store, ___lambda3__gasync_ready_callback, block1_data_ref (_data1_));
#line 77 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_signal_connect_object (_data1_->backend_store, "backend-available", (GCallback) ___lambda4__folks_backend_store_backend_available, self, 0);
#line 94 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_backend_store_load_backends (_data1_->backend_store, NULL, NULL);
#line 96 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 98 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp35_ = self->priv->_capabilities_received;
#line 98 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp36_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp35_, "can-add-personas");
#line 98 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (_tmp36_, "this._capabilities_received.contains (\"can-add-personas\")");
#line 99 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp37_ = self->priv->_capabilities_received;
#line 99 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp38_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp37_, "can-remove-personas");
#line 99 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (_tmp38_, "this._capabilities_received.contains (\"can-remove-personas\")");
#line 100 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp39_ = self->priv->_capabilities_received;
#line 100 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp40_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp39_, "can-alias-personas");
#line 100 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (!_tmp40_, "!this._capabilities_received.contains (\"can-alias-personas\")");
#line 101 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp41_ = self->priv->_capabilities_received;
#line 101 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp42_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp41_, "can-group-personas");
#line 101 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (_tmp42_, "this._capabilities_received.contains (\"can-group-personas\")");
#line 103 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp43_ = ((EdsTestTestCase*) self)->eds_backend;
#line 103 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	eds_test_backend_tear_down (_tmp43_);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__vala_GValue_free0 (v);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_main_loop_unref0 (main_loop);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (c2);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (c1);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	block1_data_unref (_data1_);
#line 47 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data1_ = NULL;
#line 624 "persona-store-tests.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return _data2_;
#line 633 "persona-store-tests.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 642 "persona-store-tests.c"
		PersonaStoreTests* self;
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		self = _data2_->self;
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_g_object_unref0 (_data2_->store);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_g_object_unref0 (self);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_slice_free (Block2Data, _data2_);
#line 652 "persona-store-tests.c"
	}
}


static void __persona_store_tests_can_add_personas_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 117 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_persona_store_tests_can_add_personas_cb ((PersonaStoreTests*) self, _sender, pspec);
#line 660 "persona-store-tests.c"
}


static void __persona_store_tests_can_remove_personas_cb_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 123 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_persona_store_tests_can_remove_personas_cb ((PersonaStoreTests*) self, _sender, pspec);
#line 667 "persona-store-tests.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	for (i = 0; i < stack_length; i++) {
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			return TRUE;
#line 679 "persona-store-tests.c"
		}
	}
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return FALSE;
#line 684 "persona-store-tests.c"
}


static void __lambda6_ (Block2Data* _data2_, GObject* obj, GAsyncResult* _result_) {
	PersonaStoreTests* self;
	GError * _inner_error_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self = _data2_->self;
#line 108 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (_result_ != NULL);
#line 695 "persona-store-tests.c"
	{
		FolksPersonaStore* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		FolksPersonaStore* _tmp2_ = NULL;
		FolksMaybeBool _tmp3_ = 0;
		FolksMaybeBool _tmp4_ = 0;
		FolksPersonaStore* _tmp7_ = NULL;
		FolksMaybeBool _tmp8_ = 0;
		FolksMaybeBool _tmp9_ = 0;
		FolksPersonaStore* _tmp12_ = NULL;
		gchar** _tmp13_ = NULL;
		gint _tmp13__length1 = 0;
		gchar** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
		FolksPersonaStore* _tmp16_ = NULL;
		gchar** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
		gchar** _tmp18_ = NULL;
		gint _tmp18__length1 = 0;
#line 112 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp0_ = _data2_->store;
#line 112 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp1_ = _result_;
#line 112 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		folks_persona_store_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 112 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		if (_inner_error_ != NULL) {
#line 723 "persona-store-tests.c"
			goto __catch0_g_error;
		}
#line 114 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp2_ = _data2_->store;
#line 114 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp3_ = folks_persona_store_get_can_add_personas (_tmp2_);
#line 114 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp4_ = _tmp3_;
#line 114 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		if (_tmp4_ != FOLKS_MAYBE_BOOL_UNSET) {
#line 734 "persona-store-tests.c"
			FolksPersonaStore* _tmp5_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp5_ = _data2_->store;
#line 115 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_persona_store_tests_can_add_personas_cb (self, (GObject*) _tmp5_, NULL);
#line 740 "persona-store-tests.c"
		} else {
			FolksPersonaStore* _tmp6_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp6_ = _data2_->store;
#line 117 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			g_signal_connect_object ((GObject*) _tmp6_, "notify::can-add-personas", (GCallback) __persona_store_tests_can_add_personas_cb_g_object_notify, self, 0);
#line 747 "persona-store-tests.c"
		}
#line 120 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp7_ = _data2_->store;
#line 120 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp8_ = folks_persona_store_get_can_remove_personas (_tmp7_);
#line 120 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp9_ = _tmp8_;
#line 120 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		if (_tmp9_ != FOLKS_MAYBE_BOOL_UNSET) {
#line 757 "persona-store-tests.c"
			FolksPersonaStore* _tmp10_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp10_ = _data2_->store;
#line 121 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_persona_store_tests_can_remove_personas_cb (self, (GObject*) _tmp10_, NULL);
#line 763 "persona-store-tests.c"
		} else {
			FolksPersonaStore* _tmp11_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp11_ = _data2_->store;
#line 123 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			g_signal_connect_object ((GObject*) _tmp11_, "notify::can-remove-personas", (GCallback) __persona_store_tests_can_remove_personas_cb_g_object_notify, self, 0);
#line 770 "persona-store-tests.c"
		}
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp12_ = _data2_->store;
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp13_ = folks_persona_store_get_always_writeable_properties (_tmp12_, &_tmp13__length1);
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp14_ = _tmp13_;
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp14__length1 = _tmp13__length1;
#line 126 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		if (_vala_string_array_contains (_tmp14_, _tmp14__length1, "alias")) {
#line 782 "persona-store-tests.c"
			FolksPersonaStore* _tmp15_ = NULL;
#line 127 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp15_ = _data2_->store;
#line 127 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_persona_store_tests_check_can_alias_personas (self, (GObject*) _tmp15_, NULL);
#line 788 "persona-store-tests.c"
		}
#line 129 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp16_ = _data2_->store;
#line 129 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp17_ = folks_persona_store_get_always_writeable_properties (_tmp16_, &_tmp17__length1);
#line 129 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp18_ = _tmp17_;
#line 129 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp18__length1 = _tmp17__length1;
#line 129 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		if (_vala_string_array_contains (_tmp18_, _tmp18__length1, "groups")) {
#line 800 "persona-store-tests.c"
			FolksPersonaStore* _tmp19_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_tmp19_ = _data2_->store;
#line 130 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
			_persona_store_tests_check_can_group_personas (self, (GObject*) _tmp19_, NULL);
#line 806 "persona-store-tests.c"
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		FolksPersonaStore* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		FolksPersonaStore* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		GError* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		e = _inner_error_;
#line 110 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_inner_error_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp20_ = _data2_->store;
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp21_ = folks_persona_store_get_type_id (_tmp20_);
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp22_ = _tmp21_;
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp23_ = _data2_->store;
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp24_ = folks_persona_store_get_id (_tmp23_);
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp25_ = _tmp24_;
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp26_ = e;
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp27_ = _tmp26_->message;
#line 134 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_warning ("Error preparing PersonaStore type: %s, id: %s: " "'%s'", _tmp22_, _tmp25_, _tmp27_);
#line 110 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_g_error_free0 (e);
#line 845 "persona-store-tests.c"
	}
	__finally0:
#line 110 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (_inner_error_ != NULL) {
#line 110 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 110 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_clear_error (&_inner_error_);
#line 110 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		return;
#line 856 "persona-store-tests.c"
	}
}


static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 108 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	__lambda6_ (self, source_object, res);
#line 108 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	block2_data_unref (self);
#line 866 "persona-store-tests.c"
}


static void _persona_store_tests_set_up_persona_store (PersonaStoreTests* self, FolksPersonaStore* store) {
	Block2Data* _data2_;
	FolksPersonaStore* _tmp0_ = NULL;
	FolksPersonaStore* _tmp1_ = NULL;
	FolksPersonaStore* _tmp2_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (self != NULL);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (store != NULL);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data2_->_ref_count_ = 1;
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data2_->self = g_object_ref (self);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = store;
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (_data2_->store);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data2_->store = _tmp1_;
#line 108 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp2_ = _data2_->store;
#line 108 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_persona_store_prepare (_tmp2_, ___lambda6__gasync_ready_callback, block2_data_ref (_data2_));
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	block2_data_unref (_data2_);
#line 106 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_data2_ = NULL;
#line 901 "persona-store-tests.c"
}


static void _persona_store_tests_can_add_personas_cb (PersonaStoreTests* self, GObject* s, GParamSpec* p) {
	GObject* _tmp0_ = NULL;
	EdsfPersonaStore* store = NULL;
	GObject* _tmp1_ = NULL;
	EdsfPersonaStore* _tmp2_ = NULL;
	EdsfPersonaStore* _tmp3_ = NULL;
	FolksMaybeBool _tmp4_ = 0;
	FolksMaybeBool _tmp5_ = 0;
#line 140 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (self != NULL);
#line 140 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (s != NULL);
#line 142 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = s;
#line 142 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, EDSF_TYPE_PERSONA_STORE), "s is Edsf.PersonaStore");
#line 143 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp1_ = s;
#line 143 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, EDSF_TYPE_PERSONA_STORE, EdsfPersonaStore));
#line 143 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	store = _tmp2_;
#line 145 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp3_ = store;
#line 145 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp4_ = folks_persona_store_get_can_add_personas ((FolksPersonaStore*) _tmp3_);
#line 145 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp5_ = _tmp4_;
#line 145 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (_tmp5_ != FOLKS_MAYBE_BOOL_UNSET) {
#line 935 "persona-store-tests.c"
		EdsfPersonaStore* _tmp6_ = NULL;
		FolksMaybeBool _tmp7_ = 0;
		FolksMaybeBool _tmp8_ = 0;
		GeeHashSet* _tmp9_ = NULL;
		EdsfPersonaStore* _tmp10_ = NULL;
		guint _tmp11_ = 0U;
		GQuark _tmp12_ = 0U;
#line 147 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp6_ = store;
#line 147 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp7_ = folks_persona_store_get_can_add_personas ((FolksPersonaStore*) _tmp6_);
#line 147 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp8_ = _tmp7_;
#line 147 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_vala_assert (_tmp8_ == FOLKS_MAYBE_BOOL_TRUE, "store.can_add_personas == MaybeBool.TRUE");
#line 149 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp9_ = self->priv->_capabilities_received;
#line 149 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, "can-add-personas");
#line 151 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp10_ = store;
#line 151 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_signal_parse_name ("notify::can-add-personas", G_TYPE_OBJECT, &_tmp11_, &_tmp12_, TRUE);
#line 151 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_signal_handlers_disconnect_matched ((GObject*) _tmp10_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DETAIL | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, _tmp12_, NULL, (GCallback) __persona_store_tests_can_add_personas_cb_g_object_notify, self);
#line 961 "persona-store-tests.c"
	}
#line 140 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (store);
#line 965 "persona-store-tests.c"
}


static void _persona_store_tests_can_remove_personas_cb (PersonaStoreTests* self, GObject* s, GParamSpec* p) {
	GObject* _tmp0_ = NULL;
	EdsfPersonaStore* store = NULL;
	GObject* _tmp1_ = NULL;
	EdsfPersonaStore* _tmp2_ = NULL;
	EdsfPersonaStore* _tmp3_ = NULL;
	FolksMaybeBool _tmp4_ = 0;
	FolksMaybeBool _tmp5_ = 0;
#line 156 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (self != NULL);
#line 156 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (s != NULL);
#line 158 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = s;
#line 158 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, EDSF_TYPE_PERSONA_STORE), "s is Edsf.PersonaStore");
#line 159 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp1_ = s;
#line 159 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, EDSF_TYPE_PERSONA_STORE, EdsfPersonaStore));
#line 159 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	store = _tmp2_;
#line 161 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp3_ = store;
#line 161 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp4_ = folks_persona_store_get_can_remove_personas ((FolksPersonaStore*) _tmp3_);
#line 161 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp5_ = _tmp4_;
#line 161 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (_tmp5_ != FOLKS_MAYBE_BOOL_UNSET) {
#line 999 "persona-store-tests.c"
		EdsfPersonaStore* _tmp6_ = NULL;
		FolksMaybeBool _tmp7_ = 0;
		FolksMaybeBool _tmp8_ = 0;
		GeeHashSet* _tmp9_ = NULL;
		EdsfPersonaStore* _tmp10_ = NULL;
		guint _tmp11_ = 0U;
		GQuark _tmp12_ = 0U;
#line 163 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp6_ = store;
#line 163 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp7_ = folks_persona_store_get_can_remove_personas ((FolksPersonaStore*) _tmp6_);
#line 163 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp8_ = _tmp7_;
#line 163 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_vala_assert (_tmp8_ == FOLKS_MAYBE_BOOL_TRUE, "store.can_remove_personas == MaybeBool.TRUE");
#line 165 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp9_ = self->priv->_capabilities_received;
#line 165 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, "can-remove-personas");
#line 167 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp10_ = store;
#line 167 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_signal_parse_name ("notify::can-remove-personas", G_TYPE_OBJECT, &_tmp11_, &_tmp12_, TRUE);
#line 167 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		g_signal_handlers_disconnect_matched ((GObject*) _tmp10_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DETAIL | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, _tmp12_, NULL, (GCallback) __persona_store_tests_can_remove_personas_cb_g_object_notify, self);
#line 1025 "persona-store-tests.c"
	}
#line 156 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (store);
#line 1029 "persona-store-tests.c"
}


static void _persona_store_tests_check_can_alias_personas (PersonaStoreTests* self, GObject* s, GParamSpec* p) {
	GObject* _tmp0_ = NULL;
	EdsfPersonaStore* store = NULL;
	GObject* _tmp1_ = NULL;
	EdsfPersonaStore* _tmp2_ = NULL;
	EdsfPersonaStore* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
#line 172 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (self != NULL);
#line 172 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (s != NULL);
#line 174 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = s;
#line 174 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, EDSF_TYPE_PERSONA_STORE), "s is Edsf.PersonaStore");
#line 175 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp1_ = s;
#line 175 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, EDSF_TYPE_PERSONA_STORE, EdsfPersonaStore));
#line 175 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	store = _tmp2_;
#line 177 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp3_ = store;
#line 177 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp4_ = folks_persona_store_get_always_writeable_properties ((FolksPersonaStore*) _tmp3_, &_tmp4__length1);
#line 177 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp5_ = _tmp4_;
#line 177 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp5__length1 = _tmp4__length1;
#line 177 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (_vala_string_array_contains (_tmp5_, _tmp5__length1, "alias")) {
#line 1067 "persona-store-tests.c"
		GeeHashSet* _tmp6_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp6_ = self->priv->_capabilities_received;
#line 179 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp6_, "can-alias-personas");
#line 1073 "persona-store-tests.c"
	}
#line 172 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (store);
#line 1077 "persona-store-tests.c"
}


static void _persona_store_tests_check_can_group_personas (PersonaStoreTests* self, GObject* s, GParamSpec* p) {
	GObject* _tmp0_ = NULL;
	EdsfPersonaStore* store = NULL;
	GObject* _tmp1_ = NULL;
	EdsfPersonaStore* _tmp2_ = NULL;
	EdsfPersonaStore* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
#line 183 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (self != NULL);
#line 183 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_return_if_fail (s != NULL);
#line 185 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = s;
#line 185 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, EDSF_TYPE_PERSONA_STORE), "s is Edsf.PersonaStore");
#line 186 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp1_ = s;
#line 186 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, EDSF_TYPE_PERSONA_STORE, EdsfPersonaStore));
#line 186 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	store = _tmp2_;
#line 188 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp3_ = store;
#line 188 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp4_ = folks_persona_store_get_always_writeable_properties ((FolksPersonaStore*) _tmp3_, &_tmp4__length1);
#line 188 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp5_ = _tmp4_;
#line 188 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp5__length1 = _tmp4__length1;
#line 188 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	if (_vala_string_array_contains (_tmp5_, _tmp5__length1, "groups")) {
#line 1115 "persona-store-tests.c"
		GeeHashSet* _tmp6_ = NULL;
#line 190 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		_tmp6_ = self->priv->_capabilities_received;
#line 190 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp6_, "can-group-personas");
#line 1121 "persona-store-tests.c"
	}
#line 183 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (store);
#line 1125 "persona-store-tests.c"
}


static void persona_store_tests_class_init (PersonaStoreTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	persona_store_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_type_class_add_private (klass, sizeof (PersonaStoreTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = persona_store_tests_real_set_up;
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = persona_store_tests_real_tear_down;
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	G_OBJECT_CLASS (klass)->finalize = persona_store_tests_finalize;
#line 1140 "persona-store-tests.c"
}


static void persona_store_tests_instance_init (PersonaStoreTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self->priv = PERSONA_STORE_TESTS_GET_PRIVATE (self);
#line 27 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self->priv->_capabilities_received = NULL;
#line 1149 "persona-store-tests.c"
}


static void persona_store_tests_finalize (GObject* obj) {
	PersonaStoreTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PERSONA_STORE_TESTS, PersonaStoreTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (self->priv->_capabilities_received);
#line 25 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	G_OBJECT_CLASS (persona_store_tests_parent_class)->finalize (obj);
#line 1161 "persona-store-tests.c"
}


GType persona_store_tests_get_type (void) {
	static volatile gsize persona_store_tests_type_id__volatile = 0;
	if (g_once_init_enter (&persona_store_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PersonaStoreTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) persona_store_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PersonaStoreTests), 0, (GInstanceInitFunc) persona_store_tests_instance_init, NULL };
		GType persona_store_tests_type_id;
		persona_store_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "PersonaStoreTests", &g_define_type_info, 0);
		g_once_init_leave (&persona_store_tests_type_id__volatile, persona_store_tests_type_id);
	}
	return persona_store_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PersonaStoreTests* tests = NULL;
	PersonaStoreTests* _tmp0_ = NULL;
#line 197 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_test_init (&args_length1, &args, NULL);
#line 199 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_tmp0_ = persona_store_tests_new ();
#line 199 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	tests = _tmp0_;
#line 200 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 201 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	g_test_run ();
#line 202 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 204 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	result = 0;
#line 204 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	_g_object_unref0 (tests);
#line 204 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return result;
#line 1199 "persona-store-tests.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 195 "/opt/gnome3/source/folks/tests/eds/persona-store-tests.vala"
	return _vala_main (argv, argc);
#line 1209 "persona-store-tests.c"
}



