/* name-details.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from name-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gio/gio.h>


#define TYPE_NAME_DETAILS_TESTS (name_details_tests_get_type ())
#define NAME_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME_DETAILS_TESTS, NameDetailsTests))
#define NAME_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsClass))
#define IS_NAME_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME_DETAILS_TESTS))
#define IS_NAME_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME_DETAILS_TESTS))
#define NAME_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsClass))

typedef struct _NameDetailsTests NameDetailsTests;
typedef struct _NameDetailsTestsClass NameDetailsTestsClass;
typedef struct _NameDetailsTestsPrivate NameDetailsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _NameDetailsTestsTestNamesAsyncData NameDetailsTestsTestNamesAsyncData;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _NameDetailsTests {
	EdsTestTestCase parent_instance;
	NameDetailsTestsPrivate * priv;
};

struct _NameDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _NameDetailsTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _names_count;
	GeeHashMap* _c1;
	GeeHashMap* _c2;
};

struct _NameDetailsTestsTestNamesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	NameDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer name_details_tests_parent_class = NULL;

GType name_details_tests_get_type (void) G_GNUC_CONST;
#define NAME_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_NAME_DETAILS_TESTS, NameDetailsTestsPrivate))
enum  {
	NAME_DETAILS_TESTS_DUMMY_PROPERTY
};
NameDetailsTests* name_details_tests_new (void);
NameDetailsTests* name_details_tests_construct (GType object_type);
void name_details_tests_test_names (NameDetailsTests* self);
static void _name_details_tests_test_names_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _name_details_tests_test_names_async (NameDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _name_details_tests_test_names_finish (NameDetailsTests* self, GAsyncResult* _res_);
static void _name_details_tests_test_names_async_data_free (gpointer _data);
static gboolean _name_details_tests_test_names_async_co (NameDetailsTestsTestNamesAsyncData* _data_);
static void _name_details_tests_test_names_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _name_details_tests_individuals_changed_cb (NameDetailsTests* self, GeeMultiMap* changes);
static void __name_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void name_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _name_details_tests_test_names_folks_test_case_test_method (gpointer self) {
#line 37 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	name_details_tests_test_names ((NameDetailsTests*) self);
#line 117 "name-details.c"
}


NameDetailsTests* name_details_tests_construct (GType object_type) {
	NameDetailsTests * self = NULL;
#line 35 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self = (NameDetailsTests*) eds_test_test_case_construct (object_type, "NameDetails");
#line 37 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "name details interface", _name_details_tests_test_names_folks_test_case_test_method, self);
#line 33 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return self;
#line 129 "name-details.c"
}


NameDetailsTests* name_details_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return name_details_tests_construct (TYPE_NAME_DETAILS_TESTS);
#line 136 "name-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 42 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 143 "name-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 42 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_unset (self);
#line 42 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_free (self);
#line 152 "name-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 159 "name-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 166 "name-details.c"
}


void name_details_tests_test_names (NameDetailsTests* self) {
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GMainLoop* _tmp2_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp3_ = NULL;
	GValue _tmp4_ = {0};
	GValue _tmp5_ = {0};
	GValue* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GeeHashMap* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue* _tmp10_ = NULL;
	GValue _tmp11_ = {0};
	GValue _tmp12_ = {0};
	GValue* _tmp13_ = NULL;
	GValue* _tmp14_ = NULL;
	GeeHashMap* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	GValue* _tmp17_ = NULL;
	GValue _tmp18_ = {0};
	GValue _tmp19_ = {0};
	GValue* _tmp20_ = NULL;
	GValue* _tmp21_ = NULL;
	GeeHashMap* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	GValue* _tmp24_ = NULL;
	GValue _tmp25_ = {0};
	GValue _tmp26_ = {0};
	GValue* _tmp27_ = NULL;
	GValue* _tmp28_ = NULL;
	GeeHashMap* _tmp29_ = NULL;
	GValue* _tmp30_ = NULL;
	GValue* _tmp31_ = NULL;
	GValue _tmp32_ = {0};
	GValue _tmp33_ = {0};
	GValue* _tmp34_ = NULL;
	GValue* _tmp35_ = NULL;
	GeeHashMap* _tmp36_ = NULL;
	GValue* _tmp37_ = NULL;
	GValue* _tmp38_ = NULL;
	GValue _tmp39_ = {0};
	GValue _tmp40_ = {0};
	GValue* _tmp41_ = NULL;
	GValue* _tmp42_ = NULL;
	GeeHashMap* _tmp43_ = NULL;
	GValue* _tmp44_ = NULL;
	GValue* _tmp45_ = NULL;
	GValue _tmp46_ = {0};
	GValue _tmp47_ = {0};
	GValue* _tmp48_ = NULL;
	GValue* _tmp49_ = NULL;
	GeeHashMap* _tmp50_ = NULL;
	GValue* _tmp51_ = NULL;
	GValue* _tmp52_ = NULL;
	EdsTestBackend* _tmp53_ = NULL;
	GeeHashMap* _tmp54_ = NULL;
	GeeHashMap* _tmp55_ = NULL;
	GValue _tmp56_ = {0};
	GValue _tmp57_ = {0};
	GValue* _tmp58_ = NULL;
	GValue* _tmp59_ = NULL;
	GeeHashMap* _tmp60_ = NULL;
	GValue* _tmp61_ = NULL;
	GValue* _tmp62_ = NULL;
	GValue _tmp63_ = {0};
	GValue _tmp64_ = {0};
	GValue* _tmp65_ = NULL;
	GValue* _tmp66_ = NULL;
	GeeHashMap* _tmp67_ = NULL;
	GValue* _tmp68_ = NULL;
	GValue* _tmp69_ = NULL;
	GValue _tmp70_ = {0};
	GValue _tmp71_ = {0};
	GValue* _tmp72_ = NULL;
	GValue* _tmp73_ = NULL;
	GeeHashMap* _tmp74_ = NULL;
	GValue* _tmp75_ = NULL;
	GValue* _tmp76_ = NULL;
	EdsTestBackend* _tmp77_ = NULL;
	GeeHashMap* _tmp78_ = NULL;
	GeeHashMap* _tmp79_ = NULL;
	GMainLoop* _tmp80_ = NULL;
	gint _tmp81_ = 0;
	GeeHashMap* _tmp82_ = NULL;
	gint _tmp83_ = 0;
	gint _tmp84_ = 0;
	GeeHashMap* _tmp85_ = NULL;
	gint _tmp86_ = 0;
	gint _tmp87_ = 0;
#line 40 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_return_if_fail (self != NULL);
#line 42 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 42 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 42 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self->priv->_c1 = _tmp0_;
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 43 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self->priv->_c2 = _tmp1_;
#line 44 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self->priv->_names_count = 0;
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp2_ = g_main_loop_new (NULL, FALSE);
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 45 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self->priv->_main_loop = _tmp2_;
#line 48 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp3_ = ((EdsTestTestCase*) self)->eds_backend;
#line 48 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_reset (_tmp3_);
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp4_, G_TYPE_STRING);
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp5_ = _tmp4_;
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp6_ = __g_value_dup0 (&_tmp5_);
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp6_;
#line 51 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp5_) ? (g_value_unset (&_tmp5_), NULL) : NULL;
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp7_ = v;
#line 52 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp7_, "bernie h. innocenti");
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp8_ = self->priv->_c1;
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp9_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp10_ = _tmp9_;
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, "full_name", _tmp10_);
#line 53 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp10_);
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp11_, G_TYPE_STRING);
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp12_ = _tmp11_;
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp13_ = __g_value_dup0 (&_tmp12_);
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp13_;
#line 54 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp12_) ? (g_value_unset (&_tmp12_), NULL) : NULL;
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp14_ = v;
#line 55 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp14_, "bernie");
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp15_ = self->priv->_c1;
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp16_ = v;
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp17_ = _tmp16_;
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, "nickname", _tmp17_);
#line 56 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp17_);
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp18_, G_TYPE_STRING);
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp19_ = _tmp18_;
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp20_ = __g_value_dup0 (&_tmp19_);
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp20_;
#line 57 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp19_) ? (g_value_unset (&_tmp19_), NULL) : NULL;
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp21_ = v;
#line 58 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp21_, "Innocenti");
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp22_ = self->priv->_c1;
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp23_ = v;
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp24_ = _tmp23_;
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp22_, "contact_name_family", _tmp24_);
#line 59 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp24_);
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp25_, G_TYPE_STRING);
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp26_ = _tmp25_;
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp27_ = __g_value_dup0 (&_tmp26_);
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp27_;
#line 60 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp26_) ? (g_value_unset (&_tmp26_), NULL) : NULL;
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp28_ = v;
#line 61 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp28_, "Bernardo");
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp29_ = self->priv->_c1;
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp30_ = v;
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp31_ = _tmp30_;
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp29_, "contact_name_given", _tmp31_);
#line 62 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp31_);
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp32_, G_TYPE_STRING);
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp33_ = _tmp32_;
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp34_ = __g_value_dup0 (&_tmp33_);
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp34_;
#line 63 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp33_) ? (g_value_unset (&_tmp33_), NULL) : NULL;
#line 64 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp35_ = v;
#line 64 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp35_, "H.");
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp36_ = self->priv->_c1;
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp37_ = v;
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp38_ = _tmp37_;
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp36_, "contact_name_additional", _tmp38_);
#line 65 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp38_);
#line 66 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp39_, G_TYPE_STRING);
#line 66 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp40_ = _tmp39_;
#line 66 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp41_ = __g_value_dup0 (&_tmp40_);
#line 66 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 66 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp41_;
#line 66 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp40_) ? (g_value_unset (&_tmp40_), NULL) : NULL;
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp42_ = v;
#line 67 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp42_, "Mr.");
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp43_ = self->priv->_c1;
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp44_ = v;
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp45_ = _tmp44_;
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp43_, "contact_name_prefixes", _tmp45_);
#line 68 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp45_);
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp46_, G_TYPE_STRING);
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp47_ = _tmp46_;
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp48_ = __g_value_dup0 (&_tmp47_);
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp48_;
#line 69 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp47_) ? (g_value_unset (&_tmp47_), NULL) : NULL;
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp49_ = v;
#line 70 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp49_, "(sysadmin FSF)");
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp50_ = self->priv->_c1;
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp51_ = v;
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp52_ = _tmp51_;
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp50_, "contact_name_suffixes", _tmp52_);
#line 71 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp52_);
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp53_ = ((EdsTestTestCase*) self)->eds_backend;
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp54_ = self->priv->_c1;
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp55_ = _g_object_ref0 (_tmp54_);
#line 72 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_add_contact (_tmp53_, _tmp55_);
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp56_, G_TYPE_STRING);
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp57_ = _tmp56_;
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp58_ = __g_value_dup0 (&_tmp57_);
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp58_;
#line 74 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp57_) ? (g_value_unset (&_tmp57_), NULL) : NULL;
#line 75 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp59_ = v;
#line 75 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp59_, "richard m. stallman");
#line 76 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp60_ = self->priv->_c2;
#line 76 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp61_ = v;
#line 76 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 76 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp62_ = _tmp61_;
#line 76 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp60_, "full_name", _tmp62_);
#line 76 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp62_);
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp63_, G_TYPE_STRING);
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp64_ = _tmp63_;
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp65_ = __g_value_dup0 (&_tmp64_);
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp65_;
#line 77 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp64_) ? (g_value_unset (&_tmp64_), NULL) : NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp66_ = v;
#line 78 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp66_, "Stallman");
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp67_ = self->priv->_c2;
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp68_ = v;
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp69_ = _tmp68_;
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp67_, "contact_name_family", _tmp69_);
#line 79 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp69_);
#line 80 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_init (&_tmp70_, G_TYPE_STRING);
#line 80 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp71_ = _tmp70_;
#line 80 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp72_ = __g_value_dup0 (&_tmp71_);
#line 80 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 80 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = _tmp72_;
#line 80 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_IS_VALUE (&_tmp71_) ? (g_value_unset (&_tmp71_), NULL) : NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp73_ = v;
#line 81 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_value_set_string (_tmp73_, "Richard M.");
#line 82 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp74_ = self->priv->_c2;
#line 82 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp75_ = v;
#line 82 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	v = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp76_ = _tmp75_;
#line 82 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp74_, "contact_name_given", _tmp76_);
#line 82 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (_tmp76_);
#line 83 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp77_ = ((EdsTestTestCase*) self)->eds_backend;
#line 83 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp78_ = self->priv->_c2;
#line 83 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp79_ = _g_object_ref0 (_tmp78_);
#line 83 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_add_contact (_tmp77_, _tmp79_);
#line 85 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_name_details_tests_test_names_async (self, NULL, NULL);
#line 87 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp80_ = self->priv->_main_loop;
#line 87 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp80_, 5);
#line 89 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp81_ = self->priv->_names_count;
#line 89 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp81_ == 2, "this._names_count == 2");
#line 90 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp82_ = self->priv->_c1;
#line 90 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp83_ = gee_abstract_map_get_size ((GeeMap*) _tmp82_);
#line 90 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp84_ = _tmp83_;
#line 90 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp84_ == 0, "this._c1.size == 0");
#line 91 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp85_ = self->priv->_c2;
#line 91 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp86_ = gee_abstract_map_get_size ((GeeMap*) _tmp85_);
#line 91 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp87_ = _tmp86_;
#line 91 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp87_ == 0, "this._c2.size == 0");
#line 40 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	__vala_GValue_free0 (v);
#line 610 "name-details.c"
}


static void _name_details_tests_test_names_async_data_free (gpointer _data) {
	NameDetailsTestsTestNamesAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_slice_free (NameDetailsTestsTestNamesAsyncData, _data_);
#line 621 "name-details.c"
}


static void _name_details_tests_test_names_async (NameDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	NameDetailsTestsTestNamesAsyncData* _data_;
	NameDetailsTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_ = g_slice_new0 (NameDetailsTestsTestNamesAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _name_details_tests_test_names_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _name_details_tests_test_names_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_name_details_tests_test_names_async_co (_data_);
#line 640 "name-details.c"
}


static void _name_details_tests_test_names_finish (NameDetailsTests* self, GAsyncResult* _res_) {
	NameDetailsTestsTestNamesAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 648 "name-details.c"
}


static void _name_details_tests_test_names_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	NameDetailsTestsTestNamesAsyncData* _data_;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_ = _user_data_;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_source_object_ = source_object;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_res_ = _res_;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_name_details_tests_test_names_async_co (_data_);
#line 662 "name-details.c"
}


static void __name_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 102 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_name_details_tests_individuals_changed_cb ((NameDetailsTests*) self, changes);
#line 669 "name-details.c"
}


static gboolean _name_details_tests_test_names_async_co (NameDetailsTestsTestNamesAsyncData* _data_) {
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	switch (_data_->_state_) {
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		case 0:
#line 678 "name-details.c"
		goto _state_0;
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		case 1:
#line 682 "name-details.c"
		goto _state_1;
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		case 2:
#line 686 "name-details.c"
		goto _state_2;
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		case 3:
#line 690 "name-details.c"
		goto _state_3;
		default:
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		g_assert_not_reached ();
#line 695 "name-details.c"
	}
	_state_0:
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp0_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_state_ = 1;
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _name_details_tests_test_names_async_ready, _data_);
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return FALSE;
#line 708 "name-details.c"
	_state_1:
#line 97 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 99 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp1_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 99 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->store = _data_->_tmp1_;
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_state_ = 2;
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_backend_store_prepare (_data_->store, _name_details_tests_test_names_async_ready, _data_);
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return FALSE;
#line 724 "name-details.c"
	_state_2:
#line 100 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp2_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 101 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 102 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp3_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 102 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __name_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 742 "name-details.c"
	{
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_tmp4_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_state_ = 3;
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _name_details_tests_test_names_async_ready, _data_);
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		return FALSE;
#line 754 "name-details.c"
		_state_3:
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 106 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 760 "name-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->e = _data_->_inner_error_;
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_inner_error_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_tmp5_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 110 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_tmp6_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 110 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		g_warning ("name-details.vala:110: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_g_error_free0 (_data_->e);
#line 783 "name-details.c"
	}
	__finally0:
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_g_object_unref0 (_data_->store);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 104 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		return FALSE;
#line 796 "name-details.c"
	}
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (_data_->store);
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	if (_data_->_state_ == 0) {
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 804 "name-details.c"
	} else {
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 808 "name-details.c"
	}
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_object_unref (_data_->_async_result);
#line 94 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return FALSE;
#line 814 "name-details.c"
}


static void _name_details_tests_individuals_changed_cb (NameDetailsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp157_ = NULL;
	gint _tmp158_ = 0;
	gint _tmp159_ = 0;
	gboolean _tmp167_ = FALSE;
	GeeHashMap* _tmp168_ = NULL;
	gint _tmp169_ = 0;
	gint _tmp170_ = 0;
#line 114 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_return_if_fail (self != NULL);
#line 114 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_return_if_fail (changes != NULL);
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp0_ = changes;
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 117 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	added = _tmp1_;
#line 118 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp2_ = changes;
#line 118 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 118 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	removed = _tmp3_;
#line 848 "name-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp4_ = added;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_i_it = _tmp5_;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		while (TRUE) {
#line 861 "name-details.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* s = NULL;
			FolksIndividual* _tmp11_ = NULL;
			GeeSet* _tmp12_ = NULL;
			GeeSet* _tmp13_ = NULL;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			FolksNameDetails* name = NULL;
			FolksIndividual* _tmp16_ = NULL;
			FolksNameDetails* _tmp17_ = NULL;
			FolksIndividual* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			gint _tmp156_ = 0;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp6_ = _i_it;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			if (!_tmp7_) {
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				break;
#line 889 "name-details.c"
			}
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp8_ = _i_it;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 122 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp10_ = i;
#line 122 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp11_ = i;
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp13_ = _tmp12_;
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp15_ = _tmp14_;
#line 126 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_vala_assert (_tmp15_ == 1, "i.personas.size == 1");
#line 128 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp16_ = i;
#line 128 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 128 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			name = _tmp17_;
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp18_ = i;
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp19_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp18_);
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp20_ = _tmp19_;
#line 130 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			if (g_strcmp0 (_tmp20_, "bernie h. innocenti") == 0) {
#line 927 "name-details.c"
				FolksNameDetails* _tmp21_ = NULL;
				FolksStructuredName* _tmp22_ = NULL;
				FolksStructuredName* _tmp23_ = NULL;
				gboolean _tmp24_ = FALSE;
				GeeHashMap* _tmp25_ = NULL;
				gpointer _tmp26_ = NULL;
				GValue* _tmp27_ = NULL;
				GValue _tmp28_ = {0};
				const gchar* _tmp29_ = NULL;
				gchar* _tmp30_ = NULL;
				FolksNameDetails* _tmp31_ = NULL;
				const gchar* _tmp32_ = NULL;
				const gchar* _tmp33_ = NULL;
				const gchar* _tmp34_ = NULL;
				GeeHashMap* _tmp35_ = NULL;
				GeeHashMap* _tmp36_ = NULL;
				gpointer _tmp37_ = NULL;
				GValue* _tmp38_ = NULL;
				GValue _tmp39_ = {0};
				const gchar* _tmp40_ = NULL;
				gchar* _tmp41_ = NULL;
				FolksNameDetails* _tmp42_ = NULL;
				const gchar* _tmp43_ = NULL;
				const gchar* _tmp44_ = NULL;
				const gchar* _tmp45_ = NULL;
				GeeHashMap* _tmp46_ = NULL;
				GeeHashMap* _tmp47_ = NULL;
				gpointer _tmp48_ = NULL;
				GValue* _tmp49_ = NULL;
				GValue _tmp50_ = {0};
				const gchar* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
				FolksNameDetails* _tmp53_ = NULL;
				FolksStructuredName* _tmp54_ = NULL;
				FolksStructuredName* _tmp55_ = NULL;
				const gchar* _tmp56_ = NULL;
				const gchar* _tmp57_ = NULL;
				const gchar* _tmp58_ = NULL;
				GeeHashMap* _tmp59_ = NULL;
				GeeHashMap* _tmp60_ = NULL;
				gpointer _tmp61_ = NULL;
				GValue* _tmp62_ = NULL;
				GValue _tmp63_ = {0};
				const gchar* _tmp64_ = NULL;
				gchar* _tmp65_ = NULL;
				FolksNameDetails* _tmp66_ = NULL;
				FolksStructuredName* _tmp67_ = NULL;
				FolksStructuredName* _tmp68_ = NULL;
				const gchar* _tmp69_ = NULL;
				const gchar* _tmp70_ = NULL;
				const gchar* _tmp71_ = NULL;
				GeeHashMap* _tmp72_ = NULL;
				GeeHashMap* _tmp73_ = NULL;
				gpointer _tmp74_ = NULL;
				GValue* _tmp75_ = NULL;
				GValue _tmp76_ = {0};
				const gchar* _tmp77_ = NULL;
				gchar* _tmp78_ = NULL;
				FolksNameDetails* _tmp79_ = NULL;
				FolksStructuredName* _tmp80_ = NULL;
				FolksStructuredName* _tmp81_ = NULL;
				const gchar* _tmp82_ = NULL;
				const gchar* _tmp83_ = NULL;
				const gchar* _tmp84_ = NULL;
				GeeHashMap* _tmp85_ = NULL;
				GeeHashMap* _tmp86_ = NULL;
				gpointer _tmp87_ = NULL;
				GValue* _tmp88_ = NULL;
				GValue _tmp89_ = {0};
				const gchar* _tmp90_ = NULL;
				gchar* _tmp91_ = NULL;
				FolksNameDetails* _tmp92_ = NULL;
				FolksStructuredName* _tmp93_ = NULL;
				FolksStructuredName* _tmp94_ = NULL;
				const gchar* _tmp95_ = NULL;
				const gchar* _tmp96_ = NULL;
				const gchar* _tmp97_ = NULL;
				GeeHashMap* _tmp98_ = NULL;
				GeeHashMap* _tmp99_ = NULL;
				gpointer _tmp100_ = NULL;
				GValue* _tmp101_ = NULL;
				GValue _tmp102_ = {0};
				const gchar* _tmp103_ = NULL;
				gchar* _tmp104_ = NULL;
				FolksNameDetails* _tmp105_ = NULL;
				FolksStructuredName* _tmp106_ = NULL;
				FolksStructuredName* _tmp107_ = NULL;
				const gchar* _tmp108_ = NULL;
				const gchar* _tmp109_ = NULL;
				const gchar* _tmp110_ = NULL;
				GeeHashMap* _tmp111_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp21_ = name;
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp22_ = folks_name_details_get_structured_name (_tmp21_);
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp23_ = _tmp22_;
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp24_ = folks_structured_name_is_empty (_tmp23_);
#line 132 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (_tmp24_ == FALSE, "name.structured_name.is_empty () == false");
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp25_ = self->priv->_c1;
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp26_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp25_, "full_name");
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp27_ = (GValue*) _tmp26_;
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp28_ = *_tmp27_;
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp29_ = g_value_get_string (&_tmp28_);
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp30_ = g_strdup (_tmp29_);
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				s = _tmp30_;
#line 134 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp27_);
#line 135 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp31_ = name;
#line 135 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp32_ = folks_name_details_get_full_name (_tmp31_);
#line 135 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp33_ = _tmp32_;
#line 135 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp34_ = s;
#line 135 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (g_strcmp0 (_tmp33_, _tmp34_) == 0, "name.full_name == s");
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp35_ = self->priv->_c1;
#line 136 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp35_, "full_name", NULL);
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp36_ = self->priv->_c1;
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp37_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp36_, "nickname");
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp38_ = (GValue*) _tmp37_;
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp39_ = *_tmp38_;
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp40_ = g_value_get_string (&_tmp39_);
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp41_ = g_strdup (_tmp40_);
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				s = _tmp41_;
#line 138 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp38_);
#line 139 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp42_ = name;
#line 139 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp43_ = folks_name_details_get_nickname (_tmp42_);
#line 139 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp44_ = _tmp43_;
#line 139 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp45_ = s;
#line 139 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (g_strcmp0 (_tmp44_, _tmp45_) == 0, "name.nickname == s");
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp46_ = self->priv->_c1;
#line 140 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp46_, "nickname", NULL);
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp47_ = self->priv->_c1;
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp48_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp47_, "contact_name_family");
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp49_ = (GValue*) _tmp48_;
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp50_ = *_tmp49_;
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp51_ = g_value_get_string (&_tmp50_);
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp52_ = g_strdup (_tmp51_);
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				s = _tmp52_;
#line 142 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp49_);
#line 143 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp53_ = name;
#line 143 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp54_ = folks_name_details_get_structured_name (_tmp53_);
#line 143 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp55_ = _tmp54_;
#line 143 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp56_ = folks_structured_name_get_family_name (_tmp55_);
#line 143 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp57_ = _tmp56_;
#line 143 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp58_ = s;
#line 143 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (g_strcmp0 (_tmp57_, _tmp58_) == 0, "name.structured_name.family_name == s");
#line 144 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp59_ = self->priv->_c1;
#line 144 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp59_, "contact_name_family", NULL);
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp60_ = self->priv->_c1;
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp61_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp60_, "contact_name_given");
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp62_ = (GValue*) _tmp61_;
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp63_ = *_tmp62_;
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp64_ = g_value_get_string (&_tmp63_);
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp65_ = g_strdup (_tmp64_);
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				s = _tmp65_;
#line 146 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp62_);
#line 147 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp66_ = name;
#line 147 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp67_ = folks_name_details_get_structured_name (_tmp66_);
#line 147 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp68_ = _tmp67_;
#line 147 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp69_ = folks_structured_name_get_given_name (_tmp68_);
#line 147 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp70_ = _tmp69_;
#line 147 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp71_ = s;
#line 147 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (g_strcmp0 (_tmp70_, _tmp71_) == 0, "name.structured_name.given_name == s");
#line 148 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp72_ = self->priv->_c1;
#line 148 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp72_, "contact_name_given", NULL);
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp73_ = self->priv->_c1;
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp74_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp73_, "contact_name_additional");
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp75_ = (GValue*) _tmp74_;
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp76_ = *_tmp75_;
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp77_ = g_value_get_string (&_tmp76_);
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp78_ = g_strdup (_tmp77_);
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				s = _tmp78_;
#line 150 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp75_);
#line 151 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp79_ = name;
#line 151 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp80_ = folks_name_details_get_structured_name (_tmp79_);
#line 151 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp81_ = _tmp80_;
#line 151 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp82_ = folks_structured_name_get_additional_names (_tmp81_);
#line 151 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp83_ = _tmp82_;
#line 151 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp84_ = s;
#line 151 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (g_strcmp0 (_tmp83_, _tmp84_) == 0, "name.structured_name.additional_names == s");
#line 152 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp85_ = self->priv->_c1;
#line 152 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp85_, "contact_name_additional", NULL);
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp86_ = self->priv->_c1;
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp87_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp86_, "contact_name_prefixes");
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp88_ = (GValue*) _tmp87_;
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp89_ = *_tmp88_;
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp90_ = g_value_get_string (&_tmp89_);
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp91_ = g_strdup (_tmp90_);
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				s = _tmp91_;
#line 154 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp88_);
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp92_ = name;
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp93_ = folks_name_details_get_structured_name (_tmp92_);
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp94_ = _tmp93_;
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp95_ = folks_structured_name_get_prefixes (_tmp94_);
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp96_ = _tmp95_;
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp97_ = s;
#line 155 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (g_strcmp0 (_tmp96_, _tmp97_) == 0, "name.structured_name.prefixes == s");
#line 156 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp98_ = self->priv->_c1;
#line 156 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp98_, "contact_name_prefixes", NULL);
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp99_ = self->priv->_c1;
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp100_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp99_, "contact_name_suffixes");
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp101_ = (GValue*) _tmp100_;
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp102_ = *_tmp101_;
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp103_ = g_value_get_string (&_tmp102_);
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp104_ = g_strdup (_tmp103_);
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_g_free0 (s);
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				s = _tmp104_;
#line 158 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				__vala_GValue_free0 (_tmp101_);
#line 159 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp105_ = name;
#line 159 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp106_ = folks_name_details_get_structured_name (_tmp105_);
#line 159 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp107_ = _tmp106_;
#line 159 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp108_ = folks_structured_name_get_suffixes (_tmp107_);
#line 159 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp109_ = _tmp108_;
#line 159 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp110_ = s;
#line 159 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_vala_assert (g_strcmp0 (_tmp109_, _tmp110_) == 0, "name.structured_name.suffixes == s");
#line 160 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp111_ = self->priv->_c1;
#line 160 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				gee_abstract_map_unset ((GeeAbstractMap*) _tmp111_, "contact_name_suffixes", NULL);
#line 1273 "name-details.c"
			} else {
				FolksIndividual* _tmp112_ = NULL;
				const gchar* _tmp113_ = NULL;
				const gchar* _tmp114_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp112_ = i;
#line 162 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp113_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp112_);
#line 162 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				_tmp114_ = _tmp113_;
#line 162 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				if (g_strcmp0 (_tmp114_, "richard m. stallman") == 0) {
#line 1286 "name-details.c"
					FolksNameDetails* _tmp115_ = NULL;
					FolksStructuredName* _tmp116_ = NULL;
					FolksStructuredName* _tmp117_ = NULL;
					gboolean _tmp118_ = FALSE;
					GeeHashMap* _tmp119_ = NULL;
					gpointer _tmp120_ = NULL;
					GValue* _tmp121_ = NULL;
					GValue _tmp122_ = {0};
					const gchar* _tmp123_ = NULL;
					gchar* _tmp124_ = NULL;
					FolksNameDetails* _tmp125_ = NULL;
					const gchar* _tmp126_ = NULL;
					const gchar* _tmp127_ = NULL;
					const gchar* _tmp128_ = NULL;
					GeeHashMap* _tmp129_ = NULL;
					GeeHashMap* _tmp130_ = NULL;
					gpointer _tmp131_ = NULL;
					GValue* _tmp132_ = NULL;
					GValue _tmp133_ = {0};
					const gchar* _tmp134_ = NULL;
					gchar* _tmp135_ = NULL;
					FolksNameDetails* _tmp136_ = NULL;
					FolksStructuredName* _tmp137_ = NULL;
					FolksStructuredName* _tmp138_ = NULL;
					const gchar* _tmp139_ = NULL;
					const gchar* _tmp140_ = NULL;
					const gchar* _tmp141_ = NULL;
					GeeHashMap* _tmp142_ = NULL;
					GeeHashMap* _tmp143_ = NULL;
					gpointer _tmp144_ = NULL;
					GValue* _tmp145_ = NULL;
					GValue _tmp146_ = {0};
					const gchar* _tmp147_ = NULL;
					gchar* _tmp148_ = NULL;
					FolksNameDetails* _tmp149_ = NULL;
					FolksStructuredName* _tmp150_ = NULL;
					FolksStructuredName* _tmp151_ = NULL;
					const gchar* _tmp152_ = NULL;
					const gchar* _tmp153_ = NULL;
					const gchar* _tmp154_ = NULL;
					GeeHashMap* _tmp155_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp115_ = name;
#line 164 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp116_ = folks_name_details_get_structured_name (_tmp115_);
#line 164 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp117_ = _tmp116_;
#line 164 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp118_ = folks_structured_name_is_empty (_tmp117_);
#line 164 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_vala_assert (_tmp118_ == FALSE, "name.structured_name.is_empty () == false");
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp119_ = self->priv->_c2;
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp120_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp119_, "full_name");
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp121_ = (GValue*) _tmp120_;
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp122_ = *_tmp121_;
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp123_ = g_value_get_string (&_tmp122_);
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp124_ = g_strdup (_tmp123_);
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_g_free0 (s);
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					s = _tmp124_;
#line 166 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					__vala_GValue_free0 (_tmp121_);
#line 167 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp125_ = name;
#line 167 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp126_ = folks_name_details_get_full_name (_tmp125_);
#line 167 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp127_ = _tmp126_;
#line 167 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp128_ = s;
#line 167 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_vala_assert (g_strcmp0 (_tmp127_, _tmp128_) == 0, "name.full_name == s");
#line 168 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp129_ = self->priv->_c2;
#line 168 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp129_, "full_name", NULL);
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp130_ = self->priv->_c2;
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp131_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp130_, "contact_name_family");
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp132_ = (GValue*) _tmp131_;
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp133_ = *_tmp132_;
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp134_ = g_value_get_string (&_tmp133_);
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp135_ = g_strdup (_tmp134_);
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_g_free0 (s);
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					s = _tmp135_;
#line 170 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					__vala_GValue_free0 (_tmp132_);
#line 171 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp136_ = name;
#line 171 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp137_ = folks_name_details_get_structured_name (_tmp136_);
#line 171 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp138_ = _tmp137_;
#line 171 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp139_ = folks_structured_name_get_family_name (_tmp138_);
#line 171 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp140_ = _tmp139_;
#line 171 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp141_ = s;
#line 171 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_vala_assert (g_strcmp0 (_tmp140_, _tmp141_) == 0, "name.structured_name.family_name == s");
#line 172 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp142_ = self->priv->_c2;
#line 172 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp142_, "contact_name_family", NULL);
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp143_ = self->priv->_c2;
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp144_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp143_, "contact_name_given");
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp145_ = (GValue*) _tmp144_;
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp146_ = *_tmp145_;
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp147_ = g_value_get_string (&_tmp146_);
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp148_ = g_strdup (_tmp147_);
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_g_free0 (s);
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					s = _tmp148_;
#line 174 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					__vala_GValue_free0 (_tmp145_);
#line 175 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp149_ = name;
#line 175 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp150_ = folks_name_details_get_structured_name (_tmp149_);
#line 175 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp151_ = _tmp150_;
#line 175 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp152_ = folks_structured_name_get_given_name (_tmp151_);
#line 175 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp153_ = _tmp152_;
#line 175 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp154_ = s;
#line 175 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_vala_assert (g_strcmp0 (_tmp153_, _tmp154_) == 0, "name.structured_name.given_name == s");
#line 176 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					_tmp155_ = self->priv->_c2;
#line 176 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
					gee_abstract_map_unset ((GeeAbstractMap*) _tmp155_, "contact_name_given", NULL);
#line 1442 "name-details.c"
				}
			}
#line 179 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp156_ = self->priv->_names_count;
#line 179 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			self->priv->_names_count = _tmp156_ + 1;
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_g_object_unref0 (name);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_g_free0 (s);
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_g_object_unref0 (i);
#line 1455 "name-details.c"
		}
#line 120 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_g_object_unref0 (_i_it);
#line 1459 "name-details.c"
	}
#line 182 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp157_ = removed;
#line 182 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp158_ = gee_collection_get_size ((GeeCollection*) _tmp157_);
#line 182 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp159_ = _tmp158_;
#line 182 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_vala_assert (_tmp159_ == 1, "removed.size == 1");
#line 1469 "name-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp160_ = NULL;
		GeeIterator* _tmp161_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp160_ = removed;
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp161_ = gee_iterable_iterator ((GeeIterable*) _tmp160_);
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_i_it = _tmp161_;
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		while (TRUE) {
#line 1482 "name-details.c"
			GeeIterator* _tmp162_ = NULL;
			gboolean _tmp163_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp164_ = NULL;
			gpointer _tmp165_ = NULL;
			FolksIndividual* _tmp166_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp162_ = _i_it;
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp163_ = gee_iterator_next (_tmp162_);
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			if (!_tmp163_) {
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
				break;
#line 1497 "name-details.c"
			}
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp164_ = _i_it;
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp165_ = gee_iterator_get (_tmp164_);
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			i = (FolksIndividual*) _tmp165_;
#line 186 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_tmp166_ = i;
#line 186 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_vala_assert (_tmp166_ == NULL, "i == null");
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
			_g_object_unref0 (i);
#line 1511 "name-details.c"
		}
#line 184 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_g_object_unref0 (_i_it);
#line 1515 "name-details.c"
	}
#line 189 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp168_ = self->priv->_c1;
#line 189 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp169_ = gee_abstract_map_get_size ((GeeMap*) _tmp168_);
#line 189 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp170_ = _tmp169_;
#line 189 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	if (_tmp170_ == 0) {
#line 1525 "name-details.c"
		GeeHashMap* _tmp171_ = NULL;
		gint _tmp172_ = 0;
		gint _tmp173_ = 0;
#line 190 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp171_ = self->priv->_c2;
#line 190 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp172_ = gee_abstract_map_get_size ((GeeMap*) _tmp171_);
#line 190 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp173_ = _tmp172_;
#line 190 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp167_ = _tmp173_ == 0;
#line 1537 "name-details.c"
	} else {
#line 189 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp167_ = FALSE;
#line 1541 "name-details.c"
	}
#line 189 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	if (_tmp167_) {
#line 1545 "name-details.c"
		GMainLoop* _tmp174_ = NULL;
#line 192 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		_tmp174_ = self->priv->_main_loop;
#line 192 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
		g_main_loop_quit (_tmp174_);
#line 1551 "name-details.c"
	}
#line 114 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (removed);
#line 114 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (added);
#line 1557 "name-details.c"
}


static void name_details_tests_class_init (NameDetailsTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	name_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_type_class_add_private (klass, sizeof (NameDetailsTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_OBJECT_CLASS (klass)->finalize = name_details_tests_finalize;
#line 1568 "name-details.c"
}


static void name_details_tests_instance_init (NameDetailsTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self->priv = NAME_DETAILS_TESTS_GET_PRIVATE (self);
#line 1575 "name-details.c"
}


static void name_details_tests_finalize (GObject* obj) {
	NameDetailsTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_NAME_DETAILS_TESTS, NameDetailsTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 28 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 31 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 25 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	G_OBJECT_CLASS (name_details_tests_parent_class)->finalize (obj);
#line 1593 "name-details.c"
}


GType name_details_tests_get_type (void) {
	static volatile gsize name_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&name_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NameDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) name_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NameDetailsTests), 0, (GInstanceInitFunc) name_details_tests_instance_init, NULL };
		GType name_details_tests_type_id;
		name_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "NameDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&name_details_tests_type_id__volatile, name_details_tests_type_id);
	}
	return name_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	NameDetailsTests* tests = NULL;
	NameDetailsTests* _tmp0_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 201 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_tmp0_ = name_details_tests_new ();
#line 201 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	tests = _tmp0_;
#line 202 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 203 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	g_test_run ();
#line 204 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 206 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	result = 0;
#line 206 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	_g_object_unref0 (tests);
#line 206 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return result;
#line 1631 "name-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 197 "/opt/gnome3/source/folks/tests/eds/name-details.vala"
	return _vala_main (argv, argc);
#line 1641 "name-details.c"
}



