/* linkable-properties.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from linkable-properties.vala, do not modify */

/*
 * Copyright (C) 2014 Renato Araujo Oliveira Filho
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Travis Reitter <travis.reitter@collabora.co.uk>
 *          Renato Araujo Oliveira Filho <renato@canonical.com>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <dummy-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks-dummy.h>
#include <gio/gio.h>
#include <gee.h>


#define TYPE_LINKABLE_PROPERTIES_TESTS (linkable_properties_tests_get_type ())
#define LINKABLE_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTests))
#define LINKABLE_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTestsClass))
#define IS_LINKABLE_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LINKABLE_PROPERTIES_TESTS))
#define IS_LINKABLE_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LINKABLE_PROPERTIES_TESTS))
#define LINKABLE_PROPERTIES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTestsClass))

typedef struct _LinkablePropertiesTests LinkablePropertiesTests;
typedef struct _LinkablePropertiesTestsClass LinkablePropertiesTestsClass;
typedef struct _LinkablePropertiesTestsPrivate LinkablePropertiesTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _LinkablePropertiesTestsAddPersonaData LinkablePropertiesTestsAddPersonaData;
typedef struct _LinkablePropertiesTestsAddPersonasData LinkablePropertiesTestsAddPersonasData;
typedef struct _LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _LinkablePropertiesTests {
	DummyTestTestCase parent_instance;
	LinkablePropertiesTestsPrivate * priv;
};

struct _LinkablePropertiesTestsClass {
	DummyTestTestCaseClass parent_class;
};

struct _LinkablePropertiesTestsPrivate {
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	gboolean _found_before_update;
	gboolean _found_after_update;
	FolksIndividual* _ind_1;
	FolksIndividual* _ind_2;
};

struct _LinkablePropertiesTestsAddPersonaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkablePropertiesTests* self;
	GeeHashMap* c;
	GHashTable* details;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* v1;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	GeeHashMap* _tmp8_;
	gpointer _tmp9_;
	GValue* _tmp10_;
	GValue _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	GValue* _tmp15_;
	GValue* v2;
	GValue _tmp16_;
	GValue _tmp17_;
	GValue* _tmp18_;
	GValue* _tmp19_;
	GeeHashSet* emails;
	GeeHashSet* _tmp20_;
	FolksEmailFieldDetails* email_1;
	GeeHashMap* _tmp21_;
	gpointer _tmp22_;
	GValue* _tmp23_;
	GValue _tmp24_;
	const gchar* _tmp25_;
	FolksEmailFieldDetails* _tmp26_;
	FolksEmailFieldDetails* _tmp27_;
	GValue* _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	GValue* _tmp31_;
	GValue* v5;
	GValue _tmp32_;
	GValue _tmp33_;
	GValue* _tmp34_;
	GValue* _tmp35_;
	GeeHashSet* phones;
	GeeHashSet* _tmp36_;
	FolksPhoneFieldDetails* phone_1;
	GeeHashMap* _tmp37_;
	gpointer _tmp38_;
	GValue* _tmp39_;
	GValue _tmp40_;
	const gchar* _tmp41_;
	FolksPhoneFieldDetails* _tmp42_;
	FolksPhoneFieldDetails* _tmp43_;
	GValue* _tmp44_;
	const gchar* _tmp45_;
	gchar* _tmp46_;
	GValue* _tmp47_;
	FolksIndividualAggregator* _tmp48_;
	FolksDummyPersonaStore* _tmp49_;
	FolksPersona* _tmp50_;
	FolksPersona* _tmp51_;
	GError* e;
	GError* _tmp52_;
	const gchar* _tmp53_;
	GError * _inner_error_;
};

struct _LinkablePropertiesTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkablePropertiesTests* self;
	GeeHashMap* c;
	GValue* v;
	GeeHashMap* _tmp0_;
	GValue _tmp1_;
	GValue _tmp2_;
	GValue* _tmp3_;
	GValue* _tmp4_;
	GeeHashMap* _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	GValue _tmp8_;
	GValue _tmp9_;
	GValue* _tmp10_;
	GValue* _tmp11_;
	GeeHashMap* _tmp12_;
	GValue* _tmp13_;
	GValue* _tmp14_;
	GValue _tmp15_;
	GValue _tmp16_;
	GValue* _tmp17_;
	GValue* _tmp18_;
	GeeHashMap* _tmp19_;
	GValue* _tmp20_;
	GValue* _tmp21_;
	GeeHashMap* _tmp22_;
	GeeHashMap* _tmp23_;
	GeeHashMap* _tmp24_;
	GValue _tmp25_;
	GValue _tmp26_;
	GValue* _tmp27_;
	GValue* _tmp28_;
	GeeHashMap* _tmp29_;
	GValue* _tmp30_;
	GValue* _tmp31_;
	GValue _tmp32_;
	GValue _tmp33_;
	GValue* _tmp34_;
	GValue* _tmp35_;
	GeeHashMap* _tmp36_;
	GValue* _tmp37_;
	GValue* _tmp38_;
	GValue _tmp39_;
	GValue _tmp40_;
	GValue* _tmp41_;
	GValue* _tmp42_;
	GeeHashMap* _tmp43_;
	GValue* _tmp44_;
	GValue* _tmp45_;
	GeeHashMap* _tmp46_;
	GeeHashMap* _tmp47_;
};

struct _LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkablePropertiesTests* self;
	FolksIndividualAggregator* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	GError* e;
	GError* _tmp3_;
	const gchar* _tmp4_;
	GError * _inner_error_;
};


static gpointer linkable_properties_tests_parent_class = NULL;

GType linkable_properties_tests_get_type (void) G_GNUC_CONST;
#define LINKABLE_PROPERTIES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTestsPrivate))
enum  {
	LINKABLE_PROPERTIES_TESTS_DUMMY_PROPERTY
};
#define LINKABLE_PROPERTIES_TESTS__full_name_1 "bernie h. innocenti"
#define LINKABLE_PROPERTIES_TESTS__email_1 "bernie@example.org"
#define LINKABLE_PROPERTIES_TESTS__phone_1 "5551234"
#define LINKABLE_PROPERTIES_TESTS__full_name_2 "Clyde McPoyle"
#define LINKABLE_PROPERTIES_TESTS__email_2 "clyde@example.org"
#define LINKABLE_PROPERTIES_TESTS__phone_2 "987654321"
LinkablePropertiesTests* linkable_properties_tests_new (void);
LinkablePropertiesTests* linkable_properties_tests_construct (GType object_type);
static void linkable_properties_tests_test_linkable_properties_aggregate_after_change (LinkablePropertiesTests* self);
static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_folks_test_case_test_method (gpointer self);
static void linkable_properties_tests_real_set_up (FolksTestCase* base);
static void linkable_properties_tests_real_configure_primary_store (DummyTestTestCase* base);
static void _linkable_properties_tests_add_persona_data_free (gpointer _data);
static void _linkable_properties_tests_add_persona (LinkablePropertiesTests* self, GeeHashMap* c, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _linkable_properties_tests_add_persona_finish (LinkablePropertiesTests* self, GAsyncResult* _res_);
static gboolean _linkable_properties_tests_add_persona_co (LinkablePropertiesTestsAddPersonaData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _linkable_properties_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _linkable_properties_tests_add_personas_data_free (gpointer _data);
static void _linkable_properties_tests_add_personas (LinkablePropertiesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _linkable_properties_tests_add_personas_finish (LinkablePropertiesTests* self, GAsyncResult* _res_);
static gboolean _linkable_properties_tests_add_personas_co (LinkablePropertiesTestsAddPersonasData* _data_);
static void _linkable_properties_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue (LinkablePropertiesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_finish (LinkablePropertiesTests* self, GAsyncResult* _res_);
static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_data_free (gpointer _data);
static gboolean linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_co (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData* _data_);
static void _linkable_properties_tests_individuals_changed_aggregate_after_change_cb (LinkablePropertiesTests* self, GeeMultiMap* changes);
static void __linkable_properties_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void linkable_properties_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_folks_test_case_test_method (gpointer self) {
#line 50 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	linkable_properties_tests_test_linkable_properties_aggregate_after_change ((LinkablePropertiesTests*) self);
#line 273 "linkable-properties.c"
}


LinkablePropertiesTests* linkable_properties_tests_construct (GType object_type) {
	LinkablePropertiesTests * self = NULL;
#line 48 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self = (LinkablePropertiesTests*) dummy_test_test_case_construct (object_type, "LinkableProperties");
#line 50 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "correct aggregation after linkable property change", _linkable_properties_tests_test_linkable_properties_aggregate_after_change_folks_test_case_test_method, self);
#line 46 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return self;
#line 285 "linkable-properties.c"
}


LinkablePropertiesTests* linkable_properties_tests_new (void) {
#line 46 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return linkable_properties_tests_construct (TYPE_LINKABLE_PROPERTIES_TESTS);
#line 292 "linkable-properties.c"
}


static void linkable_properties_tests_real_set_up (FolksTestCase* base) {
	LinkablePropertiesTests * self;
#line 54 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self = (LinkablePropertiesTests*) base;
#line 56 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	FOLKS_TEST_CASE_CLASS (linkable_properties_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, DUMMY_TEST_TYPE_TEST_CASE, DummyTestTestCase));
#line 58 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self->priv->_found_before_update = FALSE;
#line 59 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self->priv->_found_after_update = FALSE;
#line 306 "linkable-properties.c"
}


static void linkable_properties_tests_real_configure_primary_store (DummyTestTestCase* base) {
	LinkablePropertiesTests * self;
	FolksDummyPersonaStore* _tmp0_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self = (LinkablePropertiesTests*) base;
#line 64 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	DUMMY_TEST_TEST_CASE_CLASS (linkable_properties_tests_parent_class)->configure_primary_store (G_TYPE_CHECK_INSTANCE_CAST (self, DUMMY_TEST_TYPE_TEST_CASE, DummyTestTestCase));
#line 65 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp0_ = ((DummyTestTestCase*) self)->dummy_persona_store;
#line 65 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	folks_dummy_persona_store_update_trust_level (_tmp0_, FOLKS_PERSONA_STORE_TRUST_FULL);
#line 321 "linkable-properties.c"
}


static void _linkable_properties_tests_add_persona_data_free (gpointer _data) {
	LinkablePropertiesTestsAddPersonaData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->c);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_slice_free (LinkablePropertiesTestsAddPersonaData, _data_);
#line 334 "linkable-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 341 "linkable-properties.c"
}


static void _linkable_properties_tests_add_persona (LinkablePropertiesTests* self, GeeHashMap* c, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkablePropertiesTestsAddPersonaData* _data_;
	LinkablePropertiesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = g_slice_new0 (LinkablePropertiesTestsAddPersonaData);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _linkable_properties_tests_add_persona);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _linkable_properties_tests_add_persona_data_free);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->c);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->c = c;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_persona_co (_data_);
#line 364 "linkable-properties.c"
}


static void _linkable_properties_tests_add_persona_finish (LinkablePropertiesTests* self, GAsyncResult* _res_) {
	LinkablePropertiesTestsAddPersonaData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 372 "linkable-properties.c"
}


static void _g_free0_ (gpointer var) {
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	var = (g_free (var), NULL);
#line 379 "linkable-properties.c"
}


static void _vala_GValue_free (GValue* self) {
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_unset (self);
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_free (self);
#line 388 "linkable-properties.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 395 "linkable-properties.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 402 "linkable-properties.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return self ? _g_value_dup (self) : NULL;
#line 409 "linkable-properties.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 79 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return result;
#line 418 "linkable-properties.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 79 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return result;
#line 427 "linkable-properties.c"
}


static void _linkable_properties_tests_add_persona_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkablePropertiesTestsAddPersonaData* _data_;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = _user_data_;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_source_object_ = source_object;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_res_ = _res_;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_persona_co (_data_);
#line 441 "linkable-properties.c"
}


static gboolean _linkable_properties_tests_add_persona_co (LinkablePropertiesTestsAddPersonaData* _data_) {
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	switch (_data_->_state_) {
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 0:
#line 450 "linkable-properties.c"
		goto _state_0;
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 1:
#line 454 "linkable-properties.c"
		goto _state_1;
		default:
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_assert_not_reached ();
#line 459 "linkable-properties.c"
	}
	_state_0:
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp0_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp0_ = g_str_hash;
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp1_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp1_ = g_str_equal;
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp2_ = NULL;
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 70 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->details = _data_->_tmp2_;
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp3_, G_TYPE_STRING);
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GValue));
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp5_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp6_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 73 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v1 = _data_->_tmp6_;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp7_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp7_ = _data_->v1;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp8_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp8_ = _data_->c;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp9_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp9_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp8_, "full_name");
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp10_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp10_ = (GValue*) _data_->_tmp9_;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp11_, 0, sizeof (GValue));
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp11_ = *_data_->_tmp10_;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp12_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp12_ = g_value_get_string (&_data_->_tmp11_);
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_string (_data_->_tmp7_, _data_->_tmp12_);
#line 74 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp10_);
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp13_ = NULL;
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp13_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_FULL_NAME);
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp14_ = NULL;
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp14_ = g_strdup (_data_->_tmp13_);
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp15_ = NULL;
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp15_ = _data_->v1;
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v1 = NULL;
#line 75 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp14_, _data_->_tmp15_);
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp16_, 0, sizeof (GValue));
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp16_, GEE_TYPE_SET);
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp17_, 0, sizeof (GValue));
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp18_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp18_ = __g_value_dup0 (&_data_->_tmp17_);
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp19_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp17_) ? (g_value_unset (&_data_->_tmp17_), NULL) : NULL;
#line 78 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v2 = _data_->_tmp19_;
#line 79 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp20_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp20_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 79 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->emails = _data_->_tmp20_;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp21_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp21_ = _data_->c;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp22_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp22_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp21_, "email_1");
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp23_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp23_ = (GValue*) _data_->_tmp22_;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp24_, 0, sizeof (GValue));
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp24_ = *_data_->_tmp23_;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp25_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp25_ = g_value_get_string (&_data_->_tmp24_);
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp26_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp26_ = folks_email_field_details_new (_data_->_tmp25_, NULL);
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp27_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp27_ = _data_->_tmp26_;
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp23_);
#line 82 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->email_1 = _data_->_tmp27_;
#line 83 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->email_1, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 85 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->emails, _data_->email_1);
#line 86 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp28_ = NULL;
#line 86 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp28_ = _data_->v2;
#line 86 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_object (_data_->_tmp28_, (GObject*) _data_->emails);
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp29_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp29_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_EMAIL_ADDRESSES);
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp30_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp30_ = g_strdup (_data_->_tmp29_);
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp31_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp31_ = _data_->v2;
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v2 = NULL;
#line 87 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp30_, _data_->_tmp31_);
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp32_, 0, sizeof (GValue));
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp32_, GEE_TYPE_SET);
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp33_, 0, sizeof (GValue));
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp33_ = _data_->_tmp32_;
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp34_ = NULL;
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp34_ = __g_value_dup0 (&_data_->_tmp33_);
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp35_ = NULL;
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp35_ = _data_->_tmp34_;
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp33_) ? (g_value_unset (&_data_->_tmp33_), NULL) : NULL;
#line 91 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v5 = _data_->_tmp35_;
#line 92 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp36_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp36_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 92 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->phones = _data_->_tmp36_;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp37_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp37_ = _data_->c;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp38_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp38_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp37_, "home_phone");
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp39_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp39_ = (GValue*) _data_->_tmp38_;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp40_, 0, sizeof (GValue));
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp40_ = *_data_->_tmp39_;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp41_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp41_ = g_value_get_string (&_data_->_tmp40_);
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp42_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp42_ = folks_phone_field_details_new (_data_->_tmp41_, NULL);
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp43_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp43_ = _data_->_tmp42_;
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp39_);
#line 96 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->phone_1 = _data_->_tmp43_;
#line 97 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->phone_1, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 99 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _data_->phones, _data_->phone_1);
#line 100 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp44_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp44_ = _data_->v5;
#line 100 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_object (_data_->_tmp44_, (GObject*) _data_->phones);
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp45_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp45_ = folks_persona_store_detail_key (FOLKS_PERSONA_DETAIL_PHONE_NUMBERS);
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp46_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp46_ = g_strdup (_data_->_tmp45_);
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp47_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp47_ = _data_->v5;
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v5 = NULL;
#line 101 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_hash_table_insert (_data_->details, _data_->_tmp46_, _data_->_tmp47_);
#line 708 "linkable-properties.c"
	{
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp48_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp48_ = _data_->self->priv->_aggregator;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp49_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp49_ = ((DummyTestTestCase*) _data_->self)->dummy_persona_store;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_state_ = 1;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp48_, NULL, (FolksPersonaStore*) _data_->_tmp49_, _data_->details, _linkable_properties_tests_add_persona_ready, _data_);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		return FALSE;
#line 724 "linkable-properties.c"
		_state_1:
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp50_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp50_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp48_, _data_->_res_, &_data_->_inner_error_);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp51_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp51_ = _data_->_tmp50_;
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (_data_->_tmp51_);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		if (_data_->_inner_error_ != NULL) {
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 740 "linkable-properties.c"
				goto __catch0_folks_individual_aggregator_error;
			}
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (_data_->phone_1);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (_data_->phones);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			__vala_GValue_free0 (_data_->v5);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (_data_->email_1);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (_data_->emails);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			__vala_GValue_free0 (_data_->v2);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			__vala_GValue_free0 (_data_->v1);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_hash_table_unref0 (_data_->details);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (_data_->c);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			g_clear_error (&_data_->_inner_error_);
#line 107 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			return FALSE;
#line 767 "linkable-properties.c"
		}
	}
	goto __finally0;
	__catch0_folks_individual_aggregator_error:
	{
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->e = _data_->_inner_error_;
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_inner_error_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp52_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp52_ = _data_->e;
#line 112 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp53_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp53_ = _data_->_tmp52_->message;
#line 112 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_warning ("linkable-properties.vala:112: [AddPersonaError] add_persona_from_detai" \
"ls: %s\n", _data_->_tmp53_);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_error_free0 (_data_->e);
#line 789 "linkable-properties.c"
	}
	__finally0:
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	if (_data_->_inner_error_ != NULL) {
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (_data_->phone_1);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (_data_->phones);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		__vala_GValue_free0 (_data_->v5);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (_data_->email_1);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (_data_->emails);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		__vala_GValue_free0 (_data_->v2);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		__vala_GValue_free0 (_data_->v1);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_hash_table_unref0 (_data_->details);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (_data_->c);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_clear_error (&_data_->_inner_error_);
#line 105 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		return FALSE;
#line 818 "linkable-properties.c"
	}
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->phone_1);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->phones);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v5);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->email_1);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->emails);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v2);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v1);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_hash_table_unref0 (_data_->details);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->c);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	if (_data_->_state_ == 0) {
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 842 "linkable-properties.c"
	} else {
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 846 "linkable-properties.c"
	}
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_object_unref (_data_->_async_result);
#line 68 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return FALSE;
#line 852 "linkable-properties.c"
}


static void _linkable_properties_tests_add_personas_data_free (gpointer _data) {
	LinkablePropertiesTestsAddPersonasData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_slice_free (LinkablePropertiesTestsAddPersonasData, _data_);
#line 863 "linkable-properties.c"
}


static void _linkable_properties_tests_add_personas (LinkablePropertiesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkablePropertiesTestsAddPersonasData* _data_;
	LinkablePropertiesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = g_slice_new0 (LinkablePropertiesTestsAddPersonasData);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _linkable_properties_tests_add_personas);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _linkable_properties_tests_add_personas_data_free);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_personas_co (_data_);
#line 882 "linkable-properties.c"
}


static void _linkable_properties_tests_add_personas_finish (LinkablePropertiesTests* self, GAsyncResult* _res_) {
	LinkablePropertiesTestsAddPersonasData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 890 "linkable-properties.c"
}


static void _linkable_properties_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkablePropertiesTestsAddPersonasData* _data_;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = _user_data_;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_source_object_ = source_object;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_res_ = _res_;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_personas_co (_data_);
#line 904 "linkable-properties.c"
}


static gboolean _linkable_properties_tests_add_personas_co (LinkablePropertiesTestsAddPersonasData* _data_) {
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	switch (_data_->_state_) {
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 0:
#line 913 "linkable-properties.c"
		goto _state_0;
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 1:
#line 917 "linkable-properties.c"
		goto _state_1;
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 2:
#line 921 "linkable-properties.c"
		goto _state_2;
		default:
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_assert_not_reached ();
#line 926 "linkable-properties.c"
	}
	_state_0:
#line 126 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->self->priv->_found_before_update = FALSE;
#line 127 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->self->priv->_found_after_update = FALSE;
#line 129 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp0_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 129 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->c);
#line 129 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->c = _data_->_tmp0_;
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp1_, 0, sizeof (GValue));
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp1_, G_TYPE_STRING);
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp2_, 0, sizeof (GValue));
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp3_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp3_ = __g_value_dup0 (&_data_->_tmp2_);
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v);
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = _data_->_tmp3_;
#line 130 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp2_) ? (g_value_unset (&_data_->_tmp2_), NULL) : NULL;
#line 131 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp4_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp4_ = _data_->v;
#line 131 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_string (_data_->_tmp4_, LINKABLE_PROPERTIES_TESTS__full_name_1);
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp5_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp5_ = _data_->c;
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp6_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp6_ = _data_->v;
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = NULL;
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp7_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp5_, "full_name", _data_->_tmp7_);
#line 132 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp7_);
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp8_, 0, sizeof (GValue));
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp8_, G_TYPE_STRING);
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp9_, 0, sizeof (GValue));
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp10_ = NULL;
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp10_ = __g_value_dup0 (&_data_->_tmp9_);
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v);
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = _data_->_tmp10_;
#line 133 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp9_) ? (g_value_unset (&_data_->_tmp9_), NULL) : NULL;
#line 134 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp11_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp11_ = _data_->v;
#line 134 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_string (_data_->_tmp11_, LINKABLE_PROPERTIES_TESTS__email_1);
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp12_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp12_ = _data_->c;
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp13_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp13_ = _data_->v;
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp14_ = NULL;
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp12_, "email_1", _data_->_tmp14_);
#line 135 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp14_);
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp15_, 0, sizeof (GValue));
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp15_, G_TYPE_STRING);
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp16_, 0, sizeof (GValue));
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp17_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp17_ = __g_value_dup0 (&_data_->_tmp16_);
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v);
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = _data_->_tmp17_;
#line 136 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp16_) ? (g_value_unset (&_data_->_tmp16_), NULL) : NULL;
#line 137 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp18_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp18_ = _data_->v;
#line 137 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_string (_data_->_tmp18_, LINKABLE_PROPERTIES_TESTS__phone_1);
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp19_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp19_ = _data_->c;
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp20_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp20_ = _data_->v;
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = NULL;
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp21_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp21_ = _data_->_tmp20_;
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp19_, "home_phone", _data_->_tmp21_);
#line 138 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp21_);
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp22_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp22_ = _data_->c;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp23_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp23_ = _g_object_ref0 (_data_->_tmp22_);
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_state_ = 1;
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_persona (_data_->self, _data_->_tmp23_, _linkable_properties_tests_add_personas_ready, _data_);
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return FALSE;
#line 1081 "linkable-properties.c"
	_state_1:
#line 139 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_persona_finish (_data_->self, _data_->_res_);
#line 141 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp24_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp24_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 141 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->c);
#line 141 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->c = _data_->_tmp24_;
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp25_, 0, sizeof (GValue));
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp25_, G_TYPE_STRING);
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp26_, 0, sizeof (GValue));
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp27_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp27_ = __g_value_dup0 (&_data_->_tmp26_);
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v);
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = _data_->_tmp27_;
#line 142 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp26_) ? (g_value_unset (&_data_->_tmp26_), NULL) : NULL;
#line 143 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp28_ = NULL;
#line 143 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp28_ = _data_->v;
#line 143 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_string (_data_->_tmp28_, LINKABLE_PROPERTIES_TESTS__full_name_2);
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp29_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp29_ = _data_->c;
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp30_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp30_ = _data_->v;
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = NULL;
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp31_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp29_, "full_name", _data_->_tmp31_);
#line 144 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp31_);
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp32_, 0, sizeof (GValue));
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp32_, G_TYPE_STRING);
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp33_, 0, sizeof (GValue));
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp33_ = _data_->_tmp32_;
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp34_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp34_ = __g_value_dup0 (&_data_->_tmp33_);
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v);
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = _data_->_tmp34_;
#line 145 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp33_) ? (g_value_unset (&_data_->_tmp33_), NULL) : NULL;
#line 146 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp35_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp35_ = _data_->v;
#line 146 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_string (_data_->_tmp35_, LINKABLE_PROPERTIES_TESTS__email_2);
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp36_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp36_ = _data_->c;
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp37_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp37_ = _data_->v;
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp38_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp38_ = _data_->_tmp37_;
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp36_, "email_1", _data_->_tmp38_);
#line 147 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp38_);
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp39_, 0, sizeof (GValue));
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_init (&_data_->_tmp39_, G_TYPE_STRING);
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	memset (&_data_->_tmp40_, 0, sizeof (GValue));
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp40_ = _data_->_tmp39_;
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp41_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp41_ = __g_value_dup0 (&_data_->_tmp40_);
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v);
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = _data_->_tmp41_;
#line 148 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_IS_VALUE (&_data_->_tmp40_) ? (g_value_unset (&_data_->_tmp40_), NULL) : NULL;
#line 149 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp42_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp42_ = _data_->v;
#line 149 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_value_set_string (_data_->_tmp42_, LINKABLE_PROPERTIES_TESTS__phone_2);
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp43_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp43_ = _data_->c;
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp44_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp44_ = _data_->v;
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->v = NULL;
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp45_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp45_ = _data_->_tmp44_;
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp43_, "home_phone", _data_->_tmp45_);
#line 150 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->_tmp45_);
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp46_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp46_ = _data_->c;
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp47_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp47_ = _g_object_ref0 (_data_->_tmp46_);
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_state_ = 2;
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_persona (_data_->self, _data_->_tmp47_, _linkable_properties_tests_add_personas_ready, _data_);
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return FALSE;
#line 1233 "linkable-properties.c"
	_state_2:
#line 151 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_persona_finish (_data_->self, _data_->_res_);
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	__vala_GValue_free0 (_data_->v);
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->c);
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	if (_data_->_state_ == 0) {
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1245 "linkable-properties.c"
	} else {
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1249 "linkable-properties.c"
	}
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_object_unref (_data_->_async_result);
#line 121 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return FALSE;
#line 1255 "linkable-properties.c"
}


static void linkable_properties_tests_test_linkable_properties_aggregate_after_change (LinkablePropertiesTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GMainLoop* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 154 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_return_if_fail (self != NULL);
#line 156 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 156 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 156 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self->priv->_main_loop = _tmp0_;
#line 157 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue (self, NULL, NULL);
#line 158 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp1_ = self->priv->_main_loop;
#line 158 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	folks_test_utils_loop_run_with_timeout (_tmp1_, 5);
#line 160 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp2_ = self->priv->_found_before_update;
#line 160 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_vala_assert (_tmp2_, "this._found_before_update");
#line 161 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp3_ = self->priv->_found_after_update;
#line 161 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_vala_assert (_tmp3_, "this._found_after_update");
#line 1286 "linkable-properties.c"
}


static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_data_free (gpointer _data) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_slice_free (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData, _data_);
#line 1297 "linkable-properties.c"
}


static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue (LinkablePropertiesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData* _data_;
	LinkablePropertiesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = g_slice_new0 (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_data_free);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_co (_data_);
#line 1316 "linkable-properties.c"
}


static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_finish (LinkablePropertiesTests* self, GAsyncResult* _res_) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1324 "linkable-properties.c"
}


static void __linkable_properties_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 167 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_individuals_changed_aggregate_after_change_cb ((LinkablePropertiesTests*) self, changes);
#line 1331 "linkable-properties.c"
}


static void linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData* _data_;
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_ = _user_data_;
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_source_object_ = source_object;
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_res_ = _res_;
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_co (_data_);
#line 1345 "linkable-properties.c"
}


static gboolean linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_co (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeContinueData* _data_) {
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	switch (_data_->_state_) {
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 0:
#line 1354 "linkable-properties.c"
		goto _state_0;
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 1:
#line 1358 "linkable-properties.c"
		goto _state_1;
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		case 2:
#line 1362 "linkable-properties.c"
		goto _state_2;
		default:
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_assert_not_reached ();
#line 1367 "linkable-properties.c"
	}
	_state_0:
#line 166 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp0_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp0_ = folks_individual_aggregator_dup ();
#line 166 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 166 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->self->priv->_aggregator = _data_->_tmp0_;
#line 167 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp1_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_tmp1_ = _data_->self->priv->_aggregator;
#line 167 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_signal_connect_object (_data_->_tmp1_, "individuals-changed-detailed", (GCallback) __linkable_properties_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 1384 "linkable-properties.c"
	{
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp2_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_state_ = 1;
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		folks_individual_aggregator_prepare (_data_->_tmp2_, linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_ready, _data_);
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		return FALSE;
#line 1396 "linkable-properties.c"
		_state_1:
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 170 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1402 "linkable-properties.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
#line 168 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->e = _data_->_inner_error_;
#line 168 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_inner_error_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp3_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp3_ = _data_->e;
#line 174 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp4_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_data_->_tmp4_ = _data_->_tmp3_->message;
#line 174 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_warning ("linkable-properties.vala:174: Error when calling prepare: %s\n", _data_->_tmp4_);
#line 168 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_error_free0 (_data_->e);
#line 1425 "linkable-properties.c"
	}
	__finally1:
#line 168 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	if (_data_->_inner_error_ != NULL) {
#line 168 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 168 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_clear_error (&_data_->_inner_error_);
#line 168 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		return FALSE;
#line 1436 "linkable-properties.c"
	}
#line 177 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_data_->_state_ = 2;
#line 177 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_personas (_data_->self, linkable_properties_tests_test_linkable_properties_aggregate_after_change_continue_ready, _data_);
#line 177 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return FALSE;
#line 1444 "linkable-properties.c"
	_state_2:
#line 177 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_linkable_properties_tests_add_personas_finish (_data_->self, _data_->_res_);
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	if (_data_->_state_ == 0) {
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1452 "linkable-properties.c"
	} else {
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1456 "linkable-properties.c"
	}
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_object_unref (_data_->_async_result);
#line 164 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return FALSE;
#line 1462 "linkable-properties.c"
}


static void _linkable_properties_tests_individuals_changed_aggregate_after_change_cb (LinkablePropertiesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 180 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_return_if_fail (self != NULL);
#line 180 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_return_if_fail (changes != NULL);
#line 183 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp0_ = changes;
#line 183 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 183 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	added = _tmp1_;
#line 185 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp2_ = self->priv->_found_before_update;
#line 185 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	if (!_tmp2_) {
#line 1485 "linkable-properties.c"
		{
			GeeIterator* _i_it = NULL;
			GeeCollection* _tmp3_ = NULL;
			GeeIterator* _tmp4_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp3_ = added;
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_i_it = _tmp4_;
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			while (TRUE) {
#line 1498 "linkable-properties.c"
				GeeIterator* _tmp5_ = NULL;
				gboolean _tmp6_ = FALSE;
				FolksIndividual* i = NULL;
				GeeIterator* _tmp7_ = NULL;
				gpointer _tmp8_ = NULL;
				FolksIndividual* _tmp9_ = NULL;
				FolksNameDetails* name = NULL;
				FolksIndividual* _tmp10_ = NULL;
				FolksNameDetails* _tmp11_ = NULL;
				FolksNameDetails* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp5_ = _i_it;
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp6_ = gee_iterator_next (_tmp5_);
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				if (!_tmp6_) {
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					break;
#line 1519 "linkable-properties.c"
				}
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp7_ = _i_it;
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp8_ = gee_iterator_get (_tmp7_);
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				i = (FolksIndividual*) _tmp8_;
#line 189 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp9_ = i;
#line 189 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_vala_assert (_tmp9_ != NULL, "i != null");
#line 191 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp10_ = i;
#line 191 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 191 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				name = _tmp11_;
#line 193 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp12_ = name;
#line 193 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp13_ = folks_name_details_get_full_name (_tmp12_);
#line 193 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp14_ = _tmp13_;
#line 193 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				if (g_strcmp0 (_tmp14_, LINKABLE_PROPERTIES_TESTS__full_name_1) == 0) {
#line 1545 "linkable-properties.c"
					FolksIndividual* _tmp15_ = NULL;
					FolksIndividual* _tmp16_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					_tmp15_ = i;
#line 195 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					_tmp16_ = _g_object_ref0 (_tmp15_);
#line 195 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					_g_object_unref0 (self->priv->_ind_1);
#line 195 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					self->priv->_ind_1 = _tmp16_;
#line 1556 "linkable-properties.c"
				} else {
					FolksNameDetails* _tmp17_ = NULL;
					const gchar* _tmp18_ = NULL;
					const gchar* _tmp19_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					_tmp17_ = name;
#line 199 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					_tmp18_ = folks_name_details_get_full_name (_tmp17_);
#line 199 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					_tmp19_ = _tmp18_;
#line 199 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					if (g_strcmp0 (_tmp19_, LINKABLE_PROPERTIES_TESTS__full_name_2) == 0) {
#line 1569 "linkable-properties.c"
						FolksIndividual* _tmp20_ = NULL;
						FolksIndividual* _tmp21_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp20_ = i;
#line 201 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp21_ = _g_object_ref0 (_tmp20_);
#line 201 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_g_object_unref0 (self->priv->_ind_2);
#line 201 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						self->priv->_ind_2 = _tmp21_;
#line 202 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						self->priv->_found_before_update = TRUE;
#line 1582 "linkable-properties.c"
						{
							GeeIterator* _p_it = NULL;
							FolksIndividual* _tmp22_ = NULL;
							GeeSet* _tmp23_ = NULL;
							GeeSet* _tmp24_ = NULL;
							GeeIterator* _tmp25_ = NULL;
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp22_ = i;
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp23_ = folks_individual_get_personas (_tmp22_);
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp24_ = _tmp23_;
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp25_ = gee_iterable_iterator ((GeeIterable*) _tmp24_);
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_p_it = _tmp25_;
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							while (TRUE) {
#line 1601 "linkable-properties.c"
								GeeIterator* _tmp26_ = NULL;
								gboolean _tmp27_ = FALSE;
								FolksPersona* p = NULL;
								GeeIterator* _tmp28_ = NULL;
								gpointer _tmp29_ = NULL;
								GeeHashSet* emails = NULL;
								GeeHashSet* _tmp30_ = NULL;
								FolksEmailFieldDetails* email_1 = NULL;
								FolksEmailFieldDetails* _tmp31_ = NULL;
								FolksEmailFieldDetails* _tmp32_ = NULL;
								GeeHashSet* _tmp33_ = NULL;
								FolksEmailFieldDetails* _tmp34_ = NULL;
								FolksPersona* _tmp35_ = NULL;
								GeeHashSet* _tmp36_ = NULL;
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp26_ = _p_it;
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp27_ = gee_iterator_next (_tmp26_);
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								if (!_tmp27_) {
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
									break;
#line 1624 "linkable-properties.c"
								}
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp28_ = _p_it;
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp29_ = gee_iterator_get (_tmp28_);
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								p = (FolksPersona*) _tmp29_;
#line 206 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp30_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 206 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								emails = _tmp30_;
#line 209 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp31_ = folks_email_field_details_new (LINKABLE_PROPERTIES_TESTS__email_1, NULL);
#line 209 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								email_1 = _tmp31_;
#line 210 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp32_ = email_1;
#line 210 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _tmp32_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 212 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp33_ = emails;
#line 212 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp34_ = email_1;
#line 212 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								gee_abstract_collection_add ((GeeAbstractCollection*) _tmp33_, _tmp34_);
#line 213 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp35_ = p;
#line 213 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_tmp36_ = emails;
#line 213 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								folks_email_details_set_email_addresses (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, FOLKS_TYPE_EMAIL_DETAILS, FolksEmailDetails), (GeeSet*) _tmp36_);
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_g_object_unref0 (email_1);
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_g_object_unref0 (emails);
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								_g_object_unref0 (p);
#line 1662 "linkable-properties.c"
							}
#line 204 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_g_object_unref0 (_p_it);
#line 1666 "linkable-properties.c"
						}
					}
				}
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (name);
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (i);
#line 1674 "linkable-properties.c"
			}
#line 187 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (_i_it);
#line 1678 "linkable-properties.c"
		}
	} else {
		FolksIndividual* replaced = NULL;
		GeeMultiMap* _tmp37_ = NULL;
		FolksIndividual* _tmp38_ = NULL;
		gboolean _tmp39_ = FALSE;
		GeeCollection* replacements = NULL;
		GeeMultiMap* _tmp47_ = NULL;
		FolksIndividual* _tmp48_ = NULL;
		GeeCollection* _tmp49_ = NULL;
#line 222 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_tmp37_ = changes;
#line 222 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_tmp38_ = self->priv->_ind_1;
#line 222 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_tmp39_ = gee_multi_map_contains (_tmp37_, _tmp38_);
#line 222 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		if (_tmp39_) {
#line 1697 "linkable-properties.c"
			FolksIndividual* _tmp40_ = NULL;
			FolksIndividual* _tmp41_ = NULL;
#line 224 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp40_ = self->priv->_ind_1;
#line 224 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp41_ = _g_object_ref0 (_tmp40_);
#line 224 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (replaced);
#line 224 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			replaced = _tmp41_;
#line 1708 "linkable-properties.c"
		} else {
			GeeMultiMap* _tmp42_ = NULL;
			FolksIndividual* _tmp43_ = NULL;
			gboolean _tmp44_ = FALSE;
#line 226 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp42_ = changes;
#line 226 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp43_ = self->priv->_ind_2;
#line 226 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp44_ = gee_multi_map_contains (_tmp42_, _tmp43_);
#line 226 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			if (_tmp44_) {
#line 1721 "linkable-properties.c"
				FolksIndividual* _tmp45_ = NULL;
				FolksIndividual* _tmp46_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp45_ = self->priv->_ind_2;
#line 228 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp46_ = _g_object_ref0 (_tmp45_);
#line 228 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (replaced);
#line 228 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				replaced = _tmp46_;
#line 1732 "linkable-properties.c"
			} else {
#line 232 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (replaced);
#line 232 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (added);
#line 232 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				return;
#line 1740 "linkable-properties.c"
			}
		}
#line 235 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_tmp47_ = changes;
#line 235 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_tmp48_ = replaced;
#line 235 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_tmp49_ = gee_multi_map_get (_tmp47_, _tmp48_);
#line 235 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		replacements = _tmp49_;
#line 1751 "linkable-properties.c"
		{
			GeeIterator* _r_it = NULL;
			GeeCollection* _tmp50_ = NULL;
			GeeIterator* _tmp51_ = NULL;
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp50_ = replacements;
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_tmp51_ = gee_iterable_iterator ((GeeIterable*) _tmp50_);
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_r_it = _tmp51_;
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			while (TRUE) {
#line 1764 "linkable-properties.c"
				GeeIterator* _tmp52_ = NULL;
				gboolean _tmp53_ = FALSE;
				FolksIndividual* r = NULL;
				GeeIterator* _tmp54_ = NULL;
				gpointer _tmp55_ = NULL;
				FolksPhoneFieldDetails* phone_fd_1 = NULL;
				FolksPhoneFieldDetails* _tmp56_ = NULL;
				FolksPhoneFieldDetails* phone_fd_2 = NULL;
				FolksPhoneFieldDetails* _tmp57_ = NULL;
				gboolean num_equal_1 = FALSE;
				gboolean num_equal_2 = FALSE;
				FolksIndividual* _tmp58_ = NULL;
				GeeSet* _tmp59_ = NULL;
				GeeSet* _tmp60_ = NULL;
				gint _tmp61_ = 0;
				gint _tmp62_ = 0;
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp52_ = _r_it;
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp53_ = gee_iterator_next (_tmp52_);
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				if (!_tmp53_) {
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					break;
#line 1789 "linkable-properties.c"
				}
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp54_ = _r_it;
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp55_ = gee_iterator_get (_tmp54_);
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				r = (FolksIndividual*) _tmp55_;
#line 238 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp56_ = folks_phone_field_details_new (LINKABLE_PROPERTIES_TESTS__phone_1, NULL);
#line 238 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				phone_fd_1 = _tmp56_;
#line 239 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp57_ = folks_phone_field_details_new (LINKABLE_PROPERTIES_TESTS__phone_1, NULL);
#line 239 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				phone_fd_2 = _tmp57_;
#line 240 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				num_equal_1 = FALSE;
#line 241 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				num_equal_2 = FALSE;
#line 243 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp58_ = r;
#line 243 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp59_ = folks_individual_get_personas (_tmp58_);
#line 243 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp60_ = _tmp59_;
#line 243 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp61_ = gee_collection_get_size ((GeeCollection*) _tmp60_);
#line 243 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_tmp62_ = _tmp61_;
#line 243 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				if (_tmp62_ == 2) {
#line 1821 "linkable-properties.c"
					gboolean _tmp77_ = FALSE;
					gboolean _tmp78_ = FALSE;
					{
						GeeIterator* _num_it = NULL;
						FolksIndividual* _tmp63_ = NULL;
						GeeSet* _tmp64_ = NULL;
						GeeSet* _tmp65_ = NULL;
						GeeIterator* _tmp66_ = NULL;
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp63_ = r;
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp64_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp63_);
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp65_ = _tmp64_;
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp66_ = gee_iterable_iterator ((GeeIterable*) _tmp65_);
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_num_it = _tmp66_;
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						while (TRUE) {
#line 1842 "linkable-properties.c"
							GeeIterator* _tmp67_ = NULL;
							gboolean _tmp68_ = FALSE;
							FolksPhoneFieldDetails* num = NULL;
							GeeIterator* _tmp69_ = NULL;
							gpointer _tmp70_ = NULL;
							FolksPhoneFieldDetails* _tmp71_ = NULL;
							FolksPhoneFieldDetails* _tmp72_ = NULL;
							gboolean _tmp73_ = FALSE;
							FolksPhoneFieldDetails* _tmp74_ = NULL;
							FolksPhoneFieldDetails* _tmp75_ = NULL;
							gboolean _tmp76_ = FALSE;
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp67_ = _num_it;
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp68_ = gee_iterator_next (_tmp67_);
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							if (!_tmp68_) {
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								break;
#line 1862 "linkable-properties.c"
							}
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp69_ = _num_it;
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp70_ = gee_iterator_get (_tmp69_);
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							num = (FolksPhoneFieldDetails*) _tmp70_;
#line 247 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp71_ = num;
#line 247 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp72_ = phone_fd_1;
#line 247 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp73_ = folks_abstract_field_details_values_equal ((FolksAbstractFieldDetails*) _tmp71_, (FolksAbstractFieldDetails*) _tmp72_);
#line 247 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							if (_tmp73_) {
#line 248 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								num_equal_1 = TRUE;
#line 1880 "linkable-properties.c"
							}
#line 250 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp74_ = num;
#line 250 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp75_ = phone_fd_2;
#line 250 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_tmp76_ = folks_abstract_field_details_values_equal ((FolksAbstractFieldDetails*) _tmp74_, (FolksAbstractFieldDetails*) _tmp75_);
#line 250 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							if (_tmp76_) {
#line 251 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
								num_equal_2 = TRUE;
#line 1892 "linkable-properties.c"
							}
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
							_g_object_unref0 (num);
#line 1896 "linkable-properties.c"
						}
#line 245 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_g_object_unref0 (_num_it);
#line 1900 "linkable-properties.c"
					}
#line 254 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					_tmp78_ = num_equal_1;
#line 254 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					if (_tmp78_) {
#line 1906 "linkable-properties.c"
						gboolean _tmp79_ = FALSE;
#line 254 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp79_ = num_equal_2;
#line 254 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp77_ = _tmp79_;
#line 1912 "linkable-properties.c"
					} else {
#line 254 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp77_ = FALSE;
#line 1916 "linkable-properties.c"
					}
#line 254 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
					if (_tmp77_) {
#line 1920 "linkable-properties.c"
						GMainLoop* _tmp80_ = NULL;
#line 256 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						self->priv->_found_after_update = TRUE;
#line 257 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						_tmp80_ = self->priv->_main_loop;
#line 257 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
						g_main_loop_quit (_tmp80_);
#line 1928 "linkable-properties.c"
					}
				}
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (phone_fd_2);
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (phone_fd_1);
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
				_g_object_unref0 (r);
#line 1937 "linkable-properties.c"
			}
#line 236 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
			_g_object_unref0 (_r_it);
#line 1941 "linkable-properties.c"
		}
#line 185 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (replacements);
#line 185 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
		_g_object_unref0 (replaced);
#line 1947 "linkable-properties.c"
	}
#line 180 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (added);
#line 1951 "linkable-properties.c"
}


static void linkable_properties_tests_class_init (LinkablePropertiesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	linkable_properties_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_type_class_add_private (klass, sizeof (LinkablePropertiesTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = linkable_properties_tests_real_set_up;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	DUMMY_TEST_TEST_CASE_CLASS (klass)->configure_primary_store = linkable_properties_tests_real_configure_primary_store;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = linkable_properties_tests_finalize;
#line 1966 "linkable-properties.c"
}


static void linkable_properties_tests_instance_init (LinkablePropertiesTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self->priv = LINKABLE_PROPERTIES_TESTS_GET_PRIVATE (self);
#line 1973 "linkable-properties.c"
}


static void linkable_properties_tests_finalize (GObject* obj) {
	LinkablePropertiesTests * self;
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTests);
#line 28 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 40 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (self->priv->_ind_1);
#line 41 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (self->priv->_ind_2);
#line 26 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	G_OBJECT_CLASS (linkable_properties_tests_parent_class)->finalize (obj);
#line 1991 "linkable-properties.c"
}


GType linkable_properties_tests_get_type (void) {
	static volatile gsize linkable_properties_tests_type_id__volatile = 0;
	if (g_once_init_enter (&linkable_properties_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LinkablePropertiesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) linkable_properties_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LinkablePropertiesTests), 0, (GInstanceInitFunc) linkable_properties_tests_instance_init, NULL };
		GType linkable_properties_tests_type_id;
		linkable_properties_tests_type_id = g_type_register_static (DUMMY_TEST_TYPE_TEST_CASE, "LinkablePropertiesTests", &g_define_type_info, 0);
		g_once_init_leave (&linkable_properties_tests_type_id__volatile, linkable_properties_tests_type_id);
	}
	return linkable_properties_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	LinkablePropertiesTests* tests = NULL;
	LinkablePropertiesTests* _tmp0_ = NULL;
#line 267 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_test_init (&args_length1, &args, NULL);
#line 269 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_tmp0_ = linkable_properties_tests_new ();
#line 269 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	tests = _tmp0_;
#line 270 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 271 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	g_test_run ();
#line 272 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 274 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	result = 0;
#line 274 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	_g_object_unref0 (tests);
#line 274 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return result;
#line 2029 "linkable-properties.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 265 "/opt/gnome3/source/folks/tests/dummy/linkable-properties.vala"
	return _vala_main (argv, argc);
#line 2039 "linkable-properties.c"
}



