/* postal-address-details.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from postal-address-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-eds.h>
#include <gio/gio.h>


#define TYPE_POSTAL_ADDRESS_DETAILS_TESTS (postal_address_details_tests_get_type ())
#define POSTAL_ADDRESS_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTests))
#define POSTAL_ADDRESS_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTestsClass))
#define IS_POSTAL_ADDRESS_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_POSTAL_ADDRESS_DETAILS_TESTS))
#define IS_POSTAL_ADDRESS_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_POSTAL_ADDRESS_DETAILS_TESTS))
#define POSTAL_ADDRESS_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTestsClass))

typedef struct _PostalAddressDetailsTests PostalAddressDetailsTests;
typedef struct _PostalAddressDetailsTestsClass PostalAddressDetailsTestsClass;
typedef struct _PostalAddressDetailsTestsPrivate PostalAddressDetailsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PostalAddressDetailsTests {
	EdsTestTestCase parent_instance;
	PostalAddressDetailsTestsPrivate * priv;
};

struct _PostalAddressDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _PostalAddressDetailsTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _pobox;
	gchar* _locality;
	gchar* _postalcode;
	gchar* _street;
	gchar* _extended;
	gchar* _country;
	gchar* _region;
	FolksPostalAddressFieldDetails* _postal_address;
	gboolean _found_postal_address;
	gchar* _fullname;
};

struct _PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	PostalAddressDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer postal_address_details_tests_parent_class = NULL;

GType postal_address_details_tests_get_type (void) G_GNUC_CONST;
#define POSTAL_ADDRESS_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTestsPrivate))
enum  {
	POSTAL_ADDRESS_DETAILS_TESTS_DUMMY_PROPERTY
};
PostalAddressDetailsTests* postal_address_details_tests_new (void);
PostalAddressDetailsTests* postal_address_details_tests_construct (GType object_type);
void postal_address_details_tests_test_postal_address_details_interface (PostalAddressDetailsTests* self);
static void _postal_address_details_tests_test_postal_address_details_interface_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _postal_address_details_tests_test_postal_address_details_interface_async (PostalAddressDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _postal_address_details_tests_test_postal_address_details_interface_finish (PostalAddressDetailsTests* self, GAsyncResult* _res_);
static void _postal_address_details_tests_test_postal_address_details_interface_async_data_free (gpointer _data);
static gboolean _postal_address_details_tests_test_postal_address_details_interface_async_co (PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData* _data_);
static void _postal_address_details_tests_test_postal_address_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _postal_address_details_tests_individuals_changed_cb (PostalAddressDetailsTests* self, GeeMultiMap* changes);
static void __postal_address_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void postal_address_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _postal_address_details_tests_test_postal_address_details_interface_folks_test_case_test_method (gpointer self) {
#line 43 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	postal_address_details_tests_test_postal_address_details_interface ((PostalAddressDetailsTests*) self);
#line 125 "postal-address-details.c"
}


PostalAddressDetailsTests* postal_address_details_tests_construct (GType object_type) {
	PostalAddressDetailsTests * self = NULL;
#line 41 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self = (PostalAddressDetailsTests*) eds_test_test_case_construct (object_type, "PostalAddressDetailsTests");
#line 43 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test postal address details interface", _postal_address_details_tests_test_postal_address_details_interface_folks_test_case_test_method, self);
#line 39 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return self;
#line 137 "postal-address-details.c"
}


PostalAddressDetailsTests* postal_address_details_tests_new (void) {
#line 39 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return postal_address_details_tests_construct (TYPE_POSTAL_ADDRESS_DETAILS_TESTS);
#line 144 "postal-address-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 50 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 151 "postal-address-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 50 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_unset (self);
#line 50 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_free (self);
#line 160 "postal-address-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 167 "postal-address-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 87 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 174 "postal-address-details.c"
}


void postal_address_details_tests_test_postal_address_details_interface (PostalAddressDetailsTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GValue* v = NULL;
	FolksPostalAddress* pa = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	FolksPostalAddress* _tmp10_ = NULL;
	FolksPostalAddressFieldDetails* _tmp11_ = NULL;
	FolksPostalAddressFieldDetails* _tmp12_ = NULL;
	GValue _tmp13_ = {0};
	GValue _tmp14_ = {0};
	GValue* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	GValue* _tmp18_ = NULL;
	GValue* _tmp19_ = NULL;
	FolksPostalAddress* pa_copy = NULL;
	const gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	FolksPostalAddress* _tmp27_ = NULL;
	FolksPostalAddressFieldDetails* pa_fd_copy = NULL;
	FolksPostalAddressFieldDetails* _tmp28_ = NULL;
	GValue _tmp29_ = {0};
	GValue _tmp30_ = {0};
	GValue* _tmp31_ = NULL;
	GValue* _tmp32_ = NULL;
	const gchar* _tmp33_ = NULL;
	GValue* _tmp34_ = NULL;
	GValue* _tmp35_ = NULL;
	EdsTestBackend* _tmp36_ = NULL;
	GeeHashMap* _tmp37_ = NULL;
	GMainLoop* _tmp38_ = NULL;
	gboolean _tmp39_ = FALSE;
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_return_if_fail (self != NULL);
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 49 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_main_loop = _tmp0_;
#line 50 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 50 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	c1 = _tmp1_;
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_fullname);
#line 51 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_fullname = _tmp2_;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp3_ = self->priv->_pobox;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp4_ = self->priv->_extended;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp5_ = self->priv->_street;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp6_ = self->priv->_locality;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp7_ = self->priv->_region;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp8_ = self->priv->_postalcode;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp9_ = self->priv->_country;
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp10_ = folks_postal_address_new (_tmp3_, _tmp4_, _tmp5_, _tmp6_, _tmp7_, _tmp8_, _tmp9_, NULL, "eds_id");
#line 54 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	pa = _tmp10_;
#line 63 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp11_ = folks_postal_address_field_details_new (pa, NULL);
#line 63 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (self->priv->_postal_address);
#line 63 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_postal_address = _tmp11_;
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp12_ = self->priv->_postal_address;
#line 64 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp12_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_init (&_tmp13_, G_TYPE_STRING);
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp14_ = _tmp13_;
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp15_ = __g_value_dup0 (&_tmp14_);
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (v);
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = _tmp15_;
#line 67 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	G_IS_VALUE (&_tmp14_) ? (g_value_unset (&_tmp14_), NULL) : NULL;
#line 68 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp16_ = v;
#line 68 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp17_ = self->priv->_fullname;
#line 68 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_set_string (_tmp16_, _tmp17_);
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp18_ = v;
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = NULL;
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp19_ = _tmp18_;
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp19_);
#line 69 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (_tmp19_);
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp20_ = self->priv->_pobox;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp21_ = self->priv->_extended;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp22_ = self->priv->_street;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp23_ = self->priv->_locality;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp24_ = self->priv->_region;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp25_ = self->priv->_postalcode;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp26_ = self->priv->_country;
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp27_ = folks_postal_address_new (_tmp20_, _tmp21_, _tmp22_, _tmp23_, _tmp24_, _tmp25_, _tmp26_, NULL, "eds_id");
#line 70 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	pa_copy = _tmp27_;
#line 79 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp28_ = folks_postal_address_field_details_new (pa_copy, NULL);
#line 79 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	pa_fd_copy = _tmp28_;
#line 80 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) pa_fd_copy, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 82 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_init (&_tmp29_, FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS);
#line 82 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp30_ = _tmp29_;
#line 82 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp31_ = __g_value_dup0 (&_tmp30_);
#line 82 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (v);
#line 82 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = _tmp31_;
#line 82 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	G_IS_VALUE (&_tmp30_) ? (g_value_unset (&_tmp30_), NULL) : NULL;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp32_ = v;
#line 83 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_value_set_object (_tmp32_, (GObject*) pa_fd_copy);
#line 85 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp33_ = EDSF_PERSONA_address_fields[0];
#line 85 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp34_ = v;
#line 85 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	v = NULL;
#line 85 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp35_ = _tmp34_;
#line 85 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, _tmp33_, _tmp35_);
#line 85 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (_tmp35_);
#line 87 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp36_ = ((EdsTestTestCase*) self)->eds_backend;
#line 87 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp37_ = _g_object_ref0 (c1);
#line 87 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	eds_test_backend_add_contact (_tmp36_, _tmp37_);
#line 89 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_found_postal_address = FALSE;
#line 91 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_postal_address_details_tests_test_postal_address_details_interface_async (self, NULL, NULL);
#line 93 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp38_ = self->priv->_main_loop;
#line 93 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_utils_loop_run_with_timeout (_tmp38_, 5);
#line 95 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp39_ = self->priv->_found_postal_address;
#line 95 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_vala_assert (_tmp39_ == TRUE, "this._found_postal_address == true");
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (pa_fd_copy);
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (pa_copy);
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (pa);
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	__vala_GValue_free0 (v);
#line 47 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (c1);
#line 378 "postal-address-details.c"
}


static void _postal_address_details_tests_test_postal_address_details_interface_async_data_free (gpointer _data) {
	PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_slice_free (PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData, _data_);
#line 389 "postal-address-details.c"
}


static void _postal_address_details_tests_test_postal_address_details_interface_async (PostalAddressDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
	PostalAddressDetailsTests* _tmp0_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_ = g_slice_new0 (PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData);
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _postal_address_details_tests_test_postal_address_details_interface_async);
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _postal_address_details_tests_test_postal_address_details_interface_async_data_free);
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->self = _tmp0_;
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_postal_address_details_tests_test_postal_address_details_interface_async_co (_data_);
#line 408 "postal-address-details.c"
}


static void _postal_address_details_tests_test_postal_address_details_interface_finish (PostalAddressDetailsTests* self, GAsyncResult* _res_) {
	PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 416 "postal-address-details.c"
}


static void _postal_address_details_tests_test_postal_address_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_ = _user_data_;
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_source_object_ = source_object;
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_res_ = _res_;
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_postal_address_details_tests_test_postal_address_details_interface_async_co (_data_);
#line 430 "postal-address-details.c"
}


static void __postal_address_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 106 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_postal_address_details_tests_individuals_changed_cb ((PostalAddressDetailsTests*) self, changes);
#line 437 "postal-address-details.c"
}


static gboolean _postal_address_details_tests_test_postal_address_details_interface_async_co (PostalAddressDetailsTestsTestPostalAddressDetailsInterfaceAsyncData* _data_) {
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	switch (_data_->_state_) {
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		case 0:
#line 446 "postal-address-details.c"
		goto _state_0;
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		case 1:
#line 450 "postal-address-details.c"
		goto _state_1;
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		case 2:
#line 454 "postal-address-details.c"
		goto _state_2;
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		case 3:
#line 458 "postal-address-details.c"
		goto _state_3;
		default:
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		g_assert_not_reached ();
#line 463 "postal-address-details.c"
	}
	_state_0:
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp0_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_state_ = 1;
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _postal_address_details_tests_test_postal_address_details_interface_async_ready, _data_);
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return FALSE;
#line 476 "postal-address-details.c"
	_state_1:
#line 101 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 103 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp1_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 103 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->store = _data_->_tmp1_;
#line 104 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_state_ = 2;
#line 104 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_backend_store_prepare (_data_->store, _postal_address_details_tests_test_postal_address_details_interface_async_ready, _data_);
#line 104 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return FALSE;
#line 492 "postal-address-details.c"
	_state_2:
#line 104 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 105 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp2_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 105 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 105 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 106 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp3_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 106 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __postal_address_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 510 "postal-address-details.c"
	{
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_tmp4_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_state_ = 3;
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _postal_address_details_tests_test_postal_address_details_interface_async_ready, _data_);
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		return FALSE;
#line 522 "postal-address-details.c"
		_state_3:
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 110 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 528 "postal-address-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->e = _data_->_inner_error_;
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_inner_error_ = NULL;
#line 114 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_tmp5_ = NULL;
#line 114 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 114 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_tmp6_ = NULL;
#line 114 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 114 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		g_warning ("postal-address-details.vala:114: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_g_error_free0 (_data_->e);
#line 551 "postal-address-details.c"
	}
	__finally0:
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_g_object_unref0 (_data_->store);
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 108 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		return FALSE;
#line 564 "postal-address-details.c"
	}
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (_data_->store);
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	if (_data_->_state_ == 0) {
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 572 "postal-address-details.c"
	} else {
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 576 "postal-address-details.c"
	}
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_object_unref (_data_->_async_result);
#line 98 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return FALSE;
#line 582 "postal-address-details.c"
}


static void _postal_address_details_tests_individuals_changed_cb (PostalAddressDetailsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp31_ = NULL;
	gint _tmp32_ = 0;
	gint _tmp33_ = 0;
#line 119 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_return_if_fail (self != NULL);
#line 119 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_return_if_fail (changes != NULL);
#line 122 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp0_ = changes;
#line 122 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 122 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	added = _tmp1_;
#line 123 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp2_ = changes;
#line 123 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 123 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	removed = _tmp3_;
#line 612 "postal-address-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp4_ = added;
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_i_it = _tmp5_;
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		while (TRUE) {
#line 625 "postal-address-details.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp6_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			if (!_tmp7_) {
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
				break;
#line 644 "postal-address-details.c"
			}
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp8_ = _i_it;
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 127 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp10_ = i;
#line 127 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 129 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp11_ = i;
#line 129 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 129 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp13_ = _tmp12_;
#line 129 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp14_ = self->priv->_fullname;
#line 129 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 666 "postal-address-details.c"
				{
					GeeIterator* _pa_fd_it = NULL;
					FolksIndividual* _tmp15_ = NULL;
					GeeSet* _tmp16_ = NULL;
					GeeSet* _tmp17_ = NULL;
					GeeIterator* _tmp18_ = NULL;
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
					_tmp15_ = i;
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
					_tmp16_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp15_);
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
					_tmp17_ = _tmp16_;
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
					_tmp18_ = gee_iterable_iterator ((GeeIterable*) _tmp17_);
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
					_pa_fd_it = _tmp18_;
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
					while (TRUE) {
#line 685 "postal-address-details.c"
						GeeIterator* _tmp19_ = NULL;
						gboolean _tmp20_ = FALSE;
						FolksPostalAddressFieldDetails* pa_fd = NULL;
						GeeIterator* _tmp21_ = NULL;
						gpointer _tmp22_ = NULL;
						FolksPostalAddressFieldDetails* _tmp23_ = NULL;
						FolksPostalAddressFieldDetails* _tmp24_ = NULL;
						const gchar* _tmp25_ = NULL;
						const gchar* _tmp26_ = NULL;
						FolksPostalAddressFieldDetails* _tmp27_ = NULL;
						FolksPostalAddressFieldDetails* _tmp28_ = NULL;
						gboolean _tmp29_ = FALSE;
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp19_ = _pa_fd_it;
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp20_ = gee_iterator_next (_tmp19_);
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						if (!_tmp20_) {
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
							break;
#line 706 "postal-address-details.c"
						}
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp21_ = _pa_fd_it;
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp22_ = gee_iterator_get (_tmp21_);
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						pa_fd = (FolksPostalAddressFieldDetails*) _tmp22_;
#line 137 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp23_ = self->priv->_postal_address;
#line 137 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp24_ = pa_fd;
#line 137 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp25_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp24_);
#line 137 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp26_ = _tmp25_;
#line 137 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _tmp23_, _tmp26_);
#line 139 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp27_ = pa_fd;
#line 139 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp28_ = self->priv->_postal_address;
#line 139 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_tmp29_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp27_, (FolksAbstractFieldDetails*) _tmp28_);
#line 139 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						if (_tmp29_) {
#line 732 "postal-address-details.c"
							GMainLoop* _tmp30_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
							self->priv->_found_postal_address = TRUE;
#line 142 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
							_tmp30_ = self->priv->_main_loop;
#line 142 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
							g_main_loop_quit (_tmp30_);
#line 740 "postal-address-details.c"
						}
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
						_g_object_unref0 (pa_fd);
#line 744 "postal-address-details.c"
					}
#line 131 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
					_g_object_unref0 (_pa_fd_it);
#line 748 "postal-address-details.c"
				}
			}
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_g_object_unref0 (i);
#line 753 "postal-address-details.c"
		}
#line 125 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_g_object_unref0 (_i_it);
#line 757 "postal-address-details.c"
	}
#line 148 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp31_ = removed;
#line 148 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp32_ = gee_collection_get_size ((GeeCollection*) _tmp31_);
#line 148 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp33_ = _tmp32_;
#line 148 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_vala_assert (_tmp33_ == 1, "removed.size == 1");
#line 767 "postal-address-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp34_ = NULL;
		GeeIterator* _tmp35_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp34_ = removed;
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_i_it = _tmp35_;
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		while (TRUE) {
#line 780 "postal-address-details.c"
			GeeIterator* _tmp36_ = NULL;
			gboolean _tmp37_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp38_ = NULL;
			gpointer _tmp39_ = NULL;
			FolksIndividual* _tmp40_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp36_ = _i_it;
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp37_ = gee_iterator_next (_tmp36_);
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			if (!_tmp37_) {
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
				break;
#line 795 "postal-address-details.c"
			}
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp38_ = _i_it;
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp39_ = gee_iterator_get (_tmp38_);
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			i = (FolksIndividual*) _tmp39_;
#line 152 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_tmp40_ = i;
#line 152 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_vala_assert (_tmp40_ == NULL, "i == null");
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
			_g_object_unref0 (i);
#line 809 "postal-address-details.c"
		}
#line 150 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
		_g_object_unref0 (_i_it);
#line 813 "postal-address-details.c"
	}
#line 119 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (removed);
#line 119 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (added);
#line 819 "postal-address-details.c"
}


static void postal_address_details_tests_class_init (PostalAddressDetailsTestsClass * klass) {
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	postal_address_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_type_class_add_private (klass, sizeof (PostalAddressDetailsTestsPrivate));
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	G_OBJECT_CLASS (klass)->finalize = postal_address_details_tests_finalize;
#line 830 "postal-address-details.c"
}


static void postal_address_details_tests_instance_init (PostalAddressDetailsTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv = POSTAL_ADDRESS_DETAILS_TESTS_GET_PRIVATE (self);
#line 28 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp0_ = g_strdup ("12345");
#line 28 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_pobox = _tmp0_;
#line 29 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp1_ = g_strdup ("example locality");
#line 29 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_locality = _tmp1_;
#line 30 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp2_ = g_strdup ("example postalcode");
#line 30 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_postalcode = _tmp2_;
#line 31 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp3_ = g_strdup ("example street");
#line 31 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_street = _tmp3_;
#line 32 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp4_ = g_strdup ("example extended address");
#line 32 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_extended = _tmp4_;
#line 33 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp5_ = g_strdup ("example country");
#line 33 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_country = _tmp5_;
#line 34 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp6_ = g_strdup ("example region");
#line 34 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self->priv->_region = _tmp6_;
#line 872 "postal-address-details.c"
}


static void postal_address_details_tests_finalize (GObject* obj) {
	PostalAddressDetailsTests * self;
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_POSTAL_ADDRESS_DETAILS_TESTS, PostalAddressDetailsTests);
#line 26 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 27 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 28 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_pobox);
#line 29 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_locality);
#line 30 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_postalcode);
#line 31 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_street);
#line 32 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_extended);
#line 33 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_country);
#line 34 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_region);
#line 35 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (self->priv->_postal_address);
#line 37 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_free0 (self->priv->_fullname);
#line 24 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	G_OBJECT_CLASS (postal_address_details_tests_parent_class)->finalize (obj);
#line 904 "postal-address-details.c"
}


GType postal_address_details_tests_get_type (void) {
	static volatile gsize postal_address_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&postal_address_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PostalAddressDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) postal_address_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PostalAddressDetailsTests), 0, (GInstanceInitFunc) postal_address_details_tests_instance_init, NULL };
		GType postal_address_details_tests_type_id;
		postal_address_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "PostalAddressDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&postal_address_details_tests_type_id__volatile, postal_address_details_tests_type_id);
	}
	return postal_address_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PostalAddressDetailsTests* tests = NULL;
	PostalAddressDetailsTests* _tmp0_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 161 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_tmp0_ = postal_address_details_tests_new ();
#line 161 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	tests = _tmp0_;
#line 162 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 163 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	g_test_run ();
#line 164 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 166 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	result = 0;
#line 166 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	_g_object_unref0 (tests);
#line 166 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return result;
#line 942 "postal-address-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 157 "/opt/gnome3/source/folks/tests/eds/postal-address-details.vala"
	return _vala_main (argv, argc);
#line 952 "postal-address-details.c"
}



