/* types.c generated by valac 0.25.3, the Vala compiler
 * generated from types.vala, do not modify */

/*
 * Copyright (C) 2010 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>


#define FOLKS_TYPE_MAYBE_BOOL (folks_maybe_bool_get_type ())

typedef enum  {
	FOLKS_MAYBE_BOOL_UNSET = 0,
	FOLKS_MAYBE_BOOL_FALSE = 1,
	FOLKS_MAYBE_BOOL_TRUE = 2
} FolksMaybeBool;



GType folks_maybe_bool_get_type (void) G_GNUC_CONST;


/**
   * A 'boolean' type that has a distinct 'unset' state.
   *
   * @since 0.3.1
   */
GType folks_maybe_bool_get_type (void) {
	static volatile gsize folks_maybe_bool_type_id__volatile = 0;
	if (g_once_init_enter (&folks_maybe_bool_type_id__volatile)) {
		static const GEnumValue values[] = {{FOLKS_MAYBE_BOOL_UNSET, "FOLKS_MAYBE_BOOL_UNSET", "unset"}, {FOLKS_MAYBE_BOOL_FALSE, "FOLKS_MAYBE_BOOL_FALSE", "false"}, {FOLKS_MAYBE_BOOL_TRUE, "FOLKS_MAYBE_BOOL_TRUE", "true"}, {0, NULL, NULL}};
		GType folks_maybe_bool_type_id;
		folks_maybe_bool_type_id = g_enum_register_static ("FolksMaybeBool", values);
		g_once_init_leave (&folks_maybe_bool_type_id__volatile, folks_maybe_bool_type_id);
	}
	return folks_maybe_bool_type_id__volatile;
}



