/* im-details.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from im-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_IM_DETAILS_TESTS (im_details_tests_get_type ())
#define IM_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IM_DETAILS_TESTS, ImDetailsTests))
#define IM_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IM_DETAILS_TESTS, ImDetailsTestsClass))
#define IS_IM_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IM_DETAILS_TESTS))
#define IS_IM_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IM_DETAILS_TESTS))
#define IM_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IM_DETAILS_TESTS, ImDetailsTestsClass))

typedef struct _ImDetailsTests ImDetailsTests;
typedef struct _ImDetailsTestsClass ImDetailsTestsClass;
typedef struct _ImDetailsTestsPrivate ImDetailsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _ImDetailsTestsTestImDetailsInterfaceAsyncData ImDetailsTestsTestImDetailsInterfaceAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ImDetailsTests {
	EdsTestTestCase parent_instance;
	ImDetailsTestsPrivate * priv;
};

struct _ImDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _ImDetailsTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _num_addrs;
	gboolean _found_addr_1;
	gboolean _found_addr_2;
	gchar* _fullname;
	gchar* _im_addrs;
};

struct _ImDetailsTestsTestImDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ImDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer im_details_tests_parent_class = NULL;

GType im_details_tests_get_type (void) G_GNUC_CONST;
#define IM_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_IM_DETAILS_TESTS, ImDetailsTestsPrivate))
enum  {
	IM_DETAILS_TESTS_DUMMY_PROPERTY
};
ImDetailsTests* im_details_tests_new (void);
ImDetailsTests* im_details_tests_construct (GType object_type);
void im_details_tests_test_im_details_interface (ImDetailsTests* self);
static void _im_details_tests_test_im_details_interface_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _im_details_tests_test_im_details_interface_async (ImDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _im_details_tests_test_im_details_interface_finish (ImDetailsTests* self, GAsyncResult* _res_);
static void _im_details_tests_test_im_details_interface_async_data_free (gpointer _data);
static gboolean _im_details_tests_test_im_details_interface_async_co (ImDetailsTestsTestImDetailsInterfaceAsyncData* _data_);
static void _im_details_tests_test_im_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _im_details_tests_individuals_changed_cb (ImDetailsTests* self, GeeMultiMap* changes);
static void __im_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void im_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _im_details_tests_test_im_details_interface_folks_test_case_test_method (gpointer self) {
#line 38 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	im_details_tests_test_im_details_interface ((ImDetailsTests*) self);
#line 119 "im-details.c"
}


ImDetailsTests* im_details_tests_construct (GType object_type) {
	ImDetailsTests * self = NULL;
#line 36 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self = (ImDetailsTests*) eds_test_test_case_construct (object_type, "ImDetailsTests");
#line 38 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test im details interface", _im_details_tests_test_im_details_interface_folks_test_case_test_method, self);
#line 34 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return self;
#line 131 "im-details.c"
}


ImDetailsTests* im_details_tests_new (void) {
#line 34 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return im_details_tests_construct (TYPE_IM_DETAILS_TESTS);
#line 138 "im-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 45 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 145 "im-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 45 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_value_unset (self);
#line 45 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_free (self);
#line 154 "im-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 53 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 161 "im-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 60 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 168 "im-details.c"
}


void im_details_tests_test_im_details_interface (ImDetailsTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp6_ = NULL;
	GValue _tmp7_ = {0};
	GValue _tmp8_ = {0};
	GValue* _tmp9_ = NULL;
	GValue* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	GValue* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	GValue _tmp14_ = {0};
	GValue _tmp15_ = {0};
	GValue* _tmp16_ = NULL;
	GValue* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	GValue* _tmp19_ = NULL;
	GValue* _tmp20_ = NULL;
	EdsTestBackend* _tmp21_ = NULL;
	GeeHashMap* _tmp22_ = NULL;
	GMainLoop* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	gboolean _tmp25_ = FALSE;
	gboolean _tmp26_ = FALSE;
#line 42 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_return_if_fail (self != NULL);
#line 44 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 44 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 44 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv->_main_loop = _tmp0_;
#line 45 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	c1 = _tmp1_;
#line 46 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 46 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_free0 (self->priv->_fullname);
#line 46 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv->_fullname = _tmp2_;
#line 47 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp3_ = g_strdup ("im_jabber_home_1#test1@example.org");
#line 47 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_free0 (self->priv->_im_addrs);
#line 47 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv->_im_addrs = _tmp3_;
#line 48 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp4_ = self->priv->_im_addrs;
#line 48 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp5_ = g_strconcat (_tmp4_, ",im_yahoo_home_1#test2@example.org", NULL);
#line 48 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_free0 (self->priv->_im_addrs);
#line 48 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv->_im_addrs = _tmp5_;
#line 51 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp6_ = ((EdsTestTestCase*) self)->eds_backend;
#line 51 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	eds_test_backend_reset (_tmp6_);
#line 53 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_value_init (&_tmp7_, G_TYPE_STRING);
#line 53 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp8_ = _tmp7_;
#line 53 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp9_ = __g_value_dup0 (&_tmp8_);
#line 53 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	__vala_GValue_free0 (v);
#line 53 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	v = _tmp9_;
#line 53 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	G_IS_VALUE (&_tmp8_) ? (g_value_unset (&_tmp8_), NULL) : NULL;
#line 54 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp10_ = v;
#line 54 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp11_ = self->priv->_fullname;
#line 54 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_value_set_string (_tmp10_, _tmp11_);
#line 55 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp12_ = v;
#line 55 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	v = NULL;
#line 55 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp13_ = _tmp12_;
#line 55 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp13_);
#line 55 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	__vala_GValue_free0 (_tmp13_);
#line 56 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_value_init (&_tmp14_, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp15_ = _tmp14_;
#line 56 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp16_ = __g_value_dup0 (&_tmp15_);
#line 56 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	__vala_GValue_free0 (v);
#line 56 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	v = _tmp16_;
#line 56 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	G_IS_VALUE (&_tmp15_) ? (g_value_unset (&_tmp15_), NULL) : NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp17_ = v;
#line 57 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp18_ = self->priv->_im_addrs;
#line 57 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_value_set_string (_tmp17_, _tmp18_);
#line 58 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp19_ = v;
#line 58 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	v = NULL;
#line 58 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp20_ = _tmp19_;
#line 58 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "im_addresses", _tmp20_);
#line 58 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	__vala_GValue_free0 (_tmp20_);
#line 60 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp21_ = ((EdsTestTestCase*) self)->eds_backend;
#line 60 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp22_ = _g_object_ref0 (c1);
#line 60 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	eds_test_backend_add_contact (_tmp21_, _tmp22_);
#line 62 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv->_num_addrs = 0;
#line 63 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv->_found_addr_1 = FALSE;
#line 64 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv->_found_addr_2 = FALSE;
#line 66 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_im_details_tests_test_im_details_interface_async (self, NULL, NULL);
#line 68 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp23_ = self->priv->_main_loop;
#line 68 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	folks_test_utils_loop_run_with_timeout (_tmp23_, 5);
#line 70 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp24_ = self->priv->_num_addrs;
#line 70 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_vala_assert (_tmp24_ == 2, "this._num_addrs == 2");
#line 71 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp25_ = self->priv->_found_addr_1;
#line 71 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_vala_assert (_tmp25_ == TRUE, "this._found_addr_1 == true");
#line 72 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp26_ = self->priv->_found_addr_2;
#line 72 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_vala_assert (_tmp26_ == TRUE, "this._found_addr_2 == true");
#line 42 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	__vala_GValue_free0 (v);
#line 42 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (c1);
#line 328 "im-details.c"
}


static void _im_details_tests_test_im_details_interface_async_data_free (gpointer _data) {
	ImDetailsTestsTestImDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_slice_free (ImDetailsTestsTestImDetailsInterfaceAsyncData, _data_);
#line 339 "im-details.c"
}


static void _im_details_tests_test_im_details_interface_async (ImDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ImDetailsTestsTestImDetailsInterfaceAsyncData* _data_;
	ImDetailsTests* _tmp0_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_ = g_slice_new0 (ImDetailsTestsTestImDetailsInterfaceAsyncData);
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _im_details_tests_test_im_details_interface_async);
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _im_details_tests_test_im_details_interface_async_data_free);
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->self = _tmp0_;
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_im_details_tests_test_im_details_interface_async_co (_data_);
#line 358 "im-details.c"
}


static void _im_details_tests_test_im_details_interface_finish (ImDetailsTests* self, GAsyncResult* _res_) {
	ImDetailsTestsTestImDetailsInterfaceAsyncData* _data_;
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 366 "im-details.c"
}


static void _im_details_tests_test_im_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ImDetailsTestsTestImDetailsInterfaceAsyncData* _data_;
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_ = _user_data_;
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_source_object_ = source_object;
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_res_ = _res_;
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_im_details_tests_test_im_details_interface_async_co (_data_);
#line 380 "im-details.c"
}


static void __im_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 83 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_im_details_tests_individuals_changed_cb ((ImDetailsTests*) self, changes);
#line 387 "im-details.c"
}


static gboolean _im_details_tests_test_im_details_interface_async_co (ImDetailsTestsTestImDetailsInterfaceAsyncData* _data_) {
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	switch (_data_->_state_) {
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		case 0:
#line 396 "im-details.c"
		goto _state_0;
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		case 1:
#line 400 "im-details.c"
		goto _state_1;
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		case 2:
#line 404 "im-details.c"
		goto _state_2;
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		case 3:
#line 408 "im-details.c"
		goto _state_3;
		default:
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		g_assert_not_reached ();
#line 413 "im-details.c"
	}
	_state_0:
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp0_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_state_ = 1;
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _im_details_tests_test_im_details_interface_async_ready, _data_);
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return FALSE;
#line 426 "im-details.c"
	_state_1:
#line 78 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 80 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp1_ = NULL;
#line 80 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 80 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->store = _data_->_tmp1_;
#line 81 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_state_ = 2;
#line 81 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	folks_backend_store_prepare (_data_->store, _im_details_tests_test_im_details_interface_async_ready, _data_);
#line 81 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return FALSE;
#line 442 "im-details.c"
	_state_2:
#line 81 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 82 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp2_ = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 82 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 82 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 83 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp3_ = NULL;
#line 83 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 83 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __im_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 460 "im-details.c"
	{
#line 87 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_tmp4_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 87 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_state_ = 3;
#line 87 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _im_details_tests_test_im_details_interface_async_ready, _data_);
#line 87 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		return FALSE;
#line 472 "im-details.c"
		_state_3:
#line 87 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 87 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 478 "im-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->e = _data_->_inner_error_;
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_inner_error_ = NULL;
#line 91 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_tmp5_ = NULL;
#line 91 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 91 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_tmp6_ = NULL;
#line 91 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 91 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		g_warning ("im-details.vala:91: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_g_error_free0 (_data_->e);
#line 501 "im-details.c"
	}
	__finally0:
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_g_object_unref0 (_data_->store);
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 85 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		return FALSE;
#line 514 "im-details.c"
	}
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (_data_->store);
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	if (_data_->_state_ == 0) {
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 522 "im-details.c"
	} else {
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 526 "im-details.c"
	}
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_object_unref (_data_->_async_result);
#line 75 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return FALSE;
#line 532 "im-details.c"
}


static void _im_details_tests_individuals_changed_cb (ImDetailsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp47_ = NULL;
	gint _tmp48_ = 0;
	gint _tmp49_ = 0;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp58_ = FALSE;
	gint _tmp59_ = 0;
#line 95 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_return_if_fail (self != NULL);
#line 95 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_return_if_fail (changes != NULL);
#line 98 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp0_ = changes;
#line 98 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 98 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	added = _tmp1_;
#line 99 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp2_ = changes;
#line 99 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 99 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	removed = _tmp3_;
#line 565 "im-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp4_ = added;
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_i_it = _tmp5_;
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		while (TRUE) {
#line 578 "im-details.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp6_ = _i_it;
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			if (!_tmp7_) {
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
				break;
#line 600 "im-details.c"
			}
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp8_ = _i_it;
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 103 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp10_ = i;
#line 103 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 105 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp11_ = i;
#line 105 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 105 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp13_ = _tmp12_;
#line 105 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 105 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			full_name = _tmp14_;
#line 106 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp15_ = full_name;
#line 106 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp16_ = self->priv->_fullname;
#line 106 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			if (g_strcmp0 (_tmp15_, _tmp16_) == 0) {
#line 628 "im-details.c"
				{
					GeeIterator* _proto_it = NULL;
					FolksIndividual* _tmp17_ = NULL;
					GeeMultiMap* _tmp18_ = NULL;
					GeeMultiMap* _tmp19_ = NULL;
					GeeSet* _tmp20_ = NULL;
					GeeSet* _tmp21_ = NULL;
					GeeIterator* _tmp22_ = NULL;
					GeeIterator* _tmp23_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_tmp17_ = i;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_tmp18_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp17_);
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_tmp19_ = _tmp18_;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_tmp20_ = gee_multi_map_get_keys (_tmp19_);
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_tmp21_ = _tmp20_;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_tmp23_ = _tmp22_;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_g_object_unref0 (_tmp21_);
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_proto_it = _tmp23_;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					while (TRUE) {
#line 658 "im-details.c"
						GeeIterator* _tmp24_ = NULL;
						gboolean _tmp25_ = FALSE;
						gchar* proto = NULL;
						GeeIterator* _tmp26_ = NULL;
						gpointer _tmp27_ = NULL;
						GeeCollection* addrs = NULL;
						FolksIndividual* _tmp28_ = NULL;
						GeeMultiMap* _tmp29_ = NULL;
						GeeMultiMap* _tmp30_ = NULL;
						const gchar* _tmp31_ = NULL;
						GeeCollection* _tmp32_ = NULL;
						const gchar* _tmp33_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp24_ = _proto_it;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp25_ = gee_iterator_next (_tmp24_);
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						if (!_tmp25_) {
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							break;
#line 679 "im-details.c"
						}
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp26_ = _proto_it;
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp27_ = gee_iterator_get (_tmp26_);
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						proto = (gchar*) _tmp27_;
#line 110 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp28_ = i;
#line 110 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp29_ = folks_im_details_get_im_addresses ((FolksImDetails*) _tmp28_);
#line 110 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp30_ = _tmp29_;
#line 110 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp31_ = proto;
#line 110 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp32_ = gee_multi_map_get (_tmp30_, _tmp31_);
#line 110 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						addrs = _tmp32_;
#line 112 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_tmp33_ = proto;
#line 112 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						if (g_strcmp0 (_tmp33_, "jabber") == 0) {
#line 703 "im-details.c"
							GeeCollection* _tmp34_ = NULL;
							FolksImFieldDetails* _tmp35_ = NULL;
							FolksImFieldDetails* _tmp36_ = NULL;
							gboolean _tmp37_ = FALSE;
							gboolean _tmp38_ = FALSE;
#line 114 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							_tmp34_ = addrs;
#line 114 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							_tmp35_ = folks_im_field_details_new ("test1@example.org", NULL);
#line 114 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							_tmp36_ = _tmp35_;
#line 114 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							_tmp37_ = gee_collection_contains (_tmp34_, _tmp36_);
#line 114 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							_tmp38_ = _tmp37_;
#line 114 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							_g_object_unref0 (_tmp36_);
#line 114 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							if (_tmp38_) {
#line 723 "im-details.c"
								gint _tmp39_ = 0;
#line 117 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								self->priv->_found_addr_1 = TRUE;
#line 118 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								_tmp39_ = self->priv->_num_addrs;
#line 118 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								self->priv->_num_addrs = _tmp39_ + 1;
#line 731 "im-details.c"
							}
						} else {
							const gchar* _tmp40_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							_tmp40_ = proto;
#line 121 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
							if (g_strcmp0 (_tmp40_, "yahoo") == 0) {
#line 739 "im-details.c"
								GeeCollection* _tmp41_ = NULL;
								FolksImFieldDetails* _tmp42_ = NULL;
								FolksImFieldDetails* _tmp43_ = NULL;
								gboolean _tmp44_ = FALSE;
								gboolean _tmp45_ = FALSE;
#line 123 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								_tmp41_ = addrs;
#line 123 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								_tmp42_ = folks_im_field_details_new ("test2@example.org", NULL);
#line 123 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								_tmp43_ = _tmp42_;
#line 123 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								_tmp44_ = gee_collection_contains (_tmp41_, _tmp43_);
#line 123 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								_tmp45_ = _tmp44_;
#line 123 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								_g_object_unref0 (_tmp43_);
#line 123 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
								if (_tmp45_) {
#line 759 "im-details.c"
									gint _tmp46_ = 0;
#line 126 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
									self->priv->_found_addr_2 = TRUE;
#line 127 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
									_tmp46_ = self->priv->_num_addrs;
#line 127 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
									self->priv->_num_addrs = _tmp46_ + 1;
#line 767 "im-details.c"
								}
							}
						}
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_g_object_unref0 (addrs);
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
						_g_free0 (proto);
#line 775 "im-details.c"
					}
#line 108 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
					_g_object_unref0 (_proto_it);
#line 779 "im-details.c"
				}
			}
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_g_free0 (full_name);
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_g_object_unref0 (i);
#line 786 "im-details.c"
		}
#line 101 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_g_object_unref0 (_i_it);
#line 790 "im-details.c"
	}
#line 134 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp47_ = removed;
#line 134 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp48_ = gee_collection_get_size ((GeeCollection*) _tmp47_);
#line 134 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp49_ = _tmp48_;
#line 134 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_vala_assert (_tmp49_ == 1, "removed.size == 1");
#line 800 "im-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp50_ = NULL;
		GeeIterator* _tmp51_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp50_ = removed;
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp51_ = gee_iterable_iterator ((GeeIterable*) _tmp50_);
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_i_it = _tmp51_;
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		while (TRUE) {
#line 813 "im-details.c"
			GeeIterator* _tmp52_ = NULL;
			gboolean _tmp53_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp54_ = NULL;
			gpointer _tmp55_ = NULL;
			FolksIndividual* _tmp56_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp52_ = _i_it;
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp53_ = gee_iterator_next (_tmp52_);
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			if (!_tmp53_) {
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
				break;
#line 828 "im-details.c"
			}
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp54_ = _i_it;
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp55_ = gee_iterator_get (_tmp54_);
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			i = (FolksIndividual*) _tmp55_;
#line 138 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_tmp56_ = i;
#line 138 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_vala_assert (_tmp56_ == NULL, "i == null");
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
			_g_object_unref0 (i);
#line 842 "im-details.c"
		}
#line 136 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_g_object_unref0 (_i_it);
#line 846 "im-details.c"
	}
#line 141 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp59_ = self->priv->_num_addrs;
#line 141 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	if (_tmp59_ == 2) {
#line 852 "im-details.c"
		gboolean _tmp60_ = FALSE;
#line 142 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp60_ = self->priv->_found_addr_1;
#line 142 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp58_ = _tmp60_ == TRUE;
#line 858 "im-details.c"
	} else {
#line 141 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp58_ = FALSE;
#line 862 "im-details.c"
	}
#line 141 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	if (_tmp58_) {
#line 866 "im-details.c"
		gboolean _tmp61_ = FALSE;
#line 143 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp61_ = self->priv->_found_addr_2;
#line 143 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp57_ = _tmp61_ == TRUE;
#line 872 "im-details.c"
	} else {
#line 141 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp57_ = FALSE;
#line 876 "im-details.c"
	}
#line 141 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	if (_tmp57_) {
#line 880 "im-details.c"
		GMainLoop* _tmp62_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		_tmp62_ = self->priv->_main_loop;
#line 144 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
		g_main_loop_quit (_tmp62_);
#line 886 "im-details.c"
	}
#line 95 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (removed);
#line 95 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (added);
#line 892 "im-details.c"
}


static void im_details_tests_class_init (ImDetailsTestsClass * klass) {
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	im_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_type_class_add_private (klass, sizeof (ImDetailsTestsPrivate));
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	G_OBJECT_CLASS (klass)->finalize = im_details_tests_finalize;
#line 903 "im-details.c"
}


static void im_details_tests_instance_init (ImDetailsTests * self) {
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self->priv = IM_DETAILS_TESTS_GET_PRIVATE (self);
#line 910 "im-details.c"
}


static void im_details_tests_finalize (GObject* obj) {
	ImDetailsTests * self;
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_IM_DETAILS_TESTS, ImDetailsTests);
#line 26 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 27 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 31 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_free0 (self->priv->_fullname);
#line 32 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_free0 (self->priv->_im_addrs);
#line 24 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	G_OBJECT_CLASS (im_details_tests_parent_class)->finalize (obj);
#line 928 "im-details.c"
}


GType im_details_tests_get_type (void) {
	static volatile gsize im_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&im_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) im_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImDetailsTests), 0, (GInstanceInitFunc) im_details_tests_instance_init, NULL };
		GType im_details_tests_type_id;
		im_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "ImDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&im_details_tests_type_id__volatile, im_details_tests_type_id);
	}
	return im_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	ImDetailsTests* tests = NULL;
	ImDetailsTests* _tmp0_ = NULL;
#line 150 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 152 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_tmp0_ = im_details_tests_new ();
#line 152 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	tests = _tmp0_;
#line 153 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 154 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	g_test_run ();
#line 155 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 157 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	result = 0;
#line 157 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	_g_object_unref0 (tests);
#line 157 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return result;
#line 966 "im-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 148 "/opt/gnome3/source/folks/tests/eds/im-details.vala"
	return _vala_main (argv, argc);
#line 976 "im-details.c"
}



