/* postal-address-details-interface.c generated by valac 0.24.0.111-cb21a, the Vala compiler
 * generated from postal-address-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS (postal_address_details_interface_tests_get_type ())
#define POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS, PostalAddressDetailsInterfaceTests))
#define POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS, PostalAddressDetailsInterfaceTestsClass))
#define IS_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS))
#define IS_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS))
#define POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS, PostalAddressDetailsInterfaceTestsClass))

typedef struct _PostalAddressDetailsInterfaceTests PostalAddressDetailsInterfaceTests;
typedef struct _PostalAddressDetailsInterfaceTestsClass PostalAddressDetailsInterfaceTestsClass;
typedef struct _PostalAddressDetailsInterfaceTestsPrivate PostalAddressDetailsInterfaceTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PostalAddressDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	PostalAddressDetailsInterfaceTestsPrivate * priv;
};

struct _PostalAddressDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _PostalAddressDetailsInterfaceTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gchar* _pobox;
	gchar* _district;
	gchar* _county;
	gchar* _locality;
	gchar* _postalcode;
	gchar* _street;
	gchar* _address;
	gchar* _extended;
	gchar* _country;
	gchar* _region;
	FolksPostalAddressFieldDetails* _postal_address_fd;
	gboolean _found_postal_address;
	gchar* _fullname;
};

struct _PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	PostalAddressDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer postal_address_details_interface_tests_parent_class = NULL;

GType postal_address_details_interface_tests_get_type (void) G_GNUC_CONST;
#define POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS, PostalAddressDetailsInterfaceTestsPrivate))
enum  {
	POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
PostalAddressDetailsInterfaceTests* postal_address_details_interface_tests_new (void);
PostalAddressDetailsInterfaceTests* postal_address_details_interface_tests_construct (GType object_type);
void postal_address_details_interface_tests_test_postal_address_details_interface (PostalAddressDetailsInterfaceTests* self);
static void _postal_address_details_interface_tests_test_postal_address_details_interface_folks_test_case_test_method (gpointer self);
static void _postal_address_details_interface_tests_test_postal_address_details_interface_async (PostalAddressDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _postal_address_details_interface_tests_test_postal_address_details_interface_finish (PostalAddressDetailsInterfaceTests* self, GAsyncResult* _res_);
static void _postal_address_details_interface_tests_test_postal_address_details_interface_async_data_free (gpointer _data);
static gboolean _postal_address_details_interface_tests_test_postal_address_details_interface_async_co (PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData* _data_);
static void _postal_address_details_interface_tests_test_postal_address_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _postal_address_details_interface_tests_individuals_changed_cb (PostalAddressDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __postal_address_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void postal_address_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _postal_address_details_interface_tests_test_postal_address_details_interface_folks_test_case_test_method (gpointer self) {
#line 48 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_address_details_interface_tests_test_postal_address_details_interface ((PostalAddressDetailsInterfaceTests*) self);
#line 124 "postal-address-details-interface.c"
}


PostalAddressDetailsInterfaceTests* postal_address_details_interface_tests_construct (GType object_type) {
	PostalAddressDetailsInterfaceTests * self = NULL;
#line 46 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self = (PostalAddressDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "PostalAddressDetailsInterfaceTests");
#line 48 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test postal address details interface", _postal_address_details_interface_tests_test_postal_address_details_interface_folks_test_case_test_method, self);
#line 44 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	return self;
#line 136 "postal-address-details-interface.c"
}


PostalAddressDetailsInterfaceTests* postal_address_details_interface_tests_new (void) {
#line 44 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	return postal_address_details_interface_tests_construct (TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS);
#line 143 "postal-address-details-interface.c"
}


void postal_address_details_interface_tests_test_postal_address_details_interface (PostalAddressDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	FolksPostalAddress* pa = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	FolksPostalAddress* _tmp11_ = NULL;
	FolksPostalAddressFieldDetails* _tmp12_ = NULL;
	gchar* postal_info = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	const gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	const gchar* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
	gchar* _tmp37_ = NULL;
	gchar* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	const gchar* _tmp40_ = NULL;
	const gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	gchar* _tmp44_ = NULL;
	const gchar* _tmp45_ = NULL;
	const gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	const gchar* _tmp50_ = NULL;
	const gchar* _tmp51_ = NULL;
	gchar* _tmp52_ = NULL;
	gchar* _tmp53_ = NULL;
	gchar* _tmp54_ = NULL;
	const gchar* _tmp55_ = NULL;
	const gchar* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	const gchar* _tmp58_ = NULL;
	TrackerTestBackend* _tmp59_ = NULL;
	TrackerTestBackend* _tmp60_ = NULL;
	GMainLoop* _tmp61_ = NULL;
	gboolean _tmp62_ = FALSE;
#line 52 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 54 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 54 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 54 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 55 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 55 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	c1 = _tmp1_;
#line 56 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp2_ = g_strdup ("persona #1");
#line 56 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_fullname);
#line 56 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_fullname = _tmp2_;
#line 57 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp3_ = self->priv->_fullname;
#line 57 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, _tmp3_);
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp4_ = self->priv->_pobox;
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp5_ = self->priv->_extended;
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp6_ = self->priv->_street;
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp7_ = self->priv->_locality;
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp8_ = self->priv->_region;
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp9_ = self->priv->_postalcode;
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp10_ = self->priv->_country;
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp11_ = folks_postal_address_new (_tmp4_, _tmp5_, _tmp6_, _tmp7_, _tmp8_, _tmp9_, _tmp10_, NULL, "tracker_id");
#line 59 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	pa = _tmp11_;
#line 68 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp12_ = folks_postal_address_field_details_new (pa, NULL);
#line 68 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (self->priv->_postal_address_fd);
#line 68 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_postal_address_fd = _tmp12_;
#line 73 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp13_ = self->priv->_pobox;
#line 73 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp14_ = g_strconcat (_tmp13_, ":", NULL);
#line 73 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp14_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp15_ = postal_info;
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp16_ = self->priv->_district;
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp17_ = g_strconcat (_tmp16_, ":", NULL);
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp18_ = _tmp17_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp19_ = g_strconcat (_tmp15_, _tmp18_, NULL);
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp19_;
#line 74 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp18_);
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp20_ = postal_info;
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp21_ = self->priv->_county;
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp22_ = g_strconcat (_tmp21_, ":", NULL);
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp23_ = _tmp22_;
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp24_ = g_strconcat (_tmp20_, _tmp23_, NULL);
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp24_;
#line 75 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp23_);
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp25_ = postal_info;
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp26_ = self->priv->_locality;
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp27_ = g_strconcat (_tmp26_, ":", NULL);
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp28_ = _tmp27_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp29_ = g_strconcat (_tmp25_, _tmp28_, NULL);
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp29_;
#line 76 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp28_);
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp30_ = postal_info;
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp31_ = self->priv->_postalcode;
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp32_ = g_strconcat (_tmp31_, ":", NULL);
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp33_ = _tmp32_;
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp34_ = g_strconcat (_tmp30_, _tmp33_, NULL);
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp34_;
#line 77 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp33_);
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp35_ = postal_info;
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp36_ = self->priv->_street;
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp37_ = g_strconcat (_tmp36_, ":", NULL);
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp38_ = _tmp37_;
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp39_ = g_strconcat (_tmp35_, _tmp38_, NULL);
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp39_;
#line 78 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp38_);
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp40_ = postal_info;
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp41_ = self->priv->_address;
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp42_ = g_strconcat (_tmp41_, ":", NULL);
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp43_ = _tmp42_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp44_ = g_strconcat (_tmp40_, _tmp43_, NULL);
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp44_;
#line 79 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp43_);
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp45_ = postal_info;
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp46_ = self->priv->_extended;
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp47_ = g_strconcat (_tmp46_, ":", NULL);
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp48_ = _tmp47_;
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp49_ = g_strconcat (_tmp45_, _tmp48_, NULL);
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp49_;
#line 80 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp48_);
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp50_ = postal_info;
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp51_ = self->priv->_country;
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp52_ = g_strconcat (_tmp51_, ":", NULL);
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp53_ = _tmp52_;
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp54_ = g_strconcat (_tmp50_, _tmp53_, NULL);
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp54_;
#line 81 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (_tmp53_);
#line 82 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp55_ = postal_info;
#line 82 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp56_ = self->priv->_region;
#line 82 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp57_ = g_strconcat (_tmp55_, _tmp56_, NULL);
#line 82 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 82 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_info = _tmp57_;
#line 84 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp58_ = postal_info;
#line 84 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_POSTAL_ADDRESS, _tmp58_);
#line 85 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp59_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 85 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 86 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp60_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 86 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 88 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_found_postal_address = FALSE;
#line 90 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_postal_address_details_interface_tests_test_postal_address_details_interface_async (self, NULL, NULL);
#line 92 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp61_ = self->priv->_main_loop;
#line 92 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp61_, 5);
#line 94 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp62_ = self->priv->_found_postal_address;
#line 94 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_vala_assert (_tmp62_ == TRUE, "this._found_postal_address == true");
#line 52 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (postal_info);
#line 52 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (pa);
#line 52 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (c1);
#line 434 "postal-address-details-interface.c"
}


static void _postal_address_details_interface_tests_test_postal_address_details_interface_async_data_free (gpointer _data) {
	PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_slice_free (PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData, _data_);
#line 445 "postal-address-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 452 "postal-address-details-interface.c"
}


static void _postal_address_details_interface_tests_test_postal_address_details_interface_async (PostalAddressDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
	PostalAddressDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_ = g_slice_new0 (PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _postal_address_details_interface_tests_test_postal_address_details_interface_async);
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _postal_address_details_interface_tests_test_postal_address_details_interface_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_postal_address_details_interface_tests_test_postal_address_details_interface_async_co (_data_);
#line 471 "postal-address-details-interface.c"
}


static void _postal_address_details_interface_tests_test_postal_address_details_interface_finish (PostalAddressDetailsInterfaceTests* self, GAsyncResult* _res_) {
	PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 479 "postal-address-details-interface.c"
}


static void _postal_address_details_interface_tests_test_postal_address_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData* _data_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_ = _user_data_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_res_ = _res_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_postal_address_details_interface_tests_test_postal_address_details_interface_async_co (_data_);
#line 493 "postal-address-details-interface.c"
}


static void __postal_address_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 102 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_postal_address_details_interface_tests_individuals_changed_cb ((PostalAddressDetailsInterfaceTests*) self, changes);
#line 500 "postal-address-details-interface.c"
}


static gboolean _postal_address_details_interface_tests_test_postal_address_details_interface_async_co (PostalAddressDetailsInterfaceTestsTestPostalAddressDetailsInterfaceAsyncData* _data_) {
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	switch (_data_->_state_) {
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		case 0:
#line 509 "postal-address-details-interface.c"
		goto _state_0;
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		case 1:
#line 513 "postal-address-details-interface.c"
		goto _state_1;
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		case 2:
#line 517 "postal-address-details-interface.c"
		goto _state_2;
		default:
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		g_assert_not_reached ();
#line 522 "postal-address-details-interface.c"
	}
	_state_0:
#line 99 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 99 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_state_ = 1;
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	folks_backend_store_prepare (_data_->store, _postal_address_details_interface_tests_test_postal_address_details_interface_async_ready, _data_);
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	return FALSE;
#line 537 "postal-address-details-interface.c"
	_state_1:
#line 100 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 101 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 101 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 101 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 101 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 102 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 102 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 102 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __postal_address_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 555 "postal-address-details-interface.c"
	{
#line 106 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 106 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_state_ = 2;
#line 106 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _postal_address_details_interface_tests_test_postal_address_details_interface_async_ready, _data_);
#line 106 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		return FALSE;
#line 567 "postal-address-details-interface.c"
		_state_2:
#line 106 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 106 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 573 "postal-address-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 110 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 110 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		g_warning ("postal-address-details-interface.vala:110: Error when calling prepare:" \
" %s\n", _data_->_tmp5_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 596 "postal-address-details-interface.c"
	}
	__finally0:
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 104 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		return FALSE;
#line 609 "postal-address-details-interface.c"
	}
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 617 "postal-address-details-interface.c"
	} else {
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 621 "postal-address-details-interface.c"
	}
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 97 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	return FALSE;
#line 627 "postal-address-details-interface.c"
}


static void _postal_address_details_interface_tests_individuals_changed_cb (PostalAddressDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp85_ = NULL;
	gint _tmp86_ = 0;
	gint _tmp87_ = 0;
#line 115 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 115 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 118 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp0_ = changes;
#line 118 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 118 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	added = _tmp1_;
#line 119 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp2_ = changes;
#line 119 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 119 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	removed = _tmp3_;
#line 657 "postal-address-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_tmp4_ = added;
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_i_it = _tmp5_;
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		while (TRUE) {
#line 670 "postal-address-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp6_ = _i_it;
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			if (!_tmp7_) {
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
				break;
#line 689 "postal-address-details-interface.c"
			}
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp8_ = _i_it;
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 123 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp10_ = i;
#line 123 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 125 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp11_ = i;
#line 125 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 125 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 125 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp14_ = self->priv->_fullname;
#line 125 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 711 "postal-address-details-interface.c"
				{
					GeeIterator* _pafd_it = NULL;
					FolksIndividual* _tmp15_ = NULL;
					GeeSet* _tmp16_ = NULL;
					GeeSet* _tmp17_ = NULL;
					GeeIterator* _tmp18_ = NULL;
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
					_tmp15_ = i;
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
					_tmp16_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp15_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
					_tmp17_ = _tmp16_;
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
					_tmp18_ = gee_iterable_iterator ((GeeIterable*) _tmp17_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
					_pafd_it = _tmp18_;
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
					while (TRUE) {
#line 730 "postal-address-details-interface.c"
						GeeIterator* _tmp19_ = NULL;
						gboolean _tmp20_ = FALSE;
						FolksPostalAddressFieldDetails* pafd = NULL;
						GeeIterator* _tmp21_ = NULL;
						gpointer _tmp22_ = NULL;
						FolksPostalAddressFieldDetails* _tmp23_ = NULL;
						FolksPostalAddressFieldDetails* _tmp24_ = NULL;
						const gchar* _tmp25_ = NULL;
						const gchar* _tmp26_ = NULL;
						FolksPostalAddressFieldDetails* _tmp27_ = NULL;
						gconstpointer _tmp28_ = NULL;
						FolksPostalAddress* _tmp29_ = NULL;
						FolksPostalAddressFieldDetails* _tmp30_ = NULL;
						gconstpointer _tmp31_ = NULL;
						FolksPostalAddress* _tmp32_ = NULL;
						gboolean _tmp33_ = FALSE;
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp19_ = _pafd_it;
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp20_ = gee_iterator_next (_tmp19_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						if (!_tmp20_) {
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							break;
#line 755 "postal-address-details-interface.c"
						}
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp21_ = _pafd_it;
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp22_ = gee_iterator_get (_tmp21_);
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						pafd = (FolksPostalAddressFieldDetails*) _tmp22_;
#line 133 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp23_ = self->priv->_postal_address_fd;
#line 133 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp24_ = pafd;
#line 133 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp25_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp24_);
#line 133 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp26_ = _tmp25_;
#line 133 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _tmp23_, _tmp26_);
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp27_ = pafd;
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp28_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp27_);
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp29_ = _tmp28_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp30_ = self->priv->_postal_address_fd;
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp31_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp30_);
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp32_ = _tmp31_;
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_tmp33_ = folks_postal_address_equal ((FolksPostalAddress*) _tmp29_, (FolksPostalAddress*) _tmp32_);
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						if (_tmp33_) {
#line 789 "postal-address-details-interface.c"
							FolksPostalAddress* pa_2 = NULL;
							FolksPostalAddressFieldDetails* _tmp34_ = NULL;
							gconstpointer _tmp35_ = NULL;
							FolksPostalAddress* _tmp36_ = NULL;
							const gchar* _tmp37_ = NULL;
							const gchar* _tmp38_ = NULL;
							FolksPostalAddressFieldDetails* _tmp39_ = NULL;
							gconstpointer _tmp40_ = NULL;
							FolksPostalAddress* _tmp41_ = NULL;
							const gchar* _tmp42_ = NULL;
							const gchar* _tmp43_ = NULL;
							FolksPostalAddressFieldDetails* _tmp44_ = NULL;
							gconstpointer _tmp45_ = NULL;
							FolksPostalAddress* _tmp46_ = NULL;
							const gchar* _tmp47_ = NULL;
							const gchar* _tmp48_ = NULL;
							FolksPostalAddressFieldDetails* _tmp49_ = NULL;
							gconstpointer _tmp50_ = NULL;
							FolksPostalAddress* _tmp51_ = NULL;
							const gchar* _tmp52_ = NULL;
							const gchar* _tmp53_ = NULL;
							FolksPostalAddressFieldDetails* _tmp54_ = NULL;
							gconstpointer _tmp55_ = NULL;
							FolksPostalAddress* _tmp56_ = NULL;
							const gchar* _tmp57_ = NULL;
							const gchar* _tmp58_ = NULL;
							FolksPostalAddressFieldDetails* _tmp59_ = NULL;
							gconstpointer _tmp60_ = NULL;
							FolksPostalAddress* _tmp61_ = NULL;
							const gchar* _tmp62_ = NULL;
							const gchar* _tmp63_ = NULL;
							FolksPostalAddressFieldDetails* _tmp64_ = NULL;
							gconstpointer _tmp65_ = NULL;
							FolksPostalAddress* _tmp66_ = NULL;
							const gchar* _tmp67_ = NULL;
							const gchar* _tmp68_ = NULL;
							FolksPostalAddressFieldDetails* _tmp69_ = NULL;
							const gchar* _tmp70_ = NULL;
							const gchar* _tmp71_ = NULL;
							FolksPostalAddress* _tmp72_ = NULL;
							FolksPostalAddressFieldDetails* pa_fd_2 = NULL;
							FolksPostalAddress* _tmp73_ = NULL;
							FolksPostalAddressFieldDetails* _tmp74_ = NULL;
							FolksPostalAddressFieldDetails* _tmp75_ = NULL;
							FolksPostalAddressFieldDetails* _tmp76_ = NULL;
							gboolean _tmp77_ = FALSE;
							FolksPostalAddressFieldDetails* _tmp78_ = NULL;
							const gchar* _tmp79_ = NULL;
							const gchar* _tmp80_ = NULL;
							FolksPostalAddressFieldDetails* _tmp81_ = NULL;
							const gchar* _tmp82_ = NULL;
							const gchar* _tmp83_ = NULL;
							GMainLoop* _tmp84_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp34_ = self->priv->_postal_address_fd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp35_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp34_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp36_ = _tmp35_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp37_ = folks_postal_address_get_po_box ((FolksPostalAddress*) _tmp36_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp38_ = _tmp37_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp39_ = self->priv->_postal_address_fd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp40_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp39_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp41_ = _tmp40_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp42_ = folks_postal_address_get_extension ((FolksPostalAddress*) _tmp41_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp43_ = _tmp42_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp44_ = self->priv->_postal_address_fd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp45_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp44_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp46_ = _tmp45_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp47_ = folks_postal_address_get_street ((FolksPostalAddress*) _tmp46_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp48_ = _tmp47_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp49_ = self->priv->_postal_address_fd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp50_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp49_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp51_ = _tmp50_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp52_ = folks_postal_address_get_locality ((FolksPostalAddress*) _tmp51_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp53_ = _tmp52_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp54_ = self->priv->_postal_address_fd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp55_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp54_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp56_ = _tmp55_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp57_ = folks_postal_address_get_region ((FolksPostalAddress*) _tmp56_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp58_ = _tmp57_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp59_ = self->priv->_postal_address_fd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp60_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp59_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp61_ = _tmp60_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp62_ = folks_postal_address_get_postal_code ((FolksPostalAddress*) _tmp61_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp63_ = _tmp62_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp64_ = self->priv->_postal_address_fd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp65_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp64_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp66_ = _tmp65_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp67_ = folks_postal_address_get_country ((FolksPostalAddress*) _tmp66_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp68_ = _tmp67_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp69_ = pafd;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp70_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp69_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp71_ = _tmp70_;
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp72_ = folks_postal_address_new (_tmp38_, _tmp43_, _tmp48_, _tmp53_, _tmp58_, _tmp63_, _tmp68_, NULL, _tmp71_);
#line 140 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							pa_2 = _tmp72_;
#line 150 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp73_ = pa_2;
#line 150 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp74_ = folks_postal_address_field_details_new (_tmp73_, NULL);
#line 150 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							pa_fd_2 = _tmp74_;
#line 151 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp75_ = pafd;
#line 151 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp76_ = pa_fd_2;
#line 151 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp77_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp75_, (FolksAbstractFieldDetails*) _tmp76_);
#line 151 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_vala_assert (_tmp77_, "pafd.equal (pa_fd_2)");
#line 152 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp78_ = pafd;
#line 152 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp79_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp78_);
#line 152 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp80_ = _tmp79_;
#line 152 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp81_ = pa_fd_2;
#line 152 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp82_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp81_);
#line 152 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp83_ = _tmp82_;
#line 152 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_vala_assert (g_strcmp0 (_tmp80_, _tmp83_) == 0, "pafd.id == pa_fd_2.id");
#line 154 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							self->priv->_found_postal_address = TRUE;
#line 155 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_tmp84_ = self->priv->_main_loop;
#line 155 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							g_main_loop_quit (_tmp84_);
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_g_object_unref0 (pa_fd_2);
#line 135 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
							_g_object_unref0 (pa_2);
#line 961 "postal-address-details-interface.c"
						}
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
						_g_object_unref0 (pafd);
#line 965 "postal-address-details-interface.c"
					}
#line 127 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
					_g_object_unref0 (_pafd_it);
#line 969 "postal-address-details-interface.c"
				}
			}
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_g_object_unref0 (i);
#line 974 "postal-address-details-interface.c"
		}
#line 121 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 978 "postal-address-details-interface.c"
	}
#line 161 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp85_ = removed;
#line 161 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp86_ = gee_collection_get_size ((GeeCollection*) _tmp85_);
#line 161 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp87_ = _tmp86_;
#line 161 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_vala_assert (_tmp87_ == 1, "removed.size == 1");
#line 988 "postal-address-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp88_ = NULL;
		GeeIterator* _tmp89_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_tmp88_ = removed;
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_tmp89_ = gee_iterable_iterator ((GeeIterable*) _tmp88_);
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_i_it = _tmp89_;
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		while (TRUE) {
#line 1001 "postal-address-details-interface.c"
			GeeIterator* _tmp90_ = NULL;
			gboolean _tmp91_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp92_ = NULL;
			gpointer _tmp93_ = NULL;
			FolksIndividual* _tmp94_ = NULL;
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp90_ = _i_it;
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp91_ = gee_iterator_next (_tmp90_);
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			if (!_tmp91_) {
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
				break;
#line 1016 "postal-address-details-interface.c"
			}
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp92_ = _i_it;
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp93_ = gee_iterator_get (_tmp92_);
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			i = (FolksIndividual*) _tmp93_;
#line 165 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_tmp94_ = i;
#line 165 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_vala_assert (_tmp94_ == NULL, "i == null");
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
			_g_object_unref0 (i);
#line 1030 "postal-address-details-interface.c"
		}
#line 163 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 1034 "postal-address-details-interface.c"
	}
#line 115 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (removed);
#line 115 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (added);
#line 1040 "postal-address-details-interface.c"
}


static void postal_address_details_interface_tests_class_init (PostalAddressDetailsInterfaceTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	postal_address_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_type_class_add_private (klass, sizeof (PostalAddressDetailsInterfaceTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = postal_address_details_interface_tests_finalize;
#line 1051 "postal-address-details-interface.c"
}


static void postal_address_details_interface_tests_instance_init (PostalAddressDetailsInterfaceTests * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv = POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 30 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp0_ = g_strdup ("12345");
#line 30 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_pobox = _tmp0_;
#line 31 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp1_ = g_strdup ("example district");
#line 31 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_district = _tmp1_;
#line 32 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp2_ = g_strdup ("example country");
#line 32 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_county = _tmp2_;
#line 33 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp3_ = g_strdup ("example locality");
#line 33 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_locality = _tmp3_;
#line 34 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp4_ = g_strdup ("example postalcode");
#line 34 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_postalcode = _tmp4_;
#line 35 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp5_ = g_strdup ("example street");
#line 35 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_street = _tmp5_;
#line 36 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp6_ = g_strdup ("example address");
#line 36 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_address = _tmp6_;
#line 37 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp7_ = g_strdup ("example extended address");
#line 37 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_extended = _tmp7_;
#line 38 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp8_ = g_strdup ("example country");
#line 38 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_country = _tmp8_;
#line 39 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp9_ = g_strdup ("example region");
#line 39 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self->priv->_region = _tmp9_;
#line 1108 "postal-address-details-interface.c"
}


static void postal_address_details_interface_tests_finalize (GObject* obj) {
	PostalAddressDetailsInterfaceTests * self;
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_POSTAL_ADDRESS_DETAILS_INTERFACE_TESTS, PostalAddressDetailsInterfaceTests);
#line 28 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_pobox);
#line 31 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_district);
#line 32 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_county);
#line 33 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_locality);
#line 34 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_postalcode);
#line 35 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_street);
#line 36 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_address);
#line 37 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_extended);
#line 38 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_country);
#line 39 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_region);
#line 40 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (self->priv->_postal_address_fd);
#line 42 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_free0 (self->priv->_fullname);
#line 26 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	G_OBJECT_CLASS (postal_address_details_interface_tests_parent_class)->finalize (obj);
#line 1146 "postal-address-details-interface.c"
}


GType postal_address_details_interface_tests_get_type (void) {
	static volatile gsize postal_address_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&postal_address_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PostalAddressDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) postal_address_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PostalAddressDetailsInterfaceTests), 0, (GInstanceInitFunc) postal_address_details_interface_tests_instance_init, NULL };
		GType postal_address_details_interface_tests_type_id;
		postal_address_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "PostalAddressDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&postal_address_details_interface_tests_type_id__volatile, postal_address_details_interface_tests_type_id);
	}
	return postal_address_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PostalAddressDetailsInterfaceTests* tests = NULL;
	PostalAddressDetailsInterfaceTests* _tmp0_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 174 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_tmp0_ = postal_address_details_interface_tests_new ();
#line 174 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	tests = _tmp0_;
#line 175 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 176 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	g_test_run ();
#line 177 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 179 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	result = 0;
#line 179 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	_g_object_unref0 (tests);
#line 179 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	return result;
#line 1184 "postal-address-details-interface.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 170 "/opt/gnome3/source/folks/tests/tracker/postal-address-details-interface.vala"
	return _vala_main (argv, argc);
#line 1194 "postal-address-details-interface.c"
}



