/* test-case.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from test-case.vala, do not modify */

/* test-case.vala
 *
 * Copyright © 2011 Collabora Ltd.
 * Copyright © 2013 Intel Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Authors:
 *      Alban Crequy <alban.crequy@collabora.co.uk>
 *      Simon McVittie <simon.mcvittie@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <stdlib.h>
#include <string.h>


#define LIBSOCIALWEB_TEST_TYPE_TEST_CASE (libsocialweb_test_test_case_get_type ())
#define LIBSOCIALWEB_TEST_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_TEST_CASE, LibsocialwebTestTestCase))
#define LIBSOCIALWEB_TEST_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBSOCIALWEB_TEST_TYPE_TEST_CASE, LibsocialwebTestTestCaseClass))
#define LIBSOCIALWEB_TEST_IS_TEST_CASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_TEST_CASE))
#define LIBSOCIALWEB_TEST_IS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBSOCIALWEB_TEST_TYPE_TEST_CASE))
#define LIBSOCIALWEB_TEST_TEST_CASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBSOCIALWEB_TEST_TYPE_TEST_CASE, LibsocialwebTestTestCaseClass))

typedef struct _LibsocialwebTestTestCase LibsocialwebTestTestCase;
typedef struct _LibsocialwebTestTestCaseClass LibsocialwebTestTestCaseClass;
typedef struct _LibsocialwebTestTestCasePrivate LibsocialwebTestTestCasePrivate;

#define LIBSOCIALWEB_TEST_TYPE_BACKEND (libsocialweb_test_backend_get_type ())
#define LIBSOCIALWEB_TEST_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackend))
#define LIBSOCIALWEB_TEST_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackendClass))
#define LIBSOCIALWEB_TEST_IS_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBSOCIALWEB_TEST_TYPE_BACKEND))
#define LIBSOCIALWEB_TEST_IS_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBSOCIALWEB_TEST_TYPE_BACKEND))
#define LIBSOCIALWEB_TEST_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackendClass))

typedef struct _LibsocialwebTestBackend LibsocialwebTestBackend;
typedef struct _LibsocialwebTestBackendClass LibsocialwebTestBackendClass;
#define _libsocialweb_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (libsocialweb_test_backend_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_context_unref0(var) ((var == NULL) ? NULL : (var = (g_main_context_unref (var), NULL)))

struct _LibsocialwebTestTestCase {
	FolksTestCase parent_instance;
	LibsocialwebTestTestCasePrivate * priv;
	LibsocialwebTestBackend* lsw_backend;
};

struct _LibsocialwebTestTestCaseClass {
	FolksTestCaseClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	LibsocialwebTestTestCase* self;
	GMainLoop* main_loop;
};


static gpointer libsocialweb_test_test_case_parent_class = NULL;

GType libsocialweb_test_test_case_get_type (void) G_GNUC_CONST;
gpointer libsocialweb_test_backend_ref (gpointer instance);
void libsocialweb_test_backend_unref (gpointer instance);
GParamSpec* libsocialweb_test_param_spec_backend (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void libsocialweb_test_value_set_backend (GValue* value, gpointer v_object);
void libsocialweb_test_value_take_backend (GValue* value, gpointer v_object);
gpointer libsocialweb_test_value_get_backend (const GValue* value);
GType libsocialweb_test_backend_get_type (void) G_GNUC_CONST;
enum  {
	LIBSOCIALWEB_TEST_TEST_CASE_DUMMY_PROPERTY,
	LIBSOCIALWEB_TEST_TEST_CASE_USES_DBUS_1
};
LibsocialwebTestTestCase* libsocialweb_test_test_case_new (const gchar* name);
LibsocialwebTestTestCase* libsocialweb_test_test_case_construct (GType object_type, const gchar* name);
static void libsocialweb_test_test_case_real_set_up (FolksTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
LibsocialwebTestBackend* libsocialweb_test_backend_new (void);
LibsocialwebTestBackend* libsocialweb_test_backend_construct (GType object_type);
static void __lambda6_ (Block1Data* _data1_);
static void ___lambda6__libsocialweb_test_backend_ready (LibsocialwebTestBackend* _sender, gpointer self);
void libsocialweb_test_backend_set_up (LibsocialwebTestBackend* self);
static void libsocialweb_test_test_case_real_tear_down (FolksTestCase* base);
void libsocialweb_test_backend_tear_down (LibsocialwebTestBackend* self);
static void libsocialweb_test_test_case_finalize (GObject* obj);
static void _vala_libsocialweb_test_test_case_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


LibsocialwebTestTestCase* libsocialweb_test_test_case_construct (GType object_type, const gchar* name) {
	LibsocialwebTestTestCase * self = NULL;
	const gchar* _tmp0_ = NULL;
#line 40 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 42 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp0_ = name;
#line 42 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self = (LibsocialwebTestTestCase*) folks_test_case_construct (object_type, _tmp0_);
#line 44 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	g_setenv ("FOLKS_BACKENDS_ALLOWED", "libsocialweb", TRUE);
#line 45 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	g_setenv ("FOLKS_PRIMARY_STORE", "", TRUE);
#line 40 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	return self;
#line 124 "test-case.c"
}


LibsocialwebTestTestCase* libsocialweb_test_test_case_new (const gchar* name) {
#line 40 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	return libsocialweb_test_test_case_construct (LIBSOCIALWEB_TEST_TYPE_TEST_CASE, name);
#line 131 "test-case.c"
}


/**
   * Set up the libsocialweb test backend and wait for it to become ready.
   */
static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	return _data1_;
#line 143 "test-case.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 152 "test-case.c"
		LibsocialwebTestTestCase* self;
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		self = _data1_->self;
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		_g_main_loop_unref0 (_data1_->main_loop);
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		_g_object_unref0 (self);
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		g_slice_free (Block1Data, _data1_);
#line 162 "test-case.c"
	}
}


static gpointer _libsocialweb_test_backend_ref0 (gpointer self) {
#line 68 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	return self ? libsocialweb_test_backend_ref (self) : NULL;
#line 170 "test-case.c"
}


static void __lambda6_ (Block1Data* _data1_) {
	LibsocialwebTestTestCase* self;
#line 72 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self = _data1_->self;
#line 74 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	g_main_loop_quit (_data1_->main_loop);
#line 180 "test-case.c"
}


static void ___lambda6__libsocialweb_test_backend_ready (LibsocialwebTestBackend* _sender, gpointer self) {
#line 72 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	__lambda6_ (self);
#line 187 "test-case.c"
}


static void libsocialweb_test_test_case_real_set_up (FolksTestCase* base) {
	LibsocialwebTestTestCase * self;
	Block1Data* _data1_;
	LibsocialwebTestBackend* _tmp0_ = NULL;
	LibsocialwebTestBackend* lsw_backend = NULL;
	LibsocialwebTestBackend* _tmp1_ = NULL;
	LibsocialwebTestBackend* _tmp2_ = NULL;
	GMainLoop* _tmp3_ = NULL;
	LibsocialwebTestBackend* _tmp4_ = NULL;
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self = (LibsocialwebTestTestCase*) base;
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_data1_->_ref_count_ = 1;
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_data1_->self = g_object_ref (self);
#line 64 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	FOLKS_TEST_CASE_CLASS (libsocialweb_test_test_case_parent_class)->set_up (G_TYPE_CHECK_INSTANCE_CAST (self, FOLKS_TYPE_TEST_CASE, FolksTestCase));
#line 66 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp0_ = libsocialweb_test_backend_new ();
#line 66 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_libsocialweb_test_backend_unref0 (self->lsw_backend);
#line 66 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self->lsw_backend = _tmp0_;
#line 68 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp1_ = self->lsw_backend;
#line 68 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp2_ = _libsocialweb_test_backend_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackend));
#line 68 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	lsw_backend = _tmp2_;
#line 70 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp3_ = g_main_loop_new (NULL, FALSE);
#line 70 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_data1_->main_loop = _tmp3_;
#line 72 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp4_ = self->lsw_backend;
#line 72 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	g_signal_connect_data (_tmp4_, "ready", (GCallback) ___lambda6__libsocialweb_test_backend_ready, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 77 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	libsocialweb_test_backend_set_up (lsw_backend);
#line 78 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	folks_test_utils_loop_run_with_timeout (_data1_->main_loop, 5);
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_libsocialweb_test_backend_unref0 (lsw_backend);
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	block1_data_unref (_data1_);
#line 62 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_data1_ = NULL;
#line 240 "test-case.c"
}


static gpointer _g_main_context_ref0 (gpointer self) {
#line 95 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	return self ? g_main_context_ref (self) : NULL;
#line 247 "test-case.c"
}


static void libsocialweb_test_test_case_real_tear_down (FolksTestCase* base) {
	LibsocialwebTestTestCase * self;
	LibsocialwebTestBackend* _tmp0_ = NULL;
	GMainContext* context = NULL;
	GMainContext* _tmp2_ = NULL;
	GMainContext* _tmp3_ = NULL;
#line 81 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self = (LibsocialwebTestTestCase*) base;
#line 83 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp0_ = self->lsw_backend;
#line 83 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	if (_tmp0_ != NULL) {
#line 263 "test-case.c"
		LibsocialwebTestBackend* _tmp1_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		_tmp1_ = self->lsw_backend;
#line 85 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		libsocialweb_test_backend_tear_down (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, LIBSOCIALWEB_TEST_TYPE_BACKEND, LibsocialwebTestBackend));
#line 86 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		_libsocialweb_test_backend_unref0 (self->lsw_backend);
#line 86 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		self->lsw_backend = NULL;
#line 273 "test-case.c"
	}
#line 95 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp2_ = g_main_context_default ();
#line 95 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_tmp3_ = _g_main_context_ref0 (_tmp2_);
#line 95 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	context = _tmp3_;
#line 96 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	while (TRUE) {
#line 283 "test-case.c"
		GMainContext* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
#line 96 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		_tmp4_ = context;
#line 96 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		_tmp5_ = g_main_context_iteration (_tmp4_, FALSE);
#line 96 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		if (!_tmp5_) {
#line 96 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
			break;
#line 294 "test-case.c"
		}
	}
#line 98 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	FOLKS_TEST_CASE_CLASS (libsocialweb_test_test_case_parent_class)->tear_down (G_TYPE_CHECK_INSTANCE_CAST (self, FOLKS_TYPE_TEST_CASE, FolksTestCase));
#line 81 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_g_main_context_unref0 (context);
#line 301 "test-case.c"
}


static gboolean libsocialweb_test_test_case_real_get_uses_dbus_1 (FolksTestCase* base) {
	gboolean result;
	LibsocialwebTestTestCase* self;
#line 53 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self = (LibsocialwebTestTestCase*) base;
#line 55 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	result = TRUE;
#line 55 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	return result;
#line 314 "test-case.c"
}


static void libsocialweb_test_test_case_class_init (LibsocialwebTestTestCaseClass * klass) {
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	libsocialweb_test_test_case_parent_class = g_type_class_peek_parent (klass);
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = libsocialweb_test_test_case_real_set_up;
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = libsocialweb_test_test_case_real_tear_down;
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	FOLKS_TEST_CASE_CLASS (klass)->get_uses_dbus_1 = libsocialweb_test_test_case_real_get_uses_dbus_1;
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_libsocialweb_test_test_case_get_property;
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	G_OBJECT_CLASS (klass)->finalize = libsocialweb_test_test_case_finalize;
#line 331 "test-case.c"
	/**
	   * This test does use libdbus, via libsocialweb.
	   */
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), LIBSOCIALWEB_TEST_TEST_CASE_USES_DBUS_1, g_param_spec_boolean ("uses-dbus-1", "uses-dbus-1", "uses-dbus-1", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 337 "test-case.c"
}


static void libsocialweb_test_test_case_instance_init (LibsocialwebTestTestCase * self) {
#line 38 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self->lsw_backend = NULL;
#line 344 "test-case.c"
}


static void libsocialweb_test_test_case_finalize (GObject* obj) {
	LibsocialwebTestTestCase * self;
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBSOCIALWEB_TEST_TYPE_TEST_CASE, LibsocialwebTestTestCase);
#line 38 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	_libsocialweb_test_backend_unref0 (self->lsw_backend);
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	G_OBJECT_CLASS (libsocialweb_test_test_case_parent_class)->finalize (obj);
#line 356 "test-case.c"
}


/**
 * A test case for the libsocialweb backend. Folks is configured
 * to use that backend and no others, with no primary store.
 */
GType libsocialweb_test_test_case_get_type (void) {
	static volatile gsize libsocialweb_test_test_case_type_id__volatile = 0;
	if (g_once_init_enter (&libsocialweb_test_test_case_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibsocialwebTestTestCaseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) libsocialweb_test_test_case_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibsocialwebTestTestCase), 0, (GInstanceInitFunc) libsocialweb_test_test_case_instance_init, NULL };
		GType libsocialweb_test_test_case_type_id;
		libsocialweb_test_test_case_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "LibsocialwebTestTestCase", &g_define_type_info, 0);
		g_once_init_leave (&libsocialweb_test_test_case_type_id__volatile, libsocialweb_test_test_case_type_id);
	}
	return libsocialweb_test_test_case_type_id__volatile;
}


static void _vala_libsocialweb_test_test_case_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	LibsocialwebTestTestCase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, LIBSOCIALWEB_TEST_TYPE_TEST_CASE, LibsocialwebTestTestCase);
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
	switch (property_id) {
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		case LIBSOCIALWEB_TEST_TEST_CASE_USES_DBUS_1:
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		g_value_set_boolean (value, folks_test_case_get_uses_dbus_1 ((FolksTestCase*) self));
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		break;
#line 387 "test-case.c"
		default:
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 29 "/opt/gnome3/source/folks/tests/lib/libsocialweb/test-case.vala"
		break;
#line 393 "test-case.c"
	}
}



