/* linkable-properties.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from linkable-properties.vala, do not modify */

/*
 * Copyright (C) 2012 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Travis Reitter <travis.reitter@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_LINKABLE_PROPERTIES_TESTS (linkable_properties_tests_get_type ())
#define LINKABLE_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTests))
#define LINKABLE_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTestsClass))
#define IS_LINKABLE_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LINKABLE_PROPERTIES_TESTS))
#define IS_LINKABLE_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LINKABLE_PROPERTIES_TESTS))
#define LINKABLE_PROPERTIES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTestsClass))

typedef struct _LinkablePropertiesTests LinkablePropertiesTests;
typedef struct _LinkablePropertiesTestsClass LinkablePropertiesTestsClass;
typedef struct _LinkablePropertiesTestsPrivate LinkablePropertiesTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _LinkablePropertiesTests {
	EdsTestTestCase parent_instance;
	LinkablePropertiesTestsPrivate * priv;
};

struct _LinkablePropertiesTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _LinkablePropertiesTestsPrivate {
	FolksIndividualAggregator* _aggregator;
	GMainLoop* _main_loop;
	gboolean _found_before_update;
	gboolean _found_after_update;
	FolksIndividual* _ind_1;
	FolksIndividual* _ind_2;
};

struct _LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkablePropertiesTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer linkable_properties_tests_parent_class = NULL;

GType linkable_properties_tests_get_type (void) G_GNUC_CONST;
#define LINKABLE_PROPERTIES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTestsPrivate))
enum  {
	LINKABLE_PROPERTIES_TESTS_DUMMY_PROPERTY
};
#define LINKABLE_PROPERTIES_TESTS__full_name_1 "bernie h. innocenti"
#define LINKABLE_PROPERTIES_TESTS__email_1 "bernie@example.org"
#define LINKABLE_PROPERTIES_TESTS__phone_1 "5551234"
#define LINKABLE_PROPERTIES_TESTS__full_name_2 "Clyde McPoyle"
#define LINKABLE_PROPERTIES_TESTS__email_2 "clyde@example.org"
#define LINKABLE_PROPERTIES_TESTS__phone_2 "987654321"
LinkablePropertiesTests* linkable_properties_tests_new (void);
LinkablePropertiesTests* linkable_properties_tests_construct (GType object_type);
static void linkable_properties_tests_test_linkable_properties_aggregate_after_change (LinkablePropertiesTests* self);
static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_folks_test_case_test_method (gpointer self);
static void linkable_properties_tests_real_set_up (FolksTestCase* base);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async (LinkablePropertiesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_finish (LinkablePropertiesTests* self, GAsyncResult* _res_);
static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_data_free (gpointer _data);
static gboolean _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_co (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData* _data_);
static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _linkable_properties_tests_individuals_changed_aggregate_after_change_cb (LinkablePropertiesTests* self, GeeMultiMap* changes);
static void __linkable_properties_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void linkable_properties_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_folks_test_case_test_method (gpointer self) {
#line 50 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	linkable_properties_tests_test_linkable_properties_aggregate_after_change ((LinkablePropertiesTests*) self);
#line 127 "linkable-properties.c"
}


LinkablePropertiesTests* linkable_properties_tests_construct (GType object_type) {
	LinkablePropertiesTests * self = NULL;
#line 48 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self = (LinkablePropertiesTests*) eds_test_test_case_construct (object_type, "LinkableProperties");
#line 50 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "correct aggregation after linkable property change", _linkable_properties_tests_test_linkable_properties_aggregate_after_change_folks_test_case_test_method, self);
#line 46 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return self;
#line 139 "linkable-properties.c"
}


LinkablePropertiesTests* linkable_properties_tests_new (void) {
#line 46 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return linkable_properties_tests_construct (TYPE_LINKABLE_PROPERTIES_TESTS);
#line 146 "linkable-properties.c"
}


static void linkable_properties_tests_real_set_up (FolksTestCase* base) {
	LinkablePropertiesTests * self;
#line 54 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self = (LinkablePropertiesTests*) base;
#line 56 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	FOLKS_TEST_CASE_CLASS (linkable_properties_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, EDS_TEST_TYPE_TEST_CASE, EdsTestTestCase));
#line 58 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self->priv->_found_before_update = FALSE;
#line 59 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self->priv->_found_after_update = FALSE;
#line 160 "linkable-properties.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 79 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 167 "linkable-properties.c"
}


static void _vala_GValue_free (GValue* self) {
#line 79 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_unset (self);
#line 79 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_free (self);
#line 176 "linkable-properties.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 80 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return self ? _g_value_dup (self) : NULL;
#line 183 "linkable-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 89 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 190 "linkable-properties.c"
}


static void linkable_properties_tests_test_linkable_properties_aggregate_after_change (LinkablePropertiesTests* self) {
	GeeHashMap* c = NULL;
	GMainLoop* _tmp0_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp1_ = NULL;
	GeeHashMap* _tmp2_ = NULL;
	GValue _tmp3_ = {0};
	GValue _tmp4_ = {0};
	GValue* _tmp5_ = NULL;
	GValue* _tmp6_ = NULL;
	GeeHashMap* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue _tmp10_ = {0};
	GValue _tmp11_ = {0};
	GValue* _tmp12_ = NULL;
	GValue* _tmp13_ = NULL;
	GeeHashMap* _tmp14_ = NULL;
	GValue* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	GValue _tmp17_ = {0};
	GValue _tmp18_ = {0};
	GValue* _tmp19_ = NULL;
	GValue* _tmp20_ = NULL;
	GeeHashMap* _tmp21_ = NULL;
	GValue* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	EdsTestBackend* _tmp24_ = NULL;
	GeeHashMap* _tmp25_ = NULL;
	GeeHashMap* _tmp26_ = NULL;
	GeeHashMap* _tmp27_ = NULL;
	GValue _tmp28_ = {0};
	GValue _tmp29_ = {0};
	GValue* _tmp30_ = NULL;
	GValue* _tmp31_ = NULL;
	GeeHashMap* _tmp32_ = NULL;
	GValue* _tmp33_ = NULL;
	GValue* _tmp34_ = NULL;
	GValue _tmp35_ = {0};
	GValue _tmp36_ = {0};
	GValue* _tmp37_ = NULL;
	GValue* _tmp38_ = NULL;
	GeeHashMap* _tmp39_ = NULL;
	GValue* _tmp40_ = NULL;
	GValue* _tmp41_ = NULL;
	GValue _tmp42_ = {0};
	GValue _tmp43_ = {0};
	GValue* _tmp44_ = NULL;
	GValue* _tmp45_ = NULL;
	GeeHashMap* _tmp46_ = NULL;
	GValue* _tmp47_ = NULL;
	GValue* _tmp48_ = NULL;
	EdsTestBackend* _tmp49_ = NULL;
	GeeHashMap* _tmp50_ = NULL;
	GeeHashMap* _tmp51_ = NULL;
	GMainLoop* _tmp52_ = NULL;
	gboolean _tmp53_ = FALSE;
	gboolean _tmp54_ = FALSE;
#line 68 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_return_if_fail (self != NULL);
#line 71 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 71 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 71 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self->priv->_main_loop = _tmp0_;
#line 74 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self->priv->_found_before_update = FALSE;
#line 75 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self->priv->_found_after_update = FALSE;
#line 77 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp1_ = ((EdsTestTestCase*) self)->eds_backend;
#line 77 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	eds_test_backend_reset (_tmp1_);
#line 79 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 79 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (c);
#line 79 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	c = _tmp2_;
#line 80 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_init (&_tmp3_, G_TYPE_STRING);
#line 80 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp4_ = _tmp3_;
#line 80 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp5_ = __g_value_dup0 (&_tmp4_);
#line 80 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (v);
#line 80 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = _tmp5_;
#line 80 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_IS_VALUE (&_tmp4_) ? (g_value_unset (&_tmp4_), NULL) : NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp6_ = v;
#line 81 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_set_string (_tmp6_, LINKABLE_PROPERTIES_TESTS__full_name_1);
#line 82 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp7_ = c;
#line 82 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp8_ = v;
#line 82 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp9_ = _tmp8_;
#line 82 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp7_, "full_name", _tmp9_);
#line 82 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (_tmp9_);
#line 83 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_init (&_tmp10_, G_TYPE_STRING);
#line 83 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp11_ = _tmp10_;
#line 83 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp12_ = __g_value_dup0 (&_tmp11_);
#line 83 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (v);
#line 83 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = _tmp12_;
#line 83 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_IS_VALUE (&_tmp11_) ? (g_value_unset (&_tmp11_), NULL) : NULL;
#line 84 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp13_ = v;
#line 84 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_set_string (_tmp13_, LINKABLE_PROPERTIES_TESTS__email_1);
#line 85 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp14_ = c;
#line 85 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp15_ = v;
#line 85 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = NULL;
#line 85 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp16_ = _tmp15_;
#line 85 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp14_, "email_1", _tmp16_);
#line 85 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (_tmp16_);
#line 86 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_init (&_tmp17_, G_TYPE_STRING);
#line 86 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp18_ = _tmp17_;
#line 86 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp19_ = __g_value_dup0 (&_tmp18_);
#line 86 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (v);
#line 86 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = _tmp19_;
#line 86 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_IS_VALUE (&_tmp18_) ? (g_value_unset (&_tmp18_), NULL) : NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp20_ = v;
#line 87 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_set_string (_tmp20_, LINKABLE_PROPERTIES_TESTS__phone_1);
#line 88 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp21_ = c;
#line 88 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp22_ = v;
#line 88 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = NULL;
#line 88 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp23_ = _tmp22_;
#line 88 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp21_, "home_phone", _tmp23_);
#line 88 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (_tmp23_);
#line 89 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp24_ = ((EdsTestTestCase*) self)->eds_backend;
#line 89 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp25_ = c;
#line 89 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp26_ = _g_object_ref0 (_tmp25_);
#line 89 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	eds_test_backend_add_contact (_tmp24_, _tmp26_);
#line 91 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp27_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 91 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (c);
#line 91 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	c = _tmp27_;
#line 92 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_init (&_tmp28_, G_TYPE_STRING);
#line 92 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp29_ = _tmp28_;
#line 92 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp30_ = __g_value_dup0 (&_tmp29_);
#line 92 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (v);
#line 92 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = _tmp30_;
#line 92 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_IS_VALUE (&_tmp29_) ? (g_value_unset (&_tmp29_), NULL) : NULL;
#line 93 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp31_ = v;
#line 93 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_set_string (_tmp31_, LINKABLE_PROPERTIES_TESTS__full_name_2);
#line 94 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp32_ = c;
#line 94 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp33_ = v;
#line 94 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp34_ = _tmp33_;
#line 94 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp32_, "full_name", _tmp34_);
#line 94 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (_tmp34_);
#line 95 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_init (&_tmp35_, G_TYPE_STRING);
#line 95 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp36_ = _tmp35_;
#line 95 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp37_ = __g_value_dup0 (&_tmp36_);
#line 95 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (v);
#line 95 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = _tmp37_;
#line 95 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_IS_VALUE (&_tmp36_) ? (g_value_unset (&_tmp36_), NULL) : NULL;
#line 96 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp38_ = v;
#line 96 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_set_string (_tmp38_, LINKABLE_PROPERTIES_TESTS__email_2);
#line 97 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp39_ = c;
#line 97 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp40_ = v;
#line 97 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = NULL;
#line 97 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp41_ = _tmp40_;
#line 97 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp39_, "email_1", _tmp41_);
#line 97 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (_tmp41_);
#line 98 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_init (&_tmp42_, G_TYPE_STRING);
#line 98 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp43_ = _tmp42_;
#line 98 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp44_ = __g_value_dup0 (&_tmp43_);
#line 98 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (v);
#line 98 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = _tmp44_;
#line 98 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_IS_VALUE (&_tmp43_) ? (g_value_unset (&_tmp43_), NULL) : NULL;
#line 99 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp45_ = v;
#line 99 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_value_set_string (_tmp45_, LINKABLE_PROPERTIES_TESTS__phone_2);
#line 100 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp46_ = c;
#line 100 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp47_ = v;
#line 100 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	v = NULL;
#line 100 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp48_ = _tmp47_;
#line 100 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp46_, "mobile_phone", _tmp48_);
#line 100 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (_tmp48_);
#line 101 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp49_ = ((EdsTestTestCase*) self)->eds_backend;
#line 101 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp50_ = c;
#line 101 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp51_ = _g_object_ref0 (_tmp50_);
#line 101 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	eds_test_backend_add_contact (_tmp49_, _tmp51_);
#line 103 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_linkable_properties_tests_test_linkable_properties_aggregate_after_change_async (self, NULL, NULL);
#line 105 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp52_ = self->priv->_main_loop;
#line 105 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	folks_test_utils_loop_run_with_timeout (_tmp52_, 5);
#line 107 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp53_ = self->priv->_found_before_update;
#line 107 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_vala_assert (_tmp53_, "this._found_before_update");
#line 108 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp54_ = self->priv->_found_after_update;
#line 108 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_vala_assert (_tmp54_, "this._found_after_update");
#line 68 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	__vala_GValue_free0 (v);
#line 68 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (c);
#line 482 "linkable-properties.c"
}


static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_data_free (gpointer _data) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData* _data_;
	_data_ = _data;
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_slice_free (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData, _data_);
#line 493 "linkable-properties.c"
}


static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async (LinkablePropertiesTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData* _data_;
	LinkablePropertiesTests* _tmp0_ = NULL;
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_ = g_slice_new0 (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData);
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async);
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_data_free);
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->self = _tmp0_;
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_co (_data_);
#line 512 "linkable-properties.c"
}


static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_finish (LinkablePropertiesTests* self, GAsyncResult* _res_) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData* _data_;
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 520 "linkable-properties.c"
}


static void _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData* _data_;
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_ = _user_data_;
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_source_object_ = source_object;
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_res_ = _res_;
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_co (_data_);
#line 534 "linkable-properties.c"
}


static void __linkable_properties_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 118 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_linkable_properties_tests_individuals_changed_aggregate_after_change_cb ((LinkablePropertiesTests*) self, changes);
#line 541 "linkable-properties.c"
}


static gboolean _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_co (LinkablePropertiesTestsTestLinkablePropertiesAggregateAfterChangeAsyncData* _data_) {
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	switch (_data_->_state_) {
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		case 0:
#line 550 "linkable-properties.c"
		goto _state_0;
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		case 1:
#line 554 "linkable-properties.c"
		goto _state_1;
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		case 2:
#line 558 "linkable-properties.c"
		goto _state_2;
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		case 3:
#line 562 "linkable-properties.c"
		goto _state_3;
		default:
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		g_assert_not_reached ();
#line 567 "linkable-properties.c"
	}
	_state_0:
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp0_ = NULL;
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_state_ = 1;
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_ready, _data_);
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return FALSE;
#line 580 "linkable-properties.c"
	_state_1:
#line 113 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 115 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp1_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 115 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->store = _data_->_tmp1_;
#line 116 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_state_ = 2;
#line 116 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	folks_backend_store_prepare (_data_->store, _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_ready, _data_);
#line 116 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return FALSE;
#line 596 "linkable-properties.c"
	_state_2:
#line 116 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 117 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp2_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 117 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 117 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 118 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp3_ = NULL;
#line 118 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 118 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __linkable_properties_tests_individuals_changed_aggregate_after_change_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 614 "linkable-properties.c"
	{
#line 122 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_tmp4_ = NULL;
#line 122 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 122 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_state_ = 3;
#line 122 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _linkable_properties_tests_test_linkable_properties_aggregate_after_change_async_ready, _data_);
#line 122 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		return FALSE;
#line 626 "linkable-properties.c"
		_state_3:
#line 122 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 122 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		if (_data_->_inner_error_ != NULL) {
#line 632 "linkable-properties.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->e = _data_->_inner_error_;
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_inner_error_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_tmp5_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_tmp5_ = _data_->e;
#line 126 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_tmp6_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 126 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		g_warning ("linkable-properties.vala:126: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_g_error_free0 (_data_->e);
#line 655 "linkable-properties.c"
	}
	__finally0:
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	if (_data_->_inner_error_ != NULL) {
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_g_object_unref0 (_data_->store);
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		g_clear_error (&_data_->_inner_error_);
#line 120 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		return FALSE;
#line 668 "linkable-properties.c"
	}
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (_data_->store);
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	if (_data_->_state_ == 0) {
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 676 "linkable-properties.c"
	} else {
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 680 "linkable-properties.c"
	}
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_object_unref (_data_->_async_result);
#line 111 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return FALSE;
#line 686 "linkable-properties.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 156 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return result;
#line 695 "linkable-properties.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 156 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return result;
#line 704 "linkable-properties.c"
}


static void _linkable_properties_tests_individuals_changed_aggregate_after_change_cb (LinkablePropertiesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 130 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_return_if_fail (self != NULL);
#line 130 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_return_if_fail (changes != NULL);
#line 133 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp0_ = changes;
#line 133 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 133 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	added = _tmp1_;
#line 135 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp2_ = self->priv->_found_before_update;
#line 135 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	if (!_tmp2_) {
#line 727 "linkable-properties.c"
		{
			GeeIterator* _i_it = NULL;
			GeeCollection* _tmp3_ = NULL;
			GeeIterator* _tmp4_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp3_ = added;
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_i_it = _tmp4_;
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			while (TRUE) {
#line 740 "linkable-properties.c"
				GeeIterator* _tmp5_ = NULL;
				gboolean _tmp6_ = FALSE;
				FolksIndividual* i = NULL;
				GeeIterator* _tmp7_ = NULL;
				gpointer _tmp8_ = NULL;
				FolksIndividual* _tmp9_ = NULL;
				FolksNameDetails* name = NULL;
				FolksIndividual* _tmp10_ = NULL;
				FolksNameDetails* _tmp11_ = NULL;
				FolksNameDetails* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp5_ = _i_it;
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp6_ = gee_iterator_next (_tmp5_);
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				if (!_tmp6_) {
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					break;
#line 761 "linkable-properties.c"
				}
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp7_ = _i_it;
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp8_ = gee_iterator_get (_tmp7_);
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				i = (FolksIndividual*) _tmp8_;
#line 139 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp9_ = i;
#line 139 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_vala_assert (_tmp9_ != NULL, "i != null");
#line 141 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp10_ = i;
#line 141 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails));
#line 141 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				name = _tmp11_;
#line 143 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp12_ = name;
#line 143 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp13_ = folks_name_details_get_full_name (_tmp12_);
#line 143 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp14_ = _tmp13_;
#line 143 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				if (g_strcmp0 (_tmp14_, LINKABLE_PROPERTIES_TESTS__full_name_1) == 0) {
#line 787 "linkable-properties.c"
					FolksIndividual* _tmp15_ = NULL;
					FolksIndividual* _tmp16_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					_tmp15_ = i;
#line 145 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					_tmp16_ = _g_object_ref0 (_tmp15_);
#line 145 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					_g_object_unref0 (self->priv->_ind_1);
#line 145 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					self->priv->_ind_1 = _tmp16_;
#line 798 "linkable-properties.c"
				} else {
					FolksNameDetails* _tmp17_ = NULL;
					const gchar* _tmp18_ = NULL;
					const gchar* _tmp19_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					_tmp17_ = name;
#line 149 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					_tmp18_ = folks_name_details_get_full_name (_tmp17_);
#line 149 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					_tmp19_ = _tmp18_;
#line 149 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					if (g_strcmp0 (_tmp19_, LINKABLE_PROPERTIES_TESTS__full_name_2) == 0) {
#line 811 "linkable-properties.c"
						FolksIndividual* _tmp20_ = NULL;
						FolksIndividual* _tmp21_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp20_ = i;
#line 151 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp21_ = _g_object_ref0 (_tmp20_);
#line 151 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_g_object_unref0 (self->priv->_ind_2);
#line 151 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						self->priv->_ind_2 = _tmp21_;
#line 152 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						self->priv->_found_before_update = TRUE;
#line 824 "linkable-properties.c"
						{
							GeeIterator* _p_it = NULL;
							FolksIndividual* _tmp22_ = NULL;
							GeeSet* _tmp23_ = NULL;
							GeeSet* _tmp24_ = NULL;
							GeeIterator* _tmp25_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp22_ = i;
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp23_ = folks_individual_get_personas (_tmp22_);
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp24_ = _tmp23_;
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp25_ = gee_iterable_iterator ((GeeIterable*) _tmp24_);
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_p_it = _tmp25_;
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							while (TRUE) {
#line 843 "linkable-properties.c"
								GeeIterator* _tmp26_ = NULL;
								gboolean _tmp27_ = FALSE;
								FolksPersona* p = NULL;
								GeeIterator* _tmp28_ = NULL;
								gpointer _tmp29_ = NULL;
								GeeHashSet* emails = NULL;
								GeeHashSet* _tmp30_ = NULL;
								FolksEmailFieldDetails* email_1 = NULL;
								FolksEmailFieldDetails* _tmp31_ = NULL;
								FolksEmailFieldDetails* _tmp32_ = NULL;
								GeeHashSet* _tmp33_ = NULL;
								FolksEmailFieldDetails* _tmp34_ = NULL;
								FolksPersona* _tmp35_ = NULL;
								GeeHashSet* _tmp36_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp26_ = _p_it;
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp27_ = gee_iterator_next (_tmp26_);
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								if (!_tmp27_) {
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
									break;
#line 866 "linkable-properties.c"
								}
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp28_ = _p_it;
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp29_ = gee_iterator_get (_tmp28_);
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								p = (FolksPersona*) _tmp29_;
#line 156 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp30_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 156 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								emails = _tmp30_;
#line 159 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp31_ = folks_email_field_details_new (LINKABLE_PROPERTIES_TESTS__email_1, NULL);
#line 159 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								email_1 = _tmp31_;
#line 160 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp32_ = email_1;
#line 160 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _tmp32_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 162 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp33_ = emails;
#line 162 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp34_ = email_1;
#line 162 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								gee_abstract_collection_add ((GeeAbstractCollection*) _tmp33_, _tmp34_);
#line 163 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp35_ = p;
#line 163 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_tmp36_ = emails;
#line 163 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								folks_email_details_set_email_addresses (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, FOLKS_TYPE_EMAIL_DETAILS, FolksEmailDetails), (GeeSet*) _tmp36_);
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_g_object_unref0 (email_1);
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_g_object_unref0 (emails);
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								_g_object_unref0 (p);
#line 904 "linkable-properties.c"
							}
#line 154 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_g_object_unref0 (_p_it);
#line 908 "linkable-properties.c"
						}
					}
				}
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (name);
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (i);
#line 916 "linkable-properties.c"
			}
#line 137 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_g_object_unref0 (_i_it);
#line 920 "linkable-properties.c"
		}
	} else {
		FolksIndividual* replaced = NULL;
		GeeMultiMap* _tmp37_ = NULL;
		FolksIndividual* _tmp38_ = NULL;
		gboolean _tmp39_ = FALSE;
		GeeCollection* replacements = NULL;
		GeeMultiMap* _tmp47_ = NULL;
		FolksIndividual* _tmp48_ = NULL;
		GeeCollection* _tmp49_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_tmp37_ = changes;
#line 172 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_tmp38_ = self->priv->_ind_1;
#line 172 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_tmp39_ = gee_multi_map_contains (_tmp37_, _tmp38_);
#line 172 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		if (_tmp39_) {
#line 939 "linkable-properties.c"
			FolksIndividual* _tmp40_ = NULL;
			FolksIndividual* _tmp41_ = NULL;
#line 174 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp40_ = self->priv->_ind_1;
#line 174 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp41_ = _g_object_ref0 (_tmp40_);
#line 174 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_g_object_unref0 (replaced);
#line 174 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			replaced = _tmp41_;
#line 950 "linkable-properties.c"
		} else {
			GeeMultiMap* _tmp42_ = NULL;
			FolksIndividual* _tmp43_ = NULL;
			gboolean _tmp44_ = FALSE;
#line 176 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp42_ = changes;
#line 176 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp43_ = self->priv->_ind_2;
#line 176 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp44_ = gee_multi_map_contains (_tmp42_, _tmp43_);
#line 176 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			if (_tmp44_) {
#line 963 "linkable-properties.c"
				FolksIndividual* _tmp45_ = NULL;
				FolksIndividual* _tmp46_ = NULL;
#line 178 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp45_ = self->priv->_ind_2;
#line 178 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp46_ = _g_object_ref0 (_tmp45_);
#line 178 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (replaced);
#line 178 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				replaced = _tmp46_;
#line 974 "linkable-properties.c"
			} else {
#line 182 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (replaced);
#line 182 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (added);
#line 182 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				return;
#line 982 "linkable-properties.c"
			}
		}
#line 185 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_tmp47_ = changes;
#line 185 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_tmp48_ = replaced;
#line 185 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_tmp49_ = gee_multi_map_get (_tmp47_, _tmp48_);
#line 185 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		replacements = _tmp49_;
#line 993 "linkable-properties.c"
		{
			GeeIterator* _r_it = NULL;
			GeeCollection* _tmp50_ = NULL;
			GeeIterator* _tmp51_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp50_ = replacements;
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_tmp51_ = gee_iterable_iterator ((GeeIterable*) _tmp50_);
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_r_it = _tmp51_;
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			while (TRUE) {
#line 1006 "linkable-properties.c"
				GeeIterator* _tmp52_ = NULL;
				gboolean _tmp53_ = FALSE;
				FolksIndividual* r = NULL;
				GeeIterator* _tmp54_ = NULL;
				gpointer _tmp55_ = NULL;
				FolksPhoneFieldDetails* phone_fd_1 = NULL;
				FolksPhoneFieldDetails* _tmp56_ = NULL;
				FolksPhoneFieldDetails* phone_fd_2 = NULL;
				FolksPhoneFieldDetails* _tmp57_ = NULL;
				gboolean num_equal_1 = FALSE;
				gboolean num_equal_2 = FALSE;
				FolksIndividual* _tmp58_ = NULL;
				GeeSet* _tmp59_ = NULL;
				GeeSet* _tmp60_ = NULL;
				gint _tmp61_ = 0;
				gint _tmp62_ = 0;
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp52_ = _r_it;
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp53_ = gee_iterator_next (_tmp52_);
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				if (!_tmp53_) {
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					break;
#line 1031 "linkable-properties.c"
				}
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp54_ = _r_it;
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp55_ = gee_iterator_get (_tmp54_);
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				r = (FolksIndividual*) _tmp55_;
#line 188 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp56_ = folks_phone_field_details_new (LINKABLE_PROPERTIES_TESTS__phone_1, NULL);
#line 188 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				phone_fd_1 = _tmp56_;
#line 189 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp57_ = folks_phone_field_details_new (LINKABLE_PROPERTIES_TESTS__phone_1, NULL);
#line 189 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				phone_fd_2 = _tmp57_;
#line 190 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				num_equal_1 = FALSE;
#line 191 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				num_equal_2 = FALSE;
#line 193 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp58_ = r;
#line 193 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp59_ = folks_individual_get_personas (_tmp58_);
#line 193 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp60_ = _tmp59_;
#line 193 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp61_ = gee_collection_get_size ((GeeCollection*) _tmp60_);
#line 193 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_tmp62_ = _tmp61_;
#line 193 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				if (_tmp62_ == 2) {
#line 1063 "linkable-properties.c"
					gboolean _tmp77_ = FALSE;
					gboolean _tmp78_ = FALSE;
					{
						GeeIterator* _num_it = NULL;
						FolksIndividual* _tmp63_ = NULL;
						GeeSet* _tmp64_ = NULL;
						GeeSet* _tmp65_ = NULL;
						GeeIterator* _tmp66_ = NULL;
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp63_ = r;
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp64_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp63_);
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp65_ = _tmp64_;
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp66_ = gee_iterable_iterator ((GeeIterable*) _tmp65_);
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_num_it = _tmp66_;
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						while (TRUE) {
#line 1084 "linkable-properties.c"
							GeeIterator* _tmp67_ = NULL;
							gboolean _tmp68_ = FALSE;
							FolksPhoneFieldDetails* num = NULL;
							GeeIterator* _tmp69_ = NULL;
							gpointer _tmp70_ = NULL;
							FolksPhoneFieldDetails* _tmp71_ = NULL;
							FolksPhoneFieldDetails* _tmp72_ = NULL;
							gboolean _tmp73_ = FALSE;
							FolksPhoneFieldDetails* _tmp74_ = NULL;
							FolksPhoneFieldDetails* _tmp75_ = NULL;
							gboolean _tmp76_ = FALSE;
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp67_ = _num_it;
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp68_ = gee_iterator_next (_tmp67_);
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							if (!_tmp68_) {
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								break;
#line 1104 "linkable-properties.c"
							}
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp69_ = _num_it;
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp70_ = gee_iterator_get (_tmp69_);
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							num = (FolksPhoneFieldDetails*) _tmp70_;
#line 197 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp71_ = num;
#line 197 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp72_ = phone_fd_1;
#line 197 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp73_ = folks_abstract_field_details_values_equal ((FolksAbstractFieldDetails*) _tmp71_, (FolksAbstractFieldDetails*) _tmp72_);
#line 197 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							if (_tmp73_) {
#line 198 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								num_equal_1 = TRUE;
#line 1122 "linkable-properties.c"
							}
#line 200 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp74_ = num;
#line 200 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp75_ = phone_fd_2;
#line 200 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_tmp76_ = folks_abstract_field_details_values_equal ((FolksAbstractFieldDetails*) _tmp74_, (FolksAbstractFieldDetails*) _tmp75_);
#line 200 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							if (_tmp76_) {
#line 201 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
								num_equal_2 = TRUE;
#line 1134 "linkable-properties.c"
							}
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
							_g_object_unref0 (num);
#line 1138 "linkable-properties.c"
						}
#line 195 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_g_object_unref0 (_num_it);
#line 1142 "linkable-properties.c"
					}
#line 204 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					_tmp78_ = num_equal_1;
#line 204 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					if (_tmp78_) {
#line 1148 "linkable-properties.c"
						gboolean _tmp79_ = FALSE;
#line 204 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp79_ = num_equal_2;
#line 204 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp77_ = _tmp79_;
#line 1154 "linkable-properties.c"
					} else {
#line 204 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp77_ = FALSE;
#line 1158 "linkable-properties.c"
					}
#line 204 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
					if (_tmp77_) {
#line 1162 "linkable-properties.c"
						GMainLoop* _tmp80_ = NULL;
#line 206 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						self->priv->_found_after_update = TRUE;
#line 207 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						_tmp80_ = self->priv->_main_loop;
#line 207 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
						g_main_loop_quit (_tmp80_);
#line 1170 "linkable-properties.c"
					}
				}
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (phone_fd_2);
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (phone_fd_1);
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
				_g_object_unref0 (r);
#line 1179 "linkable-properties.c"
			}
#line 186 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
			_g_object_unref0 (_r_it);
#line 1183 "linkable-properties.c"
		}
#line 135 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_g_object_unref0 (replacements);
#line 135 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
		_g_object_unref0 (replaced);
#line 1189 "linkable-properties.c"
	}
#line 130 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (added);
#line 1193 "linkable-properties.c"
}


static void linkable_properties_tests_class_init (LinkablePropertiesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	linkable_properties_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_type_class_add_private (klass, sizeof (LinkablePropertiesTestsPrivate));
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = linkable_properties_tests_real_set_up;
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = linkable_properties_tests_finalize;
#line 1206 "linkable-properties.c"
}


static void linkable_properties_tests_instance_init (LinkablePropertiesTests * self) {
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self->priv = LINKABLE_PROPERTIES_TESTS_GET_PRIVATE (self);
#line 1213 "linkable-properties.c"
}


static void linkable_properties_tests_finalize (GObject* obj) {
	LinkablePropertiesTests * self;
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LINKABLE_PROPERTIES_TESTS, LinkablePropertiesTests);
#line 28 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 40 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (self->priv->_ind_1);
#line 41 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (self->priv->_ind_2);
#line 26 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	G_OBJECT_CLASS (linkable_properties_tests_parent_class)->finalize (obj);
#line 1231 "linkable-properties.c"
}


GType linkable_properties_tests_get_type (void) {
	static volatile gsize linkable_properties_tests_type_id__volatile = 0;
	if (g_once_init_enter (&linkable_properties_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LinkablePropertiesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) linkable_properties_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LinkablePropertiesTests), 0, (GInstanceInitFunc) linkable_properties_tests_instance_init, NULL };
		GType linkable_properties_tests_type_id;
		linkable_properties_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "LinkablePropertiesTests", &g_define_type_info, 0);
		g_once_init_leave (&linkable_properties_tests_type_id__volatile, linkable_properties_tests_type_id);
	}
	return linkable_properties_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	LinkablePropertiesTests* tests = NULL;
	LinkablePropertiesTests* _tmp0_ = NULL;
#line 217 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_test_init (&args_length1, &args, NULL);
#line 219 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_tmp0_ = linkable_properties_tests_new ();
#line 219 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	tests = _tmp0_;
#line 220 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 221 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	g_test_run ();
#line 222 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 224 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	result = 0;
#line 224 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	_g_object_unref0 (tests);
#line 224 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return result;
#line 1269 "linkable-properties.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 215 "/opt/gnome3/source/folks/tests/eds/linkable-properties.vala"
	return _vala_main (argv, argc);
#line 1279 "linkable-properties.c"
}



