/* email-details.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from email-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks-eds.h>
#include <gio/gio.h>


#define TYPE_EMAIL_DETAILS_TESTS (email_details_tests_get_type ())
#define EMAIL_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTests))
#define EMAIL_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTestsClass))
#define IS_EMAIL_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EMAIL_DETAILS_TESTS))
#define IS_EMAIL_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EMAIL_DETAILS_TESTS))
#define EMAIL_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTestsClass))

typedef struct _EmailDetailsTests EmailDetailsTests;
typedef struct _EmailDetailsTestsClass EmailDetailsTestsClass;
typedef struct _EmailDetailsTestsPrivate EmailDetailsTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _EmailDetailsTestsTestEmailDetailsAsyncData EmailDetailsTestsTestEmailDetailsAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _EmailDetailsTests {
	EdsTestTestCase parent_instance;
	EmailDetailsTestsPrivate * priv;
};

struct _EmailDetailsTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _EmailDetailsTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _email_count;
	GeeHashSet* _email_types;
	GeeHashMap* _c1;
	GeeHashMap* _c2;
	GeeHashMap* _c3;
};

struct _EmailDetailsTestsTestEmailDetailsAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	EmailDetailsTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer email_details_tests_parent_class = NULL;

GType email_details_tests_get_type (void) G_GNUC_CONST;
#define EMAIL_DETAILS_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTestsPrivate))
enum  {
	EMAIL_DETAILS_TESTS_DUMMY_PROPERTY
};
EmailDetailsTests* email_details_tests_new (void);
EmailDetailsTests* email_details_tests_construct (GType object_type);
void email_details_tests_test_email_details (EmailDetailsTests* self);
static void _email_details_tests_test_email_details_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _email_details_tests_test_email_details_async (EmailDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _email_details_tests_test_email_details_finish (EmailDetailsTests* self, GAsyncResult* _res_);
static void _email_details_tests_test_email_details_async_data_free (gpointer _data);
static gboolean _email_details_tests_test_email_details_async_co (EmailDetailsTestsTestEmailDetailsAsyncData* _data_);
static void _email_details_tests_test_email_details_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _email_details_tests_individuals_changed_cb (EmailDetailsTests* self, GeeMultiMap* changes);
static void __email_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void email_details_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _email_details_tests_test_email_details_folks_test_case_test_method (gpointer self) {
#line 39 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	email_details_tests_test_email_details ((EmailDetailsTests*) self);
#line 120 "email-details.c"
}


EmailDetailsTests* email_details_tests_construct (GType object_type) {
	EmailDetailsTests * self = NULL;
#line 37 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self = (EmailDetailsTests*) eds_test_test_case_construct (object_type, "EmailDetails");
#line 39 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "email details interface", _email_details_tests_test_email_details_folks_test_case_test_method, self);
#line 35 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return self;
#line 132 "email-details.c"
}


EmailDetailsTests* email_details_tests_new (void) {
#line 35 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return email_details_tests_construct (TYPE_EMAIL_DETAILS_TESTS);
#line 139 "email-details.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 46 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 146 "email-details.c"
}


static void _vala_GValue_free (GValue* self) {
#line 46 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_unset (self);
#line 46 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_free (self);
#line 155 "email-details.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 54 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return self ? _g_value_dup (self) : NULL;
#line 162 "email-details.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 63 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return self ? g_object_ref (self) : NULL;
#line 169 "email-details.c"
}


void email_details_tests_test_email_details (EmailDetailsTests* self) {
	GeeHashSet* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GeeHashMap* _tmp2_ = NULL;
	GeeHashMap* _tmp3_ = NULL;
	GMainLoop* _tmp4_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp5_ = NULL;
	GValue _tmp6_ = {0};
	GValue _tmp7_ = {0};
	GValue* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	GValue* _tmp11_ = NULL;
	GValue* _tmp12_ = NULL;
	GValue _tmp13_ = {0};
	GValue _tmp14_ = {0};
	GValue* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	GeeHashMap* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	GValue* _tmp19_ = NULL;
	GValue* _tmp20_ = NULL;
	GValue _tmp21_ = {0};
	GValue _tmp22_ = {0};
	GValue* _tmp23_ = NULL;
	GValue* _tmp24_ = NULL;
	GeeHashMap* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	GValue* _tmp27_ = NULL;
	GValue* _tmp28_ = NULL;
	EdsTestBackend* _tmp29_ = NULL;
	GeeHashMap* _tmp30_ = NULL;
	GeeHashMap* _tmp31_ = NULL;
	GValue _tmp32_ = {0};
	GValue _tmp33_ = {0};
	GValue* _tmp34_ = NULL;
	GValue* _tmp35_ = NULL;
	GeeHashMap* _tmp36_ = NULL;
	GValue* _tmp37_ = NULL;
	GValue* _tmp38_ = NULL;
	GValue _tmp39_ = {0};
	GValue _tmp40_ = {0};
	GValue* _tmp41_ = NULL;
	GValue* _tmp42_ = NULL;
	GeeHashMap* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	GValue* _tmp45_ = NULL;
	GValue* _tmp46_ = NULL;
	GValue _tmp47_ = {0};
	GValue _tmp48_ = {0};
	GValue* _tmp49_ = NULL;
	GValue* _tmp50_ = NULL;
	GeeHashMap* _tmp51_ = NULL;
	const gchar* _tmp52_ = NULL;
	GValue* _tmp53_ = NULL;
	GValue* _tmp54_ = NULL;
	EdsTestBackend* _tmp55_ = NULL;
	GeeHashMap* _tmp56_ = NULL;
	GeeHashMap* _tmp57_ = NULL;
	GValue _tmp58_ = {0};
	GValue _tmp59_ = {0};
	GValue* _tmp60_ = NULL;
	GValue* _tmp61_ = NULL;
	GeeHashMap* _tmp62_ = NULL;
	GValue* _tmp63_ = NULL;
	GValue* _tmp64_ = NULL;
	GValue _tmp65_ = {0};
	GValue _tmp66_ = {0};
	GValue* _tmp67_ = NULL;
	GValue* _tmp68_ = NULL;
	GeeHashMap* _tmp69_ = NULL;
	const gchar* _tmp70_ = NULL;
	GValue* _tmp71_ = NULL;
	GValue* _tmp72_ = NULL;
	GValue _tmp73_ = {0};
	GValue _tmp74_ = {0};
	GValue* _tmp75_ = NULL;
	GValue* _tmp76_ = NULL;
	GeeHashMap* _tmp77_ = NULL;
	const gchar* _tmp78_ = NULL;
	GValue* _tmp79_ = NULL;
	GValue* _tmp80_ = NULL;
	EdsTestBackend* _tmp81_ = NULL;
	GeeHashMap* _tmp82_ = NULL;
	GeeHashMap* _tmp83_ = NULL;
	GMainLoop* _tmp84_ = NULL;
	gint _tmp85_ = 0;
	GeeHashSet* _tmp86_ = NULL;
	gint _tmp87_ = 0;
	gint _tmp88_ = 0;
	GeeHashMap* _tmp89_ = NULL;
	gint _tmp90_ = 0;
	gint _tmp91_ = 0;
	GeeHashMap* _tmp92_ = NULL;
	gint _tmp93_ = 0;
	gint _tmp94_ = 0;
	GeeHashMap* _tmp95_ = NULL;
	gint _tmp96_ = 0;
	gint _tmp97_ = 0;
#line 42 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_return_if_fail (self != NULL);
#line 44 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self->priv->_email_count = 0;
#line 45 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_email_types);
#line 45 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self->priv->_email_types = _tmp0_;
#line 46 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 46 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 46 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self->priv->_c1 = _tmp1_;
#line 47 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 47 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 47 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self->priv->_c2 = _tmp2_;
#line 48 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp3_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 48 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c3);
#line 48 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self->priv->_c3 = _tmp3_;
#line 49 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp4_ = g_main_loop_new (NULL, FALSE);
#line 49 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 49 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self->priv->_main_loop = _tmp4_;
#line 52 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp5_ = ((EdsTestTestCase*) self)->eds_backend;
#line 52 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	eds_test_backend_reset (_tmp5_);
#line 54 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp6_, G_TYPE_STRING);
#line 54 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp7_ = _tmp6_;
#line 54 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp8_ = __g_value_dup0 (&_tmp7_);
#line 54 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 54 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp8_;
#line 54 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp7_) ? (g_value_unset (&_tmp7_), NULL) : NULL;
#line 55 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp9_ = v;
#line 55 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp9_, "bernie h. innocenti");
#line 56 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp10_ = self->priv->_c1;
#line 56 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp11_ = v;
#line 56 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 56 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp12_ = _tmp11_;
#line 56 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, "full_name", _tmp12_);
#line 56 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp12_);
#line 57 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp13_, G_TYPE_STRING);
#line 57 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp14_ = _tmp13_;
#line 57 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp15_ = __g_value_dup0 (&_tmp14_);
#line 57 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 57 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp15_;
#line 57 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp14_) ? (g_value_unset (&_tmp14_), NULL) : NULL;
#line 58 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp16_ = v;
#line 58 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp16_, "bernie@example.org");
#line 59 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp17_ = self->priv->_c1;
#line 59 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp18_ = EDSF_PERSONA_email_fields[0];
#line 59 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp19_ = v;
#line 59 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 59 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp20_ = _tmp19_;
#line 59 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, _tmp18_, _tmp20_);
#line 59 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp20_);
#line 60 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp21_, G_TYPE_STRING);
#line 60 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp22_ = _tmp21_;
#line 60 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp23_ = __g_value_dup0 (&_tmp22_);
#line 60 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 60 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp23_;
#line 60 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp22_) ? (g_value_unset (&_tmp22_), NULL) : NULL;
#line 61 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp24_ = v;
#line 61 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp24_, "bernie.innocenti@example.org");
#line 62 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp25_ = self->priv->_c1;
#line 62 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp26_ = EDSF_PERSONA_email_fields[1];
#line 62 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp27_ = v;
#line 62 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 62 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp28_ = _tmp27_;
#line 62 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp25_, _tmp26_, _tmp28_);
#line 62 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp28_);
#line 63 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp29_ = ((EdsTestTestCase*) self)->eds_backend;
#line 63 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp30_ = self->priv->_c1;
#line 63 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp31_ = _g_object_ref0 (_tmp30_);
#line 63 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	eds_test_backend_add_contact (_tmp29_, _tmp31_);
#line 65 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp32_, G_TYPE_STRING);
#line 65 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp33_ = _tmp32_;
#line 65 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp34_ = __g_value_dup0 (&_tmp33_);
#line 65 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 65 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp34_;
#line 65 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp33_) ? (g_value_unset (&_tmp33_), NULL) : NULL;
#line 66 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp35_ = v;
#line 66 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp35_, "richard m. stallman");
#line 67 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp36_ = self->priv->_c2;
#line 67 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp37_ = v;
#line 67 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 67 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp38_ = _tmp37_;
#line 67 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp36_, "full_name", _tmp38_);
#line 67 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp38_);
#line 68 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp39_, G_TYPE_STRING);
#line 68 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp40_ = _tmp39_;
#line 68 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp41_ = __g_value_dup0 (&_tmp40_);
#line 68 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 68 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp41_;
#line 68 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp40_) ? (g_value_unset (&_tmp40_), NULL) : NULL;
#line 69 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp42_ = v;
#line 69 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp42_, "rms@example.org");
#line 70 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp43_ = self->priv->_c2;
#line 70 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp44_ = EDSF_PERSONA_email_fields[0];
#line 70 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp45_ = v;
#line 70 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 70 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp46_ = _tmp45_;
#line 70 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp43_, _tmp44_, _tmp46_);
#line 70 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp46_);
#line 71 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp47_, G_TYPE_STRING);
#line 71 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp48_ = _tmp47_;
#line 71 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp49_ = __g_value_dup0 (&_tmp48_);
#line 71 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 71 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp49_;
#line 71 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp48_) ? (g_value_unset (&_tmp48_), NULL) : NULL;
#line 72 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp50_ = v;
#line 72 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp50_, "rms.1@example.org");
#line 73 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp51_ = self->priv->_c2;
#line 73 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp52_ = EDSF_PERSONA_email_fields[1];
#line 73 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp53_ = v;
#line 73 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 73 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp54_ = _tmp53_;
#line 73 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp51_, _tmp52_, _tmp54_);
#line 73 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp54_);
#line 74 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp55_ = ((EdsTestTestCase*) self)->eds_backend;
#line 74 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp56_ = self->priv->_c2;
#line 74 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp57_ = _g_object_ref0 (_tmp56_);
#line 74 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	eds_test_backend_add_contact (_tmp55_, _tmp57_);
#line 76 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp58_, G_TYPE_STRING);
#line 76 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp59_ = _tmp58_;
#line 76 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp60_ = __g_value_dup0 (&_tmp59_);
#line 76 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 76 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp60_;
#line 76 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp59_) ? (g_value_unset (&_tmp59_), NULL) : NULL;
#line 77 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp61_ = v;
#line 77 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp61_, "foo bar");
#line 78 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp62_ = self->priv->_c3;
#line 78 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp63_ = v;
#line 78 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp64_ = _tmp63_;
#line 78 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp62_, "full_name", _tmp64_);
#line 78 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp64_);
#line 79 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp65_, G_TYPE_STRING);
#line 79 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp66_ = _tmp65_;
#line 79 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp67_ = __g_value_dup0 (&_tmp66_);
#line 79 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 79 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp67_;
#line 79 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp66_) ? (g_value_unset (&_tmp66_), NULL) : NULL;
#line 80 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp68_ = v;
#line 80 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp68_, "foo@example.org");
#line 81 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp69_ = self->priv->_c3;
#line 81 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp70_ = EDSF_PERSONA_email_fields[0];
#line 81 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp71_ = v;
#line 81 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 81 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp72_ = _tmp71_;
#line 81 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp69_, _tmp70_, _tmp72_);
#line 81 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp72_);
#line 82 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_init (&_tmp73_, G_TYPE_STRING);
#line 82 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp74_ = _tmp73_;
#line 82 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp75_ = __g_value_dup0 (&_tmp74_);
#line 82 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 82 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = _tmp75_;
#line 82 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_IS_VALUE (&_tmp74_) ? (g_value_unset (&_tmp74_), NULL) : NULL;
#line 83 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp76_ = v;
#line 83 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_value_set_string (_tmp76_, "foo.bar@example.org");
#line 84 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp77_ = self->priv->_c3;
#line 84 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp78_ = EDSF_PERSONA_email_fields[1];
#line 84 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp79_ = v;
#line 84 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	v = NULL;
#line 84 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp80_ = _tmp79_;
#line 84 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp77_, _tmp78_, _tmp80_);
#line 84 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (_tmp80_);
#line 85 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp81_ = ((EdsTestTestCase*) self)->eds_backend;
#line 85 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp82_ = self->priv->_c3;
#line 85 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp83_ = _g_object_ref0 (_tmp82_);
#line 85 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	eds_test_backend_add_contact (_tmp81_, _tmp83_);
#line 87 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_email_details_tests_test_email_details_async (self, NULL, NULL);
#line 89 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp84_ = self->priv->_main_loop;
#line 89 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp84_, 5);
#line 91 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp85_ = self->priv->_email_count;
#line 91 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_vala_assert (_tmp85_ == 6, "this._email_count == 6");
#line 92 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp86_ = self->priv->_email_types;
#line 92 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp87_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp86_);
#line 92 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp88_ = _tmp87_;
#line 92 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_vala_assert (_tmp88_ == 1, "this._email_types.size == 1");
#line 93 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp89_ = self->priv->_c1;
#line 93 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp90_ = gee_abstract_map_get_size ((GeeMap*) _tmp89_);
#line 93 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp91_ = _tmp90_;
#line 93 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_vala_assert (_tmp91_ == 0, "this._c1.size == 0");
#line 94 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp92_ = self->priv->_c2;
#line 94 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp93_ = gee_abstract_map_get_size ((GeeMap*) _tmp92_);
#line 94 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp94_ = _tmp93_;
#line 94 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_vala_assert (_tmp94_ == 0, "this._c2.size == 0");
#line 95 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp95_ = self->priv->_c3;
#line 95 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp96_ = gee_abstract_map_get_size ((GeeMap*) _tmp95_);
#line 95 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp97_ = _tmp96_;
#line 95 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_vala_assert (_tmp97_ == 0, "this._c3.size == 0");
#line 641 "email-details.c"
	{
		GeeIterator* _pt_it = NULL;
		GeeHashSet* _tmp98_ = NULL;
		GeeIterator* _tmp99_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_tmp98_ = self->priv->_email_types;
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_tmp99_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp98_);
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_pt_it = _tmp99_;
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		while (TRUE) {
#line 654 "email-details.c"
			GeeIterator* _tmp100_ = NULL;
			gboolean _tmp101_ = FALSE;
			gchar* pt = NULL;
			GeeIterator* _tmp102_ = NULL;
			gpointer _tmp103_ = NULL;
			const gchar* _tmp104_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp100_ = _pt_it;
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp101_ = gee_iterator_next (_tmp100_);
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			if (!_tmp101_) {
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				break;
#line 669 "email-details.c"
			}
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp102_ = _pt_it;
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp103_ = gee_iterator_get (_tmp102_);
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			pt = (gchar*) _tmp103_;
#line 99 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp104_ = pt;
#line 99 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_vala_assert (g_strcmp0 (_tmp104_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER) == 0, "pt == AbstractFieldDetails.PARAM_TYPE_OTHER");
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_g_free0 (pt);
#line 683 "email-details.c"
		}
#line 97 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_pt_it);
#line 687 "email-details.c"
	}
#line 42 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	__vala_GValue_free0 (v);
#line 691 "email-details.c"
}


static void _email_details_tests_test_email_details_async_data_free (gpointer _data) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_slice_free (EmailDetailsTestsTestEmailDetailsAsyncData, _data_);
#line 702 "email-details.c"
}


static void _email_details_tests_test_email_details_async (EmailDetailsTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
	EmailDetailsTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_ = g_slice_new0 (EmailDetailsTestsTestEmailDetailsAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _email_details_tests_test_email_details_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _email_details_tests_test_email_details_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_email_details_tests_test_email_details_async_co (_data_);
#line 721 "email-details.c"
}


static void _email_details_tests_test_email_details_finish (EmailDetailsTests* self, GAsyncResult* _res_) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 729 "email-details.c"
}


static void _email_details_tests_test_email_details_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	EmailDetailsTestsTestEmailDetailsAsyncData* _data_;
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_ = _user_data_;
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_source_object_ = source_object;
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_res_ = _res_;
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_email_details_tests_test_email_details_async_co (_data_);
#line 743 "email-details.c"
}


static void __email_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 111 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_email_details_tests_individuals_changed_cb ((EmailDetailsTests*) self, changes);
#line 750 "email-details.c"
}


static gboolean _email_details_tests_test_email_details_async_co (EmailDetailsTestsTestEmailDetailsAsyncData* _data_) {
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	switch (_data_->_state_) {
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		case 0:
#line 759 "email-details.c"
		goto _state_0;
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		case 1:
#line 763 "email-details.c"
		goto _state_1;
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		case 2:
#line 767 "email-details.c"
		goto _state_2;
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		case 3:
#line 771 "email-details.c"
		goto _state_3;
		default:
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		g_assert_not_reached ();
#line 776 "email-details.c"
	}
	_state_0:
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp0_ = NULL;
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_state_ = 1;
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _email_details_tests_test_email_details_async_ready, _data_);
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return FALSE;
#line 789 "email-details.c"
	_state_1:
#line 106 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 108 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp1_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 108 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->store = _data_->_tmp1_;
#line 109 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_state_ = 2;
#line 109 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	folks_backend_store_prepare (_data_->store, _email_details_tests_test_email_details_async_ready, _data_);
#line 109 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return FALSE;
#line 805 "email-details.c"
	_state_2:
#line 109 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 110 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp2_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 110 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 110 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 111 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp3_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 111 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __email_details_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 823 "email-details.c"
	{
#line 115 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_tmp4_ = NULL;
#line 115 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 115 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_state_ = 3;
#line 115 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _email_details_tests_test_email_details_async_ready, _data_);
#line 115 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		return FALSE;
#line 835 "email-details.c"
		_state_3:
#line 115 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 115 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		if (_data_->_inner_error_ != NULL) {
#line 841 "email-details.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->e = _data_->_inner_error_;
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_inner_error_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_tmp5_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_tmp5_ = _data_->e;
#line 119 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_tmp6_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 119 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		g_warning ("email-details.vala:119: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_g_error_free0 (_data_->e);
#line 864 "email-details.c"
	}
	__finally0:
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	if (_data_->_inner_error_ != NULL) {
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_data_->store);
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		g_clear_error (&_data_->_inner_error_);
#line 113 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		return FALSE;
#line 877 "email-details.c"
	}
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (_data_->store);
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	if (_data_->_state_ == 0) {
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 885 "email-details.c"
	} else {
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 889 "email-details.c"
	}
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_object_unref (_data_->_async_result);
#line 103 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return FALSE;
#line 895 "email-details.c"
}


static void _email_details_tests_individuals_changed_cb (EmailDetailsTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp76_ = NULL;
	gint _tmp77_ = 0;
	gint _tmp78_ = 0;
#line 123 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_return_if_fail (self != NULL);
#line 123 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_return_if_fail (changes != NULL);
#line 126 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp0_ = changes;
#line 126 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 126 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	added = _tmp1_;
#line 127 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp2_ = changes;
#line 127 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 127 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	removed = _tmp3_;
#line 925 "email-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_tmp4_ = added;
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_i_it = _tmp5_;
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		while (TRUE) {
#line 938 "email-details.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			GeeHashMap* contact = NULL;
			FolksIndividual* _tmp11_ = NULL;
			GeeSet* _tmp12_ = NULL;
			GeeSet* _tmp13_ = NULL;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			FolksIndividual* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			GeeHashMap* _tmp28_ = NULL;
			GeeHashMap* _tmp29_ = NULL;
			FolksEmailDetails* email_owner = NULL;
			FolksIndividual* _tmp30_ = NULL;
			FolksEmailDetails* _tmp31_ = NULL;
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp6_ = _i_it;
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			if (!_tmp7_) {
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				break;
#line 967 "email-details.c"
			}
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp8_ = _i_it;
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			i = (FolksIndividual*) _tmp9_;
#line 131 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp10_ = i;
#line 131 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 133 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			contact = NULL;
#line 134 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp11_ = i;
#line 134 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 134 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp13_ = _tmp12_;
#line 134 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 134 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp15_ = _tmp14_;
#line 134 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_vala_assert (_tmp15_ == 1, "i.personas.size == 1");
#line 136 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp16_ = i;
#line 136 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp17_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp16_);
#line 136 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp18_ = _tmp17_;
#line 136 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			if (g_strcmp0 (_tmp18_, "bernie h. innocenti") == 0) {
#line 1001 "email-details.c"
				GeeHashMap* _tmp19_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp19_ = self->priv->_c1;
#line 138 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				contact = _tmp19_;
#line 1007 "email-details.c"
			} else {
				FolksIndividual* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp20_ = i;
#line 140 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp21_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp20_);
#line 140 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp22_ = _tmp21_;
#line 140 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				if (g_strcmp0 (_tmp22_, "richard m. stallman") == 0) {
#line 1020 "email-details.c"
					GeeHashMap* _tmp23_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp23_ = self->priv->_c2;
#line 142 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					contact = _tmp23_;
#line 1026 "email-details.c"
				} else {
					FolksIndividual* _tmp24_ = NULL;
					const gchar* _tmp25_ = NULL;
					const gchar* _tmp26_ = NULL;
#line 144 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp24_ = i;
#line 144 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp25_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp24_);
#line 144 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp26_ = _tmp25_;
#line 144 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					if (g_strcmp0 (_tmp26_, "foo bar") == 0) {
#line 1039 "email-details.c"
						GeeHashMap* _tmp27_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_tmp27_ = self->priv->_c3;
#line 146 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						contact = _tmp27_;
#line 1045 "email-details.c"
					}
				}
			}
#line 149 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp28_ = contact;
#line 149 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			if (_tmp28_ == NULL) {
#line 151 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_g_object_unref0 (i);
#line 151 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				continue;
#line 1057 "email-details.c"
			}
#line 154 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp29_ = contact;
#line 154 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			gee_abstract_map_unset ((GeeAbstractMap*) _tmp29_, "full_name", NULL);
#line 155 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp30_ = i;
#line 155 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp31_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, FOLKS_TYPE_EMAIL_DETAILS, FolksEmailDetails));
#line 155 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			email_owner = _tmp31_;
#line 1069 "email-details.c"
			{
				GeeIterator* _e_it = NULL;
				FolksEmailDetails* _tmp32_ = NULL;
				GeeSet* _tmp33_ = NULL;
				GeeSet* _tmp34_ = NULL;
				GeeIterator* _tmp35_ = NULL;
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp32_ = email_owner;
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp33_ = folks_email_details_get_email_addresses (_tmp32_);
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp34_ = _tmp33_;
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_e_it = _tmp35_;
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				while (TRUE) {
#line 1088 "email-details.c"
					GeeIterator* _tmp36_ = NULL;
					gboolean _tmp37_ = FALSE;
					FolksEmailFieldDetails* e = NULL;
					GeeIterator* _tmp38_ = NULL;
					gpointer _tmp39_ = NULL;
					gint _tmp40_ = 0;
					gboolean found = FALSE;
					gboolean _tmp64_ = FALSE;
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp36_ = _e_it;
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp37_ = gee_iterator_next (_tmp36_);
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					if (!_tmp37_) {
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						break;
#line 1105 "email-details.c"
					}
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp38_ = _e_it;
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp39_ = gee_iterator_get (_tmp38_);
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					e = (FolksEmailFieldDetails*) _tmp39_;
#line 158 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp40_ = self->priv->_email_count;
#line 158 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					self->priv->_email_count = _tmp40_ + 1;
#line 160 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					found = FALSE;
#line 1119 "email-details.c"
					{
						gint j = 0;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						j = 0;
#line 1124 "email-details.c"
						{
							gboolean _tmp41_ = FALSE;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_tmp41_ = TRUE;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							while (TRUE) {
#line 1131 "email-details.c"
								gint _tmp43_ = 0;
								gchar* v = NULL;
								gint _tmp44_ = 0;
								const gchar* _tmp45_ = NULL;
								gchar* _tmp46_ = NULL;
								gboolean _tmp47_ = FALSE;
								GeeHashMap* _tmp48_ = NULL;
								const gchar* _tmp49_ = NULL;
								gpointer _tmp50_ = NULL;
								GValue* _tmp51_ = NULL;
								gboolean _tmp52_ = FALSE;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								if (!_tmp41_) {
#line 1145 "email-details.c"
									gint _tmp42_ = 0;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp42_ = j;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									j = _tmp42_ + 1;
#line 1151 "email-details.c"
								}
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp41_ = FALSE;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp43_ = j;
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								if (!(_tmp43_ < 2)) {
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									break;
#line 1161 "email-details.c"
								}
#line 162 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp44_ = j;
#line 162 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp45_ = EDSF_PERSONA_email_fields[_tmp44_];
#line 162 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp46_ = g_strdup (_tmp45_);
#line 162 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								v = _tmp46_;
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp48_ = contact;
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp49_ = v;
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp50_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp48_, _tmp49_);
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp51_ = (GValue*) _tmp50_;
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_tmp52_ = _tmp51_ != NULL;
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								__vala_GValue_free0 (_tmp51_);
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								if (_tmp52_) {
#line 1185 "email-details.c"
									GeeHashMap* _tmp53_ = NULL;
									const gchar* _tmp54_ = NULL;
									gpointer _tmp55_ = NULL;
									GValue* _tmp56_ = NULL;
									GValue _tmp57_ = {0};
									const gchar* _tmp58_ = NULL;
									FolksEmailFieldDetails* _tmp59_ = NULL;
									gconstpointer _tmp60_ = NULL;
									const gchar* _tmp61_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp53_ = contact;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp54_ = v;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp55_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp53_, _tmp54_);
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp56_ = (GValue*) _tmp55_;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp57_ = *_tmp56_;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp58_ = g_value_get_string (&_tmp57_);
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp59_ = e;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp60_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp59_);
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp61_ = _tmp60_;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp47_ = g_strcmp0 (_tmp58_, (const gchar*) _tmp61_) == 0;
#line 164 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									__vala_GValue_free0 (_tmp56_);
#line 1217 "email-details.c"
								} else {
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp47_ = FALSE;
#line 1221 "email-details.c"
								}
#line 163 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								if (_tmp47_) {
#line 1225 "email-details.c"
									GeeHashMap* _tmp62_ = NULL;
									const gchar* _tmp63_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									found = TRUE;
#line 166 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp62_ = contact;
#line 166 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									_tmp63_ = v;
#line 166 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
									gee_abstract_map_unset ((GeeAbstractMap*) _tmp62_, _tmp63_, NULL);
#line 1236 "email-details.c"
								}
#line 161 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								_g_free0 (v);
#line 1240 "email-details.c"
							}
						}
					}
#line 169 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_tmp64_ = found;
#line 169 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_vala_assert (_tmp64_, "found");
#line 1248 "email-details.c"
					{
						GeeIterator* _v_it = NULL;
						FolksEmailFieldDetails* _tmp65_ = NULL;
						GeeCollection* _tmp66_ = NULL;
						GeeCollection* _tmp67_ = NULL;
						GeeIterator* _tmp68_ = NULL;
						GeeIterator* _tmp69_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_tmp65_ = e;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_tmp66_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp65_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_tmp67_ = _tmp66_;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_tmp68_ = gee_iterable_iterator ((GeeIterable*) _tmp67_);
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_tmp69_ = _tmp68_;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_g_object_unref0 (_tmp67_);
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_v_it = _tmp69_;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						while (TRUE) {
#line 1272 "email-details.c"
							GeeIterator* _tmp70_ = NULL;
							gboolean _tmp71_ = FALSE;
							gchar* v = NULL;
							GeeIterator* _tmp72_ = NULL;
							gpointer _tmp73_ = NULL;
							GeeHashSet* _tmp74_ = NULL;
							const gchar* _tmp75_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_tmp70_ = _v_it;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_tmp71_ = gee_iterator_next (_tmp70_);
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							if (!_tmp71_) {
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
								break;
#line 1288 "email-details.c"
							}
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_tmp72_ = _v_it;
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_tmp73_ = gee_iterator_get (_tmp72_);
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							v = (gchar*) _tmp73_;
#line 172 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_tmp74_ = self->priv->_email_types;
#line 172 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_tmp75_ = v;
#line 172 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							gee_abstract_collection_add ((GeeAbstractCollection*) _tmp74_, _tmp75_);
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
							_g_free0 (v);
#line 1304 "email-details.c"
						}
#line 170 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
						_g_object_unref0 (_v_it);
#line 1308 "email-details.c"
					}
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
					_g_object_unref0 (e);
#line 1312 "email-details.c"
				}
#line 156 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				_g_object_unref0 (_e_it);
#line 1316 "email-details.c"
			}
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_g_object_unref0 (email_owner);
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_g_object_unref0 (i);
#line 1322 "email-details.c"
		}
#line 129 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_i_it);
#line 1326 "email-details.c"
	}
#line 177 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp76_ = removed;
#line 177 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp77_ = gee_collection_get_size ((GeeCollection*) _tmp76_);
#line 177 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp78_ = _tmp77_;
#line 177 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_vala_assert (_tmp78_ == 1, "removed.size == 1");
#line 1336 "email-details.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp79_ = NULL;
		GeeIterator* _tmp80_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_tmp79_ = removed;
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_tmp80_ = gee_iterable_iterator ((GeeIterable*) _tmp79_);
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_i_it = _tmp80_;
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		while (TRUE) {
#line 1349 "email-details.c"
			GeeIterator* _tmp81_ = NULL;
			gboolean _tmp82_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp83_ = NULL;
			gpointer _tmp84_ = NULL;
			FolksIndividual* _tmp85_ = NULL;
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp81_ = _i_it;
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp82_ = gee_iterator_next (_tmp81_);
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			if (!_tmp82_) {
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
				break;
#line 1364 "email-details.c"
			}
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp83_ = _i_it;
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp84_ = gee_iterator_get (_tmp83_);
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			i = (FolksIndividual*) _tmp84_;
#line 181 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_tmp85_ = i;
#line 181 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_vala_assert (_tmp85_ == NULL, "i == null");
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
			_g_object_unref0 (i);
#line 1378 "email-details.c"
		}
#line 179 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
		_g_object_unref0 (_i_it);
#line 1382 "email-details.c"
	}
#line 123 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (removed);
#line 123 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (added);
#line 1388 "email-details.c"
}


static void email_details_tests_class_init (EmailDetailsTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	email_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_type_class_add_private (klass, sizeof (EmailDetailsTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_OBJECT_CLASS (klass)->finalize = email_details_tests_finalize;
#line 1399 "email-details.c"
}


static void email_details_tests_instance_init (EmailDetailsTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self->priv = EMAIL_DETAILS_TESTS_GET_PRIVATE (self);
#line 1406 "email-details.c"
}


static void email_details_tests_finalize (GObject* obj) {
	EmailDetailsTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_EMAIL_DETAILS_TESTS, EmailDetailsTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 28 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 30 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_email_types);
#line 31 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c1);
#line 32 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c2);
#line 33 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (self->priv->_c3);
#line 25 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	G_OBJECT_CLASS (email_details_tests_parent_class)->finalize (obj);
#line 1428 "email-details.c"
}


GType email_details_tests_get_type (void) {
	static volatile gsize email_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&email_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EmailDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) email_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EmailDetailsTests), 0, (GInstanceInitFunc) email_details_tests_instance_init, NULL };
		GType email_details_tests_type_id;
		email_details_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "EmailDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&email_details_tests_type_id__volatile, email_details_tests_type_id);
	}
	return email_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	EmailDetailsTests* tests = NULL;
	EmailDetailsTests* _tmp0_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 190 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_tmp0_ = email_details_tests_new ();
#line 190 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	tests = _tmp0_;
#line 191 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 192 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	g_test_run ();
#line 193 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 195 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	result = 0;
#line 195 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	_g_object_unref0 (tests);
#line 195 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return result;
#line 1466 "email-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 186 "/opt/gnome3/source/folks/tests/eds/email-details.vala"
	return _vala_main (argv, argc);
#line 1476 "email-details.c"
}



