/* aggregation.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from aggregation.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <tpf-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <tp-test-contactlist.h>
#include <folks/folks.h>
#include <kf-test.h>
#include <gio/gio.h>


#define TYPE_AGGREGATION_TESTS (aggregation_tests_get_type ())
#define AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AGGREGATION_TESTS, AggregationTests))
#define AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AGGREGATION_TESTS, AggregationTestsClass))
#define IS_AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AGGREGATION_TESTS))
#define IS_AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AGGREGATION_TESTS))
#define AGGREGATION_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AGGREGATION_TESTS, AggregationTestsClass))

typedef struct _AggregationTests AggregationTests;
typedef struct _AggregationTestsClass AggregationTestsClass;
typedef struct _AggregationTestsPrivate AggregationTestsPrivate;

#define AGGREGATION_TESTS_TYPE_INDIVIDUAL_STATE (aggregation_tests_individual_state_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block1Data Block1Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
typedef struct _Block7Data Block7Data;
typedef struct _Block8Data Block8Data;
typedef struct _Block9Data Block9Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AggregationTests {
	TpfTestMixedTestCase parent_instance;
	AggregationTestsPrivate * priv;
};

struct _AggregationTestsClass {
	TpfTestMixedTestCaseClass parent_class;
};

struct _AggregationTestsPrivate {
	GeeHashSet* _default_personas;
	gchar* olivier_sha1;
};

typedef enum  {
	AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED,
	AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED,
	AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED
} AggregationTestsIndividualState;

struct _Block1Data {
	int _ref_count_;
	AggregationTests* self;
	GeeHashSet* default_individuals;
	GeeHashSet* expected_individuals;
	GeeHashSet* expected_individuals_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block2Data {
	int _ref_count_;
	AggregationTests* self;
	FolksIndividual* individual1;
	FolksIndividual* individual1_detailed;
	FolksIndividual* individual2;
	FolksIndividual* individual2_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block3Data {
	int _ref_count_;
	AggregationTests* self;
	FolksIndividual* individual1;
	FolksIndividual* individual1_detailed;
	FolksIndividual* individual2;
	FolksIndividual* individual2_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block4Data {
	int _ref_count_;
	AggregationTests* self;
	FolksIndividual* user_individual;
	FolksIndividual* user_individual_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block5Data {
	int _ref_count_;
	AggregationTests* self;
	FolksIndividualAggregator* aggregator;
};

struct _Block6Data {
	int _ref_count_;
	AggregationTests* self;
	GeeHashMap* individuals_map;
	FolksIndividualAggregator* aggregator;
	gboolean aggregator_is_finalising;
};

struct _Block7Data {
	int _ref_count_;
	AggregationTests* self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};

struct _Block8Data {
	int _ref_count_;
	AggregationTests* self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};

struct _Block9Data {
	int _ref_count_;
	AggregationTests* self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};


static gpointer aggregation_tests_parent_class = NULL;
static gchar* aggregation_tests_iid_prefix;
static gchar* aggregation_tests_iid_prefix = NULL;

GType aggregation_tests_get_type (void) G_GNUC_CONST;
#define AGGREGATION_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_AGGREGATION_TESTS, AggregationTestsPrivate))
enum  {
	AGGREGATION_TESTS_DUMMY_PROPERTY
};
static GType aggregation_tests_individual_state_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
AggregationTests* aggregation_tests_new (void);
AggregationTests* aggregation_tests_construct (GType object_type);
void aggregation_tests_test_iid (AggregationTests* self);
static void _aggregation_tests_test_iid_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linkable_properties_same_store (AggregationTests* self);
static void _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linkable_properties_different_stores (AggregationTests* self);
static void _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_user (AggregationTests* self);
static void _aggregation_tests_test_user_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_untrusted_store (AggregationTests* self);
static void _aggregation_tests_test_untrusted_store_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linked_individual_refcounting (AggregationTests* self);
static void _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_trivial (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_add_persona (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_failure (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method (gpointer self);
static void aggregation_tests_real_set_up_tp (TpfTestTestCase* base);
static void aggregation_tests_real_set_up_kf (TpfTestTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes);
static void _aggregation_tests_test_iid_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, GeeSet* default_individuals, GeeSet* expected_individuals);
static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda4_ (Block1Data* _data1_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda4__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda5_ (Block1Data* _data1_);
static void __lambda6_ (Block1Data* _data1_, GObject* s, GAsyncResult* r);
static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda5__gsource_func (gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda7_ (Block2Data* _data2_, GeeMultiMap* changes);
static void _aggregation_tests_test_linkable_properties_individuals_changed (AggregationTests* self, gboolean detailed, guint num_personas, GeeCollection* added, GeeSet* removed, FolksIndividual** individual1, FolksIndividual** individual2);
static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda8_ (Block2Data* _data2_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda8__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda9_ (Block2Data* _data2_);
static void __lambda10_ (Block2Data* _data2_, GObject* s, GAsyncResult* r);
static void ___lambda10__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda9__gsource_func (gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda11_ (Block3Data* _data3_, GeeMultiMap* changes);
static void ___lambda11__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda12_ (Block3Data* _data3_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda12__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda13_ (Block3Data* _data3_);
static void __lambda14_ (Block3Data* _data3_, GObject* s, GAsyncResult* r);
static void ___lambda14__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda13__gsource_func (gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void __lambda15_ (Block4Data* _data4_, GeeMultiMap* changes);
static void _aggregation_tests_test_user_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, FolksIndividual** user_individual);
static void ___lambda15__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda16_ (Block4Data* _data4_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda16__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda17_ (Block4Data* _data4_);
static void __lambda18_ (Block4Data* _data4_, GObject* s, GAsyncResult* r);
static void ___lambda18__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda17__gsource_func (gpointer self);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void __lambda19_ (AggregationTests* self, GeeMultiMap* changes);
static void _aggregation_tests_test_untrusted_store_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed);
static void ___lambda19__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda20_ (AggregationTests* self, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda20__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda21_ (Block5Data* _data5_);
static void __lambda22_ (Block5Data* _data5_, GObject* s, GAsyncResult* r);
static void ___lambda22__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda21__gsource_func (gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void __lambda23_ (Block6Data* _data6_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ____lambda24_ (Block6Data* _data6_, GObject* obj);
static void _____lambda24__gweak_notify (gpointer self, GObject* object);
static void ___lambda23__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda25_ (Block6Data* _data6_);
static void __lambda26_ (Block6Data* _data6_, GObject* s, GAsyncResult* r);
static void ___lambda26__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda25__gsource_func (gpointer self);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static void __lambda27_ (Block7Data* _data7_, GeeMultiMap* changes);
static void ___lambda27__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda28_ (Block7Data* _data7_);
static void __lambda29_ (Block7Data* _data7_, GObject* s, GAsyncResult* r);
static void ___lambda29__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda28__gsource_func (gpointer self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static gboolean __lambda30_ (Block7Data* _data7_);
static void __lambda31_ (Block7Data* _data7_, GObject* obj, GAsyncResult* res);
static void ___lambda31__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda30__gsource_func (gpointer self);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
static void __lambda32_ (Block8Data* _data8_, GeeMultiMap* changes);
static void ___lambda32__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda33_ (Block8Data* _data8_);
static void __lambda34_ (Block8Data* _data8_, GObject* s, GAsyncResult* r);
static void ___lambda34__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda33__gsource_func (gpointer self);
static void __lambda35_ (Block8Data* _data8_, GeeMultiMap* changes);
static void ___lambda35__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda36_ (Block8Data* _data8_);
static void __lambda37_ (Block8Data* _data8_, GObject* obj, GAsyncResult* res);
static void ___lambda37__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda36__gsource_func (gpointer self);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda38_ (Block9Data* _data9_, GeeMultiMap* changes);
static void ___lambda38__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda39_ (Block9Data* _data9_);
static void __lambda40_ (Block9Data* _data9_, GObject* s, GAsyncResult* r);
static void ___lambda40__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda39__gsource_func (gpointer self);
static gboolean __lambda41_ (Block9Data* _data9_);
static void __lambda42_ (Block9Data* _data9_, GObject* obj, GAsyncResult* res);
static void ___lambda42__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda41__gsource_func (gpointer self);
static void aggregation_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static GType aggregation_tests_individual_state_get_type (void) {
	static volatile gsize aggregation_tests_individual_state_type_id__volatile = 0;
	if (g_once_init_enter (&aggregation_tests_individual_state_type_id__volatile)) {
		static const GEnumValue values[] = {{AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED", "added"}, {AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED", "removed"}, {AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED", "finalised"}, {0, NULL, NULL}};
		GType aggregation_tests_individual_state_type_id;
		aggregation_tests_individual_state_type_id = g_enum_register_static ("AggregationTestsIndividualState", values);
		g_once_init_leave (&aggregation_tests_individual_state_type_id__volatile, aggregation_tests_individual_state_type_id);
	}
	return aggregation_tests_individual_state_type_id__volatile;
}


static void _aggregation_tests_test_iid_folks_test_case_test_method (gpointer self) {
#line 50 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_iid ((AggregationTests*) self);
#line 317 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method (gpointer self) {
#line 51 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linkable_properties_same_store ((AggregationTests*) self);
#line 324 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method (gpointer self) {
#line 53 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linkable_properties_different_stores ((AggregationTests*) self);
#line 331 "aggregation.c"
}


static void _aggregation_tests_test_user_folks_test_case_test_method (gpointer self) {
#line 55 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_user ((AggregationTests*) self);
#line 338 "aggregation.c"
}


static void _aggregation_tests_test_untrusted_store_folks_test_case_test_method (gpointer self) {
#line 56 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_untrusted_store ((AggregationTests*) self);
#line 345 "aggregation.c"
}


static void _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method (gpointer self) {
#line 57 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linked_individual_refcounting ((AggregationTests*) self);
#line 352 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method (gpointer self) {
#line 58 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_trivial ((AggregationTests*) self);
#line 359 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method (gpointer self) {
#line 60 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_add_persona ((AggregationTests*) self);
#line 366 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method (gpointer self) {
#line 62 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_failure ((AggregationTests*) self);
#line 373 "aggregation.c"
}


AggregationTests* aggregation_tests_construct (GType object_type) {
	AggregationTests * self = NULL;
	GeeHashSet* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GeeHashSet* _tmp5_ = NULL;
	GeeHashSet* _tmp6_ = NULL;
	GeeHashSet* _tmp7_ = NULL;
	GeeHashSet* _tmp8_ = NULL;
#line 35 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) tpf_test_mixed_test_case_construct (object_type, "Aggregation");
#line 38 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 38 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_default_personas);
#line 38 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self->priv->_default_personas = _tmp0_;
#line 40 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_default_personas;
#line 40 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp1_, "travis@example.com");
#line 41 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_default_personas;
#line 41 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp2_, "olivier@example.com");
#line 42 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = self->priv->_default_personas;
#line 42 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, "guillaume@example.com");
#line 43 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_default_personas;
#line 43 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp4_, "sjoerd@example.com");
#line 44 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = self->priv->_default_personas;
#line 44 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, "christian@example.com");
#line 45 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = self->priv->_default_personas;
#line 45 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp6_, "wim@example.com");
#line 46 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = self->priv->_default_personas;
#line 46 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, "helen@example.com");
#line 47 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = self->priv->_default_personas;
#line 47 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp8_, "geraldine@example.com");
#line 50 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "IID", _aggregation_tests_test_iid_folks_test_case_test_method, self);
#line 51 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "linkable properties:same store", _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method, self);
#line 53 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "linkable properties:different stores", _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method, self);
#line 55 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "user", _aggregation_tests_test_user_folks_test_case_test_method, self);
#line 56 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "untrusted store", _aggregation_tests_test_untrusted_store_folks_test_case_test_method, self);
#line 57 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "refcounting", _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method, self);
#line 58 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:trivial", _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method, self);
#line 60 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:add persona", _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method, self);
#line 62 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:failure", _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method, self);
#line 33 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return self;
#line 448 "aggregation.c"
}


AggregationTests* aggregation_tests_new (void) {
#line 33 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return aggregation_tests_construct (TYPE_AGGREGATION_TESTS);
#line 455 "aggregation.c"
}


static void aggregation_tests_real_set_up_tp (TpfTestTestCase* base) {
	AggregationTests * self;
	TpTestsBackend* _tmp0_ = NULL;
#line 66 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) base;
#line 69 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = ((TpfTestTestCase*) self)->tp_backend;
#line 69 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, tp_tests_backend_get_type (), TpTestsBackend));
#line 468 "aggregation.c"
}


static void aggregation_tests_real_set_up_kf (TpfTestTestCase* base) {
	AggregationTests * self;
#line 72 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) base;
#line 476 "aggregation.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data1_;
#line 485 "aggregation.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 494 "aggregation.c"
		AggregationTests* self;
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data1_->self;
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->aggregator);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->expected_individuals_detailed);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->expected_individuals);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->default_individuals);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block1Data, _data1_);
#line 510 "aggregation.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 88 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return self ? g_object_ref (self) : NULL;
#line 518 "aggregation.c"
}


static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GeeHashSet* _tmp5_ = NULL;
#line 118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 120 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 120 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 120 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 121 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 121 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 121 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 123 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = _data1_->default_individuals;
#line 123 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data1_->expected_individuals_detailed;
#line 123 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_iid_individuals_changed (self, TRUE, added, removed, (GeeSet*) _tmp4_, (GeeSet*) _tmp5_);
#line 118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 558 "aggregation.c"
}


static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda3_ (self, changes);
#line 565 "aggregation.c"
}


static void __lambda4_ (Block1Data* _data1_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests* self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
#line 126 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 126 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 126 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 128 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 128 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 128 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _data1_->default_individuals;
#line 128 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data1_->expected_individuals;
#line 128 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_iid_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_, (GeeSet*) _tmp2_, (GeeSet*) _tmp3_);
#line 591 "aggregation.c"
}


static void ___lambda4__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 126 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda4_ (self, added, removed, message, actor, reason);
#line 598 "aggregation.c"
}


static void __lambda6_ (Block1Data* _data1_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 138 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 138 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 609 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 142 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data1_->aggregator;
#line 142 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 142 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 142 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 621 "aggregation.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 146 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:146: Failed to prepare aggregator: %s", _tmp2_);
#line 148 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 642 "aggregation.c"
	}
	__finally0:
#line 140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 653 "aggregation.c"
	}
}


static void ___lambda6__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 138 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda6_ (self, source_object, res);
#line 138 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block1_data_unref (self);
#line 663 "aggregation.c"
}


static gboolean __lambda5_ (Block1Data* _data1_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 136 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 138 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data1_->aggregator;
#line 138 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda6__gasync_ready_callback, block1_data_ref (_data1_));
#line 152 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 152 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 681 "aggregation.c"
}


static gboolean ___lambda5__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda5_ (self);
#line 136 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 690 "aggregation.c"
}


void aggregation_tests_test_iid (AggregationTests* self) {
	Block1Data* _data1_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	KfTestBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	TpTestsBackend* _tmp4_ = NULL;
	void* _tmp5_ = NULL;
	void* account2_handle = NULL;
	TpTestsBackend* _tmp6_ = NULL;
	void* _tmp7_ = NULL;
	GeeHashSet* _tmp8_ = NULL;
	GeeHashSet* _tmp22_ = NULL;
	GeeHashSet* _tmp23_ = NULL;
	FolksIndividualAggregator* _tmp34_ = NULL;
	FolksIndividualAggregator* _tmp35_ = NULL;
	FolksIndividualAggregator* _tmp36_ = NULL;
	GMainLoop* _tmp37_ = NULL;
	GeeHashSet* _tmp38_ = NULL;
	gint _tmp39_ = 0;
	gint _tmp40_ = 0;
	GeeHashSet* _tmp41_ = NULL;
	gint _tmp42_ = 0;
	gint _tmp43_ = 0;
	TpTestsBackend* _tmp44_ = NULL;
	void* _tmp45_ = NULL;
	TpTestsBackend* _tmp46_ = NULL;
	void* _tmp47_ = NULL;
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_->_ref_count_ = 1;
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_->self = g_object_ref (self);
#line 86 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 86 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 88 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->tp_backend;
#line 88 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, tp_tests_backend_get_type (), TpTestsBackend));
#line 88 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp2_;
#line 89 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = ((TpfTestTestCase*) self)->kf_backend;
#line 89 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 91 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_backend;
#line 91 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (_tmp4_, "protocol", "me@example.com", "cm", "account");
#line 91 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp5_;
#line 93 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = tp_backend;
#line 93 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = tp_tests_backend_add_account (_tmp6_, "protocol", "me2@example.com", "cm", "account2");
#line 93 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp7_;
#line 97 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 97 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_->default_individuals = _tmp8_;
#line 763 "aggregation.c"
	{
		GeeIterator* _id_it = NULL;
		GeeHashSet* _tmp9_ = NULL;
		GeeIterator* _tmp10_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp9_ = self->priv->_default_personas;
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp10_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp9_);
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_id_it = _tmp10_;
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 776 "aggregation.c"
			GeeIterator* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gchar* id = NULL;
			GeeIterator* _tmp13_ = NULL;
			gpointer _tmp14_ = NULL;
			GeeHashSet* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = _id_it;
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = gee_iterator_next (_tmp11_);
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp12_) {
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 797 "aggregation.c"
			}
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _id_it;
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = gee_iterator_get (_tmp13_);
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			id = (gchar*) _tmp14_;
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = _data1_->default_individuals;
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = aggregation_tests_iid_prefix;
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = id;
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp18_ = g_strconcat (_tmp16_, _tmp17_, NULL);
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp19_ = _tmp18_;
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp20_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp19_, (gsize) (-1));
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _tmp20_;
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, _tmp21_);
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_free0 (_tmp21_);
#line 100 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_free0 (_tmp19_);
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_free0 (id);
#line 827 "aggregation.c"
		}
#line 98 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_id_it);
#line 831 "aggregation.c"
	}
#line 108 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 108 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_->expected_individuals = _tmp22_;
#line 109 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 109 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_->expected_individuals_detailed = _tmp23_;
#line 841 "aggregation.c"
	{
		GeeIterator* _id_it = NULL;
		GeeHashSet* _tmp24_ = NULL;
		GeeIterator* _tmp25_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp24_ = _data1_->default_individuals;
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp25_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp24_);
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_id_it = _tmp25_;
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 854 "aggregation.c"
			GeeIterator* _tmp26_ = NULL;
			gboolean _tmp27_ = FALSE;
			gchar* id = NULL;
			GeeIterator* _tmp28_ = NULL;
			gpointer _tmp29_ = NULL;
			GeeHashSet* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			GeeHashSet* _tmp32_ = NULL;
			const gchar* _tmp33_ = NULL;
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = _id_it;
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = gee_iterator_next (_tmp26_);
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp27_) {
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 872 "aggregation.c"
			}
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = _id_it;
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = gee_iterator_get (_tmp28_);
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			id = (gchar*) _tmp29_;
#line 112 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = _data1_->expected_individuals;
#line 112 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = id;
#line 112 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp30_, _tmp31_);
#line 113 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = _data1_->expected_individuals_detailed;
#line 113 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = id;
#line 113 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp32_, _tmp33_);
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_free0 (id);
#line 894 "aggregation.c"
		}
#line 110 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_id_it);
#line 898 "aggregation.c"
	}
#line 117 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp34_ = folks_individual_aggregator_dup ();
#line 117 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_->aggregator = _tmp34_;
#line 118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp35_ = _data1_->aggregator;
#line 118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp35_, "individuals-changed-detailed", (GCallback) ___lambda3__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 126 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp36_ = _data1_->aggregator;
#line 126 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp36_, "individuals-changed", (GCallback) ___lambda4__folks_individual_aggregator_individuals_changed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 136 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda5__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 155 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp37_ = main_loop;
#line 155 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp37_, 3);
#line 158 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp38_ = _data1_->expected_individuals;
#line 158 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp39_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp38_);
#line 158 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp40_ = _tmp39_;
#line 158 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp40_ == 0, "expected_individuals.size == 0");
#line 159 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp41_ = _data1_->expected_individuals_detailed;
#line 159 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp42_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp41_);
#line 159 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp43_ = _tmp42_;
#line 159 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp43_ == 0, "expected_individuals_detailed.size == 0");
#line 162 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp44_ = tp_backend;
#line 162 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp45_ = account2_handle;
#line 162 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp44_, _tmp45_);
#line 163 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp46_ = tp_backend;
#line 163 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp47_ = account1_handle;
#line 163 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp46_, _tmp47_);
#line 164 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data1_->aggregator);
#line 164 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_->aggregator = NULL;
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block1_data_unref (_data1_);
#line 84 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data1_ = NULL;
#line 958 "aggregation.c"
}


static void _aggregation_tests_test_iid_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, GeeSet* default_individuals, GeeSet* expected_individuals) {
#line 167 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 167 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 167 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 167 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (default_individuals != NULL);
#line 167 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (expected_individuals != NULL);
#line 973 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 986 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			gboolean _tmp11_ = FALSE;
			FolksIndividual* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			gboolean _tmp14_ = FALSE;
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 1008 "aggregation.c"
			}
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 175 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 175 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 175 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 1022 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 175 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 175 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 1029 "aggregation.c"
			}
#line 175 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp6_, "i != null || detailed == true");
#line 176 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = i;
#line 176 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp9_ == NULL) {
#line 178 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 178 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 1041 "aggregation.c"
			}
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = folks_individual_get_is_user (_tmp12_);
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp13_;
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp14_) {
#line 1051 "aggregation.c"
				FolksIndividual* _tmp15_ = NULL;
				GeeSet* _tmp16_ = NULL;
				GeeSet* _tmp17_ = NULL;
				gint _tmp18_ = 0;
				gint _tmp19_ = 0;
#line 182 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 182 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = folks_individual_get_personas (_tmp15_);
#line 182 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = _tmp16_;
#line 182 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 182 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp19_ = _tmp18_;
#line 182 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = _tmp19_ == 2;
#line 1069 "aggregation.c"
			} else {
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp11_ = FALSE;
#line 1073 "aggregation.c"
			}
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp11_) {
#line 1077 "aggregation.c"
				GeeSet* _tmp20_ = NULL;
				FolksIndividual* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
				const gchar* _tmp23_ = NULL;
				gboolean _tmp24_ = FALSE;
#line 183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp20_ = default_individuals;
#line 183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp21_ = i;
#line 183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp22_ = folks_individual_get_id (_tmp21_);
#line 183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp23_ = _tmp22_;
#line 183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp24_ = gee_collection_contains ((GeeCollection*) _tmp20_, _tmp23_);
#line 183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp10_ = _tmp24_;
#line 1095 "aggregation.c"
			} else {
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp10_ = FALSE;
#line 1099 "aggregation.c"
			}
#line 181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_) {
#line 1103 "aggregation.c"
				GeeSet* _tmp25_ = NULL;
				FolksIndividual* _tmp26_ = NULL;
				const gchar* _tmp27_ = NULL;
				const gchar* _tmp28_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp25_ = expected_individuals;
#line 185 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp26_ = i;
#line 185 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp27_ = folks_individual_get_id (_tmp26_);
#line 185 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp28_ = _tmp27_;
#line 185 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				gee_collection_add ((GeeCollection*) _tmp25_, _tmp28_);
#line 1118 "aggregation.c"
			}
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 1122 "aggregation.c"
		}
#line 173 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1126 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp29_ = NULL;
		GeeIterator* _tmp30_ = NULL;
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp29_ = added;
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp30_ = gee_iterable_iterator ((GeeIterable*) _tmp29_);
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp30_;
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 1140 "aggregation.c"
			GeeIterator* _tmp31_ = NULL;
			gboolean _tmp32_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp33_ = NULL;
			gpointer _tmp34_ = NULL;
			gboolean _tmp35_ = FALSE;
			FolksIndividual* _tmp36_ = NULL;
			FolksIndividual* _tmp38_ = NULL;
			GeeSet* personas = NULL;
			FolksIndividual* _tmp39_ = NULL;
			GeeSet* _tmp40_ = NULL;
			GeeSet* _tmp41_ = NULL;
			GeeSet* _tmp42_ = NULL;
			gboolean _tmp43_ = FALSE;
			FolksIndividual* _tmp44_ = NULL;
			gboolean _tmp45_ = FALSE;
			gboolean _tmp46_ = FALSE;
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = _i_it;
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = gee_iterator_next (_tmp31_);
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp32_) {
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 1166 "aggregation.c"
			}
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = _i_it;
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = gee_iterator_get (_tmp33_);
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp34_;
#line 193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp36_ = i;
#line 193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp36_ != NULL) {
#line 193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp35_ = TRUE;
#line 1180 "aggregation.c"
			} else {
				gboolean _tmp37_ = FALSE;
#line 193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp37_ = detailed;
#line 193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp35_ = _tmp37_ == TRUE;
#line 1187 "aggregation.c"
			}
#line 193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp35_, "i != null || detailed == true");
#line 194 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp38_ = i;
#line 194 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp38_ == NULL) {
#line 196 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 196 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 1199 "aggregation.c"
			}
#line 199 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = i;
#line 199 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = folks_individual_get_personas (_tmp39_);
#line 199 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp41_ = _tmp40_;
#line 199 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp42_ = _g_object_ref0 (_tmp41_);
#line 199 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			personas = _tmp42_;
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp44_ = i;
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp45_ = folks_individual_get_is_user (_tmp44_);
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp46_ = _tmp45_;
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp46_) {
#line 1219 "aggregation.c"
				GeeSet* _tmp47_ = NULL;
				gint _tmp48_ = 0;
				gint _tmp49_ = 0;
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp47_ = personas;
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp48_ = gee_collection_get_size ((GeeCollection*) _tmp47_);
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp49_ = _tmp48_;
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp43_ = _tmp49_ == 2;
#line 1231 "aggregation.c"
			} else {
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp43_ = FALSE;
#line 1235 "aggregation.c"
			}
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp43_) {
#line 1239 "aggregation.c"
				GeeSet* _tmp50_ = NULL;
				FolksIndividual* _tmp51_ = NULL;
				const gchar* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gboolean _tmp54_ = FALSE;
				gchar* iid = NULL;
#line 204 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp50_ = expected_individuals;
#line 204 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp51_ = i;
#line 204 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp52_ = folks_individual_get_id (_tmp51_);
#line 204 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp53_ = _tmp52_;
#line 204 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp54_ = gee_collection_remove ((GeeCollection*) _tmp50_, _tmp53_);
#line 204 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp54_, "expected_individuals.remove (i.id)");
#line 206 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				iid = NULL;
#line 1260 "aggregation.c"
				{
					GeeIterator* _persona_it = NULL;
					GeeSet* _tmp55_ = NULL;
					GeeIterator* _tmp56_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp55_ = personas;
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp56_ = gee_iterable_iterator ((GeeIterable*) _tmp55_);
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_persona_it = _tmp56_;
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					while (TRUE) {
#line 1273 "aggregation.c"
						GeeIterator* _tmp57_ = NULL;
						gboolean _tmp58_ = FALSE;
						FolksPersona* persona = NULL;
						GeeIterator* _tmp59_ = NULL;
						gpointer _tmp60_ = NULL;
						const gchar* _tmp61_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp57_ = _persona_it;
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp58_ = gee_iterator_next (_tmp57_);
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						if (!_tmp58_) {
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							break;
#line 1288 "aggregation.c"
						}
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp59_ = _persona_it;
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp60_ = gee_iterator_get (_tmp59_);
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						persona = (FolksPersona*) _tmp60_;
#line 209 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp61_ = iid;
#line 209 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						if (_tmp61_ != NULL) {
#line 1300 "aggregation.c"
							FolksPersona* _tmp62_ = NULL;
							const gchar* _tmp63_ = NULL;
							const gchar* _tmp64_ = NULL;
							const gchar* _tmp65_ = NULL;
#line 211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp62_ = persona;
#line 211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp63_ = folks_persona_get_iid (_tmp62_);
#line 211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp64_ = _tmp63_;
#line 211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp65_ = iid;
#line 211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_vala_assert (g_strcmp0 (_tmp64_, _tmp65_) == 0, "persona.iid == iid");
#line 1315 "aggregation.c"
						} else {
							FolksPersona* _tmp66_ = NULL;
							const gchar* _tmp67_ = NULL;
							const gchar* _tmp68_ = NULL;
							gchar* _tmp69_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp66_ = persona;
#line 215 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp67_ = folks_persona_get_iid (_tmp66_);
#line 215 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp68_ = _tmp67_;
#line 215 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp69_ = g_strdup (_tmp68_);
#line 215 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_g_free0 (iid);
#line 215 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							iid = _tmp69_;
#line 1333 "aggregation.c"
						}
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_g_object_unref0 (persona);
#line 1337 "aggregation.c"
					}
#line 207 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_persona_it);
#line 1341 "aggregation.c"
				}
#line 202 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_free0 (iid);
#line 1345 "aggregation.c"
			}
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (personas);
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 1351 "aggregation.c"
		}
#line 191 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1355 "aggregation.c"
	}
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data2_;
#line 1365 "aggregation.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1374 "aggregation.c"
		AggregationTests* self;
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data2_->self;
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data2_->aggregator);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block2Data, _data2_);
#line 1384 "aggregation.c"
	}
}


static void __lambda7_ (Block2Data* _data2_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 253 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 253 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 253 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 254 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 254 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 254 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 256 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, TRUE, (guint) 5, added, removed, &_data2_->individual1_detailed, &_data2_->individual2_detailed);
#line 251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1419 "aggregation.c"
}


static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda7_ (self, changes);
#line 1426 "aggregation.c"
}


static void __lambda8_ (Block2Data* _data2_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests* self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 259 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 259 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 259 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 261 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 261 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 261 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, FALSE, (guint) 5, (GeeCollection*) _tmp0_, _tmp1_, &_data2_->individual1, &_data2_->individual2);
#line 1446 "aggregation.c"
}


static void ___lambda8__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 259 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda8_ (self, added, removed, message, actor, reason);
#line 1453 "aggregation.c"
}


static void __lambda10_ (Block2Data* _data2_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 1464 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 275 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data2_->aggregator;
#line 275 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 275 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 275 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 1476 "aggregation.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 273 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 273 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 279 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 279 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:279: Failed to prepare aggregator: %s", _tmp2_);
#line 281 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 273 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 1497 "aggregation.c"
	}
	__finally1:
#line 273 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 273 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 273 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 273 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 1508 "aggregation.c"
	}
}


static void ___lambda10__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda10_ (self, source_object, res);
#line 271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block2_data_unref (self);
#line 1518 "aggregation.c"
}


static gboolean __lambda9_ (Block2Data* _data2_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 269 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data2_->aggregator;
#line 271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda10__gasync_ready_callback, block2_data_ref (_data2_));
#line 285 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 285 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 1536 "aggregation.c"
}


static gboolean ___lambda9__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda9_ (self);
#line 269 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 1545 "aggregation.c"
}


void aggregation_tests_test_linkable_properties_same_store (AggregationTests* self) {
	Block2Data* _data2_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	void* _tmp3_ = NULL;
	FolksIndividualAggregator* _tmp4_ = NULL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	GMainLoop* _tmp7_ = NULL;
	FolksIndividual* _tmp8_ = NULL;
	FolksIndividual* _tmp9_ = NULL;
	FolksIndividual* _tmp10_ = NULL;
	FolksIndividual* _tmp11_ = NULL;
	GeeHashSet* individual1_expected = NULL;
	GeeHashSet* _tmp12_ = NULL;
	GeeHashSet* _tmp13_ = NULL;
	GeeHashSet* _tmp14_ = NULL;
	GeeHashSet* _tmp15_ = NULL;
	GeeHashSet* _tmp16_ = NULL;
	GeeHashSet* _tmp17_ = NULL;
	GeeHashSet* individual2_expected = NULL;
	GeeHashSet* _tmp18_ = NULL;
	GeeHashSet* _tmp19_ = NULL;
	GeeHashSet* _tmp20_ = NULL;
	GeeHashSet* _tmp21_ = NULL;
	GeeHashSet* _tmp22_ = NULL;
	GeeHashSet* _tmp23_ = NULL;
	GeeHashSet* set_in_use = NULL;
	gboolean detailed_swapped = FALSE;
	GeeHashSet* _tmp84_ = NULL;
	gint _tmp85_ = 0;
	gint _tmp86_ = 0;
	GeeHashSet* _tmp87_ = NULL;
	GeeHashSet* _tmp88_ = NULL;
	GeeHashSet* _tmp121_ = NULL;
	gint _tmp122_ = 0;
	gint _tmp123_ = 0;
	TpTestsBackend* _tmp124_ = NULL;
	void* _tmp125_ = NULL;
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->_ref_count_ = 1;
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->self = g_object_ref (self);
#line 230 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 230 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 232 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 232 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com");
#line 239 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 239 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_tests_backend_add_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend), "protocol", "me@example.com", "cm", "account");
#line 239 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	((TpfTestTestCase*) self)->account_handle = _tmp3_;
#line 244 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->individual1 = NULL;
#line 245 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->individual1_detailed = NULL;
#line 246 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->individual2 = NULL;
#line 247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->individual2_detailed = NULL;
#line 250 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = folks_individual_aggregator_dup ();
#line 250 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->aggregator = _tmp4_;
#line 251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data2_->aggregator;
#line 251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp5_, "individuals-changed-detailed", (GCallback) ___lambda7__folks_individual_aggregator_individuals_changed_detailed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 259 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data2_->aggregator;
#line 259 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp6_, "individuals-changed", (GCallback) ___lambda8__folks_individual_aggregator_individuals_changed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 269 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda9__gsource_func, block2_data_ref (_data2_), block2_data_unref);
#line 288 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = main_loop;
#line 288 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp7_, 3);
#line 291 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data2_->individual1;
#line 291 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp8_ != NULL, "individual1 != null");
#line 292 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data2_->individual1_detailed;
#line 292 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp9_ != NULL, "individual1_detailed != null");
#line 293 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data2_->individual2;
#line 293 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp10_ != NULL, "individual2 != null");
#line 294 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data2_->individual2_detailed;
#line 294 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp11_ != NULL, "individual2_detailed != null");
#line 296 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 296 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	individual1_expected = _tmp12_;
#line 297 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = individual1_expected;
#line 297 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, "0");
#line 298 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = individual1_expected;
#line 298 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, "travis@example.com");
#line 299 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = individual1_expected;
#line 299 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, "olivier@example.com");
#line 300 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = individual1_expected;
#line 300 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp16_, "guillaume@example.com");
#line 301 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = individual1_expected;
#line 301 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp17_, "sjoerd@example.com");
#line 303 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 303 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	individual2_expected = _tmp18_;
#line 304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = individual2_expected;
#line 304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp19_, "1");
#line 305 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = individual2_expected;
#line 305 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp20_, "christian@example.com");
#line 306 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = individual2_expected;
#line 306 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp21_, "wim@example.com");
#line 307 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = individual2_expected;
#line 307 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp22_, "helen@example.com");
#line 308 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = individual2_expected;
#line 308 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp23_, "geraldine@example.com");
#line 310 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	set_in_use = NULL;
#line 311 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	detailed_swapped = FALSE;
#line 1706 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp24_ = NULL;
		GeeSet* _tmp25_ = NULL;
		GeeSet* _tmp26_ = NULL;
		GeeIterator* _tmp27_ = NULL;
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp24_ = _data2_->individual1;
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp25_ = folks_individual_get_personas (_tmp24_);
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp26_ = _tmp25_;
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp27_;
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 1725 "aggregation.c"
			GeeIterator* _tmp28_ = NULL;
			gboolean _tmp29_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp30_ = NULL;
			gpointer _tmp31_ = NULL;
			gboolean _tmp32_ = FALSE;
			GeeHashSet* _tmp33_ = NULL;
			GeeHashSet* _tmp44_ = NULL;
			FolksPersona* _tmp45_ = NULL;
			const gchar* _tmp46_ = NULL;
			const gchar* _tmp47_ = NULL;
			gboolean _tmp48_ = FALSE;
			gboolean found_detailed = FALSE;
			gboolean _tmp63_ = FALSE;
			gboolean _tmp64_ = FALSE;
			gboolean _tmp83_ = FALSE;
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = _p_it;
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = gee_iterator_next (_tmp28_);
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp29_) {
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 1750 "aggregation.c"
			}
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = _p_it;
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = gee_iterator_get (_tmp30_);
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp31_;
#line 315 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = set_in_use;
#line 315 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp33_ == NULL) {
#line 1762 "aggregation.c"
				GeeHashSet* _tmp34_ = NULL;
				FolksPersona* _tmp35_ = NULL;
				const gchar* _tmp36_ = NULL;
				const gchar* _tmp37_ = NULL;
				gboolean _tmp38_ = FALSE;
#line 316 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp34_ = individual1_expected;
#line 316 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp35_ = p;
#line 316 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp36_ = folks_persona_get_display_id (_tmp35_);
#line 316 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp37_ = _tmp36_;
#line 316 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp34_, _tmp37_);
#line 316 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp32_ = _tmp38_;
#line 1780 "aggregation.c"
			} else {
#line 315 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp32_ = FALSE;
#line 1784 "aggregation.c"
			}
#line 315 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp32_) {
#line 1788 "aggregation.c"
				GeeHashSet* _tmp39_ = NULL;
				GeeHashSet* _tmp40_ = NULL;
#line 318 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp39_ = individual1_expected;
#line 318 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp40_ = _g_object_ref0 (_tmp39_);
#line 318 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (set_in_use);
#line 318 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				set_in_use = _tmp40_;
#line 1799 "aggregation.c"
			} else {
				GeeHashSet* _tmp41_ = NULL;
#line 320 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = set_in_use;
#line 320 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				if (_tmp41_ == NULL) {
#line 1806 "aggregation.c"
					GeeHashSet* _tmp42_ = NULL;
					GeeHashSet* _tmp43_ = NULL;
#line 322 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp42_ = individual2_expected;
#line 322 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp43_ = _g_object_ref0 (_tmp42_);
#line 322 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (set_in_use);
#line 322 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					set_in_use = _tmp43_;
#line 1817 "aggregation.c"
				}
			}
#line 325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp44_ = set_in_use;
#line 325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp45_ = p;
#line 325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp46_ = folks_persona_get_display_id (_tmp45_);
#line 325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp47_ = _tmp46_;
#line 325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp48_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp44_, _tmp47_);
#line 325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp48_, "set_in_use.remove (p.display_id)");
#line 327 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			found_detailed = FALSE;
#line 1834 "aggregation.c"
			{
				GeeIterator* _pd_it = NULL;
				FolksIndividual* _tmp49_ = NULL;
				GeeSet* _tmp50_ = NULL;
				GeeSet* _tmp51_ = NULL;
				GeeIterator* _tmp52_ = NULL;
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp49_ = _data2_->individual1_detailed;
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp50_ = folks_individual_get_personas (_tmp49_);
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp51_ = _tmp50_;
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp52_ = gee_iterable_iterator ((GeeIterable*) _tmp51_);
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_pd_it = _tmp52_;
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 1853 "aggregation.c"
					GeeIterator* _tmp53_ = NULL;
					gboolean _tmp54_ = FALSE;
					FolksPersona* pd = NULL;
					GeeIterator* _tmp55_ = NULL;
					gpointer _tmp56_ = NULL;
					FolksPersona* _tmp57_ = NULL;
					const gchar* _tmp58_ = NULL;
					const gchar* _tmp59_ = NULL;
					FolksPersona* _tmp60_ = NULL;
					const gchar* _tmp61_ = NULL;
					const gchar* _tmp62_ = NULL;
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp53_ = _pd_it;
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp54_ = gee_iterator_next (_tmp53_);
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (!_tmp54_) {
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						break;
#line 1873 "aggregation.c"
					}
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp55_ = _pd_it;
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp56_ = gee_iterator_get (_tmp55_);
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					pd = (FolksPersona*) _tmp56_;
#line 330 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp57_ = pd;
#line 330 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp58_ = folks_persona_get_uid (_tmp57_);
#line 330 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp59_ = _tmp58_;
#line 330 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp60_ = p;
#line 330 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp61_ = folks_persona_get_uid (_tmp60_);
#line 330 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp62_ = _tmp61_;
#line 330 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp59_, _tmp62_) == 0) {
#line 332 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						found_detailed = TRUE;
#line 1897 "aggregation.c"
					}
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (pd);
#line 1901 "aggregation.c"
				}
#line 328 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_pd_it);
#line 1905 "aggregation.c"
			}
#line 336 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp64_ = found_detailed;
#line 336 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp64_) {
#line 1911 "aggregation.c"
				gboolean _tmp65_ = FALSE;
#line 336 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp65_ = detailed_swapped;
#line 336 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp63_ = !_tmp65_;
#line 1917 "aggregation.c"
			} else {
#line 336 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp63_ = FALSE;
#line 1921 "aggregation.c"
			}
#line 336 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp63_) {
#line 1925 "aggregation.c"
				FolksIndividual* tmp = NULL;
				FolksIndividual* _tmp66_ = NULL;
				FolksIndividual* _tmp67_ = NULL;
				FolksIndividual* _tmp68_ = NULL;
#line 340 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp66_ = _data2_->individual1_detailed;
#line 340 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				tmp = _tmp66_;
#line 341 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp67_ = _data2_->individual2_detailed;
#line 341 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_data2_->individual1_detailed = _tmp67_;
#line 342 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp68_ = tmp;
#line 342 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_data2_->individual2_detailed = _tmp68_;
#line 343 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				detailed_swapped = TRUE;
#line 1944 "aggregation.c"
				{
					GeeIterator* _pd_it = NULL;
					FolksIndividual* _tmp69_ = NULL;
					GeeSet* _tmp70_ = NULL;
					GeeSet* _tmp71_ = NULL;
					GeeIterator* _tmp72_ = NULL;
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp69_ = _data2_->individual1_detailed;
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp70_ = folks_individual_get_personas (_tmp69_);
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp71_ = _tmp70_;
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp72_ = gee_iterable_iterator ((GeeIterable*) _tmp71_);
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_pd_it = _tmp72_;
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					while (TRUE) {
#line 1963 "aggregation.c"
						GeeIterator* _tmp73_ = NULL;
						gboolean _tmp74_ = FALSE;
						FolksPersona* pd = NULL;
						GeeIterator* _tmp75_ = NULL;
						gpointer _tmp76_ = NULL;
						FolksPersona* _tmp77_ = NULL;
						const gchar* _tmp78_ = NULL;
						const gchar* _tmp79_ = NULL;
						FolksPersona* _tmp80_ = NULL;
						const gchar* _tmp81_ = NULL;
						const gchar* _tmp82_ = NULL;
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp73_ = _pd_it;
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp74_ = gee_iterator_next (_tmp73_);
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						if (!_tmp74_) {
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							break;
#line 1983 "aggregation.c"
						}
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp75_ = _pd_it;
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp76_ = gee_iterator_get (_tmp75_);
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						pd = (FolksPersona*) _tmp76_;
#line 347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp77_ = pd;
#line 347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp78_ = folks_persona_get_uid (_tmp77_);
#line 347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp79_ = _tmp78_;
#line 347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp80_ = p;
#line 347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp81_ = folks_persona_get_uid (_tmp80_);
#line 347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp82_ = _tmp81_;
#line 347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						if (g_strcmp0 (_tmp79_, _tmp82_) == 0) {
#line 349 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							found_detailed = TRUE;
#line 2007 "aggregation.c"
						}
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_g_object_unref0 (pd);
#line 2011 "aggregation.c"
					}
#line 345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_pd_it);
#line 2015 "aggregation.c"
				}
			}
#line 354 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp83_ = found_detailed;
#line 354 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp83_ == TRUE, "found_detailed == true");
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2024 "aggregation.c"
		}
#line 312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2028 "aggregation.c"
	}
#line 357 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp84_ = set_in_use;
#line 357 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp85_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp84_);
#line 357 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp86_ = _tmp85_;
#line 357 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp86_ == 0, "set_in_use.size == 0");
#line 359 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp87_ = set_in_use;
#line 359 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp88_ = individual1_expected;
#line 359 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_tmp87_ == _tmp88_) {
#line 2044 "aggregation.c"
		GeeHashSet* _tmp89_ = NULL;
		GeeHashSet* _tmp90_ = NULL;
#line 361 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp89_ = individual2_expected;
#line 361 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp90_ = _g_object_ref0 (_tmp89_);
#line 361 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (set_in_use);
#line 361 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		set_in_use = _tmp90_;
#line 2055 "aggregation.c"
	} else {
		GeeHashSet* _tmp91_ = NULL;
		GeeHashSet* _tmp92_ = NULL;
#line 365 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp91_ = individual1_expected;
#line 365 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp92_ = _g_object_ref0 (_tmp91_);
#line 365 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (set_in_use);
#line 365 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		set_in_use = _tmp92_;
#line 2067 "aggregation.c"
	}
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp93_ = NULL;
		GeeSet* _tmp94_ = NULL;
		GeeSet* _tmp95_ = NULL;
		GeeIterator* _tmp96_ = NULL;
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp93_ = _data2_->individual2;
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp94_ = folks_individual_get_personas (_tmp93_);
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp95_ = _tmp94_;
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp96_ = gee_iterable_iterator ((GeeIterable*) _tmp95_);
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp96_;
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2087 "aggregation.c"
			GeeIterator* _tmp97_ = NULL;
			gboolean _tmp98_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp99_ = NULL;
			gpointer _tmp100_ = NULL;
			GeeHashSet* _tmp101_ = NULL;
			FolksPersona* _tmp102_ = NULL;
			const gchar* _tmp103_ = NULL;
			const gchar* _tmp104_ = NULL;
			gboolean _tmp105_ = FALSE;
			gboolean found_detailed = FALSE;
			gboolean _tmp120_ = FALSE;
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp97_ = _p_it;
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp98_ = gee_iterator_next (_tmp97_);
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp98_) {
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 2108 "aggregation.c"
			}
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp99_ = _p_it;
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp100_ = gee_iterator_get (_tmp99_);
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp100_;
#line 370 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp101_ = set_in_use;
#line 370 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp102_ = p;
#line 370 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp103_ = folks_persona_get_display_id (_tmp102_);
#line 370 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp104_ = _tmp103_;
#line 370 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp105_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp101_, _tmp104_);
#line 370 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp105_, "set_in_use.remove (p.display_id)");
#line 372 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			found_detailed = FALSE;
#line 2130 "aggregation.c"
			{
				GeeIterator* _pd_it = NULL;
				FolksIndividual* _tmp106_ = NULL;
				GeeSet* _tmp107_ = NULL;
				GeeSet* _tmp108_ = NULL;
				GeeIterator* _tmp109_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp106_ = _data2_->individual2_detailed;
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp107_ = folks_individual_get_personas (_tmp106_);
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp108_ = _tmp107_;
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp109_ = gee_iterable_iterator ((GeeIterable*) _tmp108_);
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_pd_it = _tmp109_;
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 2149 "aggregation.c"
					GeeIterator* _tmp110_ = NULL;
					gboolean _tmp111_ = FALSE;
					FolksPersona* pd = NULL;
					GeeIterator* _tmp112_ = NULL;
					gpointer _tmp113_ = NULL;
					FolksPersona* _tmp114_ = NULL;
					const gchar* _tmp115_ = NULL;
					const gchar* _tmp116_ = NULL;
					FolksPersona* _tmp117_ = NULL;
					const gchar* _tmp118_ = NULL;
					const gchar* _tmp119_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp110_ = _pd_it;
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp111_ = gee_iterator_next (_tmp110_);
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (!_tmp111_) {
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						break;
#line 2169 "aggregation.c"
					}
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp112_ = _pd_it;
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp113_ = gee_iterator_get (_tmp112_);
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					pd = (FolksPersona*) _tmp113_;
#line 375 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp114_ = pd;
#line 375 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp115_ = folks_persona_get_uid (_tmp114_);
#line 375 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp116_ = _tmp115_;
#line 375 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp117_ = p;
#line 375 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp118_ = folks_persona_get_uid (_tmp117_);
#line 375 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp119_ = _tmp118_;
#line 375 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp116_, _tmp119_) == 0) {
#line 377 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						found_detailed = TRUE;
#line 2193 "aggregation.c"
					}
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (pd);
#line 2197 "aggregation.c"
				}
#line 373 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_pd_it);
#line 2201 "aggregation.c"
			}
#line 380 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp120_ = found_detailed;
#line 380 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp120_ == TRUE, "found_detailed == true");
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2209 "aggregation.c"
		}
#line 368 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2213 "aggregation.c"
	}
#line 383 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp121_ = set_in_use;
#line 383 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp122_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp121_);
#line 383 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp123_ = _tmp122_;
#line 383 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp123_ == 0, "set_in_use.size == 0");
#line 386 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp124_ = ((TpfTestTestCase*) self)->tp_backend;
#line 386 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp125_ = ((TpfTestTestCase*) self)->account_handle;
#line 386 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp124_, tp_tests_backend_get_type (), TpTestsBackend), (void*) _tmp125_);
#line 387 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data2_->aggregator);
#line 387 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_->aggregator = NULL;
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (set_in_use);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (individual2_expected);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (individual1_expected);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block2_data_unref (_data2_);
#line 228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data2_ = NULL;
#line 2245 "aggregation.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data3_;
#line 2254 "aggregation.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2263 "aggregation.c"
		AggregationTests* self;
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data3_->self;
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data3_->aggregator);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block3Data, _data3_);
#line 2273 "aggregation.c"
	}
}


static void __lambda11_ (Block3Data* _data3_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 427 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 427 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 429 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 429 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 429 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 430 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 430 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 430 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 432 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, TRUE, (guint) 9, added, removed, &_data3_->individual1_detailed, &_data3_->individual2_detailed);
#line 427 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 427 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 2308 "aggregation.c"
}


static void ___lambda11__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 427 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda11_ (self, changes);
#line 2315 "aggregation.c"
}


static void __lambda12_ (Block3Data* _data3_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests* self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 435 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 435 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 435 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 437 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 437 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 437 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, FALSE, (guint) 9, (GeeCollection*) _tmp0_, _tmp1_, &_data3_->individual1, &_data3_->individual2);
#line 2335 "aggregation.c"
}


static void ___lambda12__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 435 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda12_ (self, added, removed, message, actor, reason);
#line 2342 "aggregation.c"
}


static void __lambda14_ (Block3Data* _data3_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 447 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 447 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 2353 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 451 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data3_->aggregator;
#line 451 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 451 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 451 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 2365 "aggregation.c"
			goto __catch2_g_error;
		}
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 449 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 449 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 455 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 455 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:455: Failed to prepare aggregator: %s", _tmp2_);
#line 457 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 449 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 2386 "aggregation.c"
	}
	__finally2:
#line 449 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 449 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 449 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 449 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 2397 "aggregation.c"
	}
}


static void ___lambda14__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 447 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda14_ (self, source_object, res);
#line 447 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block3_data_unref (self);
#line 2407 "aggregation.c"
}


static gboolean __lambda13_ (Block3Data* _data3_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 445 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 447 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data3_->aggregator;
#line 447 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda14__gasync_ready_callback, block3_data_ref (_data3_));
#line 461 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 461 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 2425 "aggregation.c"
}


static gboolean ___lambda13__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda13_ (self);
#line 445 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 2434 "aggregation.c"
}


void aggregation_tests_test_linkable_properties_different_stores (AggregationTests* self) {
	Block3Data* _data3_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	TpTestsBackend* _tmp4_ = NULL;
	void* _tmp5_ = NULL;
	void* account2_handle = NULL;
	TpTestsBackend* _tmp6_ = NULL;
	void* _tmp7_ = NULL;
	FolksIndividualAggregator* _tmp8_ = NULL;
	FolksIndividualAggregator* _tmp9_ = NULL;
	FolksIndividualAggregator* _tmp10_ = NULL;
	GMainLoop* _tmp11_ = NULL;
	FolksIndividual* _tmp12_ = NULL;
	FolksIndividual* _tmp13_ = NULL;
	FolksIndividual* _tmp14_ = NULL;
	FolksIndividual* _tmp15_ = NULL;
	GeeHashSet* expected_personas1 = NULL;
	GeeHashSet* _tmp16_ = NULL;
	GeeHashSet* expected_personas1_detailed = NULL;
	GeeHashSet* _tmp17_ = NULL;
	GeeHashSet* expected_personas2 = NULL;
	GeeHashSet* _tmp18_ = NULL;
	GeeHashSet* expected_personas2_detailed = NULL;
	GeeHashSet* _tmp19_ = NULL;
	GeeHashSet* _tmp55_ = NULL;
	gint _tmp56_ = 0;
	gint _tmp57_ = 0;
	GeeHashSet* _tmp79_ = NULL;
	gint _tmp80_ = 0;
	gint _tmp81_ = 0;
	GeeHashSet* _tmp103_ = NULL;
	gint _tmp104_ = 0;
	gint _tmp105_ = 0;
	GeeHashSet* _tmp127_ = NULL;
	gint _tmp128_ = 0;
	gint _tmp129_ = 0;
	TpTestsBackend* _tmp130_ = NULL;
	void* _tmp131_ = NULL;
	TpTestsBackend* _tmp132_ = NULL;
	void* _tmp133_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->_ref_count_ = 1;
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->self = g_object_ref (self);
#line 399 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 399 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 401 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 401 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "protocol2=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com\n" "protocol2=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com");
#line 412 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 412 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 412 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp3_;
#line 413 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_backend;
#line 413 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (_tmp4_, "protocol", "me@example.com", "cm", "account");
#line 413 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp5_;
#line 415 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = tp_backend;
#line 415 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = tp_tests_backend_add_account (_tmp6_, "protocol2", "me@example.com", "cm", "account2");
#line 415 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp7_;
#line 420 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->individual1 = NULL;
#line 421 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->individual1_detailed = NULL;
#line 422 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->individual2 = NULL;
#line 423 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->individual2_detailed = NULL;
#line 426 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = folks_individual_aggregator_dup ();
#line 426 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->aggregator = _tmp8_;
#line 427 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data3_->aggregator;
#line 427 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp9_, "individuals-changed-detailed", (GCallback) ___lambda11__folks_individual_aggregator_individuals_changed_detailed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 435 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data3_->aggregator;
#line 435 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp10_, "individuals-changed", (GCallback) ___lambda12__folks_individual_aggregator_individuals_changed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 445 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda13__gsource_func, block3_data_ref (_data3_), block3_data_unref);
#line 464 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = main_loop;
#line 464 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp11_, 3);
#line 467 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data3_->individual1;
#line 467 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp12_ != NULL, "individual1 != null");
#line 468 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = _data3_->individual1_detailed;
#line 468 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp13_ != NULL, "individual1_detailed != null");
#line 469 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data3_->individual2;
#line 469 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp14_ != NULL, "individual2 != null");
#line 470 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = _data3_->individual2_detailed;
#line 470 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp15_ != NULL, "individual2_detailed != null");
#line 476 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 476 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	expected_personas1 = _tmp16_;
#line 477 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 477 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	expected_personas1_detailed = _tmp17_;
#line 478 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 478 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	expected_personas2 = _tmp18_;
#line 479 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 479 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	expected_personas2_detailed = _tmp19_;
#line 2576 "aggregation.c"
	{
		GeeIterator* _id_it = NULL;
		GeeHashSet* _tmp20_ = NULL;
		GeeIterator* _tmp21_ = NULL;
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp20_ = self->priv->_default_personas;
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp21_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp20_);
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_id_it = _tmp21_;
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2589 "aggregation.c"
			GeeIterator* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
			gchar* id = NULL;
			GeeIterator* _tmp24_ = NULL;
			gpointer _tmp25_ = NULL;
			GeeHashSet* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			GeeHashSet* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			GeeHashSet* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			GeeHashSet* _tmp32_ = NULL;
			const gchar* _tmp33_ = NULL;
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = _id_it;
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = gee_iterator_next (_tmp22_);
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp23_) {
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 2611 "aggregation.c"
			}
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = _id_it;
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = gee_iterator_get (_tmp24_);
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			id = (gchar*) _tmp25_;
#line 482 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = expected_personas1;
#line 482 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = id;
#line 482 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp26_, _tmp27_);
#line 483 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = expected_personas1_detailed;
#line 483 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = id;
#line 483 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp28_, _tmp29_);
#line 484 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = expected_personas2;
#line 484 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = id;
#line 484 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp30_, _tmp31_);
#line 485 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = expected_personas2_detailed;
#line 485 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = id;
#line 485 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp32_, _tmp33_);
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_free0 (id);
#line 2645 "aggregation.c"
		}
#line 480 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_id_it);
#line 2649 "aggregation.c"
	}
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp34_ = NULL;
		GeeSet* _tmp35_ = NULL;
		GeeSet* _tmp36_ = NULL;
		GeeIterator* _tmp37_ = NULL;
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp34_ = _data3_->individual1;
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp35_ = folks_individual_get_personas (_tmp34_);
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp36_ = _tmp35_;
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp37_ = gee_iterable_iterator ((GeeIterable*) _tmp36_);
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp37_;
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2669 "aggregation.c"
			GeeIterator* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp40_ = NULL;
			gpointer _tmp41_ = NULL;
			gboolean _tmp42_ = FALSE;
			gboolean _tmp43_ = FALSE;
			GeeHashSet* _tmp44_ = NULL;
			FolksPersona* _tmp45_ = NULL;
			const gchar* _tmp46_ = NULL;
			const gchar* _tmp47_ = NULL;
			gboolean _tmp48_ = FALSE;
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp38_ = _p_it;
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = gee_iterator_next (_tmp38_);
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp39_) {
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 2690 "aggregation.c"
			}
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = _p_it;
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp41_ = gee_iterator_get (_tmp40_);
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp41_;
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp44_ = expected_personas1;
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp45_ = p;
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp46_ = folks_persona_get_display_id (_tmp45_);
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp47_ = _tmp46_;
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp48_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp44_, _tmp47_);
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp48_) {
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp43_ = TRUE;
#line 2712 "aggregation.c"
			} else {
				FolksPersona* _tmp49_ = NULL;
				const gchar* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp49_ = p;
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp50_ = folks_persona_get_display_id (_tmp49_);
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp51_ = _tmp50_;
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp43_ = g_strcmp0 (_tmp51_, "0") == 0;
#line 2725 "aggregation.c"
			}
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp43_) {
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp42_ = TRUE;
#line 2731 "aggregation.c"
			} else {
				FolksPersona* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				const gchar* _tmp54_ = NULL;
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp52_ = p;
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp53_ = folks_persona_get_display_id (_tmp52_);
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp54_ = _tmp53_;
#line 491 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp42_ = g_strcmp0 (_tmp54_, "1") == 0;
#line 2744 "aggregation.c"
			}
#line 490 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp42_, "expected_personas1.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2750 "aggregation.c"
		}
#line 488 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2754 "aggregation.c"
	}
#line 494 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp55_ = expected_personas1;
#line 494 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp56_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp55_);
#line 494 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp57_ = _tmp56_;
#line 494 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp57_ == 0, "expected_personas1.size == 0");
#line 2764 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp58_ = NULL;
		GeeSet* _tmp59_ = NULL;
		GeeSet* _tmp60_ = NULL;
		GeeIterator* _tmp61_ = NULL;
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp58_ = _data3_->individual1_detailed;
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp59_ = folks_individual_get_personas (_tmp58_);
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp60_ = _tmp59_;
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp61_ = gee_iterable_iterator ((GeeIterable*) _tmp60_);
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp61_;
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2783 "aggregation.c"
			GeeIterator* _tmp62_ = NULL;
			gboolean _tmp63_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp64_ = NULL;
			gpointer _tmp65_ = NULL;
			gboolean _tmp66_ = FALSE;
			gboolean _tmp67_ = FALSE;
			GeeHashSet* _tmp68_ = NULL;
			FolksPersona* _tmp69_ = NULL;
			const gchar* _tmp70_ = NULL;
			const gchar* _tmp71_ = NULL;
			gboolean _tmp72_ = FALSE;
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp62_ = _p_it;
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp63_ = gee_iterator_next (_tmp62_);
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp63_) {
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 2804 "aggregation.c"
			}
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp64_ = _p_it;
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp65_ = gee_iterator_get (_tmp64_);
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp65_;
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp68_ = expected_personas1_detailed;
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp69_ = p;
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp70_ = folks_persona_get_display_id (_tmp69_);
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp71_ = _tmp70_;
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp72_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp68_, _tmp71_);
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp72_) {
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp67_ = TRUE;
#line 2826 "aggregation.c"
			} else {
				FolksPersona* _tmp73_ = NULL;
				const gchar* _tmp74_ = NULL;
				const gchar* _tmp75_ = NULL;
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp73_ = p;
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp74_ = folks_persona_get_display_id (_tmp73_);
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp75_ = _tmp74_;
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp67_ = g_strcmp0 (_tmp75_, "0") == 0;
#line 2839 "aggregation.c"
			}
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp67_) {
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp66_ = TRUE;
#line 2845 "aggregation.c"
			} else {
				FolksPersona* _tmp76_ = NULL;
				const gchar* _tmp77_ = NULL;
				const gchar* _tmp78_ = NULL;
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp76_ = p;
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp77_ = folks_persona_get_display_id (_tmp76_);
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp78_ = _tmp77_;
#line 499 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp66_ = g_strcmp0 (_tmp78_, "1") == 0;
#line 2858 "aggregation.c"
			}
#line 498 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp66_, "expected_personas1_detailed.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2864 "aggregation.c"
		}
#line 496 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2868 "aggregation.c"
	}
#line 502 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp79_ = expected_personas1_detailed;
#line 502 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp80_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp79_);
#line 502 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp81_ = _tmp80_;
#line 502 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp81_ == 0, "expected_personas1_detailed.size == 0");
#line 2878 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp82_ = NULL;
		GeeSet* _tmp83_ = NULL;
		GeeSet* _tmp84_ = NULL;
		GeeIterator* _tmp85_ = NULL;
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp82_ = _data3_->individual2;
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp83_ = folks_individual_get_personas (_tmp82_);
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp84_ = _tmp83_;
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp85_ = gee_iterable_iterator ((GeeIterable*) _tmp84_);
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp85_;
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2897 "aggregation.c"
			GeeIterator* _tmp86_ = NULL;
			gboolean _tmp87_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp88_ = NULL;
			gpointer _tmp89_ = NULL;
			gboolean _tmp90_ = FALSE;
			gboolean _tmp91_ = FALSE;
			GeeHashSet* _tmp92_ = NULL;
			FolksPersona* _tmp93_ = NULL;
			const gchar* _tmp94_ = NULL;
			const gchar* _tmp95_ = NULL;
			gboolean _tmp96_ = FALSE;
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp86_ = _p_it;
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp87_ = gee_iterator_next (_tmp86_);
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp87_) {
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 2918 "aggregation.c"
			}
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp88_ = _p_it;
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp89_ = gee_iterator_get (_tmp88_);
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp89_;
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp92_ = expected_personas2;
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp93_ = p;
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp94_ = folks_persona_get_display_id (_tmp93_);
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp95_ = _tmp94_;
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp96_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp92_, _tmp95_);
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp96_) {
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp91_ = TRUE;
#line 2940 "aggregation.c"
			} else {
				FolksPersona* _tmp97_ = NULL;
				const gchar* _tmp98_ = NULL;
				const gchar* _tmp99_ = NULL;
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp97_ = p;
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp98_ = folks_persona_get_display_id (_tmp97_);
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp99_ = _tmp98_;
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp91_ = g_strcmp0 (_tmp99_, "0") == 0;
#line 2953 "aggregation.c"
			}
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp91_) {
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp90_ = TRUE;
#line 2959 "aggregation.c"
			} else {
				FolksPersona* _tmp100_ = NULL;
				const gchar* _tmp101_ = NULL;
				const gchar* _tmp102_ = NULL;
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp100_ = p;
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp101_ = folks_persona_get_display_id (_tmp100_);
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp102_ = _tmp101_;
#line 507 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp90_ = g_strcmp0 (_tmp102_, "1") == 0;
#line 2972 "aggregation.c"
			}
#line 506 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp90_, "expected_personas2.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2978 "aggregation.c"
		}
#line 504 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2982 "aggregation.c"
	}
#line 510 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp103_ = expected_personas2;
#line 510 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp104_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp103_);
#line 510 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp105_ = _tmp104_;
#line 510 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp105_ == 0, "expected_personas2.size == 0");
#line 2992 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp106_ = NULL;
		GeeSet* _tmp107_ = NULL;
		GeeSet* _tmp108_ = NULL;
		GeeIterator* _tmp109_ = NULL;
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp106_ = _data3_->individual2_detailed;
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp107_ = folks_individual_get_personas (_tmp106_);
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp108_ = _tmp107_;
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp109_ = gee_iterable_iterator ((GeeIterable*) _tmp108_);
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp109_;
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3011 "aggregation.c"
			GeeIterator* _tmp110_ = NULL;
			gboolean _tmp111_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp112_ = NULL;
			gpointer _tmp113_ = NULL;
			gboolean _tmp114_ = FALSE;
			gboolean _tmp115_ = FALSE;
			GeeHashSet* _tmp116_ = NULL;
			FolksPersona* _tmp117_ = NULL;
			const gchar* _tmp118_ = NULL;
			const gchar* _tmp119_ = NULL;
			gboolean _tmp120_ = FALSE;
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp110_ = _p_it;
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp111_ = gee_iterator_next (_tmp110_);
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp111_) {
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 3032 "aggregation.c"
			}
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp112_ = _p_it;
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp113_ = gee_iterator_get (_tmp112_);
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp113_;
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp116_ = expected_personas2_detailed;
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp117_ = p;
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp118_ = folks_persona_get_display_id (_tmp117_);
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp119_ = _tmp118_;
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp120_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp116_, _tmp119_);
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp120_) {
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp115_ = TRUE;
#line 3054 "aggregation.c"
			} else {
				FolksPersona* _tmp121_ = NULL;
				const gchar* _tmp122_ = NULL;
				const gchar* _tmp123_ = NULL;
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp121_ = p;
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp122_ = folks_persona_get_display_id (_tmp121_);
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp123_ = _tmp122_;
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp115_ = g_strcmp0 (_tmp123_, "0") == 0;
#line 3067 "aggregation.c"
			}
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp115_) {
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp114_ = TRUE;
#line 3073 "aggregation.c"
			} else {
				FolksPersona* _tmp124_ = NULL;
				const gchar* _tmp125_ = NULL;
				const gchar* _tmp126_ = NULL;
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp124_ = p;
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp125_ = folks_persona_get_display_id (_tmp124_);
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp126_ = _tmp125_;
#line 515 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp114_ = g_strcmp0 (_tmp126_, "1") == 0;
#line 3086 "aggregation.c"
			}
#line 514 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp114_, "expected_personas2_detailed.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 3092 "aggregation.c"
		}
#line 512 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 3096 "aggregation.c"
	}
#line 518 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp127_ = expected_personas2_detailed;
#line 518 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp128_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp127_);
#line 518 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp129_ = _tmp128_;
#line 518 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp129_ == 0, "expected_personas2_detailed.size == 0");
#line 521 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp130_ = tp_backend;
#line 521 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp131_ = account2_handle;
#line 521 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp130_, _tmp131_);
#line 522 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp132_ = tp_backend;
#line 522 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp133_ = account1_handle;
#line 522 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp132_, _tmp133_);
#line 523 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data3_->aggregator);
#line 523 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_->aggregator = NULL;
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas2_detailed);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas2);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas1_detailed);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas1);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block3_data_unref (_data3_);
#line 397 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data3_ = NULL;
#line 3138 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_individuals_changed (AggregationTests* self, gboolean detailed, guint num_personas, GeeCollection* added, GeeSet* removed, FolksIndividual** individual1, FolksIndividual** individual2) {
#line 526 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 526 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 526 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 3149 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3162 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			FolksIndividual* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gboolean _tmp13_ = FALSE;
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 3183 "aggregation.c"
			}
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 533 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 533 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 533 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 3197 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 533 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 533 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 3204 "aggregation.c"
			}
#line 533 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp6_, "i != null || detailed == true");
#line 534 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = i;
#line 534 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp9_ == NULL) {
#line 536 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 536 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 3216 "aggregation.c"
			}
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = i;
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _tmp12_;
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp13_) {
#line 3226 "aggregation.c"
				FolksIndividual* _tmp14_ = NULL;
				GeeSet* _tmp15_ = NULL;
				GeeSet* _tmp16_ = NULL;
				gint _tmp17_ = 0;
				gint _tmp18_ = 0;
				guint _tmp19_ = 0U;
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = i;
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = folks_individual_get_personas (_tmp14_);
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp19_ = num_personas;
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp10_ = ((guint) _tmp18_) == _tmp19_;
#line 3247 "aggregation.c"
			} else {
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp10_ = FALSE;
#line 3251 "aggregation.c"
			}
#line 539 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_) {
#line 3255 "aggregation.c"
				FolksIndividual* _tmp20_ = NULL;
				FolksIndividual* _tmp21_ = NULL;
#line 541 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp20_ = i;
#line 541 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp21_ = *individual1;
#line 541 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				if (_tmp20_ == _tmp21_) {
#line 543 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					*individual1 = NULL;
#line 3266 "aggregation.c"
				} else {
					FolksIndividual* _tmp22_ = NULL;
					FolksIndividual* _tmp23_ = NULL;
#line 545 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp22_ = i;
#line 545 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp23_ = *individual2;
#line 545 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (_tmp22_ == _tmp23_) {
#line 547 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						*individual2 = NULL;
#line 3278 "aggregation.c"
					} else {
						guint _tmp24_ = 0U;
						FolksIndividual* _tmp25_ = NULL;
						const gchar* _tmp26_ = NULL;
						const gchar* _tmp27_ = NULL;
#line 551 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp24_ = num_personas;
#line 551 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp25_ = i;
#line 551 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp26_ = folks_individual_get_id (_tmp25_);
#line 551 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp27_ = _tmp26_;
#line 551 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						g_critical ("aggregation.vala:551: Unknown %u-persona individual: %s", _tmp24_, _tmp27_);
#line 553 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						g_assert_not_reached ();
#line 3296 "aggregation.c"
					}
				}
			}
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 3302 "aggregation.c"
		}
#line 531 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 3306 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp28_ = NULL;
		GeeIterator* _tmp29_ = NULL;
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp28_ = added;
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp29_ = gee_iterable_iterator ((GeeIterable*) _tmp28_);
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp29_;
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3320 "aggregation.c"
			GeeIterator* _tmp30_ = NULL;
			gboolean _tmp31_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp32_ = NULL;
			gpointer _tmp33_ = NULL;
			gboolean _tmp34_ = FALSE;
			FolksIndividual* _tmp35_ = NULL;
			FolksIndividual* _tmp37_ = NULL;
			gboolean _tmp38_ = FALSE;
			FolksIndividual* _tmp39_ = NULL;
			gboolean _tmp40_ = FALSE;
			gboolean _tmp41_ = FALSE;
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = _i_it;
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = gee_iterator_next (_tmp30_);
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp31_) {
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 3341 "aggregation.c"
			}
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = _i_it;
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = gee_iterator_get (_tmp32_);
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp33_;
#line 560 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp35_ = i;
#line 560 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp35_ != NULL) {
#line 560 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp34_ = TRUE;
#line 3355 "aggregation.c"
			} else {
				gboolean _tmp36_ = FALSE;
#line 560 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp36_ = detailed;
#line 560 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp34_ = _tmp36_ == TRUE;
#line 3362 "aggregation.c"
			}
#line 560 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp34_, "i != null || detailed == true");
#line 561 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp37_ = i;
#line 561 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp37_ == NULL) {
#line 563 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 563 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 3374 "aggregation.c"
			}
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = i;
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = folks_individual_get_is_user (_tmp39_);
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp41_ = _tmp40_;
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp41_) {
#line 3384 "aggregation.c"
				FolksIndividual* _tmp42_ = NULL;
				GeeSet* _tmp43_ = NULL;
				GeeSet* _tmp44_ = NULL;
				gint _tmp45_ = 0;
				gint _tmp46_ = 0;
				guint _tmp47_ = 0U;
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp42_ = i;
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp43_ = folks_individual_get_personas (_tmp42_);
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp44_ = _tmp43_;
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp45_ = gee_collection_get_size ((GeeCollection*) _tmp44_);
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp46_ = _tmp45_;
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp47_ = num_personas;
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = ((guint) _tmp46_) == _tmp47_;
#line 3405 "aggregation.c"
			} else {
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp38_ = FALSE;
#line 3409 "aggregation.c"
			}
#line 566 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp38_) {
#line 3413 "aggregation.c"
				gboolean _tmp48_ = FALSE;
				FolksIndividual* _tmp49_ = NULL;
#line 568 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp49_ = *individual1;
#line 568 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				if (_tmp49_ == NULL) {
#line 3420 "aggregation.c"
					FolksIndividual* _tmp50_ = NULL;
					FolksIndividual* _tmp51_ = NULL;
#line 568 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp50_ = *individual2;
#line 568 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp51_ = i;
#line 568 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp48_ = _tmp50_ != _tmp51_;
#line 3429 "aggregation.c"
				} else {
#line 568 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp48_ = FALSE;
#line 3433 "aggregation.c"
				}
#line 568 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				if (_tmp48_) {
#line 3437 "aggregation.c"
					FolksIndividual* _tmp52_ = NULL;
#line 570 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp52_ = i;
#line 570 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					*individual1 = _tmp52_;
#line 3443 "aggregation.c"
				} else {
					gboolean _tmp53_ = FALSE;
					FolksIndividual* _tmp54_ = NULL;
#line 572 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp54_ = *individual2;
#line 572 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (_tmp54_ == NULL) {
#line 3451 "aggregation.c"
						FolksIndividual* _tmp55_ = NULL;
						FolksIndividual* _tmp56_ = NULL;
#line 572 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp55_ = *individual1;
#line 572 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp56_ = i;
#line 572 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp53_ = _tmp55_ != _tmp56_;
#line 3460 "aggregation.c"
					} else {
#line 572 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp53_ = FALSE;
#line 3464 "aggregation.c"
					}
#line 572 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (_tmp53_) {
#line 3468 "aggregation.c"
						FolksIndividual* _tmp57_ = NULL;
#line 574 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp57_ = i;
#line 574 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						*individual2 = _tmp57_;
#line 3474 "aggregation.c"
					} else {
						gboolean _tmp58_ = FALSE;
						FolksIndividual* _tmp59_ = NULL;
						FolksIndividual* _tmp60_ = NULL;
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp59_ = *individual1;
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp60_ = i;
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						if (_tmp59_ != _tmp60_) {
#line 3485 "aggregation.c"
							FolksIndividual* _tmp61_ = NULL;
							FolksIndividual* _tmp62_ = NULL;
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp61_ = *individual2;
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp62_ = i;
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp58_ = _tmp61_ != _tmp62_;
#line 3494 "aggregation.c"
						} else {
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp58_ = FALSE;
#line 3498 "aggregation.c"
						}
#line 576 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						if (_tmp58_) {
#line 3502 "aggregation.c"
							guint _tmp63_ = 0U;
							FolksIndividual* _tmp64_ = NULL;
							const gchar* _tmp65_ = NULL;
							const gchar* _tmp66_ = NULL;
#line 578 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp63_ = num_personas;
#line 578 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp64_ = i;
#line 578 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp65_ = folks_individual_get_id (_tmp64_);
#line 578 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							_tmp66_ = _tmp65_;
#line 578 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							g_critical ("aggregation.vala:578: Unknown %u-persona individual: %s", _tmp63_, _tmp66_);
#line 580 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							g_assert_not_reached ();
#line 3519 "aggregation.c"
						}
					}
				}
			}
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 3526 "aggregation.c"
		}
#line 558 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 3530 "aggregation.c"
	}
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data4_;
#line 3540 "aggregation.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 3549 "aggregation.c"
		AggregationTests* self;
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data4_->self;
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->aggregator);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->user_individual_detailed);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->user_individual);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block4Data, _data4_);
#line 3563 "aggregation.c"
	}
}


static void __lambda15_ (Block4Data* _data4_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 606 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 606 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 608 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 608 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 608 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 609 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 609 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 609 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 611 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_user_individuals_changed (self, TRUE, added, removed, &_data4_->user_individual_detailed);
#line 606 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 606 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 3598 "aggregation.c"
}


static void ___lambda15__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 605 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda15_ (self, changes);
#line 3605 "aggregation.c"
}


static void __lambda16_ (Block4Data* _data4_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests* self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 615 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 615 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 615 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 617 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 617 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 617 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_user_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_, &_data4_->user_individual);
#line 3625 "aggregation.c"
}


static void ___lambda16__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 614 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda16_ (self, added, removed, message, actor, reason);
#line 3632 "aggregation.c"
}


static void __lambda18_ (Block4Data* _data4_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 627 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 627 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 3643 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 631 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data4_->aggregator;
#line 631 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 631 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 631 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 3655 "aggregation.c"
			goto __catch3_g_error;
		}
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 629 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 629 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 635 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 635 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:635: Failed to prepare aggregator: %s", _tmp2_);
#line 637 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 629 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 3676 "aggregation.c"
	}
	__finally3:
#line 629 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 629 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 629 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 629 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 3687 "aggregation.c"
	}
}


static void ___lambda18__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 627 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda18_ (self, source_object, res);
#line 627 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block4_data_unref (self);
#line 3697 "aggregation.c"
}


static gboolean __lambda17_ (Block4Data* _data4_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 625 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 627 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data4_->aggregator;
#line 627 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda18__gasync_ready_callback, block4_data_ref (_data4_));
#line 641 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 641 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 3715 "aggregation.c"
}


static gboolean ___lambda17__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda17_ (self);
#line 625 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 3724 "aggregation.c"
}


void aggregation_tests_test_user (AggregationTests* self) {
	Block4Data* _data4_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	TpTestsBackend* _tmp4_ = NULL;
	void* _tmp5_ = NULL;
	void* account2_handle = NULL;
	TpTestsBackend* _tmp6_ = NULL;
	void* _tmp7_ = NULL;
	FolksIndividualAggregator* _tmp8_ = NULL;
	gulong individuals_changed_detailed_id = 0UL;
	FolksIndividualAggregator* _tmp9_ = NULL;
	gulong _tmp10_ = 0UL;
	gulong individuals_changed_id = 0UL;
	FolksIndividualAggregator* _tmp11_ = NULL;
	gulong _tmp12_ = 0UL;
	GMainLoop* _tmp13_ = NULL;
	FolksIndividualAggregator* _tmp14_ = NULL;
	FolksIndividual* _tmp15_ = NULL;
	FolksIndividual* _tmp16_ = NULL;
	FolksIndividual* _tmp17_ = NULL;
	FolksIndividualAggregator* _tmp18_ = NULL;
	FolksIndividual* _tmp19_ = NULL;
	FolksIndividual* _tmp20_ = NULL;
	FolksIndividual* _tmp21_ = NULL;
	FolksIndividual* _tmp22_ = NULL;
	GeeSet* _tmp23_ = NULL;
	GeeSet* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gint _tmp26_ = 0;
	FolksIndividual* _tmp27_ = NULL;
	GeeSet* _tmp28_ = NULL;
	GeeSet* _tmp29_ = NULL;
	gint _tmp30_ = 0;
	gint _tmp31_ = 0;
	GeeHashSet* display_ids = NULL;
	GeeHashSet* _tmp32_ = NULL;
	gboolean _tmp45_ = FALSE;
	GeeHashSet* _tmp46_ = NULL;
	gboolean _tmp47_ = FALSE;
	GeeHashSet* display_ids_detailed = NULL;
	GeeHashSet* _tmp50_ = NULL;
	gboolean _tmp63_ = FALSE;
	GeeHashSet* _tmp64_ = NULL;
	gboolean _tmp65_ = FALSE;
	FolksIndividualAggregator* _tmp68_ = NULL;
	gulong _tmp69_ = 0UL;
	FolksIndividualAggregator* _tmp70_ = NULL;
	gulong _tmp71_ = 0UL;
	TpTestsBackend* _tmp72_ = NULL;
	void* _tmp73_ = NULL;
	TpTestsBackend* _tmp74_ = NULL;
	void* _tmp75_ = NULL;
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_->_ref_count_ = 1;
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_->self = g_object_ref (self);
#line 590 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 590 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 592 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 592 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 594 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 594 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 594 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp3_;
#line 595 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_backend;
#line 595 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (_tmp4_, "protocol", "me@example.com", "cm", "account");
#line 595 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp5_;
#line 597 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = tp_backend;
#line 597 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = tp_tests_backend_add_account (_tmp6_, "protocol", "me2@example.com", "cm", "account2");
#line 597 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp7_;
#line 600 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_->user_individual = NULL;
#line 601 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_->user_individual_detailed = NULL;
#line 604 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = folks_individual_aggregator_dup ();
#line 604 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_->aggregator = _tmp8_;
#line 605 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data4_->aggregator;
#line 605 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = g_signal_connect_data (_tmp9_, "individuals-changed-detailed", (GCallback) ___lambda15__folks_individual_aggregator_individuals_changed_detailed, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 605 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	individuals_changed_detailed_id = _tmp10_;
#line 614 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data4_->aggregator;
#line 614 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = g_signal_connect_data (_tmp11_, "individuals-changed", (GCallback) ___lambda16__folks_individual_aggregator_individuals_changed, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 614 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	individuals_changed_id = _tmp12_;
#line 625 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda17__gsource_func, block4_data_ref (_data4_), block4_data_unref);
#line 644 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = main_loop;
#line 644 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp13_, 3);
#line 648 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data4_->aggregator;
#line 648 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = folks_individual_aggregator_get_user (_tmp14_);
#line 648 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = _tmp15_;
#line 648 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = _data4_->user_individual;
#line 648 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp16_ == _tmp17_, "aggregator.user == user_individual");
#line 649 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = _data4_->aggregator;
#line 649 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = folks_individual_aggregator_get_user (_tmp18_);
#line 649 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = _tmp19_;
#line 649 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = _data4_->user_individual_detailed;
#line 649 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp20_ == _tmp21_, "aggregator.user == user_individual_detailed");
#line 652 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = _data4_->user_individual;
#line 652 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = folks_individual_get_personas (_tmp22_);
#line 652 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp24_ = _tmp23_;
#line 652 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp25_ = gee_collection_get_size ((GeeCollection*) _tmp24_);
#line 652 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp26_ = _tmp25_;
#line 652 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp26_ == 2, "user_individual.personas.size == 2");
#line 653 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp27_ = _data4_->user_individual_detailed;
#line 653 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp28_ = folks_individual_get_personas (_tmp27_);
#line 653 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp29_ = _tmp28_;
#line 653 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp30_ = gee_collection_get_size ((GeeCollection*) _tmp29_);
#line 653 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp31_ = _tmp30_;
#line 653 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp31_ == 2, "user_individual_detailed.personas.size == 2");
#line 655 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp32_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 655 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	display_ids = _tmp32_;
#line 3894 "aggregation.c"
	{
		GeeIterator* _persona_it = NULL;
		FolksIndividual* _tmp33_ = NULL;
		GeeSet* _tmp34_ = NULL;
		GeeSet* _tmp35_ = NULL;
		GeeIterator* _tmp36_ = NULL;
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp33_ = _data4_->user_individual;
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp35_ = _tmp34_;
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp36_ = gee_iterable_iterator ((GeeIterable*) _tmp35_);
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_persona_it = _tmp36_;
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3913 "aggregation.c"
			GeeIterator* _tmp37_ = NULL;
			gboolean _tmp38_ = FALSE;
			FolksPersona* persona = NULL;
			GeeIterator* _tmp39_ = NULL;
			gpointer _tmp40_ = NULL;
			GeeHashSet* _tmp41_ = NULL;
			FolksPersona* _tmp42_ = NULL;
			const gchar* _tmp43_ = NULL;
			const gchar* _tmp44_ = NULL;
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp37_ = _persona_it;
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp38_ = gee_iterator_next (_tmp37_);
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp38_) {
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 3931 "aggregation.c"
			}
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp39_ = _persona_it;
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp40_ = gee_iterator_get (_tmp39_);
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			persona = (FolksPersona*) _tmp40_;
#line 658 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp41_ = display_ids;
#line 658 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp42_ = persona;
#line 658 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp43_ = folks_persona_get_display_id (_tmp42_);
#line 658 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp44_ = _tmp43_;
#line 658 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp41_, _tmp44_);
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 3951 "aggregation.c"
		}
#line 656 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_persona_it);
#line 3955 "aggregation.c"
	}
#line 661 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp46_ = display_ids;
#line 661 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp47_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp46_, "me@example.com");
#line 661 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_tmp47_) {
#line 3963 "aggregation.c"
		GeeHashSet* _tmp48_ = NULL;
		gboolean _tmp49_ = FALSE;
#line 662 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp48_ = display_ids;
#line 662 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp49_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp48_, "me2@example.com");
#line 662 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp45_ = _tmp49_;
#line 3972 "aggregation.c"
	} else {
#line 661 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp45_ = FALSE;
#line 3976 "aggregation.c"
	}
#line 661 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp45_, "display_ids.contains (\"me@example.com\") &&           display_ids.contains (\"me2@example.com\")");
#line 664 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp50_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 664 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	display_ids_detailed = _tmp50_;
#line 3984 "aggregation.c"
	{
		GeeIterator* _persona_it = NULL;
		FolksIndividual* _tmp51_ = NULL;
		GeeSet* _tmp52_ = NULL;
		GeeSet* _tmp53_ = NULL;
		GeeIterator* _tmp54_ = NULL;
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp51_ = _data4_->user_individual_detailed;
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp52_ = folks_individual_get_personas (_tmp51_);
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp53_ = _tmp52_;
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp54_ = gee_iterable_iterator ((GeeIterable*) _tmp53_);
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_persona_it = _tmp54_;
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4003 "aggregation.c"
			GeeIterator* _tmp55_ = NULL;
			gboolean _tmp56_ = FALSE;
			FolksPersona* persona = NULL;
			GeeIterator* _tmp57_ = NULL;
			gpointer _tmp58_ = NULL;
			GeeHashSet* _tmp59_ = NULL;
			FolksPersona* _tmp60_ = NULL;
			const gchar* _tmp61_ = NULL;
			const gchar* _tmp62_ = NULL;
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp55_ = _persona_it;
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp56_ = gee_iterator_next (_tmp55_);
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp56_) {
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 4021 "aggregation.c"
			}
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp57_ = _persona_it;
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp58_ = gee_iterator_get (_tmp57_);
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			persona = (FolksPersona*) _tmp58_;
#line 667 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp59_ = display_ids_detailed;
#line 667 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp60_ = persona;
#line 667 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp61_ = folks_persona_get_display_id (_tmp60_);
#line 667 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp62_ = _tmp61_;
#line 667 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp59_, _tmp62_);
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 4041 "aggregation.c"
		}
#line 665 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_persona_it);
#line 4045 "aggregation.c"
	}
#line 670 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp64_ = display_ids_detailed;
#line 670 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp65_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp64_, "me@example.com");
#line 670 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_tmp65_) {
#line 4053 "aggregation.c"
		GeeHashSet* _tmp66_ = NULL;
		gboolean _tmp67_ = FALSE;
#line 671 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp66_ = display_ids_detailed;
#line 671 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp67_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp66_, "me2@example.com");
#line 671 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp63_ = _tmp67_;
#line 4062 "aggregation.c"
	} else {
#line 670 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp63_ = FALSE;
#line 4066 "aggregation.c"
	}
#line 670 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp63_, "display_ids_detailed.contains (\"me@example.com\") &&           display_ids_detailed.contains (\"me2@example.com\")");
#line 673 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp68_ = _data4_->aggregator;
#line 673 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp69_ = individuals_changed_id;
#line 673 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp68_, _tmp69_);
#line 674 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp70_ = _data4_->aggregator;
#line 674 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp71_ = individuals_changed_detailed_id;
#line 674 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp70_, _tmp71_);
#line 677 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp72_ = tp_backend;
#line 677 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp73_ = account2_handle;
#line 677 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp72_, _tmp73_);
#line 678 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp74_ = tp_backend;
#line 678 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp75_ = account1_handle;
#line 678 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp74_, _tmp75_);
#line 679 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data4_->aggregator);
#line 679 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_->aggregator = NULL;
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (display_ids_detailed);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (display_ids);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block4_data_unref (_data4_);
#line 588 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data4_ = NULL;
#line 4110 "aggregation.c"
}


static void _aggregation_tests_test_user_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, FolksIndividual** user_individual) {
#line 682 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 682 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 682 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 4121 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4134 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
			gboolean _tmp12_ = FALSE;
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 4154 "aggregation.c"
			}
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 689 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 689 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 689 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 4168 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 689 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 689 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 4175 "aggregation.c"
			}
#line 689 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp6_, "i != null || detailed == true");
#line 690 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = i;
#line 690 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp9_ == NULL) {
#line 692 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 692 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4187 "aggregation.c"
			}
#line 695 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 695 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = folks_individual_get_is_user (_tmp10_);
#line 695 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = _tmp11_;
#line 695 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp12_) {
#line 4197 "aggregation.c"
				FolksIndividual* _tmp13_ = NULL;
				FolksIndividual* _tmp14_ = NULL;
#line 697 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp13_ = *user_individual;
#line 697 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = i;
#line 697 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp13_ == _tmp14_, "user_individual == i");
#line 698 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (*user_individual);
#line 698 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				*user_individual = NULL;
#line 4210 "aggregation.c"
			}
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4214 "aggregation.c"
		}
#line 687 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4218 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp15_ = NULL;
		GeeIterator* _tmp16_ = NULL;
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp15_ = added;
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp16_ = gee_iterable_iterator ((GeeIterable*) _tmp15_);
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp16_;
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4232 "aggregation.c"
			GeeIterator* _tmp17_ = NULL;
			gboolean _tmp18_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp19_ = NULL;
			gpointer _tmp20_ = NULL;
			gboolean _tmp21_ = FALSE;
			FolksIndividual* _tmp22_ = NULL;
			FolksIndividual* _tmp24_ = NULL;
			FolksIndividual* _tmp25_ = NULL;
			gboolean _tmp26_ = FALSE;
			gboolean _tmp27_ = FALSE;
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = _i_it;
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp18_ = gee_iterator_next (_tmp17_);
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp18_) {
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 4252 "aggregation.c"
			}
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp19_ = _i_it;
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp20_ = gee_iterator_get (_tmp19_);
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp20_;
#line 704 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = i;
#line 704 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp22_ != NULL) {
#line 704 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp21_ = TRUE;
#line 4266 "aggregation.c"
			} else {
				gboolean _tmp23_ = FALSE;
#line 704 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp23_ = detailed;
#line 704 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp21_ = _tmp23_ == TRUE;
#line 4273 "aggregation.c"
			}
#line 704 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp21_, "i != null || detailed == true");
#line 705 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = i;
#line 705 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp24_ == NULL) {
#line 707 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 707 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4285 "aggregation.c"
			}
#line 710 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = i;
#line 710 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = folks_individual_get_is_user (_tmp25_);
#line 710 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = _tmp26_;
#line 710 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp27_) {
#line 4295 "aggregation.c"
				FolksIndividual* _tmp28_ = NULL;
				FolksIndividual* _tmp29_ = NULL;
				FolksIndividual* _tmp30_ = NULL;
#line 712 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp28_ = *user_individual;
#line 712 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp28_ == NULL, "user_individual == null");
#line 713 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp29_ = i;
#line 713 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp30_ = _g_object_ref0 (_tmp29_);
#line 713 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (*user_individual);
#line 713 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				*user_individual = _tmp30_;
#line 4311 "aggregation.c"
			}
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4315 "aggregation.c"
		}
#line 702 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4319 "aggregation.c"
	}
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data5_;
#line 4329 "aggregation.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 4338 "aggregation.c"
		AggregationTests* self;
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data5_->self;
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data5_->aggregator);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block5Data, _data5_);
#line 4348 "aggregation.c"
	}
}


static void __lambda19_ (AggregationTests* self, GeeMultiMap* changes) {
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 736 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 738 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 738 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 738 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 739 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 739 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 739 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 741 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_untrusted_store_individuals_changed (self, TRUE, added, removed);
#line 736 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 736 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 4380 "aggregation.c"
}


static void ___lambda19__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 735 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda19_ ((AggregationTests*) self, changes);
#line 4387 "aggregation.c"
}


static void __lambda20_ (AggregationTests* self, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 744 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 744 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 746 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 746 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 746 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_untrusted_store_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_);
#line 4404 "aggregation.c"
}


static void ___lambda20__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 743 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda20_ ((AggregationTests*) self, added, removed, message, actor, reason);
#line 4411 "aggregation.c"
}


static void __lambda22_ (Block5Data* _data5_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 756 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data5_->self;
#line 756 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 4422 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 760 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data5_->aggregator;
#line 760 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 760 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 760 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 4434 "aggregation.c"
			goto __catch4_g_error;
		}
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 758 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 758 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 764 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 764 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:764: Failed to prepare aggregator: %s", _tmp2_);
#line 766 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 758 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 4455 "aggregation.c"
	}
	__finally4:
#line 758 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 758 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 758 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 758 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 4466 "aggregation.c"
	}
}


static void ___lambda22__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 756 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda22_ (self, source_object, res);
#line 756 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block5_data_unref (self);
#line 4476 "aggregation.c"
}


static gboolean __lambda21_ (Block5Data* _data5_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 754 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data5_->self;
#line 756 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data5_->aggregator;
#line 756 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda22__gasync_ready_callback, block5_data_ref (_data5_));
#line 770 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 770 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 4494 "aggregation.c"
}


static gboolean ___lambda21__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda21_ (self);
#line 754 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 4503 "aggregation.c"
}


void aggregation_tests_test_untrusted_store (AggregationTests* self) {
	Block5Data* _data5_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	void* _tmp4_ = NULL;
	void* account2_handle = NULL;
	void* _tmp5_ = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	gulong individuals_changed_detailed_id = 0UL;
	FolksIndividualAggregator* _tmp7_ = NULL;
	gulong _tmp8_ = 0UL;
	gulong individuals_changed_id = 0UL;
	FolksIndividualAggregator* _tmp9_ = NULL;
	gulong _tmp10_ = 0UL;
	FolksIndividualAggregator* _tmp11_ = NULL;
	FolksIndividualAggregator* _tmp12_ = NULL;
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data5_ = g_slice_new0 (Block5Data);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data5_->_ref_count_ = 1;
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data5_->self = g_object_ref (self);
#line 723 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 723 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 725 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 725 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 727 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 727 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 727 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp3_;
#line 728 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_tests_backend_add_account (tp_backend, "irc", "me@example.com", "cm", "account");
#line 728 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp4_;
#line 730 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (tp_backend, "irc", "me2@example.com", "cm", "account2");
#line 730 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp5_;
#line 734 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = folks_individual_aggregator_dup ();
#line 734 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data5_->aggregator = _tmp6_;
#line 735 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data5_->aggregator;
#line 735 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = g_signal_connect_object (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda19__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 735 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	individuals_changed_detailed_id = _tmp8_;
#line 743 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data5_->aggregator;
#line 743 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = g_signal_connect_object (_tmp9_, "individuals-changed", (GCallback) ___lambda20__folks_individual_aggregator_individuals_changed, self, 0);
#line 743 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	individuals_changed_id = _tmp10_;
#line 754 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda21__gsource_func, block5_data_ref (_data5_), block5_data_unref);
#line 773 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 775 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data5_->aggregator;
#line 775 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp11_, individuals_changed_id);
#line 776 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data5_->aggregator;
#line 776 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp12_, individuals_changed_detailed_id);
#line 779 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (tp_backend, account2_handle);
#line 780 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (tp_backend, account1_handle);
#line 781 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data5_->aggregator);
#line 781 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data5_->aggregator = NULL;
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block5_data_unref (_data5_);
#line 721 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data5_ = NULL;
#line 4602 "aggregation.c"
}


static void _aggregation_tests_test_untrusted_store_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed) {
#line 784 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 784 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 784 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 4613 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4626 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			FolksIndividual* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gboolean _tmp13_ = FALSE;
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 4647 "aggregation.c"
			}
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 791 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 791 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 791 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 4661 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 791 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 791 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 4668 "aggregation.c"
			}
#line 791 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp6_, "i != null || detailed == true");
#line 792 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = i;
#line 792 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp9_ == NULL) {
#line 794 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 794 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4680 "aggregation.c"
			}
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = i;
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _tmp12_;
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp13_) {
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp10_ = TRUE;
#line 4692 "aggregation.c"
			} else {
				FolksIndividual* _tmp14_ = NULL;
				GeeSet* _tmp15_ = NULL;
				GeeSet* _tmp16_ = NULL;
				gint _tmp17_ = 0;
				gint _tmp18_ = 0;
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = i;
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = folks_individual_get_personas (_tmp14_);
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp10_ = _tmp18_ == 1;
#line 4711 "aggregation.c"
			}
#line 797 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp10_, "i.is_user || i.personas.size == 1");
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4717 "aggregation.c"
		}
#line 789 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4721 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp19_ = NULL;
		GeeIterator* _tmp20_ = NULL;
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp19_ = added;
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp20_ = gee_iterable_iterator ((GeeIterable*) _tmp19_);
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp20_;
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4735 "aggregation.c"
			GeeIterator* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp23_ = NULL;
			gpointer _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			FolksIndividual* _tmp26_ = NULL;
			FolksIndividual* _tmp28_ = NULL;
			gboolean _tmp29_ = FALSE;
			FolksIndividual* _tmp30_ = NULL;
			gboolean _tmp31_ = FALSE;
			gboolean _tmp32_ = FALSE;
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _i_it;
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp22_) {
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 4756 "aggregation.c"
			}
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = _i_it;
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp24_;
#line 802 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = i;
#line 802 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp26_ != NULL) {
#line 802 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp25_ = TRUE;
#line 4770 "aggregation.c"
			} else {
				gboolean _tmp27_ = FALSE;
#line 802 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp27_ = detailed;
#line 802 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp25_ = _tmp27_ == TRUE;
#line 4777 "aggregation.c"
			}
#line 802 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp25_, "i != null || detailed == true");
#line 803 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = i;
#line 803 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp28_ == NULL) {
#line 805 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 805 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 4789 "aggregation.c"
			}
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = i;
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = folks_individual_get_is_user (_tmp30_);
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = _tmp31_;
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp32_) {
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp29_ = TRUE;
#line 4801 "aggregation.c"
			} else {
				FolksIndividual* _tmp33_ = NULL;
				GeeSet* _tmp34_ = NULL;
				GeeSet* _tmp35_ = NULL;
				gint _tmp36_ = 0;
				gint _tmp37_ = 0;
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp33_ = i;
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp35_ = _tmp34_;
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp36_ = gee_collection_get_size ((GeeCollection*) _tmp35_);
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp37_ = _tmp36_;
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp29_ = _tmp37_ == 1;
#line 4820 "aggregation.c"
			}
#line 808 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp29_, "i.is_user || i.personas.size == 1");
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4826 "aggregation.c"
		}
#line 800 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4830 "aggregation.c"
	}
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data6_;
#line 4840 "aggregation.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 4849 "aggregation.c"
		AggregationTests* self;
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data6_->self;
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data6_->aggregator);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data6_->individuals_map);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block6Data, _data6_);
#line 4861 "aggregation.c"
	}
}


static void ____lambda24_ (Block6Data* _data6_, GObject* obj) {
	AggregationTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	gchar* weak_key = NULL;
	FolksIndividual* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	FolksIndividual* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	AggregationTestsIndividualState state = 0;
	GeeHashMap* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gpointer _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	AggregationTestsIndividualState _tmp13_ = 0;
	GeeHashMap* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
#line 883 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 883 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (obj != NULL);
#line 885 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = obj;
#line 885 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	ind = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual);
#line 886 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ind;
#line 886 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_get_id (_tmp1_);
#line 886 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _tmp2_;
#line 886 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = ind;
#line 886 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = g_strdup_printf ("%s:%p", _tmp3_, _tmp4_);
#line 886 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	weak_key = _tmp5_;
#line 888 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data6_->individuals_map;
#line 888 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = weak_key;
#line 888 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp6_, _tmp7_);
#line 888 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp8_ == TRUE, "individuals_map.has_key (weak_key) == true");
#line 889 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data6_->individuals_map;
#line 889 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp10_ = weak_key;
#line 889 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp9_, _tmp10_);
#line 889 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	state = (AggregationTestsIndividualState) ((gintptr) _tmp11_);
#line 890 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = state;
#line 890 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_tmp13_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED) {
#line 890 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp12_ = TRUE;
#line 4929 "aggregation.c"
	} else {
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_ = FALSE;
#line 891 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp15_ = _data6_->aggregator_is_finalising;
#line 891 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_tmp15_ == TRUE) {
#line 4937 "aggregation.c"
			AggregationTestsIndividualState _tmp16_ = 0;
#line 892 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = state;
#line 892 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp16_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED;
#line 4943 "aggregation.c"
		} else {
#line 891 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = FALSE;
#line 4947 "aggregation.c"
		}
#line 891 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp12_ = _tmp14_;
#line 4951 "aggregation.c"
	}
#line 890 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp12_, "state == IndividualState.REMOVED ||                       (aggregator_is_finalising == true &&                           state == IndividualState.ADDED)");
#line 894 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = _data6_->individuals_map;
#line 894 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = weak_key;
#line 894 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, _tmp18_, (gpointer) ((gintptr) AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED));
#line 883 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_free0 (weak_key);
#line 4963 "aggregation.c"
}


static void _____lambda24__gweak_notify (gpointer self, GObject* object) {
#line 883 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	____lambda24_ (self, object);
#line 4970 "aggregation.c"
}


static void __lambda23_ (Block6Data* _data6_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests* self;
#line 858 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 858 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 858 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 4982 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4995 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gchar* key = NULL;
			FolksIndividual* _tmp6_ = NULL;
			const gchar* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
			GeeHashMap* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			GeeHashMap* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			gpointer _tmp16_ = NULL;
			GeeHashMap* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 5023 "aggregation.c"
			}
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 862 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp6_ = i;
#line 862 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = folks_individual_get_id (_tmp6_);
#line 862 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _tmp7_;
#line 862 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = i;
#line 862 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = g_strdup_printf ("%s:%p", _tmp8_, _tmp9_);
#line 862 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			key = _tmp10_;
#line 864 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = _data6_->individuals_map;
#line 864 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = key;
#line 864 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp11_, _tmp12_);
#line 864 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp13_ == TRUE, "individuals_map.has_key (key) == true");
#line 865 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _data6_->individuals_map;
#line 865 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = key;
#line 865 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp14_, _tmp15_);
#line 865 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (((AggregationTestsIndividualState) ((gintptr) _tmp16_)) == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED, "individuals_map.get (key) == IndividualState.ADDED");
#line 867 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = _data6_->individuals_map;
#line 867 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp18_ = key;
#line 867 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, _tmp18_, (gpointer) ((gintptr) AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED));
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_free0 (key);
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 5069 "aggregation.c"
		}
#line 860 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 5073 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp19_ = NULL;
		GeeIterator* _tmp20_ = NULL;
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp19_ = added;
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp20_ = gee_iterable_iterator ((GeeIterable*) _tmp19_);
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp20_;
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5087 "aggregation.c"
			GeeIterator* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp23_ = NULL;
			gpointer _tmp24_ = NULL;
			gchar* key = NULL;
			FolksIndividual* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			FolksIndividual* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			GeeHashMap* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			gboolean _tmp32_ = FALSE;
			GeeHashMap* _tmp33_ = NULL;
			const gchar* _tmp34_ = NULL;
			FolksIndividual* _tmp35_ = NULL;
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp21_ = _i_it;
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp22_) {
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 5113 "aggregation.c"
			}
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = _i_it;
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp24_;
#line 872 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = i;
#line 872 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = folks_individual_get_id (_tmp25_);
#line 872 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = _tmp26_;
#line 872 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp28_ = i;
#line 872 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp29_ = g_strdup_printf ("%s:%p", _tmp27_, _tmp28_);
#line 872 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			key = _tmp29_;
#line 874 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp30_ = _data6_->individuals_map;
#line 874 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp31_ = key;
#line 874 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp32_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp30_, _tmp31_);
#line 874 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp32_ == FALSE, "individuals_map.has_key (key) == false");
#line 876 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp33_ = _data6_->individuals_map;
#line 876 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp34_ = key;
#line 876 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp33_, _tmp34_, (gpointer) ((gintptr) AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED));
#line 883 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp35_ = i;
#line 883 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			g_object_weak_ref ((GObject*) _tmp35_, _____lambda24__gweak_notify, _data6_);
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_free0 (key);
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 5155 "aggregation.c"
		}
#line 870 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 5159 "aggregation.c"
	}
}


static void ___lambda23__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 858 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda23_ (self, added, removed, message, actor, reason);
#line 5167 "aggregation.c"
}


static void __lambda26_ (Block6Data* _data6_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 904 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 904 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 5178 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 908 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data6_->aggregator;
#line 908 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 908 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 908 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5190 "aggregation.c"
			goto __catch5_g_error;
		}
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 906 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 906 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 912 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 912 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:912: Failed to prepare aggregator: %s", _tmp2_);
#line 914 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 906 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5211 "aggregation.c"
	}
	__finally5:
#line 906 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 906 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 906 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 906 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 5222 "aggregation.c"
	}
}


static void ___lambda26__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 904 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda26_ (self, source_object, res);
#line 904 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block6_data_unref (self);
#line 5232 "aggregation.c"
}


static gboolean __lambda25_ (Block6Data* _data6_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 902 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 904 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data6_->aggregator;
#line 904 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda26__gasync_ready_callback, block6_data_ref (_data6_));
#line 918 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 918 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5250 "aggregation.c"
}


static gboolean ___lambda25__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda25_ (self);
#line 902 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5259 "aggregation.c"
}


void aggregation_tests_test_linked_individual_refcounting (AggregationTests* self) {
	Block6Data* _data6_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	void* _tmp3_ = NULL;
	GeeHashMap* _tmp4_ = NULL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	GMainLoop* _tmp7_ = NULL;
	GeeMapIterator* iter = NULL;
	GeeHashMap* _tmp8_ = NULL;
	GeeMapIterator* _tmp9_ = NULL;
	TpTestsBackend* _tmp17_ = NULL;
	void* _tmp18_ = NULL;
	KfTestBackend* _tmp19_ = NULL;
	GMainLoop* _tmp20_ = NULL;
	GeeHashMap* _tmp21_ = NULL;
	GeeMapIterator* _tmp22_ = NULL;
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_->_ref_count_ = 1;
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_->self = g_object_ref (self);
#line 828 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 828 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 830 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 830 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com");
#line 837 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 837 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_tests_backend_add_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend), "protocol", "me@example.com", "cm", "account");
#line 837 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	((TpfTestTestCase*) self)->account_handle = _tmp3_;
#line 852 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, AGGREGATION_TESTS_TYPE_INDIVIDUAL_STATE, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 852 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_->individuals_map = _tmp4_;
#line 855 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = folks_individual_aggregator_dup ();
#line 855 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator = _tmp5_;
#line 856 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator_is_finalising = FALSE;
#line 858 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data6_->aggregator;
#line 858 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp6_, "individuals-changed", (GCallback) ___lambda23__folks_individual_aggregator_individuals_changed, block6_data_ref (_data6_), (GClosureNotify) block6_data_unref, 0);
#line 902 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda25__gsource_func, block6_data_ref (_data6_), block6_data_unref);
#line 921 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = main_loop;
#line 921 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp7_, 3);
#line 925 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data6_->individuals_map;
#line 925 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp9_ = gee_abstract_map_map_iterator ((GeeAbstractMap*) _tmp8_);
#line 925 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	iter = _tmp9_;
#line 926 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	while (TRUE) {
#line 5333 "aggregation.c"
		GeeMapIterator* _tmp10_ = NULL;
		gboolean _tmp11_ = FALSE;
		AggregationTestsIndividualState state = 0;
		GeeMapIterator* _tmp12_ = NULL;
		gpointer _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
		AggregationTestsIndividualState _tmp15_ = 0;
#line 926 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp10_ = iter;
#line 926 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp11_ = gee_map_iterator_next (_tmp10_);
#line 926 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (!(_tmp11_ == TRUE)) {
#line 926 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			break;
#line 5349 "aggregation.c"
		}
#line 928 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp12_ = iter;
#line 928 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp13_ = gee_map_iterator_get_value (_tmp12_);
#line 928 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		state = (AggregationTestsIndividualState) ((gintptr) _tmp13_);
#line 929 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp15_ = state;
#line 929 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_tmp15_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED) {
#line 929 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = TRUE;
#line 5363 "aggregation.c"
		} else {
			AggregationTestsIndividualState _tmp16_ = 0;
#line 930 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = state;
#line 930 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp16_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED;
#line 5370 "aggregation.c"
		}
#line 929 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_vala_assert (_tmp14_, "state == IndividualState.ADDED ||                   state == IndividualState.FINALISED");
#line 5374 "aggregation.c"
	}
#line 934 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = ((TpfTestTestCase*) self)->tp_backend;
#line 934 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = ((TpfTestTestCase*) self)->account_handle;
#line 934 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, tp_tests_backend_get_type (), TpTestsBackend), (void*) _tmp18_);
#line 935 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = ((TpfTestTestCase*) self)->kf_backend;
#line 935 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, KF_TEST_TYPE_BACKEND, KfTestBackend));
#line 936 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator_is_finalising = TRUE;
#line 937 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data6_->aggregator);
#line 937 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_->aggregator = NULL;
#line 942 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = main_loop;
#line 942 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp20_, 3);
#line 946 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = _data6_->individuals_map;
#line 946 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = gee_abstract_map_map_iterator ((GeeAbstractMap*) _tmp21_);
#line 946 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (iter);
#line 946 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	iter = _tmp22_;
#line 947 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	while (TRUE) {
#line 5406 "aggregation.c"
		GeeMapIterator* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		GeeMapIterator* _tmp25_ = NULL;
		gpointer _tmp26_ = NULL;
#line 947 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp23_ = iter;
#line 947 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp24_ = gee_map_iterator_next (_tmp23_);
#line 947 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (!(_tmp24_ == TRUE)) {
#line 947 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			break;
#line 5419 "aggregation.c"
		}
#line 949 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp25_ = iter;
#line 949 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp26_ = gee_map_iterator_get_value (_tmp25_);
#line 949 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_vala_assert (((AggregationTestsIndividualState) ((gintptr) _tmp26_)) == AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED, "iter.get_value () == IndividualState.FINALISED");
#line 5427 "aggregation.c"
	}
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (iter);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block6_data_unref (_data6_);
#line 826 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data6_ = NULL;
#line 5437 "aggregation.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data7_;
#line 5446 "aggregation.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 5455 "aggregation.c"
		AggregationTests* self;
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data7_->self;
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->writeable_persona);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->aggregator);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->individual);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data7_->main_loop);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block7Data, _data7_);
#line 5471 "aggregation.c"
	}
}


static void __lambda27_ (Block7Data* _data7_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeMultiMap* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 970 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 970 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 972 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 972 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_size (_tmp0_);
#line 972 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 972 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp2_ == 1, "changes.size == 1");
#line 5493 "aggregation.c"
	{
		GeeIterator* _removed_it = NULL;
		GeeMultiMap* _tmp3_ = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = changes;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = gee_multi_map_get_keys (_tmp3_);
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp7_ = _tmp6_;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp5_);
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_removed_it = _tmp7_;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5517 "aggregation.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* removed = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _removed_it;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp9_) {
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 5532 "aggregation.c"
			}
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = _removed_it;
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			removed = (FolksIndividual*) _tmp11_;
#line 976 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = removed;
#line 976 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp12_ == NULL, "removed == null");
#line 5544 "aggregation.c"
			{
				GeeIterator* _i_it = NULL;
				GeeMultiMap* _tmp13_ = NULL;
				FolksIndividual* _tmp14_ = NULL;
				GeeCollection* _tmp15_ = NULL;
				GeeCollection* _tmp16_ = NULL;
				GeeIterator* _tmp17_ = NULL;
				GeeIterator* _tmp18_ = NULL;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp13_ = changes;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = removed;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = gee_multi_map_get (_tmp13_, _tmp14_);
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_tmp16_);
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_i_it = _tmp18_;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 5571 "aggregation.c"
					GeeIterator* _tmp19_ = NULL;
					gboolean _tmp20_ = FALSE;
					FolksIndividual* i = NULL;
					GeeIterator* _tmp21_ = NULL;
					gpointer _tmp22_ = NULL;
					FolksIndividual* _tmp23_ = NULL;
					FolksIndividual* _tmp24_ = NULL;
					FolksIndividual* _tmp25_ = NULL;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp19_ = _i_it;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp20_ = gee_iterator_next (_tmp19_);
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (!_tmp20_) {
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						break;
#line 5588 "aggregation.c"
					}
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp21_ = _i_it;
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp22_ = gee_iterator_get (_tmp21_);
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					i = (FolksIndividual*) _tmp22_;
#line 980 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp23_ = i;
#line 980 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_vala_assert (_tmp23_ != NULL, "i != null");
#line 981 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_vala_assert (_data7_->individual == NULL, "individual == null");
#line 983 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 983 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp25_ = _g_object_ref0 (_tmp24_);
#line 983 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_data7_->individual);
#line 983 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_data7_->individual = _tmp25_;
#line 984 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					g_main_loop_quit (_data7_->main_loop);
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (i);
#line 5614 "aggregation.c"
				}
#line 978 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 5618 "aggregation.c"
			}
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (removed);
#line 5622 "aggregation.c"
		}
#line 974 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_removed_it);
#line 5626 "aggregation.c"
	}
}


static void ___lambda27__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 970 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda27_ (self, changes);
#line 5634 "aggregation.c"
}


static void __lambda29_ (Block7Data* _data7_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 993 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 993 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 5645 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 997 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data7_->aggregator;
#line 997 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 997 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 997 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5657 "aggregation.c"
			goto __catch6_g_error;
		}
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 995 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 995 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1001 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1001 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1001: Failed to prepare aggregator: %s", _tmp2_);
#line 1003 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 995 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5678 "aggregation.c"
	}
	__finally6:
#line 995 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 995 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 995 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 995 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 5689 "aggregation.c"
	}
}


static void ___lambda29__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 993 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda29_ (self, source_object, res);
#line 993 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block7_data_unref (self);
#line 5699 "aggregation.c"
}


static gboolean __lambda28_ (Block7Data* _data7_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 991 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 993 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data7_->aggregator;
#line 993 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda29__gasync_ready_callback, block7_data_ref (_data7_));
#line 1007 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1007 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5717 "aggregation.c"
}


static gboolean ___lambda28__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda28_ (self);
#line 991 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5726 "aggregation.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	for (i = 0; i < stack_length; i++) {
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			return TRUE;
#line 5738 "aggregation.c"
		}
	}
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return FALSE;
#line 5743 "aggregation.c"
}


static void __lambda31_ (Block7Data* _data7_, GObject* obj, GAsyncResult* res) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 1033 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1033 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 5754 "aggregation.c"
	{
		FolksPersona* _tmp0_ = NULL;
		FolksIndividualAggregator* _tmp1_ = NULL;
		GAsyncResult* _tmp2_ = NULL;
		FolksPersona* _tmp3_ = NULL;
		FolksPersona* _tmp4_ = NULL;
#line 1038 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = _data7_->aggregator;
#line 1038 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = res;
#line 1038 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp1_, _tmp2_, &_inner_error_);
#line 1038 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _tmp3_;
#line 1038 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5771 "aggregation.c"
			goto __catch7_g_error;
		}
#line 1037 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = _tmp0_;
#line 1037 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = NULL;
#line 1037 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->writeable_persona);
#line 1037 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_data7_->writeable_persona = _tmp4_;
#line 1040 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data7_->main_loop);
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp0_);
#line 5786 "aggregation.c"
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp5_ = NULL;
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1044 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = e1->message;
#line 1044 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1044: Failed to ensure property writeable: %s", _tmp5_);
#line 1046 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5805 "aggregation.c"
	}
	__finally7:
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1035 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 5816 "aggregation.c"
	}
}


static void ___lambda31__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1032 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda31_ (self, source_object, res);
#line 1032 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block7_data_unref (self);
#line 5826 "aggregation.c"
}


static gboolean __lambda30_ (Block7Data* _data7_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1030 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1032 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data7_->aggregator;
#line 1032 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _data7_->individual, "alias", ___lambda31__gasync_ready_callback, block7_data_ref (_data7_));
#line 1050 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1050 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5844 "aggregation.c"
}


static gboolean ___lambda30__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda30_ (self);
#line 1030 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 5853 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_trivial (AggregationTests* self) {
	Block7Data* _data7_;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
	FolksPersona* persona = NULL;
	FolksPersona* _tmp11_ = NULL;
	FolksPersona* _tmp12_ = NULL;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	FolksPersona* _tmp15_ = NULL;
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_->_ref_count_ = 1;
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_->self = g_object_ref (self);
#line 961 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 961 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_->main_loop = _tmp0_;
#line 963 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 963 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com\n");
#line 966 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_->individual = NULL;
#line 969 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_aggregator_dup ();
#line 969 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_->aggregator = _tmp2_;
#line 970 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data7_->aggregator;
#line 970 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda27__folks_individual_aggregator_individuals_changed_detailed, block7_data_ref (_data7_), (GClosureNotify) block7_data_unref, 0);
#line 991 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda28__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1010 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data7_->main_loop, 3);
#line 1013 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_data7_->individual != NULL, "individual != null");
#line 1015 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 5905 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = folks_individual_get_personas (_data7_->individual);
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp6_;
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5921 "aggregation.c"
			gboolean _tmp7_ = FALSE;
			FolksPersona* p = NULL;
			gpointer _tmp8_ = NULL;
			FolksPersona* _tmp9_ = NULL;
			FolksPersona* _tmp10_ = NULL;
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_p_it);
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 5933 "aggregation.c"
			}
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = gee_iterator_get (_p_it);
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp8_;
#line 1018 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = p;
#line 1018 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = _g_object_ref0 (_tmp9_);
#line 1018 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1018 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			persona = _tmp10_;
#line 1019 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1019 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			break;
#line 5951 "aggregation.c"
		}
#line 1016 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 5955 "aggregation.c"
	}
#line 1023 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = persona;
#line 1023 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp11_ != NULL, "persona != null");
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = persona;
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = folks_persona_get_writeable_properties (_tmp12_, &_tmp13__length1);
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = _tmp13_;
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp14__length1 = _tmp13__length1;
#line 1024 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_vala_string_array_contains (_tmp14_, _tmp14__length1, "alias"), "\"alias\" in persona.writeable_properties");
#line 1026 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_->writeable_persona = NULL;
#line 1030 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda30__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1053 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data7_->main_loop, 3);
#line 1055 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_data7_->writeable_persona != NULL, "writeable_persona != null");
#line 1056 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp15_ = persona;
#line 1056 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_data7_->writeable_persona == _tmp15_, "writeable_persona == persona");
#line 1059 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data7_->aggregator);
#line 1059 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_->aggregator = NULL;
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block7_data_unref (_data7_);
#line 959 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data7_ = NULL;
#line 5993 "aggregation.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data8_;
#line 6002 "aggregation.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 6011 "aggregation.c"
		AggregationTests* self;
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data8_->self;
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->writeable_persona);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->aggregator);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->individual);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data8_->main_loop);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block8Data, _data8_);
#line 6027 "aggregation.c"
	}
}


static void __lambda32_ (Block8Data* _data8_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
#line 1085 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1085 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1087 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1087 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 1087 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	added = _tmp1_;
#line 1088 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 1088 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 1088 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	removed = _tmp3_;
#line 6059 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = added;
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp5_;
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6072 "aggregation.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp6_ = _i_it;
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 6091 "aggregation.c"
			}
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _i_it;
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp9_;
#line 1092 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 1092 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 1094 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = i;
#line 1094 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = folks_individual_get_id (_tmp11_);
#line 1094 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _tmp12_;
#line 1094 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = self->priv->olivier_sha1;
#line 1094 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (g_strcmp0 (_tmp13_, _tmp14_) == 0) {
#line 6113 "aggregation.c"
				FolksIndividual* _tmp15_ = NULL;
				FolksIndividual* _tmp16_ = NULL;
				FolksIndividual* _tmp17_ = NULL;
#line 1096 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = _data8_->individual;
#line 1096 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp15_ == NULL, "individual == null");
#line 1097 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = i;
#line 1097 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = _g_object_ref0 (_tmp16_);
#line 1097 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_data8_->individual);
#line 1097 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_data8_->individual = _tmp17_;
#line 1098 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1098 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 1098 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (removed);
#line 1098 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (added);
#line 1098 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				return;
#line 6139 "aggregation.c"
			}
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6143 "aggregation.c"
		}
#line 1090 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6147 "aggregation.c"
	}
#line 1102 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = removed;
#line 1102 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
#line 1102 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = _tmp19_;
#line 1102 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp20_ == 1, "removed.size == 1");
#line 6157 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp21_ = removed;
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp22_;
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6170 "aggregation.c"
			GeeIterator* _tmp23_ = NULL;
			gboolean _tmp24_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp25_ = NULL;
			gpointer _tmp26_ = NULL;
			FolksIndividual* _tmp27_ = NULL;
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp23_ = _i_it;
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp24_) {
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 6185 "aggregation.c"
			}
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp25_ = _i_it;
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp26_;
#line 1106 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp27_ = i;
#line 1106 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp27_ == NULL, "i == null");
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6199 "aggregation.c"
		}
#line 1104 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6203 "aggregation.c"
	}
#line 1085 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1085 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 6209 "aggregation.c"
}


static void ___lambda32__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1084 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda32_ (self, changes);
#line 6216 "aggregation.c"
}


static void __lambda34_ (Block8Data* _data8_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 1114 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1114 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 6227 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 1118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data8_->aggregator;
#line 1118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1118 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 6239 "aggregation.c"
			goto __catch8_g_error;
		}
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 1116 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1116 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1122 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1122 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1122: Failed to prepare aggregator: %s", _tmp2_);
#line 1124 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1116 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 6260 "aggregation.c"
	}
	__finally8:
#line 1116 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1116 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1116 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1116 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 6271 "aggregation.c"
	}
}


static void ___lambda34__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1114 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda34_ (self, source_object, res);
#line 1114 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block8_data_unref (self);
#line 6281 "aggregation.c"
}


static gboolean __lambda33_ (Block8Data* _data8_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1112 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1114 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data8_->aggregator;
#line 1114 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda34__gasync_ready_callback, block8_data_ref (_data8_));
#line 1128 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1128 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6299 "aggregation.c"
}


static gboolean ___lambda33__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda33_ (self);
#line 1112 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6308 "aggregation.c"
}


static void __lambda35_ (Block8Data* _data8_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
#line 1151 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1151 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1153 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1153 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 1153 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	added = _tmp1_;
#line 1154 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 1154 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 1154 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	removed = _tmp3_;
#line 6336 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = removed;
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp5_;
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6349 "aggregation.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			FolksIndividual* _tmp13_ = NULL;
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp6_ = _i_it;
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 6367 "aggregation.c"
			}
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _i_it;
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp9_;
#line 1158 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 1158 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 1160 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1160 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 6383 "aggregation.c"
			}
#line 1163 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = _data8_->individual;
#line 1163 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp11_ != NULL, "individual != null");
#line 1164 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 1164 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = _data8_->individual;
#line 1164 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp12_ == _tmp13_, "i == individual");
#line 1165 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (_data8_->individual);
#line 1165 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_data8_->individual = NULL;
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6401 "aggregation.c"
		}
#line 1156 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6405 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp14_ = NULL;
		GeeIterator* _tmp15_ = NULL;
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp14_ = added;
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_i_it = _tmp15_;
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6419 "aggregation.c"
			GeeIterator* _tmp16_ = NULL;
			gboolean _tmp17_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp18_ = NULL;
			gpointer _tmp19_ = NULL;
			FolksIndividual* _tmp20_ = NULL;
			gboolean got_tpf = FALSE;
			gboolean got_kf = FALSE;
			gboolean _tmp41_ = FALSE;
			gboolean _tmp42_ = FALSE;
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp16_ = _i_it;
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp17_ = gee_iterator_next (_tmp16_);
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp17_) {
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 6438 "aggregation.c"
			}
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp18_ = _i_it;
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp19_ = gee_iterator_get (_tmp18_);
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp19_;
#line 1170 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp20_ = i;
#line 1170 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp20_ == NULL) {
#line 1172 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1172 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				continue;
#line 6454 "aggregation.c"
			}
#line 1175 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			got_tpf = FALSE;
#line 1176 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			got_kf = FALSE;
#line 6460 "aggregation.c"
			{
				GeeIterator* _p_it = NULL;
				FolksIndividual* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeSet* _tmp23_ = NULL;
				GeeIterator* _tmp24_ = NULL;
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp21_ = i;
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp23_ = _tmp22_;
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp24_ = gee_iterable_iterator ((GeeIterable*) _tmp23_);
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_p_it = _tmp24_;
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 6479 "aggregation.c"
					GeeIterator* _tmp25_ = NULL;
					gboolean _tmp26_ = FALSE;
					FolksPersona* p = NULL;
					GeeIterator* _tmp27_ = NULL;
					gpointer _tmp28_ = NULL;
					FolksPersona* _tmp29_ = NULL;
					const gchar* _tmp30_ = NULL;
					const gchar* _tmp31_ = NULL;
					const gchar* _tmp32_ = NULL;
					gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
					gboolean _tmp35_ = FALSE;
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp25_ = _p_it;
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp26_ = gee_iterator_next (_tmp25_);
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (!_tmp26_) {
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						break;
#line 6500 "aggregation.c"
					}
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp27_ = _p_it;
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp28_ = gee_iterator_get (_tmp27_);
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					p = (FolksPersona*) _tmp28_;
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp29_ = p;
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp30_ = folks_persona_get_uid (_tmp29_);
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp31_ = _tmp30_;
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp32_ = aggregation_tests_iid_prefix;
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp33_ = g_strconcat (_tmp32_, "olivier@example.com", NULL);
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp34_ = _tmp33_;
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp35_ = g_strcmp0 (_tmp31_, _tmp34_) == 0;
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_free0 (_tmp34_);
#line 1183 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (_tmp35_) {
#line 1185 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						got_tpf = TRUE;
#line 6528 "aggregation.c"
					} else {
						FolksPersona* _tmp36_ = NULL;
						FolksPersonaStore* _tmp37_ = NULL;
						FolksPersonaStore* _tmp38_ = NULL;
						const gchar* _tmp39_ = NULL;
						const gchar* _tmp40_ = NULL;
#line 1187 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp36_ = p;
#line 1187 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp37_ = folks_persona_get_store (_tmp36_);
#line 1187 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp38_ = _tmp37_;
#line 1187 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp39_ = folks_persona_store_get_type_id (_tmp38_);
#line 1187 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						_tmp40_ = _tmp39_;
#line 1187 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						if (g_strcmp0 (_tmp40_, "key-file") == 0) {
#line 1189 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
							got_kf = TRUE;
#line 6549 "aggregation.c"
						}
					}
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (p);
#line 6554 "aggregation.c"
				}
#line 1181 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_p_it);
#line 6558 "aggregation.c"
			}
#line 1193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp42_ = got_tpf;
#line 1193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp42_ == TRUE) {
#line 6564 "aggregation.c"
				gboolean _tmp43_ = FALSE;
#line 1193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp43_ = got_kf;
#line 1193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = _tmp43_ == TRUE;
#line 6570 "aggregation.c"
			} else {
#line 1193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp41_ = FALSE;
#line 6574 "aggregation.c"
			}
#line 1193 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (_tmp41_) {
#line 6578 "aggregation.c"
				FolksIndividual* _tmp44_ = NULL;
				FolksIndividual* _tmp45_ = NULL;
#line 1195 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp44_ = i;
#line 1195 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp45_ = _g_object_ref0 (_tmp44_);
#line 1195 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_data8_->individual);
#line 1195 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_data8_->individual = _tmp45_;
#line 1196 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1196 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 1196 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (removed);
#line 1196 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (added);
#line 1196 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				return;
#line 6599 "aggregation.c"
			}
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6603 "aggregation.c"
		}
#line 1168 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6607 "aggregation.c"
	}
#line 1151 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1151 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 6613 "aggregation.c"
}


static void ___lambda35__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1151 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda35_ (self, changes);
#line 6620 "aggregation.c"
}


static void __lambda37_ (Block8Data* _data8_, GObject* obj, GAsyncResult* res) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 1206 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1206 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 6631 "aggregation.c"
	{
		FolksPersona* _tmp0_ = NULL;
		FolksIndividualAggregator* _tmp1_ = NULL;
		GAsyncResult* _tmp2_ = NULL;
		FolksPersona* _tmp3_ = NULL;
		FolksPersona* _tmp4_ = NULL;
#line 1211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = _data8_->aggregator;
#line 1211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = res;
#line 1211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp1_, _tmp2_, &_inner_error_);
#line 1211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _tmp3_;
#line 1211 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 6648 "aggregation.c"
			goto __catch9_g_error;
		}
#line 1210 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = _tmp0_;
#line 1210 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = NULL;
#line 1210 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->writeable_persona);
#line 1210 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_data8_->writeable_persona = _tmp4_;
#line 1213 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data8_->main_loop);
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp0_);
#line 6663 "aggregation.c"
	}
	goto __finally9;
	__catch9_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp5_ = NULL;
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1217 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = e1->message;
#line 1217 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1217: Failed to ensure property writeable: %s", _tmp5_);
#line 1219 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 6682 "aggregation.c"
	}
	__finally9:
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1208 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 6693 "aggregation.c"
	}
}


static void ___lambda37__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1205 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda37_ (self, source_object, res);
#line 1205 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block8_data_unref (self);
#line 6703 "aggregation.c"
}


static gboolean __lambda36_ (Block8Data* _data8_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 1203 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1205 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data8_->aggregator;
#line 1205 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = _data8_->individual;
#line 1205 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _tmp1_, "im-addresses", ___lambda37__gasync_ready_callback, block8_data_ref (_data8_));
#line 1223 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1223 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6724 "aggregation.c"
}


static gboolean ___lambda36__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda36_ (self);
#line 1203 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 6733 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_add_persona (AggregationTests* self) {
	Block8Data* _data8_;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	void* _tmp3_ = NULL;
	FolksIndividualAggregator* _tmp4_ = NULL;
	gulong individuals_changed_id = 0UL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
	FolksIndividual* _tmp7_ = NULL;
	FolksPersona* persona = NULL;
	FolksPersona* _tmp16_ = NULL;
	FolksPersona* _tmp17_ = NULL;
	gchar** _tmp18_ = NULL;
	gint _tmp18__length1 = 0;
	gchar** _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	FolksIndividualAggregator* _tmp20_ = NULL;
	FolksIndividualAggregator* _tmp21_ = NULL;
	FolksPersona* _tmp22_ = NULL;
	FolksPersona* _tmp23_ = NULL;
	FolksPersona* _tmp24_ = NULL;
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_ = g_slice_new0 (Block8Data);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->_ref_count_ = 1;
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->self = g_object_ref (self);
#line 1074 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 1074 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->main_loop = _tmp0_;
#line 1076 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 1076 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 1077 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 1077 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_tests_backend_add_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend), "protocol", "me@example.com", "cm", "account");
#line 1077 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	((TpfTestTestCase*) self)->account_handle = _tmp3_;
#line 1080 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->individual = NULL;
#line 1083 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp4_ = folks_individual_aggregator_dup ();
#line 1083 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->aggregator = _tmp4_;
#line 1084 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data8_->aggregator;
#line 1084 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp6_ = g_signal_connect_data (_tmp5_, "individuals-changed-detailed", (GCallback) ___lambda32__folks_individual_aggregator_individuals_changed_detailed, block8_data_ref (_data8_), (GClosureNotify) block8_data_unref, 0);
#line 1084 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	individuals_changed_id = _tmp6_;
#line 1112 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda33__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1131 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data8_->main_loop, 3);
#line 1134 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data8_->individual;
#line 1134 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp7_ != NULL, "individual != null");
#line 1136 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 6804 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp8_ = NULL;
		GeeSet* _tmp9_ = NULL;
		GeeSet* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp8_ = _data8_->individual;
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp9_ = folks_individual_get_personas (_tmp8_);
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp10_ = _tmp9_;
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp11_ = gee_iterable_iterator ((GeeIterable*) _tmp10_);
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp11_;
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6823 "aggregation.c"
			gboolean _tmp12_ = FALSE;
			FolksPersona* p = NULL;
			gpointer _tmp13_ = NULL;
			FolksPersona* _tmp14_ = NULL;
			FolksPersona* _tmp15_ = NULL;
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = gee_iterator_next (_p_it);
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp12_) {
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 6835 "aggregation.c"
			}
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp13_ = gee_iterator_get (_p_it);
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp13_;
#line 1139 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp14_ = p;
#line 1139 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp15_ = _g_object_ref0 (_tmp14_);
#line 1139 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1139 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			persona = _tmp15_;
#line 1140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1140 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			break;
#line 6853 "aggregation.c"
		}
#line 1137 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 6857 "aggregation.c"
	}
#line 1144 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp16_ = persona;
#line 1144 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp16_ != NULL, "persona != null");
#line 1145 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp17_ = persona;
#line 1145 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp18_ = folks_persona_get_writeable_properties (_tmp17_, &_tmp18__length1);
#line 1145 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp19_ = _tmp18_;
#line 1145 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp19__length1 = _tmp18__length1;
#line 1145 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (!_vala_string_array_contains (_tmp19_, _tmp19__length1, "im-addresses"), "!(\"im-addresses\" in persona.writeable_properties)");
#line 1147 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->writeable_persona = NULL;
#line 1150 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp20_ = _data8_->aggregator;
#line 1150 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp20_, individuals_changed_id);
#line 1151 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp21_ = _data8_->aggregator;
#line 1151 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp21_, "individuals-changed-detailed", (GCallback) ___lambda35__folks_individual_aggregator_individuals_changed_detailed, block8_data_ref (_data8_), (GClosureNotify) block8_data_unref, 0);
#line 1203 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda36__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1226 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data8_->main_loop, 3);
#line 1228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp22_ = _data8_->writeable_persona;
#line 1228 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp22_ != NULL, "writeable_persona != null");
#line 1229 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp23_ = _data8_->writeable_persona;
#line 1229 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp24_ = persona;
#line 1229 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp23_ != _tmp24_, "writeable_persona != persona");
#line 1232 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->individual);
#line 1232 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->individual = NULL;
#line 1233 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1233 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 1234 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->writeable_persona);
#line 1234 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->writeable_persona = NULL;
#line 1235 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->aggregator);
#line 1235 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_->aggregator = NULL;
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block8_data_unref (_data8_);
#line 1072 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data8_ = NULL;
#line 6919 "aggregation.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _data9_;
#line 6928 "aggregation.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 6937 "aggregation.c"
		AggregationTests* self;
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		self = _data9_->self;
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->writeable_persona);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->aggregator);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->individual);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data9_->main_loop);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_slice_free (Block9Data, _data9_);
#line 6953 "aggregation.c"
	}
}


static void __lambda38_ (Block9Data* _data9_, GeeMultiMap* changes) {
	AggregationTests* self;
	GeeMultiMap* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 1258 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1258 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1260 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1260 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_size (_tmp0_);
#line 1260 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 1260 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp2_ == 1, "changes.size == 1");
#line 6975 "aggregation.c"
	{
		GeeIterator* _removed_it = NULL;
		GeeMultiMap* _tmp3_ = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = changes;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = gee_multi_map_get_keys (_tmp3_);
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp7_ = _tmp6_;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp5_);
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_removed_it = _tmp7_;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6999 "aggregation.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* removed = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = _removed_it;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp9_) {
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 7014 "aggregation.c"
			}
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = _removed_it;
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			removed = (FolksIndividual*) _tmp11_;
#line 1264 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp12_ = removed;
#line 1264 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp12_ == NULL, "removed == null");
#line 7026 "aggregation.c"
			{
				GeeIterator* _i_it = NULL;
				GeeMultiMap* _tmp13_ = NULL;
				FolksIndividual* _tmp14_ = NULL;
				GeeCollection* _tmp15_ = NULL;
				GeeCollection* _tmp16_ = NULL;
				GeeIterator* _tmp17_ = NULL;
				GeeIterator* _tmp18_ = NULL;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp13_ = changes;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp14_ = removed;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp15_ = gee_multi_map_get (_tmp13_, _tmp14_);
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_tmp16_);
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_i_it = _tmp18_;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 7053 "aggregation.c"
					GeeIterator* _tmp19_ = NULL;
					gboolean _tmp20_ = FALSE;
					FolksIndividual* i = NULL;
					GeeIterator* _tmp21_ = NULL;
					gpointer _tmp22_ = NULL;
					FolksIndividual* _tmp23_ = NULL;
					FolksIndividual* _tmp24_ = NULL;
					FolksIndividual* _tmp25_ = NULL;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp19_ = _i_it;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp20_ = gee_iterator_next (_tmp19_);
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					if (!_tmp20_) {
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
						break;
#line 7070 "aggregation.c"
					}
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp21_ = _i_it;
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp22_ = gee_iterator_get (_tmp21_);
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					i = (FolksIndividual*) _tmp22_;
#line 1268 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp23_ = i;
#line 1268 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_vala_assert (_tmp23_ != NULL, "i != null");
#line 1269 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_vala_assert (_data9_->individual == NULL, "individual == null");
#line 1271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 1271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_tmp25_ = _g_object_ref0 (_tmp24_);
#line 1271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_data9_->individual);
#line 1271 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_data9_->individual = _tmp25_;
#line 1272 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					g_main_loop_quit (_data9_->main_loop);
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (i);
#line 7096 "aggregation.c"
				}
#line 1266 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 7100 "aggregation.c"
			}
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (removed);
#line 7104 "aggregation.c"
		}
#line 1262 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_removed_it);
#line 7108 "aggregation.c"
	}
}


static void ___lambda38__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1258 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda38_ (self, changes);
#line 7116 "aggregation.c"
}


static void __lambda40_ (Block9Data* _data9_, GObject* s, GAsyncResult* r) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 1281 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1281 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 7127 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 1285 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data9_->aggregator;
#line 1285 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1285 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1285 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 7139 "aggregation.c"
			goto __catch10_g_error;
		}
	}
	goto __finally10;
	__catch10_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 1283 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1283 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1289 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1289 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1289: Failed to prepare aggregator: %s", _tmp2_);
#line 1291 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1283 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 7160 "aggregation.c"
	}
	__finally10:
#line 1283 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1283 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1283 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1283 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 7171 "aggregation.c"
	}
}


static void ___lambda40__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1281 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda40_ (self, source_object, res);
#line 1281 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block9_data_unref (self);
#line 7181 "aggregation.c"
}


static gboolean __lambda39_ (Block9Data* _data9_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1279 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1281 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data9_->aggregator;
#line 1281 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda40__gasync_ready_callback, block9_data_ref (_data9_));
#line 1295 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1295 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7199 "aggregation.c"
}


static gboolean ___lambda39__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda39_ (self);
#line 1279 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7208 "aggregation.c"
}


static void __lambda42_ (Block9Data* _data9_, GObject* obj, GAsyncResult* res) {
	AggregationTests* self;
	GError * _inner_error_ = NULL;
#line 1321 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1321 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 7219 "aggregation.c"
	{
		FolksPersona* _tmp0_ = NULL;
		FolksIndividualAggregator* _tmp1_ = NULL;
		GAsyncResult* _tmp2_ = NULL;
		FolksPersona* _tmp3_ = NULL;
		FolksPersona* _tmp4_ = NULL;
#line 1326 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp1_ = _data9_->aggregator;
#line 1326 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp2_ = res;
#line 1326 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp3_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp1_, _tmp2_, &_inner_error_);
#line 1326 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = _tmp3_;
#line 1326 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 7236 "aggregation.c"
			goto __catch11_g_error;
		}
#line 1325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = _tmp0_;
#line 1325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp0_ = NULL;
#line 1325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->writeable_persona);
#line 1325 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_data9_->writeable_persona = _tmp4_;
#line 1327 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp0_);
#line 7251 "aggregation.c"
	}
	goto __finally11;
	__catch11_g_error:
	{
		GError* e1 = NULL;
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1332 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		if (!g_error_matches (e1, FOLKS_INDIVIDUAL_AGGREGATOR_ERROR, FOLKS_INDIVIDUAL_AGGREGATOR_ERROR_PROPERTY_NOT_WRITEABLE)) {
#line 7263 "aggregation.c"
			const gchar* _tmp5_ = NULL;
#line 1334 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp5_ = e1->message;
#line 1334 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			g_critical ("aggregation.vala:1334: Wrong error received: %s", _tmp5_);
#line 1335 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			g_assert_not_reached ();
#line 7271 "aggregation.c"
		}
#line 1338 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data9_->main_loop);
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 7277 "aggregation.c"
	}
	__finally11:
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1323 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		return;
#line 7288 "aggregation.c"
	}
}


static void ___lambda42__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1320 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	__lambda42_ (self, source_object, res);
#line 1320 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block9_data_unref (self);
#line 7298 "aggregation.c"
}


static gboolean __lambda41_ (Block9Data* _data9_) {
	AggregationTests* self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1318 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1320 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data9_->aggregator;
#line 1320 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _data9_->individual, "is-favourite", ___lambda42__gasync_ready_callback, block9_data_ref (_data9_));
#line 1342 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1342 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7316 "aggregation.c"
}


static gboolean ___lambda41__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda41_ (self);
#line 1318 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7325 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_failure (AggregationTests* self) {
	Block9Data* _data9_;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
	FolksPersona* persona = NULL;
	FolksPersona* _tmp11_ = NULL;
	FolksPersona* _tmp12_ = NULL;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_->_ref_count_ = 1;
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_->self = g_object_ref (self);
#line 1249 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 1249 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_->main_loop = _tmp0_;
#line 1251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 1251 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com\n");
#line 1254 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_->individual = NULL;
#line 1257 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_aggregator_dup ();
#line 1257 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_->aggregator = _tmp2_;
#line 1258 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data9_->aggregator;
#line 1258 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda38__folks_individual_aggregator_individuals_changed_detailed, block9_data_ref (_data9_), (GClosureNotify) block9_data_unref, 0);
#line 1279 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda39__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1298 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data9_->main_loop, 3);
#line 1301 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_data9_->individual != NULL, "individual != null");
#line 1303 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 7376 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp4_ = folks_individual_get_personas (_data9_->individual);
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_p_it = _tmp6_;
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 7392 "aggregation.c"
			gboolean _tmp7_ = FALSE;
			FolksPersona* p = NULL;
			gpointer _tmp8_ = NULL;
			FolksPersona* _tmp9_ = NULL;
			FolksPersona* _tmp10_ = NULL;
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_p_it);
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
				break;
#line 7404 "aggregation.c"
			}
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp8_ = gee_iterator_get (_p_it);
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp8_;
#line 1306 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp9_ = p;
#line 1306 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_tmp10_ = _g_object_ref0 (_tmp9_);
#line 1306 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1306 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			persona = _tmp10_;
#line 1307 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1307 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
			break;
#line 7422 "aggregation.c"
		}
#line 1304 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 7426 "aggregation.c"
	}
#line 1311 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp11_ = persona;
#line 1311 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp11_ != NULL, "persona != null");
#line 1312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp12_ = persona;
#line 1312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp13_ = folks_persona_get_writeable_properties (_tmp12_, &_tmp13__length1);
#line 1312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp14_ = _tmp13_;
#line 1312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp14__length1 = _tmp13__length1;
#line 1312 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (!_vala_string_array_contains (_tmp14_, _tmp14__length1, "is-favourite"), "!(\"is-favourite\" in persona.writeable_properties)");
#line 1314 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_->writeable_persona = NULL;
#line 1318 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda41__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1345 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data9_->main_loop, 3);
#line 1347 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_vala_assert (_data9_->writeable_persona == NULL, "writeable_persona == null");
#line 1350 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data9_->aggregator);
#line 1350 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_->aggregator = NULL;
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	block9_data_unref (_data9_);
#line 1247 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_data9_ = NULL;
#line 7460 "aggregation.c"
}


static void aggregation_tests_class_init (AggregationTestsClass * klass) {
	gchar* _tmp0_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_parent_class = g_type_class_peek_parent (klass);
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_type_class_add_private (klass, sizeof (AggregationTestsPrivate));
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	TPF_TEST_TEST_CASE_CLASS (klass)->set_up_tp = aggregation_tests_real_set_up_tp;
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	TPF_TEST_TEST_CASE_CLASS (klass)->set_up_kf = aggregation_tests_real_set_up_kf;
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	G_OBJECT_CLASS (klass)->finalize = aggregation_tests_finalize;
#line 28 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_strdup ("telepathy:/org/freedesktop/Telepathy/Account/cm/protocol/account:");
#line 28 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	aggregation_tests_iid_prefix = _tmp0_;
#line 7480 "aggregation.c"
}


static void aggregation_tests_instance_init (AggregationTests * self) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self->priv = AGGREGATION_TESTS_GET_PRIVATE (self);
#line 30 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = aggregation_tests_iid_prefix;
#line 30 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp1_ = g_strconcat (_tmp0_, "olivier@example.com", NULL);
#line 30 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 30 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp3_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp2_, (gsize) (-1));
#line 30 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self->priv->olivier_sha1 = _tmp3_;
#line 30 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_free0 (_tmp2_);
#line 7503 "aggregation.c"
}


static void aggregation_tests_finalize (GObject* obj) {
	AggregationTests * self;
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_AGGREGATION_TESTS, AggregationTests);
#line 26 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_default_personas);
#line 30 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_free0 (self->priv->olivier_sha1);
#line 24 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	G_OBJECT_CLASS (aggregation_tests_parent_class)->finalize (obj);
#line 7517 "aggregation.c"
}


GType aggregation_tests_get_type (void) {
	static volatile gsize aggregation_tests_type_id__volatile = 0;
	if (g_once_init_enter (&aggregation_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AggregationTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) aggregation_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AggregationTests), 0, (GInstanceInitFunc) aggregation_tests_instance_init, NULL };
		GType aggregation_tests_type_id;
		aggregation_tests_type_id = g_type_register_static (TPF_TEST_TYPE_MIXED_TEST_CASE, "AggregationTests", &g_define_type_info, 0);
		g_once_init_leave (&aggregation_tests_type_id__volatile, aggregation_tests_type_id);
	}
	return aggregation_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AggregationTests* tests = NULL;
	AggregationTests* _tmp0_ = NULL;
#line 1356 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_test_init (&args_length1, &args, NULL);
#line 1358 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_tmp0_ = aggregation_tests_new ();
#line 1358 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	tests = _tmp0_;
#line 1359 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 1360 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	g_test_run ();
#line 1361 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 1363 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	result = 0;
#line 1363 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tests);
#line 1363 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return result;
#line 7555 "aggregation.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 1354 "/opt/gnome3/source/folks/tests/folks/aggregation.vala"
	return _vala_main (argv, argc);
#line 7565 "aggregation.c"
}



